*********************************************************************************************************
// Why did the Democrats Lose the South? Bringing New Data to an Old Debate, Kuziemko & Washington (2018)
// This do file creates the main tables and graphs when using ANES Data
//
clear all
set more off
set matsize 11000
set maxvar 15000

else if "`c(username)'"=="kuziemko"  {
cap cd ~/Dropbox/southern_strategy
global path ~/Dropbox/southern_strategy/Replication
global input "$path/Input/Anes"
global add "$path/Input/Additional"
global do "$path/DoFiles"
global figures "~/Dropbox/southern_strategy/paper_for_publication/Figures"
global tables "~/Dropbox/southern_strategy/paper_for_publication/Tables"
}


else if "`c(username)'"=="fvivar" { 

cap cd ~/Dropbox/southern_strategy
global path ~/Dropbox/southern_strategy/Replication
global input "$path/Input/Anes"
global add "$path/Input/Additional"
global do "$path/DoFiles"
global figures "~/Dropbox/southern_strategy/paper_for_publication/Figures"
global tables "~/Dropbox/southern_strategy/paper_for_publication/Tables"
}
********************************************************************************
********************************************************************************
// Part 1:  Voting Trends 

use "$input/ANES_descV1.dta", clear

** 	1. Define New Variables for Regressions Later 	  **

#d;
*** Rural ;
gen rural=urban==3 if urban<10 ;
gen nonrur=1-rural ;
label var rural "Rural" ;

*** Income percentiles ;
gen inc_pct=8 if inc==1 ;
replace inc_pct=25 if inc==2 ;
replace inc_pct=50 if inc==3 ;
replace inc_pct=81.5 if inc==4 ;
replace inc_pct=98 if inc==5 ;
tab inc_pct, gen(iii) ;
label var inc_pct "Income percentile" ;

** Rich ;
gen rich=inc>3 if inc<10 ;

*** Transplants;
gen transplants=S==1 & brnS==0 if brnS~=. ;

***identify new voters by age after 1962--so those who are not 21 by 1962;
gen yearbirth = year-age;
summ yearbirth;
gen newvoter = (yearbirth>1942) if yearbirth~=.;

*** Confed / After interaction terms ;
gen aft=year>1962 ;
gen confed_aft=S*aft ;
gen confed_year=S*(year/100) ;
label var confed_aft "Confed x Aft" ;

*** Other interaction terms;
foreach var of varlist nonrur inc_pct rich { ;

gen `var'_aft=`var'*aft ;
gen `var'_confed=`var'*S ;
gen `var'_confed_aft=`var'*S*aft ;

if "`var'"=="urban" local name "Urban" ;
if "`var'"=="inc_pct" local name "Income pct." ;
if "`var'"=="rich" local name "Rich" ;

label var `var'_aft "`name' x After" ;
label var `var'_confed "`name' x Confed" ;
label var `var'_confed_aft "`name' x Confed x Aft" ;

} ;

*** Generate urban interactions and drop redundant terms ;
xi i.urban*i.aft, pre(_u_A) ;
drop _u_Aurbanis* _u_Aaft* ;

xi i.urban|year, pre(_u_Y) ;
drop _u_Yurbanis* ;

xi i.urban*i.S, pre(_J) ;
drop _Jurbanism* _JS_* ;

xi i.inc_pct*i.aft, pre(_i_A) ;
drop _i_Ainc_pct* _i_Aaft* ;

xi i.inc_pct|year, pre(_i_Y) ;
drop _i_Yinc_pct* ;

xi i.inc_pct*i.S, pre(_L) ;
drop _Linc_pct* _LS* ;

**					2. PROGRAMS FOR REGRESSION SPECIFICATIONS 				  ** ;
cap program drop _all;

*** Specs ;
program define spec_1 ;
args d_var x_var y extra  ;
eststo: areg `d_var' `x_var' i.year `extra'  if race==1 & year<=`y' & urban~=. & inc_pct~=. [pw=wgt], abs(state_n) cl(state_n) ;
end ;

program define spec_2 ;
args d_var x_var y extra ;
eststo: areg `d_var' `x_var' i.year iii* `extra' if race==1 & year<=`y' & urban~=. & inc_pct~=. [pw=wgt], abs(state_n) cl(state_n) ;
end ;

program define spec_3 ;
args d_var x_var y extra;
eststo: areg `d_var' `x_var' i.year iii* i.urban `extra' if race==1 & year<=`y' & urban~=. & inc_pct~=. [pw=wgt], abs(state_n) cl(state_n) ;
end ;

program define spec_4 ;
args d_var x_var y extra;
eststo: areg `d_var' `x_var' i.year iii* i.urban `extra' _J* _L* if race==1 & year<=`y' & urban~=. & inc_pct~=. [pw=wgt], abs(state_n) cl(state_n) ;
end ;

program define spec_5 ;
args d_var x_var y extra;
eststo: areg `d_var' `x_var' i.year `extra' if race==1 & year<=`y' & urban~=. & inc_pct~=. & transplants==0  [pw=wgt], abs(state_n) cl(state_n) ;
end ;

program define spec_6 ;
args d_var x_var y extra;
eststo: areg `d_var' `x_var' i.year `extra' if race==1 & year<=`y' & urban~=. & inc_pct~=. & newvoter==0  [pw=wgt], abs(state_n) cl(state_n) ;
end ;

program define spec_7 ;
args d_var x_var y extra;
eststo: areg `d_var' `x_var' i.year iii* i.urban `extra' _J* _L* if race==1 & year<=`y' & urban~=. & inc_pct~=. & transplants==0 & newvoter==0 [pw=wgt], abs(state_n) cl(state_n) ;
end ;

**	  3. Create new DEMID dummies based on prez and congressional votes    **;
#d;
gen prez_dem=prezvote2==1 if prezvote2<. ;
gen house_dem=houvote==1 if houvote<. ;
gen sen_dem=senvote==1 if senvote<. ;
gen xvar=. ;

********************************************************************************;
* Table 3: Explanatory power of income and urbanicity in explaining white Southern dealignment(ANES, 1952-1980) ;
* Appendix Table A.11: Explanatory power of income and urbanicity in explaining white Southern dealignment (ANES, Presidential elections, 1952-1980) ;
* Appendix Table A.13: Explanatory power of income and urbanicity in explaining white Southern dealignment (ANES, Senate elections, 1952-1980) ;
* Appendix Table A.14: Explanatory power of income and urbanicity in explaining white Southern dealignment (ANES, House elections, 1952-1980) ;
********************************************************************************;
	foreach v of varlist dem prez_dem house_dem sen_dem { ;

	forval x=1/7 { ;

	eststo clear ;

	foreach var of varlist confed_aft confed_year { ;

	if `x'==4 | `x'==7 { ;
	if "`var'"=="confed_aft" local extra_var "_u_A* _i_A*" ;
	else if "`var'"=="confed_year" local extra_var "_u_Y* _i_Y*" ;
	} ;
	else local extra_var " " ;
	di "Extra vars for `var' spec `x' :  `extra_var'" ;
	replace xvar=`var' ;

	spec_`x' `v' xvar 1980 "`extra_var'" ;
	if "`var'"=="confed_aft" { ;
		sum `v' if e(sample)==1 [aw=wgt] ;
		local d_mean_`x'=`r(mean)' ;
		local n_`x'=`r(N)' ;
		} ;
	} ;

	esttab, se nostar keep(xvar) ;
	matrix C_`x' = r(coefs) ;
	matrix list C_`x' ;

	} ;
	
	***Create a matrix C that contains all the coefficients we want to post ;
	***Need to append these one specification at a time ;
	matrix C = C_1 ;
	forval x=2/7 { ;
	matrix C = C \ C_`x' ;
	} ;

	matrix list C ;
	eststo clear ;

	local rnames : rownames C ;
	local models : coleq C ;
	local models : list uniq models ;

	 di "`models'" ;
	 local i 0 ;

	 *foreach name of local rnames { ;
	 forval x=1/7 { ; 
	  local ++i ;
		   local j 0 ;
		   capture matrix drop b ;
		   capture matrix drop se ;
		   foreach model of local models { ;
			   local ++j ;
			   matrix tmp = C[`i', 2*`j'-1] ;
			   if tmp[1,1]<. { ;
				  matrix colnames tmp = `model' ;
				  matrix b = nullmat(b), tmp ;
				  matrix tmp[1,1] = C[`i', 2*`j'] ;
				  matrix se = nullmat(se), tmp ;
			  } ;
		  } ;
		  ereturn post b ;
		  quietly estadd matrix se ;
		  eststo bodie`x'  ;
		  estadd scalar d_mean =`d_mean_`x'' ;
		  estadd scalar obs=`n_`x'' ;
		  
		  if `x'==1 { ;
		  estadd local inc_fe "No" ;
		  estadd local urb_fe "No" ;
		  estadd local interx "No" ;
		  estadd local ex_migr "No" ;
		  estadd local ex_young "No" ;
		  } ;
		  if `x'==2 { ;
		  estadd local inc_fe "Yes" ;
		  estadd local urb_fe "No" ;
		  estadd local interx "No" ;
		  estadd local ex_migr "No" ;
		  estadd local ex_young "No" ;
		  } ;
		  if `x'==3 { ;
		  estadd local inc_fe "Yes" ;
		  estadd local urb_fe "Yes" ;
		  estadd local interx "No" ;
		  estadd local ex_migr "No" ;
		  estadd local ex_young "No" ;
		  } ;
		  if `x'==4 { ;
		  estadd local inc_fe "Yes" ;
		  estadd local urb_fe "Yes" ;
		  estadd local interx "Yes" ;
		  estadd local ex_migr "No" ;
		  estadd local ex_young "No" ;
		  } ;
		  if `x'==5 { ;
		  estadd local inc_fe "No" ;
		  estadd local urb_fe "No" ;
		  estadd local interx "No" ;
		  estadd local ex_migr "Yes" ;
		  estadd local ex_young "No" ;
		  } ;
		  if `x'==6 { ;
		  estadd local inc_fe "No" ;
		  estadd local urb_fe "No" ;
		  estadd local interx "No" ;
		  estadd local ex_migr "No" ;
		  estadd local ex_young "Yes" ;
		  } ;
		  if `x'==7 { ;
		  estadd local inc_fe "Yes" ;
		  estadd local urb_fe "Yes" ;
		  estadd local interx "Yes" ;
		  estadd local ex_migr "Yes" ;
		  estadd local ex_young "Yes" ;
		  } ;
	  } ;

	esttab using "$tables/anes_inc_urb_`v'.tex", replace fragment booktabs wrap varwidth(25) cells(b(fmt(a3))  se(par([ ]))) nostar
	refcat(est1 "\underline{Panel A (Diff-in-diff spec.)}"  est2 "\underline{Panel B (Diff. trend spec.)}", nolabel)
	varlabel(est1 "South x After" est2 "South x (Year/100)" ) collabels(none) 
	stats(d_mean inc_fe urb_fe interx ex_migr ex_young obs, 
	label("Dept. var mean" "Income FE?" "City-size FE?" "Interactions?" "Ex. migrants?" "Ex. new voters?" "Observations" ))
	nonum;
} ;  
 
********************************************************************************;  
gen welfare1=1 if VCF0808==1 ;
replace welfare1=0 if VCF0808==2 ;

***NOTE: DROP PEOPLE WHO SAY THEY DO NOT KNOW, HAVEN'T THOUGHT ABOUT IT, ETC ;
gen rep_prez=prezvote==2 if prezvote<. ;
tab welfare if wht==1 & S==1 & year<1962, sum(rep_prez) ;

gen welfare2=1 if VCF0809<4 ;
replace welfare2=0 if VCF0809>4 & VCF0809<9 ;

gen welfare=welfare1 ;
replace welfare=welfare2 if welfare==. ;
  
tab welfare if wht==1 & S==1 & year>1960 & year<1972, sum(rep_prez) ;  

** gen S&J year groupsings ;

gen yr_g=50 if year<1962 ;
replace yr_g=60 if year>1960 & year<1972 ;
replace yr_g=70 if year>1970 & year<1982 ;
replace yr_g=80 if year>1980 & year<1992 ;
replace yr_g=90 if year>1990 & year<2002 ;

gen no_welfare=1-welfare ;

******IDEOLOGY EXPLAINS REALIGNMENT ? ;

gen ec_lib_1=VCF0808==1 if VCF0808<. ;
replace ec_lib_1=1 if VCF0809<4 ;
replace ec_lib_1=0 if VCF0809>3 & VCF0809<. ;

label var ec_lib_1 "Combines 0/1 (through 1968) & scale (from 1972), coding not sure as 0" ;
gen S_ec_lib_1=S*ec_lib_1 ;
gen S_aft=S*aft ;

foreach var of varlist aft year { ;
gen `var'_ec_lib_1 = aft*ec_lib_1 ;
gen S_`var'_ec_lib_1 = S*aft*ec_lib_1 ;
} ;

gen state=state_a ;

******Can we get anywhere explaining dealignment with ideology? ;

cap program drop dmean ;
program define dmean ;
sum `e(depvar)' if e(sample)==1 ;
estadd scalar dep_mean=`r(mean)' ;
end ;

****label vars ;
label var aft "After" ;
label var year "Year" ;
label var ec_lib_1 "Economically liberal" ;
label var S_ec_lib_1 "South x Econ. lib." ;
label var aft_ec_lib_1 "After x Econ. lib." ;
label var year_ec_lib_1 "Year x Econ. lib." ;
label var S_aft "South x After" ;
label var S_year "South x Year" ;
label var S_aft_ec_lib_1 "South x After x Econ. lib." ;
label var S_year_ec_lib_1 "South x Year x Econ. lib." ;

********************************************************************************;
* Appendix Table A.15: Does controlling for economically liberal preferences explain white Southern dealignment? ;
********************************************************************************;

foreach dvar of varlist dem { ;
	eststo clear ;
	
	foreach cat in aft  { ;
	
	eststo clear ;
	eststo: reg `dvar' `cat' if race==1 & year<1981 & S==1 & ec_lib<., cl(state) ;
	dmean ;
	estadd local yr_fe "No" ;
	estadd local st_fe "No" ;
	estadd local samp "South" ;
	
	eststo: reg `dvar' `cat' ec_lib_1 if race==1 & year<1981 & S==1 & ec_lib<., cl(state) ;
	dmean ;
	estadd local yr_fe "No" ;
	estadd local st_fe "No" ;
	estadd local samp "South" ;
	
	eststo: reg `dvar' `cat' ec_lib_1 `cat'_ec_lib_1 if race==1 & year<1981 & S==1 & ec_lib<., cl(state) ;
	dmean ;
	estadd local yr_fe "No" ;
	estadd local st_fe "No" ;
	estadd local samp "South" ;
	
	eststo: areg `dvar' S_`cat' i.year if race==1 & year<1981 & ec_lib<., abs(state) cl(state) ;
	dmean ;
	estadd local yr_fe "Yes" ;
	estadd local st_fe "Yes" ;
	estadd local samp "All" ;
	
	eststo: areg `dvar' S_`cat' ec_lib_1 i.year if race==1 & year<1981 & ec_lib<.  , abs(state) cl(state) ;
	dmean ;
	estadd local yr_fe "Yes" ;
	estadd local st_fe "Yes" ;
	estadd local samp "All" ;
	
	eststo: areg `dvar' aft S_`cat' ec_lib_1 S_ec_lib `cat'_ec_lib_1 S_`cat'_ec_lib_1  i.year if race==1 & year<1981 & ec_lib<., abs(state) cl(state) ;
	estadd local yr_fe "Yes" ;
	estadd local st_fe "Yes" ;
	estadd local samp "All" ;
	dmean ;

local est_command " keep(`cat' ec_lib_1 `cat'_ec_lib_1 S_`cat' S_ec_lib_1 S_`cat'_ec_lib_1) label varwidth(25) wrap se brackets nostar nomtitles
stats(dep_mean samp yr_fe st_fe N, label("Dept. var. mean" "Regions in sample" "Year FE?" "State FE?" "Observations"))
mgroups("Dep't var: Identifies as a Democrat", pattern(1 0 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) "  ;
esttab, `est_command' ;
esttab using "$tables/dem_ec_lib_`cat'.tex", replace fragment booktabs `est_command' ;

} ;
} ;
*******************************************************************************;
// Back to Clean Data ;

use "$input/ANES_descV1.dta", clear ;

#d;
**Create a few variables ;
gen dem_v_rep=prezvote==1 if prezvote~=. ;
gen dem_v_all=prezvote2==1 if prezvote2~=. ;
gen voted=VCF0702==2 if VCF0702<3 ;
gen demid=8-partyid ;
replace dem=partyid<3 ;

tab educ_4c, gen(eee) ;
tab urbanism, gen(uuu) ;
gen rural=urban==3 if urban<10 ;
gen dem_s_cand=0 ;

replace dem_s_cand=1 if S==1 & (year==1964 | year==1976 | year==1980 | year==1992 | year==1996) ;
replace dem_s_cand=-1 if S==1 & (year==2000 | year==2004) ;

xi i.year*i.S ;

****Note there are essentially NO catholics in the south in 1960 (relative to all or relative to just whites) ;
tab religion if S==1 & year==1960 [aw=wgt] ;
tab religion if S==0 & year==1960 [aw=wgt] ;
gen cath=religion==2 if religion~=. ;
xi i.cath*i.year, pre(_J) noomit ;
tab year, gen(yyy) ;

*******************************************************************************;
* Appendix Figure A.10: Democrats' advantage among Catholics in presidential elections ;
*******************************************************************************;

foreach var of varlist dem_v_all  { ;
tab year if `var'<. & year<2009, matrow(bodie) ;
local max=`r(r)' ;
gen coeff=. ;
forval x=1/`max' { ;
reg `var' cath if race==1 & year==bodie[`x', 1] [pw=wgt] ;
replace coeff=_b[cath] if year==bodie[`x', 1]  ;
} ;
twoway (connect coeff year, lw(thin) mlw(thin) msize(small)) if year<2009 , scheme(aspen) xlabel(1952(8)2008) xti("") 
yti("Democratic share of vote among" "Catholics versus other whites") scale(1.4) xsize(7) ;
graph export "$figures/`var'_cath_v_oth_by_yr.pdf", replace ;
drop coeff ;
matrix drop bodie ;
} ;


***Are southern whites getting richer or more educated (and potentially thus more R-leaning?) ;
*rescale income to correspond to percentiles ;
gen inc_pct=8 if inc==1 ;
replace inc_pct=25 if inc==2 ;
replace inc_pct=50 if inc==3 ;
replace inc_pct=81.5 if inc==4 ;
replace inc_pct=98 if inc==5 ;

****Did income or urbanicity changes make the white S become R? ;
gen aft=year>1962 ;
gen confed_aft=S*aft ;
gen rich=inc>3 if inc<10 ;
gen nonrur=1-rural ;

label var confed_aft "Confed x Aft" ;
label var inc_pct "Income percentile" ;
label var rural "Rural" ;

foreach var of varlist nonrur inc_pct rich { ;

gen `var'_aft=`var'*aft ;
gen `var'_confed=`var'*S ;
gen `var'_confed_aft=`var'*S*aft ;

if "`var'"=="urban" local name "Urban" ;
if "`var'"=="inc_pct" local name "Income pct." ;
if "`var'"=="rich" local name "Rich" ;

label var `var'_aft "`name' x After" ;
label var `var'_confed "`name' x Confed" ;
label var `var'_confed_aft "`name' x Confed x Aft" ;

} ;

gen demid_01=partyid<3 if partyid<100 ;
gen transplants=S==1 & brnS==0 if brnS~=. ;

*identify new voters by age after 1962--so those who are not 21 by 1962;
gen yearbirth = year-age;
gen newvoter = (yearbirth>1942) if yearbirth~=.;

***Generate urban interactions and drop redundant terms ;
xi i.urban*i.aft, pre(_u_A) ;
drop _u_Aurbanis* _u_Aaft* ;

xi i.urban|year, pre(_u_Y) ;
drop _u_Yurbanis* ;

xi i.urban*i.S, pre(_J) ;
drop _Jurbanism* _JS_* ;

xi i.inc_pct*i.aft, pre(_i_A) ;
drop _i_Ainc_pct* _i_Aaft* ;

xi i.inc_pct|year, pre(_i_Y) ;
drop _i_Yinc_pct* ;

xi i.inc_pct*i.S, pre(_L) ;
drop _Linc_pct* _LS* ;

tab inc_pct, gen(iii) ;
gen confed_year=S*(year/100) ;

*******************************************************************************;
* Appendix Table A.12: Did richer, non-rural whites drive Southern dealignment (1952-1980)? ;
*******************************************************************************;

****Did rich or rural differentially switch? ;
eststo clear ;
foreach var2 of varlist rich nonrur { ;

gen `var2'_yr=`var2'*year ;
gen `var2'_conf_yr=`var2'*S*year ;

local group_name=proper("`var2'") ;

label var `var2'_conf_yr "`group_name' x South x Year" ;

eststo: areg demid_01 `var2'_confed_aft confed_aft `var2' `var2'_confed `var2'_aft i.year if race==1 & year<=1980 [pw=wgt], abs(state_n) cl(state_n) ;
qui sum `e(depvar)' if e(sample)==1 [aw=wgt] ;
estadd scalar dv `r(mean)' ;
estadd local ex_N "No" ;
estadd local ex_new "No";
estadd local inc_urb "No" ;
estadd local inc_urb_x "No" ;
estadd local maxyear "`y'" ;
estadd local restrict "No" ;

eststo: areg demid_01 `var2'_confed_aft confed_aft `var2' `var2'_confed `var2'_aft i.year if race==1 & year<=1980 & transplants==0 & newvoter==0 [pw=wgt], abs(state_n) cl(state_n) ;
qui sum `e(depvar)' if e(sample)==1 [aw=wgt] ;
estadd scalar dv `r(mean)' ;
estadd local ex_N "No" ;
estadd local ex_new "No";
estadd local inc_urb "No" ;
estadd local inc_urb_x "No" ;
estadd local maxyear "`y'" ;
estadd local restrict "Yes" ;

eststo: areg demid_01 `var2'_conf_yr confed_year `var2' `var2'_confed `var2'_yr i.year if race==1 & year<=1980 [pw=wgt], abs(state_n) cl(state_n) ;
qui sum `e(depvar)' if e(sample)==1 [aw=wgt] ;
estadd scalar dv `r(mean)' ;
estadd local ex_N "No" ;
estadd local ex_new "No";
estadd local inc_urb "No" ;
estadd local inc_urb_x "No" ;
estadd local maxyear "`y'" ;
estadd local restrict "No" ;

eststo: areg demid_01 `var2'_conf_yr confed_year `var2' `var2'_confed `var2'_yr i.year if race==1 & year<=1980 & transplants==0 & newvoter==0 [pw=wgt], abs(state_n) cl(state_n) ;
qui sum `e(depvar)' if e(sample)==1 [aw=wgt] ;
estadd scalar dv `r(mean)' ;
estadd local ex_N "No" ;
estadd local ex_new "No";
estadd local inc_urb "No" ;
estadd local inc_urb_x "No" ;
estadd local maxyear "`y'" ;
estadd local restrict "Yes" ;

} ;

label var nonrur_confed_aft "Nonrural x South x Aft" ;
label var nonrur_conf_yr "Nonrural x South x Year" ;
label var rich_confed_aft "Rich x South x Aft" ;
label var confed_year "South x Year" ;
label var confed_aft "South x After" ;

esttab using "$tables/rich_nonrur_switch.tex", replace fragment booktabs keep(rich_confed_aft confed_aft rich_conf_yr confed_year nonrur_confed_aft nonrur_conf_yr) 
order(rich_confed_aft rich_conf_yr nonrur_confed_aft nonrur_conf_yr confed_aft confed_year) nostar brackets se
stats(dv restrict N, label("Mean, dept. var." "Restricted sample?" "Observations")) label varwidth(24) wrap
nomtitles mgroups("Dept. variable: Respondent identifies as a Democrat",
pattern(1 0 0 0    0 0 0 0     ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ;

********************************************************************************;
// Part 2: Party Switchers ;

use "$input/07213-0001-Data.dta", clear ;

***Extract former confederacy from PSU info ;
gen psu_string=string(V520006) ;
replace psu_string="0" + psu_string if length(psu_string)==4 ;
gen psu_string_3=substr(psu_string, 1, 3) ;
gen psu_string_3_real=real(psu_string_3) ;
gen south=psu_string_3_real>399 & psu_string_3_real<500 ;

***Add tennessee ;
replace south=1 if psu_string_3_real==541 ;

***Gen state FE from the PSU var ;
gen state=substr(psu_string, 1, 2) ;

***Current party (dropping NA/missing) ;
gen cur_party= V520237 if  V520237<9 ;
gen cur_dem=cur_party<2 ;
gen cur_dem_plus_lean=cur_party<3 ;

****Question 520060 ;
****If you are currently an R (or D), was there ever a time you thought of your self as D (R)? ;
gen switch_from_d=0 ;
replace switch_from_d=1 if V520060==1 ;

****Question 520065 ;
**** (IF INDEPENDENT OR OTHER TO REF.NO.58) WAS THERE EVER A TIME WHEN YOU THOUGHT OF YOURSELF AS A DEMOCRAT OR A REPUBLICAN ;
replace switch_from_d=1 if V520065==1 ;

***Switch-from-d defined for all (even those who were never dems) ;
***Also interesting to ONLY compare to those who were once Dems) ;

gen switch_from_d2=switch_from_d ;
replace switch_from_d2=. if ~(switch_from_d==1 | cur_dem==1) ;
label var switch_from_d2 "Switched from Democrats" ;
label var switch_from_d "Switched from Democrats " ;
						  
ren 	V520047 negr_empl ;
gen racist1=negr_empl==80 if negr_empl<99 ;
gen racist2=negr_empl==80	| negr_empl==70 if negr_empl<99 ;
gen racist3=negr_empl==80 | negr_empl==70 | negr_empl==60 if negr_empl<99 ;
gen white=V520129 ==1 ;
ren V520160 income_raw ;
gen richer=income_raw>20 if income_raw<98 ;
ren V520131  educ ;

***Another measure of "switching" ;
***You grew up a Dem but now you are no longer a Dem.  Are you more or less racist that ppl who remain dems?
****Gen parents' party ;
gen dad_dem=V520068==1 if V520068~=0 ;
gen mom_dem=V520069==1 if V520069~=0 ;
gen cur_not_dem = 1-cur_dem ;

****A third measure of "switching" ;
****I am a Dem but a voted/willvote for Ike ;

***How will vote or did vote? ;	   
		   
gen ike=V520080==2 | V520080==4 if V520080~=0 ;
gen ike_plus=ike ;
replace ike_plus=1 if V520086==2 | V520086==4 ;
gen ike_vote=V520184>30 & V520184 <61 if V520184  <91 ;

/*****Generate a table with rows that have the outcome (our various measures of switching) 
and columns that have our three proxies for racist view  ****/ ;

label var cur_not_dem "Republican or independent" ;
label var ike "Will vote for Eisenhower" ;
label var ike_plus "Will or wd. vote for Eisen." ;

*******************************************************************************;
* Appendix Table A.16: Do conservative racial views predict defection from Democratic party (Southern whites, 1952 ANES)? ;
* Appendix Table A.17: Do conservative racial views predict defection from Democratic party (non-Southern whites, 1952 ANES)?
*******************************************************************************;

gen all=1 ;

/***Do separately for South and non-South***/  ;

forval s=0/1 { ;
matrix drop _all ;

	local count=0 ;
	/***Each of our three degrees of racism (explanatory variable) ****/ ;
	foreach v of varlist racist1 racist2 racist3 { ;
		/***Two different specifications for each dept var / expl var combination (w and without controls) **/ ;
		foreach spec in no_cont w_cont { ;

			eststo clear ;
			local count=`count'+1 ;
			if "`spec'"=="no_cont" local controls " " ;
			else if "`spec'"=="w_cont" local controls "i.income_raw i.educ i.V520007 i.V520128  i.V520167 " ;

			foreach var of varlist switch_from_d switch_from_d2 cur_not_dem ike /* ike_plus */ { ;

			if "`var'"=="switch_from_d" local cond "all==1" ;
			else if "`var'"=="switch_from_d2" local cond "all==1" ;
			else if "`var'"=="cur_dem" local cond "mom_dem==1 & dad_dem==1" ;
			else if "`var'"=="ike" local cond "cur_dem==1 " ;
			else if "`var'"=="ike_plus" local cond "cur_dem==1 " ;

			eststo: areg `var' `v' `controls' if white==1 & south==`s' & `cond', abs(state) ;
			sum `v' if e(sample)==1 ;
			estadd scalar mean_exp_var = `r(mean)' ;

			****Create a variable label that has N and means in it (different for S and non-S) ;
			if "`v'"=="racist1" & "`spec'"=="no_cont" { ;
				local temp: var label `var' ;
				di "`temp'" ;
				sum `var' if racist1<. & `cond' & south==`s'  ;
				local avg=substr(string(`r(mean)'),1, 5) ;
				local varlabel_`var' "`temp' (N=`r(N)', \avg = `avg')" ;
				di "****Below is varlabel"  ;
				di "`varlabel_`var''" ;
			} ;

		/** Below -- Close loop on `var' dependent variable list**/ ;
		} ;
		
		esttab, se nostar keep(`v') stats(mean_exp_var) ;
		matrix C_`count' = r(coefs) ;
		matrix N_`count' = r(stats) ;
		matrix list C_`count' ;
		matrix list N_`count' ;			
	/** Below -- Close loop on `spec' loop **/ ;
	} ;

/** Below, close loop on `v' (racist/explanatory variable) loop **/ ;

} ;

matrix C = C_1 ;
matrix N = N_1 ;
forval i=2/6 { ;
matrix C=C \ C_`i' ;
matrix N=N \ N_`i' ;
} ;

matrix list C ;
matrix list N ;

***Rename rownames ;

matrix rownames C = "racist1" "racist1_cont" "racist2" "racist2_cont" "racist3" "racist3_cont" ;
matrix rename N_1 racist1_N  ;
matrix rename N_2 racist1_cont_N ; 
matrix rename N_3 racist2_N  ;
matrix rename N_4 racist2_cont_N  ; 
matrix rename N_5 racist3_N  ;
matrix rename N_6 racist3_cont_N  ;

eststo clear ;
local rnames : rownames C ;
local models : coleq C ;
local models : list uniq models ;
local i 0 ;

 foreach name of local rnames { ;
		
       local ++i ;
       local j 0 ;
       capture matrix drop b ;
       capture matrix drop se ;
       foreach model of local models { ;
           local ++j ;
           matrix tmp = C[`i', 2*`j'-1] ;
           if tmp[1,1]<. { ;
              matrix colnames tmp = `model' ;
              matrix b = nullmat(b), tmp ;
              matrix tmp[1,1] = C[`i', 2*`j'] ;
              matrix se = nullmat(se), tmp ;
          } ;
		  
      } ;
      ereturn post b ;
      quietly estadd matrix se ;
	  estadd matrix mean_ind=`name'_N ;
      eststo `name' ;
	  local counter=`counter'+1 ;
	  di `counter' ;
	  if strpos("`name'", "cont")==0 estadd local covar "No" ;
	  if strpos("`name'", "cont")~=0 estadd local covar "Yes" ;

	  ;
  } ;

  
di "`varlabel_ike'" ;
di "`varlabel_cur_not_dem'" ;
estadd local controls "No" "Yes" "No" "Yes" ; 
esttab using "$tables/switchers_south`s'.tex", replace fragment cells(b(fmt(a3)) se(par([ ])) mean_ind(par((\avg= ))))
booktabs nostar varlabel(est1 "`varlabel_switch_from_d'" est2 "`varlabel_switch_from_d2'"
est3 "`varlabel_cur_not_dem'" est4 "`varlabel_ike'" /* est5 "`varlabel_ike_plus'" */  , end(\\[.1pt])  ) nogap
stats(covar, label("Controls?"))
varwidth(28) wrap label collabels(none) labcol2("None" "Ex. never-Dems" "Parents were Dems" "Current Dem")  
nomtitles  ;

 } ;


gen income=0 if income_raw==0 ;
replace income=.75 if income_raw==10 ;
replace income=1.5 if income_raw==11 ;
replace income=2.5 if income_raw==12 ;
replace income=3.5 if income_raw==20 ;
replace income=4.5 if income_raw==21 ;
replace income=6.25 if income_raw==30 ;
replace income=8.75 if income_raw==31 ;
replace income=1.25 if income_raw==32 ;

ren V520007 city_size ;
gen urban = city_size==10 | city_size==20  | city_size==40 ;
label var urban "Live in urban/suburban metro area or city above 50K pop" ;
gen do_less = V520045==3 | V520045==4 if V520045<9 ;

eststo clear ;

forval s=0/1 { ;
foreach var of varlist switch_from_d switch_from_d2 cur_not_dem ike { ;

			if "`var'"=="switch_from_d" local cond "all==1" ;
			else if "`var'"=="switch_from_d2" local cond "all==1" ;
			else if "`var'"=="cur_dem" local cond "mom_dem==1 & dad_dem==1" ;
			else if "`var'"=="ike" local cond "cur_dem==1 " ;
			else if "`var'"=="ike_plus" local cond "cur_dem==1 " ;
			di "SOUTH = `s'" ;
			eststo: areg `var' richer  if white==1 & south==`s' & `cond', abs(state) ;
			eststo: areg `var' income  if white==1 & south==`s' & `cond', abs(state) ;
			eststo: areg `var' do_less  if white==1 & south==`s' & `cond', abs(state) ;

} ;
} ;

matrix drop _all ;
/**** South v. non-south */ ;

local count=0 ;
forval s=0/1 { ;

	/***Each of our two measures of income***/ ;
	foreach v of varlist richer income { ;
		local count=`count'+1 ;
		eststo clear ;		
		foreach var of varlist switch_from_d switch_from_d2 cur_not_dem ike { ;
		
			if "`var'"=="switch_from_d" local cond "all==1" ;
			else if "`var'"=="switch_from_d2" local cond "all==1" ;
			else if "`var'"=="cur_dem" local cond "mom_dem==1 & dad_dem==1" ;
			else if "`var'"=="ike" local cond "cur_dem==1 " ;
			else if "`var'"=="ike_plus" local cond "cur_dem==1 " ;

			eststo: areg `var' `v' if white==1 & south==`s' & `cond', abs(state) ;
			sum `v' if e(sample)==1 ;
			estadd scalar mean_exp_var = `r(mean)' ;
			
		/** Below -- Close loop on `var' dependent variable list**/ ;
		} ;

esttab, se nostar keep(`v') stats(mean_exp_var) ;
		matrix C_`count' = r(coefs) ;
		matrix N_`count' = r(stats) ;
		matrix list C_`count' ;
		matrix list N_`count' ;			
	/** Below, close loop on `v' explanatory variable loop **/ ;

} ;
} ;

****Construct flipped table ;
***Re-order matrix rows so South appears first ;

matrix C = C_3 ;
matrix C = C \ C_4 ;
matrix C = C \ C_1 ;
matrix C = C \ C_2 ;
matrix list C ;

***Rename rownames ;

matrix rownames C = "richer_south" "income_south" "richer_north" "income_north" ;

eststo clear ;
local rnames : rownames C ;
local models : coleq C ;
local models : list uniq models ;
local i 0 ;

 foreach name of local rnames { ;
		
       local ++i ;
       local j 0 ;
       capture matrix drop b ;
       capture matrix drop se ;
       foreach model of local models { ;
           local ++j ;
           matrix tmp = C[`i', 2*`j'-1] ;
           if tmp[1,1]<. { ;
              matrix colnames tmp = `model' ;
              matrix b = nullmat(b), tmp ;
              matrix tmp[1,1] = C[`i', 2*`j'] ;
              matrix se = nullmat(se), tmp ;
          } ;
		  
      } ;
      ereturn post b ;
      quietly estadd matrix se ;
	  *estadd matrix mean_ind=`name'_N ;
      eststo `name' ;
	  local counter=`counter'+1 ;
	  di `counter' ;
		estadd local covar "No" ;
	 
	  ;
  } ;

********************************************************************************;
* Appendix Table A.18: Does income predict defection from Democratic party in early 1950s (1952 ANES)? ;
********************************************************************************;

esttab using "$tables/switchers_income.tex", replace fragment cells(b(fmt(a3)) se(par([ ])) mean_ind(par((\avg= ))))
booktabs nostar  varlabel(est1 "Switched from Dem" est2 "Switched"
est3 "Republican or Independent" est4 "Will vote for Ike" /* est5 "`varlabel_ike_plus'" */  , end(\\[.1pt])  ) nogap
/* mlabels("No cont." "Controls" "No cont." "Controls"  "No cont." "Controls", lhs("Dept. variable")) */
/* mgroups("Anti-negro view" "Anti-negro / No Gov. role" "Anti-negro / No Fed. role",  
pattern(1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))  */
stats(covar, label("Controls?"))
varwidth(28) wrap label collabels(none) labcol2("None" "Ex. never-Dems" "Parents were Dems" "Current Dem")  
nomtitles  ;

********************************************************************************;
// Part 3: Pre/Post Differences ;

use "$input/NES1956.dta", clear ;

***Programs to clean variables (depending on whether they need to be flipped) ;
program clean_var ;
	args varname ;
	gen `varname' = 6-`varname' if `varname'_raw>0 & `varname'_raw<6 ;
	gen agree_`varname' = `varname'_raw==1 | `varname'_raw==2 if `varname'<. ;
	*replace agree_`varname' = . if `varname'_raw>7 | `varname'_raw==0 ;
end ;

program clean_var_reverse ;
	args varname ;
	gen `varname'=`varname'_raw if `varname'_raw>0 & `varname'_raw<6 ;
	gen agree_`varname'=`varname'_raw==4 | `varname'_raw==5 if `varname'<. ;
	*replace agree_`varname' = . if `varname'_raw>7 | `varname'_raw==0 ;
end ;

****Mark Southern states ;
ren V560007 state ;
gen south=(state>=40 & state<51) | state==54 ;

***Whites ;
ren V560172  race ;
gen white=race==1 ;

ren V560029 tax_raw ;
clean_var_reverse tax ;

ren V560032 jobs_raw ;
clean_var jobs ;

ren V560035 isolation_raw ;
clean_var isolation ;

ren V560038 gov_med_raw ;
clean_var gov_med ;

ren V560041  for_aid_raw ;
clean_var for_aid ;

ren V560044 negro_fair_raw ;
clean_var negro_fair ;

ren V560047 reign_in_biz_raw ;
clean_var reign_in_biz ;

ren V560050 get_tough_raw ;
clean_var get_tough ;

ren V560053 gov_school_raw ;
clean_var gov_school ;

ren V560056 milit_overseas_raw ;
clean_var milit_overseas ;

ren V560059 gov_run_util_raw ;
clean_var_reverse gov_run_util ;

ren V560062 labor_influ_raw ;
clean_var_reverse labor_influ ;

ren V560065 friendly_abroad_raw ;	
clean_var friendly_abroad ;

ren V560068 commun_rights_raw ;
clean_var_reverse commun_rights ;

ren V560071	for_aid_comm_raw ;
clean_var for_aid_comm ;

ren V560074 sch_int_raw ;
clean_var_reverse sch_int ;
gen year=1956 ;

****Add some switcher analysis ;
gen party=V560088  ;
gen cur_dem=party<2 if party<9 ;
gen dem=cur_dem ;
gen switch_from_dem=(V560089==1 | V560089==3) if V560089<9 ;

tempfile policy_1956 ;
save `policy_1956' ;


*****Add 1960 ;
use "$input/NES1960.dta", clear ;

****Mark Southern states ;
ren V600010 state ;
gen south=(state>=40 & state<51) | state==54 ;

***Whites ;
ren V600119 race ;
gen white=race==1 ;

***Party id ;
ren V600091 party ;
gen dem=party<2 if party<9 ;

***survey weight ;
ren V600003 wgt ;
		   
ren V600052 gov_run_util_raw ;
clean_var_reverse gov_run_util ;
		     	   
ren V600054 jobs_raw ;
clean_var jobs ;	

ren V600056 isolation_raw ;
clean_var isolation ;

ren V600058 gov_school_raw ;
clean_var gov_school ;

ren V600060  for_aid_raw ;
clean_var for_aid ;	   

ren V600062 negro_fair_raw ;
clean_var negro_fair ;
		   
ren V600064 milit_overseas_raw ;
clean_var milit_overseas ;

ren V600066 gov_med_raw ;
clean_var gov_med ;

gen year=1960 ;

tempfile policy_1960 ;
save `policy_1960' ;

*****Adding 1958 ;
use "$input/NES1958.dta", clear ;

ren V580021 gov_run_util_raw ;
clean_var_reverse gov_run_util ;

ren V580023 jobs_raw ;
clean_var jobs ;

ren V580025 isolation_raw ;
clean_var isolation ;

ren V580027 gov_school_raw ;
clean_var gov_school ;

ren V580029 for_aid_raw ;
clean_var for_aid ;

ren V580031 negro_fair_raw ;
clean_var negro_fair ;

ren V580033 milit_overseas_raw ;
clean_var milit_overseas ;

ren V580035 sch_int_raw ;
clean_var_reverse sch_int ;

*****Basic clean-up ;
****Mark Southern states ;
ren V580009 state ;
gen south=(state>=40 & state<51) | state==54 ;
ren V580171 race ;
gen white=race==1 ;   

***Party ;
rename  V580062 party ;
gen dem=party<2 if party< 9;

*****Append together three datasets ;

gen year=1958 ;
append using `policy_1956' ;
append using `policy_1960' ;


label var gov_run_util "Gov't sd *not* leave utilities, housing to priv. biz." ;
label var agree_gov_run_util " \quad Agree that gov't sd *not* leave...to priv biz." ;

label var jobs "Gov't should guarantee jobs" ;
label var agree_jobs " \quad Agree that gov't should guarantee jobs" ;

label var isolation "Country better off if focus domestically" ;
label var agree_isolation " \quad Agree that country better of if focus domestically" ;

label var for_aid "We sd give aid to poor countries even if can't pay back " ;
label var agree_for_aid " \quad Agree we sd. give aid to poor countries" ;

label var gov_med "Gov't sd help ppl get medical care at low cost" ;
label var agree_gov_med "\quad Agree gov't sd help with medical care" ;

label var tax "Gov't sd not cut taxes if causes cuts elsewhere " ;
label var agree_tax " \quad  Agree gov't should not cut taxes" ;

label var reign_in_biz "Gov't sd limit pol. influ. of big business" ;
label var agree_reign_in_biz "  \quad Agree that gov't should limit infl. of business" ;

label var labor_influ "Gov't sd. *not* limit pol. influ. of unions" ;
label var agree_labor_influ "  \quad Agree gov't sd. *not* limit infl. of unions" ;

label var commun_rights "Gov't cannot fire suspected communists" ;
label var agree_commun_rights " \quad  Agree gov't cannot fire susp. communists" ;

label var sch_int "Fed gov't sd. get involved in sch. integration" ;
label var agree_sch_int "   \quad Agree that fed gov't sd get involved..." ;

label var negro_fair "Gov't sd enforce fair jobs/housing for Negroes" ;
label var agree_negro_fair " \quad  Agree that gov't schould enforce fair..." ;

label var for_aid_comm "Give for. aid even if country not anti-communist" ;
label var agree_for_aid_comm " \quad Agree give for. aid even if country..." ;

label var get_tough "Best way to deal with commun. countries is get tough" ;
label var agree_get_tough " \quad  Agree best way is to get tough" ;

label var milit_overseas "Keep soldiers abroad to help countries fight comm." ;
label var agree_milit " \quad Agree we sd keep soldiers abroad...." ;

label var gov_school "Fed gov't sd help finance local school construction" ;
label var agree_gov_school " \quad  Agree fed gov't sd help finance schools" ;


order jobs agree_jobs /* tax agree_tax */ gov_med agree_gov_med reign_in_biz agree_reign_in_biz labor_influ agree_labor_influ gov_run_util agree_gov_run_util 
commun_rights agree_commun_rights milit_overseas  agree_milit_overseas isolation agree_isolation
for_aid agree_for_aid for_aid_comm agree_for_aid_comm get_tough agree_get_tough negro_fair agree_negro_fair sch_int agree_sch_int gov_school agree_gov_school ;

gen non_south=1-south ;

eststo clear ;
eststo: estpost ttest jobs - agree_gov_school if white==1   , by(non_south) ;

*******************************************************************************;
* Table 4: Pre-period policy differences between whites in South and non-South (ANES);
*******************************************************************************;

esttab using "$tables/policy_diffs.tex", fragment replace label wrap varwidth(40) 
refcat(jobs "\emph{---Economic policy}" commun_rights " \\ \emph{---Foreign policy, communism}" negro_fair "\\ \emph{---Civil rights}" , nolabel )
cells("mu_1(fmt(a2)) N_1 mu_2(fmt(a2)) N_2 b(star fmt(2))") collabels("South" "\emph{N}"  "Non-South" "\emph{N}" "Diff" "p-val") nonum noobs ;

********************************************************************************;
********************************************************************************;
* Part 4: Individual Analysis (Graphs) ;
#d ;
clear ;
cap program drop GenConfed;
program GenConfed;
	cap drop confed state_code_adj;
	gen state_code_adj = 100+state_code;
	gen confed = .;
	
	foreach x in 101 102 103 104 105 106 109 111 112 113 114 118 119 121 122 123 124 125 129
		131 132 133 134 135 136 137 138 139 151 152 153 155 156 158 161 162 163 164
		165 166 167 168 169 171 172 173 178 179 {;
		replace confed = 0 if state_code_adj==`x';
		};
	foreach x in 140 141 142 143 144 145 146 147 148 149 150 154 {;
		replace confed = 1 if state_code_adj==`x';
		};
end;

** PREP 1956 **;
use $input/NES1956.dta,clear;

	* Specify relevant jobs variables;
	rename V560046 jobs;
	rename V560045 jobs_toofar;
	
	* Specify relevant schools variables;
	rename V560076 sch;
	rename V560075 sch_toofar;
	
	* Clean other variables needed for analysis;
	rename V560007 state_code;
	rename V560009 date;
	rename V560172 race;
	rename V560171 sex;
	rename V560181 education;
	rename V560175 age;
	rename V560120 occupation;
	
	GenConfed;
	
	keep jobs* sch* state_code date race sex education age occupation confed;
	gen year=1956;
	tempfile 1956;
	save `1956', replace;

** PREP 1960 **;
use $input/NES1960.dta, clear;

	* Specify relevant jobs variables;
	rename V600063 jobs;

	* Specify relevant problems variables;
	foreach i in a b c {;
		rename V600050`i' pbm_sol`i';
		rename V600051`i' pbm_sol_who`i';
		};

	* Specify relevant schools variables;
	rename V600073 sch;

	* Clean other variables needed for analysis;
	rename V600010 state_code;
	rename V600012 date;
	rename V600003 weight;
	rename V600119 race;
	rename V600118 sex;
	rename V600128 education;
	rename V600122 age;
	rename V600129 occupation;

	GenConfed;

	keep jobs* pbm_* sch* state_code date weight race sex education age occupation confed  ;
	gen year=1960;
	tempfile 1960;
	save `1960', replace;

** PREP 1964 **;
use $input/NES1964.dta, clear;

	* Specify relevant jobs variables;
	rename V640099 jobs;

	* Specify relevant problems variables;
	rename V640036 pbm_sola;
	rename V640041 pbm_solb;
	rename V640046 pbm_solc;
	rename V640040 pbm_sol_whoa;
	rename V640045 pbm_sol_whob;
	rename V640050 pbm_sol_whoc;
	rename V640051 pbm_avda;
	rename V640056 pbm_avdb;
	rename V640061 pbm_avdc;
	rename V640055 pbm_avd_whoa;
	rename V640060 pbm_avd_whob;
	rename V640065 pbm_avd_whoc;

	* Specify relevant schools variables;
	rename V640103 sch;

	* Clean other variables needed for analysis;
	rename V640012 state_code;
	rename V640014 date;
	rename V640466 weight;
	rename V640183 race;
	rename V640182 sex;
	rename V640196 education;
	rename V640187 age;
	rename V640202 occupation;

	GenConfed;

	keep jobs* pbm_* sch* state_code date weight race sex education age occupation confed  ;
	gen year=1964;
	tempfile 1964;
	save `1964', replace;
	
** PREP 1968 **;
use $input/NES1968.dta, clear;

	* Specify relevant jobs variables;
	rename V680074 jobs;

	* Specify relevant problems variables;
	rename V680048 pbm_sola;
	rename V680052 pbm_solb;
	rename V680056 pbm_solc;
	rename V680051 pbm_sol_whoa;
	rename V680055 pbm_sol_whob;
	rename V680059 pbm_sol_whoc;

	* Specify relevant schools variables;
	rename V680077 sch;

	* Clean other variables needed for analysis;
	rename V680014 state_code;
	rename V680022 date;
	rename V680003 weight;
	rename V680264 race;
	rename V680263 sex;
	rename V680156 education;
	rename V680533 age;
	rename V680161 occupation;

	GenConfed;
	
	recode jobs sch (6=3);
	keep jobs* pbm_* sch* state_code date weight race sex education age occupation confed  ;
	gen year=1968;

** APPEND, ADJUST AND LABEL **;
append using `1956';
append using `1960';
append using `1964';
order year confed;

* Generate aggregate variable for problems;
gen pbm_sol_raceissue = 0 if !missing(pbm_sola, pbm_solb, pbm_solc);
gen pbm_avd_raceissue = 0 if !missing(pbm_avda, pbm_avdb, pbm_avdc);
gen pbm_sol_raceissue_who = .;
gen pbm_avd_raceissue_who = .;

foreach i in c b a {;
	foreach pbmcode in 301 311 320 330 341 361 390 302 312 321 362 390 {;
		replace pbm_sol_raceissue = 1 if pbm_sol`i'==`pbmcode';
		replace pbm_sol_raceissue_who = pbm_sol_who`i' if pbm_sol`i'==`pbmcode';
		replace pbm_avd_raceissue = 1 if pbm_avd`i'==`pbmcode';
		replace pbm_avd_raceissue_who = pbm_avd_who`i' if pbm_avd`i'==`pbmcode';
		}; * Does not include Puerto Rican problem, includes crime/delinquency (for race riots);
	};
	
* Label;
label define confedl 0 "Non CS" 1 "CS";
label values confed confedl;
label var confed "REGION (Contiguous US only)";

lab var jobs "WHICH PARTY: FAIR TREATMENT IN JOBS FOR BLACKS";
lab var sch "WHICH PARTY: SAME SCHOOLS FOR BLACKS";

lab define partyl 0 "Missing" 1 "Democrats" 5 "Republicans" 3 "No Difference" 8 "No opinion" 9 "NA";
foreach var of varlist jobs sch pbm_* {;
	label values `var' partyl;
	};
lab var pbm_sol_raceissue "RACE AMONG TOP 3 PROBLEMS TO ADDRESS";
lab var pbm_avd_raceissue "RACE AMONG TOP 3 PROBLEMS TO AVOID";
lab var pbm_sol_raceissue_who "WHICH PARTY: DO WHAT I WANT ON MAJOR ISSUE TO ADDRESS";
lab var pbm_avd_raceissue_who "WHICH PARTY: DO WHAT I WANT ON MAJOR ISSUE TO AVOID";
lab values pbm_sol_raceissue .;
lab values pbm_avd_raceissue .;

lab var jobs_toofar "GOVT GOING TOO FAR?: FAIR TREATMENT FOR BLACKS IN JOBS AND HOUSING";
lab var sch_toofar "GOVT GOING TOO FAR?: CONCERNED THAT BLACKS AND WHITES GO TO SAME SCHOOLS";
lab define toofarl   1 "Definitely too far"
					 2 "A little too far"
					 3 "About right"
					 4 "A little less than it should"
					 5 "A lot less than it should"
					 6 "I haven't heard what govt. is doing"
					 8 "Don't know"
					 9 "NA"
					 0 "Missing";
lab values jobs_toofar toofarl;
lab values sch_toofar toofarl;

* Graph schools :
drop if missing(sch) | sch==0 | sch==8 | sch==9;
drop if year==1956;
keep if race==1;
recode sch (1=5) (5=1) if year==1960;

gen count = 1;
gen ifdem = (sch==1);
gen ifrep = (sch==5);
collapse (sum) count ifdem ifrep, by(year confed);
foreach var of varlist if* {;
	gen share_`var' = `var'/count;
	};

sort year;
	
*******************************************************************************;
* Figure 3: Whites' views of which party will push for school integration, by region ;
*******************************************************************************;
#d;
graph twoway 
		(connected share_ifdem year if confed == 0, legend(lab(1 "Democrats, Non-south")) yaxis(1) lcolor(navy) lpattern(solid) lwidth(thin) mcolor(navy) msymbol(oh) mlw(thin))
		(connected share_ifrep year if confed == 0, legend(lab(2 "Republicans, Non-south")) yaxis(1) lcolor(maroon) lpattern(solid) lwidth(thin) mcolor(maroon) msymbol(th) mlw(thin)) 
		(connected share_ifdem year if confed == 1, legend(lab(3 "Democrats, South")) yaxis(1) lcolor(navy) lpattern(dash) lwidth(thin) mcolor(navy) msymbol(oh) mlw(thin)) 
		(connected share_ifrep year if confed == 1, legend(lab(4 "Republicans, South")) yaxis(1) lcolor(maroon) lpattern(dash) lwidth(thin) mcolor(maroon) msymbol(th) mlw(thin)),
		legend(on cols(1) size(small)) 
		xtitle(Survey Year, size(small)) xlabel(1960(4)1968, labsize(small) angle(45)) scheme(aspen)
		ytitle(Share of Responses, axis(1) size(small)) ylabel(, axis(1) labsize(small) nogrid) 
		plotregion(style(none) lcolor(black)) graphregion(style(none) lcolor(white) fcolor(white));
	*graph export "$figures/ANES_sch.pdf", replace;
	window manage close graph _all;

graph twoway 
		(connected share_ifdem year if confed == 0, yaxis(1) lcolor(blue) lpattern(solid) lwidth(thin) mcolor(blue) msymbol(oh) mlw(thin))
		(connected share_ifrep year if confed == 0, yaxis(1) lcolor(blue) lpattern(dash) lwidth(thin) mcolor(blue) msymbol(oh) mlw(thin)) 
		(connected share_ifdem year if confed == 1, yaxis(1) lcolor(red) lpattern(solid) lwidth(thin) mcolor(red) msymbol(th) mlw(thin)) 
		(connected share_ifrep year if confed == 1, yaxis(1) lcolor(red) lpattern(dash) lwidth(thin) mcolor(red) msymbol(th) mlw(thin)),
		legend(on label(1 "Non-Southerners") label(2 "Non-Southerners") label(3 "Southerners") label(4 "Southerners") 
		cols(1) pos(3) ring(0) region(lstyle(none) margin(zero)) symx(*.3) order(- `"{it: Share saying "Democrats" } "' 3 1 -  " "`"{it: Share saying "Republicans" } "' 4 2) keygap(*.3) )
		scheme(aspen) xscale(range(1959.6(.1)1968.4)) xti("")  xsize(6.4) xlabel(1960(4)1968) scale(1.1) ylabel(.05(.10).45 , axis(1) nogrid) ;
	graph export "$figures/ANES_sch_ik_version.pdf", replace;

	#delimit cr

*******************************************************************************;
// Part 5: Compare white pres vote choice including and not including Catholics
*******************************************************************************;

*** White Prez Choice Including Catholics
use "$input/ANES_descV1_keyvar_shaped.dta", clear
collapse (mean) dem_prezvote_all if race == 1 [pw=wgt], by(year confed)
rename dem_prezvote_all w
reshape wide w, i(year) j(confed)
gen diff_w = w1 - w0
tempfile temp
save `temp', replace


*** White Prez Choice Not Including Catholics
use "$input/ANES_descV1_keyvar_shaped.dta", clear
collapse (mean) dem_prezvote_all if race == 1 & religion_mj4 != 2 [pw=wgt], by(year confed)
rename dem_prezvote_all w_nocath
reshape wide w_nocath, i(year) j(confed)
gen diff_nocath = w_nocath1 - w_nocath0
merge 1:1 year using `temp'

*** Plot
#d;
twoway /*(connected w0 w1 year,  m(circle_hollow triangle_hollow) mlw (thin thin) 
	msize(medium medium) mc(forest_green*0.5 forest_green*0.5) 
	lc(forest_green*0.5 forest_green*0.5) lp(solid dash) lw(thin thin))*/
	(connected diff_w year, mc(forest_green) ms(triangle_hollow) mlw(thin) lcolor(forest_green) lpattern(solid) lw(medthin) yaxis(1))
	/*(connected w_nocath0 w_nocath1 year,  m(circle_hollow triangle_hollow) mlw (thin thin) 
	msize(medium medium) mc(purple*0.5 purple*0.5) lc(purple*0.5 purple*0.5) 
	lp(solid dash) lw(thin thin))*/
	(connected diff_nocath year, mc(purple) ms(none) mlw(thin) lcolor(purple) lpattern(solid) lw(medthick) yaxis(1))
	if inrange(year,1952,2008), scheme(aspen) 
	legend(
	on label(1 "All Whites")
	label(2 "White Non-Catholics")
	order(1 2) rows(2) ring(0) pos(1) symx(*.8) region(lstyle(none)) 
	)
	yline(0, lc(gs9) lw(thin) lp(dash) axis(1)) xline(1963)
	
	ytitle("Difference (South minus Non-south)", axis(1) )
	xtitle("")
	xlabel(1952(4)2008, `xlabelangle') xsize(6.5) scale(1.2)
	;
#d cr
graph export "$figures/anes_prezvote_cath_versus_nocath.pdf", replace






