*********************************************************************************************************
// Why did the Democrats Lose the South? Bringing New Data to an Old Debate, Kuziemko & Washington (2018)
// This do file creates the main tables and graphs when using GALLUP Data
clear all 
set more off
set matsize 11000

else if "`c(username)'"=="kuziemko"  {
cap cd ~/Dropbox/southern_strategy
global path ~/Dropbox/southern_strategy/Replication
global output "$path/Output"
global input "$path/Input"
global do "$path/DoFiles"
global figures "~/Dropbox/southern_strategy/paper_for_publication/Figures"
global tables "~/Dropbox/southern_strategy/paper_for_publication/Tables"

}


else if "`c(username)'"=="fvivar" { 

cap cd ~/Dropbox/southern_strategy
global path ~/Dropbox/southern_strategy/Replication
global output "$path/Output"
global input "$path/Input"
global do "$path/DoFiles"
global figures "~/Dropbox/southern_strategy/paper_for_publication/Figures"
global tables "~/Dropbox/southern_strategy/paper_for_publication/Tables"

}

********************************************************************************
********************************************************************************

// Part 1: Using GALLUP DATA ONLY:  NON-GSS DATA 
#delimit ;
*********************************** ;
// Cleaning ;
*********************************** ;
use "$input/gallup_and_gss_extrayears.dta", clear ;

keep if svy_type==1 ;
keep if race==1 & noprez<. & svy_year<. ;
keep if tag_dups==1 ;

cap drop cen2* ;
cap drop wgt_group* ;
cap drop cen_year* ;

****Crate a variable that is the previous census year and next census year for each Gallup obs. ;
gen cen_year_upper=10*ceil(svy_year/10) ;
gen cen_year_lower=10*floor(svy_year/10) ;

****This creates a vector of the years in the sample to loop over later ;
tab svy_year, matrow(yrs_in_samp) ;	
local numyears=`r(r)' ;	

***We create wgt_group2_by_yr which is simply the cell sizes of the 2 x 2 weights, separately by years in the sample ;
****Loop over the years in our sample;
gen wgt_group2_by_yr=. ;
cap drop temp ;
forval x=1/`numyears' { ;
local y=yrs_in_samp[`x', 1] ;
egen temp=group(confed highschool) if svy_year==`y', label ;
replace wgt_group2_by_yr=temp if svy_year==`y' ;
tab temp, matcell(gallup_shares2_`y') ;
matrix gallup_shares2_`y'=gallup_shares2_`y'/`r(N)' ;
matrix list gallup_shares2_`y' ;
drop temp ;
} ;

***We should have pretty few missing as Confed & Highschool should be non-missing for almost all observations ;
count if wgt_group2_by_yr==. ;
tempfile gallup_wgts ;
save `gallup_wgts' ;

preserve ;
use "$input/ipums_wgt_vectors" , clear ;
forval y=1940(10)2010 { ;
mkmat ipums_shares_`y'1, matrix(temp) ;
matrix ipums_shares_`y'=temp[1..8, 1] ;
mkmat ipums_shares2_`y'1, matrix(temp2) ;
matrix ipums_shares2_`y'=temp2[1..4, 1] ;
matrix drop temp temp2 ;
} ;
restore ;

***Create a vector of years in the working Gallup sample ;
gen cen2_wgt=. ;
forval x=1/`numyears' { ;
	***Grab the actual year ;
		local y=yrs_in_samp[`x', 1] ;
	****Tag the census year above and below each Gallup year ;
		foreach c in upper lower { ;
			sum cen_year_`c' if svy_year==`y' ;
			local yr_`c'=`r(mean)' ;
		} ;
	di "Inspect how Gallup shares and Census shares differ." ;
	di "They shouldn't be HUGELY different as unweighted Gallup is not terribly unrepresentative)" ;
	di "Gallup shares in year `y' (unweighted)" ;
	tab wgt_group2_by_yr if tag_dups== 1 & svy_year==`y' ;
	di "IPUMS shares in Census before year `y'" ;
	matrix list ipums_shares2_`yr_lower' ;
	di "IPUMS shares in Census after year `y' [will equal survey year if year itself a Census year]" ;
	matrix list ipums_shares2_`yr_upper' ;
	forval g=1/4 { ;	
		replace cen2_wgt=((`yr_upper'-`y')/10)*ipums_shares2_`yr_lower'[`g',1] + ((`y'- `yr_lower')/10)*ipums_shares2_`yr_upper'[`g',1] if wgt_group2_by_yr==`g' & svy_year==`y';
		***Now, just divied by Gallup share that year ;
		replace cen2_wgt=cen2_wgt/gallup_shares2_`y'[`g', 1] if wgt_group2_by_yr==`g' & svy_year==`y' ;
		****The code above is wrong for years that ACTUALLY fall in a census year bc cen_yr_upper==cen_yr_lower.  Fix below ;
		if `y'==1940 | `y'==1950 | `y'==1960 | `y'==1970 | `y'==1980 | `y'==1990 |`y'==2000 | `y'==2010 { ;		
			replace cen2_wgt=ipums_shares2_`y'[`g',1] if wgt_group2_by_yr==`g' & svy_year==`y' & cen_year_upper==cen_year_lower ;
			replace cen2_wgt=cen2_wgt/gallup_shares2_`y'[`g', 1] if wgt_group2_by_yr==`g' & svy_year==`y' & cen_year_upper==cen_year_lower ;
		} ;	
	} ;
	di "Gallup shares in year `y' (weighted)" ;
	tab wgt_group2_by_yr if  svy_year==`y' [aw=cen2_wgt] ;
	matrix temp_compare=((`yr_upper'-`y')/10)*ipums_shares2_`yr_lower'+ ((`y'- `yr_lower')/10)*ipums_shares2_`yr_upper' ;
	di "Interpolated IPUMS shares for year `y'" ;
	matrix list temp_compare ;
	matrix drop temp_compare ;
} ;


****Dept mean program after regression ;
cap program drop dvmean ;
program dvmean ;
sum `e(depvar)' if e(sample)==1 [aw  `e(wexp)'] ;
estadd scalar dvmean=`r(mean)' ;
end ;

***Create non-negative survey dates so we can use as factors in regressions ;
sum svy_date ;
gen svy_date_no_neg=svy_date - `r(min)' +1 ;

*******Robustness to different regions as control groups, Probit, Repub as outcome, South=VRA, etc. ;
#delimit cr

* Create regions (follows census divisions except HI and AK)
drop south
gen all = (!missing(state))
gen northeast = 0 if !missing(state)
	foreach x in 11 16 14 12 15 13 22 21 23 {
	replace northeast=1 if state==`x'
	}
gen midwest = 0 if !missing(state)
	foreach x in 34 33 32 31 41 43 48 42 44 47 45 46 {
	replace midwest=1 if state==`x'
	}
gen south = 0 if !missing(state)
	foreach x in 25 55 54 24 52 53 51 27 26 58 56 59 57 61 62 63 64 {
	replace south=1 if state==`x'
	}
gen west = 0 if !missing(state)
	foreach x in 72 73 74 71 77 78 76 75 81 82 83 {
	replace west=1 if state==`x'
	}

#delimit ;	
*********************************** ;
* Appendix Table A.6: Robustness of main triple-interaction results to model, control group and outcome variable ;	
*********************************** ;
	
****For d-probits, we cannot use factor variables, so create a vector of dummies & then delete ;
tab state, gen(sss) ;
tab svy_date_no_neg, gen (ddd) ;	

eststo clear ;	
eststo: dprobit dem conf_aft sss* ddd* if race==1 & svy_year<=1980 & svy_type==1 [pw=cen2_wgt], cl(state) ;
dvmean ;
estadd local south_def "Conf" ;
estadd local control "All" ;
estadd local e_model "Probit" ;

eststo: dprobit dem conf_aft noprez conf_noprez noprez_aft conf_noprez_aft sss* ddd* if race==1 & svy_year<=1980 & svy_type==1 [pw=cen2_wgt], cl(state) ;
dvmean ;
estadd local south_def "Conf" ;
estadd local control "All" ;
estadd local e_model "Probit" ;

drop sss* ddd* ;	

*****Use each Census region as the control group ;
foreach r in northeast midwest west south { ;
if "`r'"=="northeast" local stub "NE" ;
else if "`r'"=="midwest" local stub "MW" ;
else if "`r'"=="west" local stub "West" ;
else if "`r'"=="south" local stub "South" ;

eststo: areg dem conf_aft i.svy_date_no_neg if race==1 & svy_year<=1980 & svy_type==1 & (confed==1 | `r'==1) [pw=cen2_wgt], cl(state) abs(state) ;
dvmean ;
estadd local south_def "Conf" ;
estadd local control "`stub'" ;
estadd local e_model "OLS" ;

eststo: areg dem conf_aft noprez conf_noprez noprez_aft conf_noprez_aft i.svy_date_no_neg 
if race==1 & svy_year<=1980 & svy_type==1 & (confed==1 | `r'==1) [pw=cen2_wgt], cl(state) abs(state) ;
dvmean ;
estadd local south_def "Conf" ;
estadd local control "`stub'" ;
estadd local e_model "OLS" ;
} ;


****Define South as states needing pre-clearance under VRA in 1964

/*** ;
Alabama	Nov. 1, 1964	30 FR 9897	Aug. 7, 1965
Alaska	Nov. 1, 1972	40 FR 49422	Oct. 22, 1975
Arizona	Nov. 1, 1972	40 FR 43746	Sept. 23, 1975
Georgia	Nov. 1, 1964	30 FR 9897	Aug. 7, 1965
Louisiana	Nov. 1, 1964	30 FR 9897	Aug. 7, 1965
Mississippi	Nov. 1, 1964	30 FR 9897	Aug. 7, 1965
South Carolina	Nov. 1, 1964	30 FR 9897	Aug. 7, 1965
Texas	Nov. 1, 1972	40 FR 43746	Sept. 23, 1975
Virginia	Nov. 1, 1964	30 FR 9897	Aug. 7, 1965

****/ ;

***Temporarily change definition of South to those affected by VRA;

preserve ;

gen vra=0 ;
replace vra=1 if state==51 | state==53 | state==54 | state==58 | state==59 | state==62 ;
tab state if vra==1 ;

drop conf_aft conf_noprez conf_noprez_aft ;
gen conf_aft=vra*aft ;
gen conf_noprez=vra*noprez ;
gen conf_noprez_aft=vra*noprez*aft ;

eststo: areg dem conf_aft i.svy_date_no_neg if race==1 & svy_year<=1980 & svy_type==1  [pw=cen2_wgt], cl(state) abs(state) ;
dvmean ;
estadd local south_def "VRA" ;
estadd local control "All" ;
estadd local e_model "OLS" ;

eststo: areg dem conf_aft noprez conf_noprez noprez_aft conf_noprez_aft  i.svy_date_no_neg if race==1 & svy_year<=1980 & svy_type==1 [pw=cen2_wgt], cl(state) abs(state) ;
dvmean ;
estadd local south_def "VRA" ;
estadd local control "All" ;
estadd local e_model "OLS" ;

restore ;

*****Use republican as outcome ;
eststo: areg rep conf_aft i.svy_date_no_neg if race==1 & svy_year<=1980 & svy_type==1  [pw=cen2_wgt], cl(state) abs(state) ;
dvmean ;
estadd local south_def "Conf" ;
estadd local control "All" ;
estadd local e_model "OLS" ;

eststo: areg rep conf_aft noprez conf_noprez noprez_aft conf_noprez_aft  i.svy_date_no_neg if race==1 & svy_year<=1980 & svy_type==1  [pw=cen2_wgt], cl(state) abs(state) ;
dvmean ;
estadd local south_def "Conf" ;
estadd local control "All" ;
estadd local e_model "OLS" ;

esttab using "$tables/resultsProbit.tex" , replace fragment booktabs  keep(conf_aft noprez conf_noprez noprez_aft conf_noprez_aft ) nostar nodiscrete se brackets
stats(dvmean e_model south_def control N, label("Mean, d. var." "Est. model" "Def. of South" "Control gp." "Observations")) 
margin discrete("") label wrap varwidth(15) nomtitles
mgroups("Democrat" "Republican", pattern(1 0 0   0 0 0   0 0 0   0 0 0    1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ;


************************************************************************** ;
* Appendix Figure A.5: White dealignment by state as a function of pre-period racial views
************************************************************************** ;

tab state if confed==1 & aft==0 & race==1, sum(noprez) ;
egen temp=wtmean(noprez) if aft==0, weight(cen2_wgt) by(state) ;
egen noprez_st_pre=mean(temp), by(state) ;
gen yesprez=1-noprez ;
egen tag_date=tag(svy_date) ;
format svy_date %tdMonCCYY ;

***Gen pre- v post- difference by state ;

cap drop temp ;
forval a=0/1 { ;
egen temp=wtmean(dem) if aft==`a' & svy_year<1980, weight(cen2_wgt) by(state) ;
egen dem_st_aft`a'=mean(temp), by(state) ;
cap drop temp ;
} ;

gen dem_diff_st=dem_st_aft1 - dem_st_aft0 ;
egen tag_st=tag(state) ;
reg dem_diff_st noprez_st_pre if confed==1 & tag_st==1 ;
local beta=round(_b[noprez_st_pre], .001) ;
local pval= round(2 * ttail(e(df_r), abs(_b[noprez_st_pre]/_se[noprez_st_pre])), .001) ;

di `pval' ;

twoway (scatter dem_diff_st noprez_st_pre, mlabel(state) ) (lfit dem_diff_st noprez_st_pre) if confed==1 & tag_st==1,
yti("Change in Dem share, post- minus pre-period") xti("Pre-period share against a Black president") legend(off) ylabel(-.5(.1).1)
text(-.2 .8 "{it: {&beta}}=`beta' (p-value=`pval')")  ;

graph export "$figures/by_state_within_south.pdf", replace ;

*************************************** ;
* Appendix Figure A.9: Share of whites identifying as Democrats (zooming in on Civil Rights era) ;
*************************************** ;

use "$input/gallup_and_gss_extrayears.dta", clear ;

keep if race==1 ;
keep if svy_type==1 ;
keep if tag_dups==1 ;

cap drop cen2* ;
cap drop wgt_group* ;
cap drop cen_year* ;

****Crate a variable that is the previous census year and next census year for each Gallup obs. ;
gen cen_year_upper=10*ceil(svy_year/10) ;
gen cen_year_lower=10*floor(svy_year/10) ;

****This creates a vector of the years in the sample to loop over later ;
tab svy_year, matrow(yrs_in_samp) ;	
local numyears=`r(r)' ;	

***We create wgt_group2_by_yr which is simply the cell sizes of the 2 x 2 weights, separately by years in the sample ;
****Loop over the years in our sample;
gen wgt_group2_by_yr=. ;
cap drop temp ;
forval x=1/`numyears' { ;
local y=yrs_in_samp[`x', 1] ;
egen temp=group(confed highschool) if svy_year==`y', label ;
replace wgt_group2_by_yr=temp if svy_year==`y' ;
tab temp, matcell(gallup_shares2_`y') ;
matrix gallup_shares2_`y'=gallup_shares2_`y'/`r(N)' ;
matrix list gallup_shares2_`y' ;
drop temp ;
} ;

***We should have pretty few missing as Confed & Highschool should be non-missing for almost all observations ;
count if wgt_group2_by_yr==. ;
tempfile gallup_wgts ;
save `gallup_wgts' ;

preserve ;
use "$input/ipums_wgt_vectors" , clear ;
forval y=1940(10)2010 { ;
mkmat ipums_shares_`y'1, matrix(temp) ;
matrix ipums_shares_`y'=temp[1..8, 1] ;
mkmat ipums_shares2_`y'1, matrix(temp2) ;
matrix ipums_shares2_`y'=temp2[1..4, 1] ;
matrix drop temp temp2 ;
} ;
restore ;


***Create a vector of years in the working Gallup sample ;
gen cen2_wgt=. ;
forval x=1/`numyears' { ;
	***Grab the actual year ;
		local y=yrs_in_samp[`x', 1] ;
	****Tag the census year above and below each Gallup year ;
		foreach c in upper lower { ;
			sum cen_year_`c' if svy_year==`y' ;
			local yr_`c'=`r(mean)' ;
		} ;
	di "Inspect how Gallup shares and Census shares differ." ;
	di "They shouldn't be HUGELY different as unweighted Gallup is not terribly unrepresentative)" ;
	di "Gallup shares in year `y' (unweighted)" ;
	tab wgt_group2_by_yr if tag_dups== 1 & svy_year==`y' ;
	di "IPUMS shares in Census before year `y'" ;
	matrix list ipums_shares2_`yr_lower' ;
	di "IPUMS shares in Census after year `y' [will equal survey year if year itself a Census year]" ;
	matrix list ipums_shares2_`yr_upper' ;
	forval g=1/4 { ;	
		replace cen2_wgt=((`yr_upper'-`y')/10)*ipums_shares2_`yr_lower'[`g',1] + ((`y'- `yr_lower')/10)*ipums_shares2_`yr_upper'[`g',1] if wgt_group2_by_yr==`g' & svy_year==`y';
		***Now, just divied by Gallup share that year ;
		replace cen2_wgt=cen2_wgt/gallup_shares2_`y'[`g', 1] if wgt_group2_by_yr==`g' & svy_year==`y' ;
		****The code above is wrong for years that ACTUALLY fall in a census year bc cen_yr_upper==cen_yr_lower.  Fix below ;
		if `y'==1940 | `y'==1950 | `y'==1960 | `y'==1970 | `y'==1980 | `y'==1990 |`y'==2000 | `y'==2010 { ;		
			replace cen2_wgt=ipums_shares2_`y'[`g',1] if wgt_group2_by_yr==`g' & svy_year==`y' & cen_year_upper==cen_year_lower ;
			replace cen2_wgt=cen2_wgt/gallup_shares2_`y'[`g', 1] if wgt_group2_by_yr==`g' & svy_year==`y' & cen_year_upper==cen_year_lower ;
		} ;	
	} ;
	di "Gallup shares in year `y' (weighted)" ;
	tab wgt_group2_by_yr if  svy_year==`y' [aw=cen2_wgt] ;
	matrix temp_compare=((`yr_upper'-`y')/10)*ipums_shares2_`yr_lower'+ ((`y'- `yr_lower')/10)*ipums_shares2_`yr_upper' ;
	di "Interpolated IPUMS shares for year `y'" ;
	matrix list temp_compare ;
	matrix drop temp_compare ;
} ;


sum svy_date ;
gen svy_date_no_neg=svy_date - `r(min)' +1 ;

tab svy_date_no_neg if svy_year>1957 & svy_year<1971 & dem<., matrow(dates_in_samp) ;
local maxval=`r(r)' ;

forval c=0/1  { ;
*forval x=1/`maxval' { ;
egen  temp = wtmean(dem) if confed==`c', weight(cen2_wgt)  by(svy_date_no_neg) ;
egen  dem_conf`c' = wtmean(temp), weight(cen2_wgt)  by(svy_date_no_neg) ;
drop temp ;
} ;

egen tag_date=tag(svy_date) ;
gen diff=dem_conf1 - dem_conf0 ;
format svy_date %tdMonCCYY ;

twoway (connect dem_conf1 dem_conf0 svy_date, yaxis(1)) (line diff svy_date, yaxis(2)) if svy_year>1957 & svy_year<1971 & svy_date>-650, 
yti("Share identifying as a Democrat", axis(1)) yti("Difference", axis(2))
legend(on ring(0) pos(2) label(1 "Southern states") label(2 "Non-Southern state") label(3 "Difference:" "South minus non-South") symx(*.5) keygap(*.5) rows(3)) 
xti(""); 
 
graph export "$figures/white_demid_zoom.pdf", replace ;

********************************************************************************;
********************************************************************************;
// Part 2: Using GALLUP DATA and CENSUS (IPUMS);

********************************************************************************;
* Appendix Table A.2: Comparison of demographics of main Gallup analysis sample to Census ;
********************************************************************************;
******Table shows sum stats for Gallup by period and region ;
*****Then compares 1960 and 1970 to IPUMS ;

use "$input/gallup_and_GSS_extrayears.dta", clear ;
keep if race==1 ;
keep if svy_year<1990 ;
keep if svy_type==1 ;
keep if tag_dups==1 ;

cap drop cen2* ;
cap drop wgt_group* ;
cap drop cen_year* ;

****Crate a variable that is the previous census year and next census year for each Gallup obs. ;
gen cen_year_upper=10*ceil(svy_year/10) ;
gen cen_year_lower=10*floor(svy_year/10) ;

****This creates a vector of the years in the sample to loop over later ;
tab svy_year, matrow(yrs_in_samp) ;	
local numyears=`r(r)' ;	

****Loop over the years in our sample;
gen wgt_group2_by_yr=. ;
cap drop temp ;
forval x=1/`numyears' { ;
local y=yrs_in_samp[`x', 1] ;
egen temp=group(confed highschool) if svy_year==`y', label ;
replace wgt_group2_by_yr=temp if svy_year==`y' ;
tab temp, matcell(gallup_shares2_`y') ;
matrix gallup_shares2_`y'=gallup_shares2_`y'/`r(N)' ;
matrix list gallup_shares2_`y' ;
drop temp ;
} ;

***We should have pretty few missing as Confed & Highschool should be non-missing for almost all observations ;
count if wgt_group2_by_yr==. ;
tempfile gallup_wgts ;
save `gallup_wgts' ;
preserve ;

use "$input/ipums_wgt_vectors" , clear ;

forval y=1940(10)2010 { ;
mkmat ipums_shares_`y'1, matrix(temp) ;
matrix ipums_shares_`y'=temp[1..8, 1] ;
mkmat ipums_shares2_`y'1, matrix(temp2) ;
matrix ipums_shares2_`y'=temp2[1..4, 1] ;
matrix drop temp temp2 ;
} ;
restore ;

***Create a vector of years in the working Gallup sample ;
gen cen2_wgt=. ;

forval x=1/`numyears' { ;
	***Grab the actual year ;
		local y=yrs_in_samp[`x', 1] ;
	****Tag the census year above and below each Gallup year ;
		foreach c in upper lower { ;
			sum cen_year_`c' if svy_year==`y' ;
			local yr_`c'=`r(mean)' ;
		} ;
	di "Inspect how Gallup shares and Census shares differ." ;
	di "They shouldn't be HUGELY different as unweighted Gallup is not terribly unrepresentative)" ;
	di "Gallup shares in year `y' (unweighted)" ;
	tab wgt_group2_by_yr if tag_dups== 1 & svy_year==`y' ;
	di "IPUMS shares in Census before year `y'" ;
	matrix list ipums_shares2_`yr_lower' ;
	di "IPUMS shares in Census after year `y' [will equal survey year if year itself a Census year]" ;
	matrix list ipums_shares2_`yr_upper' ;
	forval g=1/4 { ;	
		replace cen2_wgt=((`yr_upper'-`y')/10)*ipums_shares2_`yr_lower'[`g',1] + ((`y'- `yr_lower')/10)*ipums_shares2_`yr_upper'[`g',1] if wgt_group2_by_yr==`g' & svy_year==`y';
		***Now, just divied by Gallup share that year ;
		replace cen2_wgt=cen2_wgt/gallup_shares2_`y'[`g', 1] if wgt_group2_by_yr==`g' & svy_year==`y' ;
		****The code above is wrong for years that ACTUALLY fall in a census year bc cen_yr_upper==cen_yr_lower.  Fix below ;
		if `y'==1940 | `y'==1950 | `y'==1960 | `y'==1970 | `y'==1980 | `y'==1990 |`y'==2000 | `y'==2010 { ;		
			replace cen2_wgt=ipums_shares2_`y'[`g',1] if wgt_group2_by_yr==`g' & svy_year==`y' & cen_year_upper==cen_year_lower ;
			replace cen2_wgt=cen2_wgt/gallup_shares2_`y'[`g', 1] if wgt_group2_by_yr==`g' & svy_year==`y' & cen_year_upper==cen_year_lower ;
		} ;	
	} ;
	di "Gallup shares in year `y' (weighted)" ;
	tab wgt_group2_by_yr if  svy_year==`y' [aw=cen2_wgt] ;
	matrix temp_compare=((`yr_upper'-`y')/10)*ipums_shares2_`yr_lower'+ ((`y'- `yr_lower')/10)*ipums_shares2_`yr_upper' ;
	di "Interpolated IPUMS shares for year `y'" ;
	matrix list temp_compare ;
	matrix drop temp_compare ;
} ;


gen noblk=blkP~=1 if blkP< . ;
tab noblk ;

eststo clear ;

gen temp_reg_label=1-confed ;
*label define temp_reg_label 0 "\quad -- \textit{Southern states}" 1 "\quad -- \textit{Non-Southern states}" ;
label define temp_reg_label 0 "--\textit{Southern states} " 1 "--\textit{Non-Southern states}" ;
label values temp_reg_label temp_reg_label ;

gen hs_dummy=eduH>4 if eduH<10 ;
gen hs2_dummy=eduH>1 if eduH<10 ;
gen col_dummy=eduH==8 if eduH<10 ;

******Maybe drop technical/trade as no comparison in IPUMS????? ;
foreach var of varlist hs_dummy hs2_dummy col_dummy { ;
replace `var'=. if eduH==6 ;
} ;

gen in_samp=race==1 & blkP<. & female<. & hs_dummy< . & urban<. & dem<. & age<. & svy_type==1 & eduH< .  ;

****First two columns shows *weighted* Gallup ;
eststo: estpost tabstat  age female hs_dummy hs2_dummy col_dummy urban noblk dem  if in_samp==1 & svy_year<1963 [aw=cen2_wgt] , statistics(mean) by(temp_reg_label) columns(statistics) nototal  ;
eststo: estpost tabstat  age female hs_dummy hs2_dummy col_dummy  urban noblk dem  if in_samp==1 & svy_year>1962 & svy_year<1981 [aw=cen2_wgt], statistics(mean) by(temp_reg_label) columns(statistics) nototal  ;

*** For 1960 & 1970 comparisons ;
*** Here we show *unweighted* Gallup (to give readers a sense of how much "work" the weights are doing) ;

eststo: estpost tabstat  age female hs_dummy hs2_dummy col_dummy  urban noblk dem if in_samp==1 & svy_year>1957 & svy_year<1963  , statistics(mean) by(temp_reg_label) columns(statistics) nototal  ;
eststo: estpost tabstat  age female hs_dummy hs2_dummy col_dummy  urban noblk dem  if in_samp==1 & svy_year>1967 & svy_year<1973 , statistics(mean) by(temp_reg_label) columns(statistics) nototal  ;

label var age "Age" ;
label var female "Female" ;
label var hs_dummy "Completed HS" ;
label var urban "Urban" ;
label var hs2_dummy "Attended some HS" ;
label var col_dummy "College graduate" ;
label var noblk "No black president" ;
label var dem "Identifies as Democrat" ;


preserve ;

use  "$input/IPUMS_Dataset_1940_2010.dta", clear ;
keep if year==1960 | year==1970 ;
keep if age>20 ;
keep if race==1 ;
keep if gq==1 ;

**Drop AK and HI ;
drop if statefip==15 | statefip==2 ;

gen hs_dummy=higraded>=150 if higraded<. ;
gen hs2_dummy=higraded>110 if higraded<. ;
gen col_dummy=higraded>=190 if higraded<. ;
gen female=sex==2 ;
ren urban urb ;
gen urban=urb==2 if urb<. ;

***Generate a label var for South, Non-South ;
gen temp_reg_label=1 ;
replace temp_reg_label=0 if inlist(statefip, 1, 5, 12, 13, 22, 28, 37, 45, 47, 48, 51) ;

*label define temp_reg_label 0 "\quad -- \textit{Southern states}" 1 "\quad -- \textit{Non-Southern states}" ;
label define temp_reg_label 0 "--\textit{Southern states} " 1 "--\textit{Non-Southern states}" ;
label values temp_reg_label temp_reg_label ;

label var age "Age" ;
label var female "Female" ;
label var hs_dummy "Completed HS" ;
label var urban "Urban" ;
label var hs2_dummy "Attended some HS" ;
label var col_dummy "College graduate" ;

tab statefip if temp_reg_label==0 ;

eststo: estpost tabstat  age female hs_dummy hs2_dummy col_dummy  urban  if year==1960 [aw=perwt] , statistics(mean) by(temp_reg_label) columns(statistics) nototal  ;
eststo: estpost tabstat  age female hs_dummy hs2_dummy col_dummy  urban  if year==1970 [aw=perwt] , statistics(mean) by(temp_reg_label) columns(statistics) nototal  ;

restore ;

esttab est1 est2 est3 est5 est4 est6, cells(mean) stats(N, label("Observations")) varwidth(25) label wrap collabels(none) nonum 
mtitles("Pre-p'd" "Post-p'd" "Gallup" "IPUMS" "Gallup" "IPUMS") ;

esttab est1 est2 est3 est5 est4 est6 using "$tables/gallup_ipums_wgt_fix.tex", replace fragment booktabs 
cells(mean(fmt(a3))) stats(N, label("Observations")) varwidth(25) label wrap collabels(none) nonum 
mtitles("Pre-p'd" "Post-p'd" "Gallup (unwtd.)" "IPUMS" "Gallup (unwtd.)" "IPUMS") 
mgroups("Gallup (weighted)" "1960 comparison" "1970 comparison", pattern(1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ;

********************************************************************************;
********************************************************************************;
// Part 3: Using Gallup Data for Diffs South/Non South Graphs

*Program to plot Confederate / non Confederate / Difference graphs;
capture program drop plotCSnonCSdiff ;
program plotCSnonCSdiff ;
	args keyvar diffvar datevar graphname ytitle yline xtitle xlabelno xlabelangle extraoption ;
	local yrefline "" ;
	if "`yline'" == "y0line" local yrefline "yline(0, axis(2) lcolor(gs9) lpattern(dash))" ;
	graph twoway (connected `keyvar' `datevar' if confed == 1, legend(lab(1 "Confederate states")) yaxis(1) lcolor(maroon) lpattern(dash) lwidth(thin) mcolor(maroon) msymbol(th) mlw(thin))
		(connected `keyvar' `datevar' if confed == 0, legend(lab(2 "Non Confederate states")) yaxis(1) lcolor(navy) lpattern(dash) lwidth(thin) mcolor(navy) msymbol(oh) mlw(thin)) 
		(line `diffvar' `datevar' if confed == 0, legend(lab(3 "Difference (Confederate states - Non Confederate states)")) yaxis(2) lcolor(forest_green) lpattern(solid)), 
		name(`graphname', replace) legend(on cols(1) size(small)) 
		xtitle(`xtitle', size(small)) xlabel(`xlabelno', labsize(small) `xlabelangle') 
		ytitle(`ytitle', axis(1) size(small)) ylabel(, axis(1) labsize(small)) 
		ytitle(Difference, axis(2) size(small)) ylabel(, axis(2) labsize(small)) `yrefline' `extraoption' ;
	graph save "$figures/`graphname'", replace ;
	graph export "$figures/`graphname'.pdf", replace ;
	window manage close graph _all ;
end ;

*Program to plot regression coefficients across time (Confederate / non Confederate) ;
capture program drop plottingregcoeff ;
program define plottingregcoeff ;
	args namesuffix depvar indepvar maxyear controls ;
	if "`controls'" == "all"{ ;
		local listcontrols "i.age_10 female i.eduHarmonized city_dummy"
	} ;
	foreach newvar in coeff_south pval_south coeff_nonsouth pval_nonsouth { ;
		capture drop `newvar'
		gen `newvar' = .
	} ;
	
	levelsof svy_date, local(list_date) ;
	
	foreach date in `list_date' { ;
		if `date' <= td(31dec`maxyear') { ;
			capture reg `depvar' `indepvar' `listcontrols' [pw=weight_scaled] 
				if race == 1 & confed == 0 & svy_date == `date', vce(robust)
			capture replace coeff_nonsouth = _b[`indepvar'] if svy_date == `date'
			capture replace pval_nonsouth = 2*ttail(e(df_r), abs(_b[`indepvar']/_se[`indepvar'])) if svy_date == `date'
			capture reg `depvar' `indepvar' `listcontrols' [pw=weight_scaled] 
				if race == 1 & confed == 1 & svy_date == `date', vce(robust)
			capture replace coeff_south = _b[`indepvar'] if svy_date == `date'
			capture replace pval_south = 2*ttail(e(df_r), abs(_b[`indepvar']/_se[`indepvar'])) if svy_date == `date'
		} ;
	} ;
	
	forvalues y = 1959/`maxyear' { ;
		local jan `jan' `=mdy(1,1,`y')'
		if mod(`y', 5) == 0 local jul `jul' `=mdy(7,1,`y')'
	} ;
	graph twoway (connected coeff_south svy_date if obs == 1 & svy_date <= td(31dec`maxyear'), legend(label(1 "Confederate states")) lcolor(maroon) lpattern(solid) lwidth(medthick) mcolor(maroon) msymbol(T)) 
		(connected coeff_nonsouth svy_date if obs == 1 & svy_date <= td(31dec`maxyear'), legend(label(2 "Non Confederate states")) lcolor(navy) lpattern(dash) lwidth(medthick) mcolor(navy) msymbol(O)), 
		name(res_C`depvar'`indepvar'`maxyear'`controls'_`namesuffix', replace) legend(on cols(1) size(small))
		xtick(`jan') xlabel(`jul', format(%tdCY) noticks labsize(small) labgap(*3)) xtitle("") 
		ytitle("Coefficient value", size(small)) ylabel(, labsize(small)) 
		yline(0, lcolor(gs9) lpattern(dash)) xline(1257, lcolor(gs9)) ;
	*graph save "$output/res_C`depvar'`indepvar'`maxyear'`controls'_`namesuffix'", replace ;
	graph export "$figures/res_C`depvar'`indepvar'`maxyear'`controls'_`namesuffix'.pdf", replace ;
	window manage close graph _all ;
	
	graph twoway (connected pval_south svy_date if obs == 1 & svy_date <= td(31dec`maxyear'), legend(label(1 "Confederate states")) lcolor(forest_green) lwidth(medthick) mcolor(forest_green) msymbol(T)) 
		(connected pval_nonsouth svy_date if obs == 1 & svy_date <= td(31dec`maxyear'), legend(label(2 "Non Confederate states")) lpattern(dash) lwidth(medthick) lcolor(forest_green) mcolor(forest_green) msymbol(O)), 
		name(res_P`depvar'`indepvar'`maxyear'`controls'_`namesuffix', replace) legend(on cols(1) size(small)) 
		xtick(`jan') xlabel(`jul', format(%tdCY) noticks labsize(small) labgap(*3)) xtitle("") 
		ytitle("p-value", size(small)) ylabel(, labsize(small)) 
		yline(0.01 0.1, lcolor(gs9) lpattern(dash)) ;
	*graph save "$output/res_P`depvar'`indepvar'`maxyear'`controls'_`namesuffix'", replace ;
	graph export "$figures/res_P`depvar'`indepvar'`maxyear'`controls'_`namesuffix'.pdf", replace ;
	window manage close graph _all ;
end ;

********************************************************************************;
*Figure 1: Share of whites identifying as Democrats, by region ;
********************************************************************************;

use "$input/gallup_and_GSS_extrayears.dta", clear ;

collapse (mean) dem if race == 1 [pw=weight_scaled], by(svy_year confed) ;
bys svy_year (confed): gen diff = dem[2] - dem[1] ;

plotCSnonCSdiff dem diff svy_year intro_dem_CSnonCS_gallup "Share of Democrats (%)" y0line Year 1950(10)2000 ;

gen line0=0 ;

twoway (connect dem svy_year if confed==1, yaxis(1) m(triangle_hollow) mc(red) lc(red) mlw(vthin) lw(vthin) msize(medsmall) lp(dash))
(connect dem svy_year if confed==0, yaxis(1) m(circle_hollow) mc(blue) lc(blue) mlw(vthin) lw(vthin) msize(small) lp(dash))
(connect diff svy_year if confed==1, m(none) lc(dkgreen) yaxis(2) lw(medthin))
(line line0 svy_year if confed==1, yaxis(2) lp(dash) lw(thin) lc(gray)) ,
legend(
on order(1 2 3) pos(2) ring(0) label(1 "South") label(2 "Non-South") label(3 "Difference (South" "minus non-South)") 
rows(3) region(lstyle(none)) symx(*.7)
)
scheme(aspen) yti("Democratic share", axis(1)) yti("Difference", axis(2)) xti("") xlabel(1950(10)2000) xsize(6) scale(1.2) ;

graph export "$figures/demid_main_ik_version.pdf", replace ;

********************************************************************************;
********************************************************************************;

// Part 4: Using Gallup and GSS Data for further analysis with Kennedy's Approval;

use "$input/gallup_and_GSS_extrayears.dta", clear;

* Recode variable values;
recode goldwaterKennedy (0=.) (5=1) (6=2);
label define lb_goldwaterKennedy 1 "GOLDWATER AND LEANS TO GOLDWATER"
								 2 "KENNEDY AND LEANS TO KENNEDY" 
								 3 "OTHER" 
								 4 "UNDECIDED", replace;
label values goldwaterKennedy lb_goldwaterKennedy;

recode goldwaterJohnson (0=.) (5=1) (6=2);
label define lb_goldwaterJohnson 1 "GOLDWATER AND LEANS TO GOLDWATER"
								 2 "JOHNSON AND LEANS TO JOHNSON" 
								 3 "OTHER" 
								 4 "UNDECIDED", replace;
label values goldwaterJohnson lb_goldwaterJohnson;

recode rockefellerKennedy (0=.) (5=1) (6=2);
label define lb_rockefellerKennedy 1 "ROCKEFELLER AND LEANS TO ROCKEFELLER"
								 2 "KENNEDY AND LEANS TO KENNEDY"
								 3 "OTHER" 
								 4 "UNDECIDED", replace;
label values rockefellerKennedy lb_rockefellerKennedy;

foreach x in State CD {;
recode party`x' (4=1) (5=2) (6=3);
label define lb_`x'				 1 "REPUBLICAN AND LEANS TO REPUBLICAN"
								 2 "DEMOCRAT AND LEANS TO DEMOCRAT" 
								 3 "OTHER PARTY AND LEANS TO OTHER PARTY" 
								 7 "UNDECIDED, REFUSED, OR NO ANSWER", replace;
label values party`x' lb_party`x';
};

keep if race==1;

**************************;
** CORRELATION ANALYSIS **;
**************************;
gen blkSchool = .;
foreach x in fewMixedSchool halfMixedSchool halfPlusMixedSchool {;
replace blkSchool = 1 if `x'==1;
replace blkSchool = 0 if `x'!=1 & !missing(`x') & `x'!=9;
};
replace noprez = blkPresident != 1 if !missing(blkPresident);

preserve;
keep if !missing(noprez, blkSchool);
corr noprez blkSchool if svy=="1958-0604";
levelsof svy, local(svys);
matrix A = J(17,1,.);

local i = 1;
foreach svy in `svys' {;
	corr noprez blkSchool if svy=="`svy'";
	matrix A[`i',1] = r(rho);
	local i = `i'+1;
	};
	
matrix list A;
restore;

**************************;
** RECOGNITION ANALYSIS **;
**************************;
format svy_date %tddd_Mon_YY ;

preserve;
local listvars = "";
foreach guy in Rockefeller Goldwater Romney Scranton {;
gen recog`guy' = (who`guy'==1 | who`guy'==2) & !missing(who`guy');
gen denom`guy' = !missing(who`guy');
local listvars = "`listvars'" + " recog`guy' denom`guy'";
};

collapse (sum) `listvars', by(svy_date confed);

foreach guy in Rockefeller Goldwater Romney Scranton {;
gen percentrecog`guy' = recog`guy'/denom`guy';
};

keep confed svy_date percent*;
keep if !missing(percentrecogRockefeller);
restore;


*******************************************************************************;
* Figure 9: Support for Kennedy versus Goldwater (whites in Gallup) ;
*******************************************************************************;

foreach prez in Kennedy  {;
preserve;
gen Goldwater = (goldwater`prez'==1) if !missing(goldwater`prez');
gen `prez' = (goldwater`prez'==2) if !missing(goldwater`prez');
gen count = 1 if !missing(goldwater`prez');
collapse (sum) count Goldwater `prez', by(svy_date confed);
gen percentGoldwater = Goldwater/count;
gen percent`prez' = `prez'/count;
keep if !missing(percentGoldwater, percent`prez');

	graph twoway 
		(connected percentGoldwater svy_date if confed == 1,  yaxis(1) lcolor(red) lpattern(dash) lwidth(thin) mcolor(red) msymbol(th) mlw(thin))
		(connected percentGoldwater svy_date if confed == 0,  yaxis(1) lcolor(blue) lpattern(dash) lwidth(thin) mcolor(blue) msymbol(oh) mlw(thin)) 
		(connected percent`prez' svy_date if confed == 1,  yaxis(1) lcolor(red) lpattern(solid) lwidth(thin) mcolor(red) msymbol(th) mlw(thin)) 
		(connected percent`prez' svy_date if confed == 0,  yaxis(1) lcolor(blue) lpattern(solid) lwidth(thin) mcolor(blue) msymbol(oh) mlw(thin)),
		legend(
		on size(small) pos(3) cols(2) rows(3) ring(0) 
		label(1 "South") label(2 "Non-South") label(3 "South") label(4 "Non-South")
		order(- "{it: Kennedy}" 3 4  - "{it: Goldwater}" 1 2)  region(lstyle(none)) colfirst symx(*.7) 
		) 
		xtitle(" ") xlabel(1155 1186 1216 1247 1277 1308 1339 1369 1400,  angle(35)) 
		ytitle("Share who would support each candidate", axis(1) ) ylabel(.3(.1).6, axis(1) nogrid) 
		plotregion(style(none) lcolor(black)) graphregion(style(none) lcolor(white) fcolor(white)) scheme(aspen) scale(1.2);
	graph export "$figures/Gallup_goldwater`prez'.pdf", replace;

restore;
};



**********************************;
** APPROVAL OF JFK AMONG BLACKS **;
**********************************;

use "$input/gallup_and_GSS_extrayears.dta", clear;

keep if svy_date>=date("20jan1961","DMY") & svy_date<=date("22nov1963","DMY") & race==2;
cap drop approve disapprove noopinion count;
gen approve = (presApprovala==1) if !missing(presApprovala);
gen disapprove = (presApprovala==2) if !missing(presApprovala);
gen noopinion = (presApprovala==3) if !missing(presApprovala);
gen count = 1 if !missing(presApprovala);
collapse (sum) count approve disapprove noopinion, by(svy_date);
foreach var of varlist approve disapprove noopinion {;
	gen percent`var' = `var'/count;
	};
	
local dateline = date("11jun1963","DMY");
format svy_date %tdddMonyy ;

graph twoway 
		(connected percentapprove svy_date, legend(lab(1 "Approve")) yaxis(1) lcolor(forest_green) lpattern(solid) lwidth(thin) mlw(thin) msymbol(sh) mcolor(forest_green))
		(connected percentdisapprove svy_date, legend(lab(2 "Disapprove")) yaxis(1) lcolor(maroon) lpattern(solid) lwidth(thin) mlw(thin) msymbol(oh) mcolor(maroon))
		(connected percentnoopinion svy_date, legend(lab(3 "No Opinion")) yaxis(1) lcolor(navy) lpattern(solid) lwidth(thin) mlw(thin) msymbol(th) mcolor(navy)),
		legend(on cols(1) region(lstyle(none)) pos(9) ring(0) ) 
		xti("") xlabel(#10, angle(45)) 
		ytitle(Share of Responses, axis(1)) ylabel(, axis(1)  nogrid) 
		plotregion(style(none) lcolor(black)) graphregion(style(none) lcolor(white) fcolor(white))
		xline(`dateline', lcolor(gs9) lpattern(dash)) scale(1.4);
graph export "$figures/jfkapp_blacks_tim.pdf", replace;

********************************************************************************;
********************************************************************************;
// Part 6: Using Gallup and GSS Data for OLS Analysis (Predicted Answers) ; 
use "$input/gallup_and_gss_extrayears.dta", clear ;

capture program drop meanvar ;
program meanvar ;
	sum `e(depvar)' if e(sample)==1 [aw `e(wexp)'] ;
	estadd scalar dvar=`r(mean)' ;
end ;

local vars_3d "noprez conf_noprez noprez_aft conf_noprez_aft" ;
summ svy_date ;
gen i_svy_date = svy_date - `r(min)' ;

local fe `"i.i_svy_date "' ;

***Just keep our main analysis sample ;
keep if race==1 ;
keep if noprez<. ;
keep if svy_type==1 ;

****Do Census weighting ;
do "$do/make_gallup_cen_wgts" ;
 
*****Set prediction variable sets ;
local predict_0 "age20 age30 age40 age50 age60 age70 age80 female i.state i.eduH i.citySize i.occupation  " ;

****First prediction set ;
local predict_1 "age20 age30 age40 age50 age60 age70 age80 female i.state  " ;

****Second set (add more background variables & opinion vars) ;
local predict_2 "age20 age30 age40 age50 age60 age70 age80 female i.state i.occupation  i.eduH i.religion i.citySize i.cathP i.jewP" ;

*** More Sets : 
local predict_3 "age20 age30 age40 age50 age60 age70 age80 female i.state i.occupation i.eduH i.religion i.citySize i.cathP i.jewP _E* _O* " ;
local predict_4 "age20 age30 age40 age50 age60 age70 age80 female i.state i.occupation i.eduH i.religion i.citySize " ;

****Interactions (things we think may have different meaning for different ages) ;

gen old=age_10>40 if age_10<. ;
xi i.old*i.eduH, pre(_E) ;
xi i.old*i.occupation, pre(_O) ;

****Create varlists we will need in the regressions ;
foreach var in predict predict_01 { ;
local vars_3d_`var' "`var' conf_`var' `var'_aft conf_`var'_aft" ;
} ;


***Generate a sample that has none of the predictors missing for a given set of predictors & and our main outcome var (dem) ;
forval x=1/4 { ;
	gen insamp_`x'=1 if noprez<. & dem<. ;
	foreach var in `predict_`x'' { ;
	di "`var'" ;
	if strpos("`var'", "*")==0 { ;
		if strpos("`var'", "i.")==0  local var_name "`var'" ;
		else if strpos("`var'", "i.")==1 local var_name = substr("`var'", 3, .) ;
		di "`var_name'" ;
		replace insamp_`x'=0 if `var_name'==. ;
		} ;
	} ;
} ;

sum insamp_* ;

****Subprogram that generates predictions separately for S and non-S for no-prez for a given set of predictors in pre-period ;
****It generates three types of predictions.  
****(1) continuous (probability that you woudl be against a Black prez given our estimate pre-period model & your covariates) ;
****(2) a 0/1 variable that has the same pre-period mean in both S and non-S as the *actual* no-black president question ;
cap program drop predict_S_nonS ;
program define predict_S_nonS, eclass ;
	args predict_set ;
	
* Estimate noprez from random draw and predict noprezhat ;
*Define pre-period ;
local y 1963 ;
		cap drop *predict* temp_cumul* ;
		
		**@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@ ;	
		****Definition (1) of the prediction variable ;
				
		gen predict=. ;
		forval x=0/1 { ;		
		reg noprez `predict_set' if race==1 & confed==`x' & svy_year<`y' [pw=weight_scaled]  ;
		predict predict_`x' if race==1 & confed==`x' & noprez<. ;
		replace predict=predict_`x' if race==1 & confed==`x' ;
		} ;
		
		**@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@ ;	
		****Definition (2) of the prediction variable ;
		****As a binary variable has mean and variance determined by a single parameter, we need to have same mean ;
		
		gen predict_01=. ;	
		forval x=0/1 { ;		
		****Generate \mu ;
		sum noprez if aft==0 & confed==`x' & predict<. [aw=weight_scaled] ;
		local cut=`r(mean)' ;
		****Generate the CDF of the predicted distribution, G ;
		cumul predict if confed==`x' & aft==0 [aw=weight_scaled], gen(temp_cumul_`x') ;
		****Below we want to know the value of `predict' that is at the percentile defined by the *actual* share who are against a black prez ;
		****Given that probability at a given point will have measure zero, we take an average of `predict' such that its CDF F(.) is within some small range of actual share (1-\mu) ;
		sum predict if confed==`x' & aft==0 & abs(temp_cumul_`x'-(1-`cut'))<.01  ;
		local cut2=`r(mean)' ;
		gen predict_01_conf`x'=predict>`cut2' if predict<. ;		
		****Display this cut point to make sure it's not crazy ;
		di "cut point for confed==`x' is  " `r(mean)' ;
		****Compare means & predicted means in the pre-period.  We should be *very* close (slightly off due to predicted distribution not being completely continuous) ;
		sum noprez predict_01_conf`x' if aft==0 & confed==`x' & noprez<. & predict<. [aw=weight_scaled] ;
		replace predict_01=predict_01_conf`x' if confed==`x' ;
		} ;
		
		**@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@ ;	
		****Label our predictors and create interactions ;	
		lab var predict "No Bl prez (pr.)" ;
		lab var predict_01 "\$\widehat{No\, Bl.\, prez}\$" ;
				
		* Create and label interactions ;
		foreach var of varlist predict predict_01 { ;
			gen conf_`var' = confed*`var' if !missing(confed) & !missing(`var') ;
			gen `var'_aft = aft*`var' if !missing(aft) & !missing(`var') ;
			gen conf_`var'_aft = confed*`var'*aft if !missing(confed) & !missing(`var') & !missing(aft) ;
			sum *predict* ;
			
			local l_`var' : variable label `var' ;
			lab var conf_`var' "`l_`var'' x South" ;
			lab var `var'_aft "`l_`var'' x Aft" ;
			lab var conf_`var'_aft "`l_`var'' x South x Aft" ;
			} ;	
end ;

*** This program represents a single iteration, which will be looped over when called upon by -bootstrap- ;
cap program drop predictnoprezhat_runreg ;
program define predictnoprezhat_runreg, eclass ;
	args yvar xvars predictors maxyear ;
	preserve ;	
	predict_S_nonS "`predictors'"  ;
		
		* Run regression of interest ;
		areg `yvar' `xvars' if race==1 & svy_year<`maxyear' & noprez<. /* & insamp_temp==1 */ [pw=weight_scaled], cl(state) abs(state) ;
	restore ;
end ;

*************************************************************************Graphs;
* Figure 6: Dependence of whites' Democratic identification on predicted answers to the black president question ;
* Appendix Figure A.4: Dependence of whites' Democratic identi cation on predicted answers ;

******Let's show for two difference predictions: predictor set 2 and 4 ;
predict_S_nonS "`predict_4'" ;

foreach p in 2 4 { ;
cap drop predict* ;
predict_S_nonS "`predict_`p''" ;
****Binscatter for our four groups (pre-South, pre-nonS, post-South, post-nonS) ;
****Save the generated data so that we can plot more flexibly ;

forval t=0/1 { ;
forval c=0/1 { ;
binscatter dem predict if aft==`t' & confed==`c' & race==1, savedata(scatter_aft`t'_conf`c') replace ;
graph export "$figures/binscatter_aft`t'_confed`c'.pdf", replace ;
} ;
} ;

preserve ;
***Insheet the data saved by binscatter (first convert .csv to .dta and then append all together) ;

forval t=0/1 { ;
forval c=0/1 { ;
insheet using scatter_aft`t'_conf`c'.csv, clear ;
gen aft=`t' ;
gen conf=`c' ;
tempfile temp_conf`c'_aft`t' ;
save `temp_conf`c'_aft`t'' ;
} ;
} ;

clear ;

forval t=0/1 { ;
forval c=0/1 { ; 
append using `temp_conf`c'_aft`t'' ;
} ;
} ;

****Plot separately for South and non-South ;
forval c=0/1 { ;
twoway (scatter dem predict if conf==`c' & aft==0) (lfit dem predict if conf==`c' & aft==0, lc(gray) lp(dash))
(scatter dem predict if conf==`c' & aft==1) (lfit dem predict if conf==`c' & aft==1, lc(gray) lp(solid)), xti(`"Predicted value for "Would not vote for a black president""')
yti("Identifies as a Democrat") ylabel(.2(.2).8) scale(1.2) legend(ring(0) pos(10) label(1 "Before Spring 1963") label(2 "Fitted line") label(3 "After Spring 1963") label(4 "Fitted line") rows(2) symx(*.5) colgap(*.3))  ;
graph export "$figures/binscatter_predict`p'_conf`c'.pdf", replace ;
} ;
restore ;

} ;


****DO we have parallel trends for the *predicted* values? ;
cap drop predict* ;

****Parsimonious predictors first (more years) ;
predict_S_nonS "`predict_4'" ;
rename predict _pred_4 ;
drop predict* ;

****Detailed predictors first (fewer years) ;
predict_S_nonS "`predict_2'" ;
rename predict _pred_2 ;
drop predict* ;
des _pre* ;

foreach p in 2 4 { ;
egen predict`p'_reg_yr=mean(_pred_`p'), by(confed svy_year) ;
} ;

*****Report coefficients on conf*year in the graph ;
gen conf_year=confed*svy_year ;
foreach p in 2 4 { ;
areg _pred_`p' conf_year i.svy_year if race==1, abs(state) cl(state) ;
local coeff_`p'=_b[conf_year] ;
local pval_`p'=2*ttail(`e(df_r)', abs(_b[conf_year]/_se[conf_year])) ;
di `pval_`p'' ;
local coeff_`p': di %8.0g `coeff_`p'' ;
local pval_`p': di %6.0g `pval_`p'' ;
} ;

egen tag=tag(svy_year confed) ;
 
*******************************************************************************;
* Appendix Figure A.3: Do predicted views among whites toward a black president follow parallel trends in the South and non-South? ;
*******************************************************************************;

twoway (scatter predict*_reg_yr svy_year if confed==1) (scatter predict*_reg_yr svy_year if confed==0) 
(lfit predict2_reg_yr svy_year if confed==0, lc(gray) lp(solid) lw(thin))
(lfit predict4_reg_yr svy_year if confed==0, lc(gray) lp(solid) lw(thin))
(lfit predict2_reg_yr svy_year if confed==1, lc(gray) lp(solid) lw(thin))
(lfit predict4_reg_yr svy_year if confed==1, lc(gray) lp(solid) lw(thin))
if svy_year>1957 & svy_year<1990 & tag==1,  
text( .88 1978 "South, parsimonious predictors")
text(.81 1963 "South, detailed predictors")
text( .53 1980 "Non-South, parsimonious predictors")
text(.45 1964 "Non-South, detailed predictors")
text(.7 1961 "Differential (South minus non-South) trend coefficients", place(e) justification(left))
text(.67 1963 "Parsimonious prediction: `coeff_4' ({it:p} =`pval_4')", place(e) justification(left))
text(.645 1963 "Detailed prediction: `coeff_2' ({it:p} =`pval_2')", place(e) justification(left))
ylabel(.4(.1).9) xti("") xlabel(1960(5)1985) legend(off) scale(1.1)
yti(`"Predicted value: "Would not vote for a black president" "')  ;
graph export "$figures/predict_parallel_trends.pdf", replace ;

******Prediction appendix table ;
* Appendix Table A.4: Comparing results using actual versus predicted values for No black president (whites in Gallup) ;

*****Set reps for bootstrap here ;
	local reps=200 ;
	
foreach var in predict_01 { ;	
	
	eststo clear ;
	* use parsimonious predictors, max years ;
	eststo: areg dem conf_aft `fe' if race==1 & noprez~=. & svy_blkPres==1 & insamp_4==1 [pw=weight_scaled], cl(state) abs(state) ;
	sum dem if e(sample) == 1 [aw=weight_scaled] ;
	estadd scalar Mean = `r(mean)' ;
	estadd scalar Observations = `r(N)' ;
	estadd local Controls "No" ;
	estadd local Dataset "Gallup" ;
	estadd local bsse "No" ;
	estadd local demog "N/A" ;
	estadd local views "N/A" ;
	estadd local intx "N/A" ;
	estadd local ex_miss "No" ;
	estadd local max_yr "1986" ;

	* use parsimonious predictors, maximize years in sample ;
	eststo: areg dem conf_aft `vars_3d' `fe' if race==1 & noprez~=. & svy_blkPres==1 & insamp_4==1 [pw=weight_scaled], cl(state) abs(state) ;
	sum dem if e(sample) == 1 [aw=weight_scaled] ;
	estadd scalar Mean = `r(mean)' ;
	estadd scalar Observations = `r(N)' ;
	estadd local Controls "No" ;
	estadd local Dataset "Gallup" ;
	estadd local bsse "No" ;
	estadd local demog "N/A" ;
	estadd local views "N/A" ;
	estadd local intx "N/A" ;
	estadd local ex_miss "No" ;
	estadd local max_yr "1986" ;

	**Set number of draws equal to sample size of previous regression ;
	local size=`e(N)' ;
	di `size' ;
		
	****Drop all but the main sample for the bootstrap reps (or else it draws from non-useable data) ;
	keep if e(sample)==1 ;
				
	***Add R-squared first ;
	predict_S_nonS "`predict_4'" ;
	reg noprez predict if race==1 & svy_year<1962 & insamp_4==1 [pw=weight_scaled] ;
	local bodie=`e(r2)' ;
		
	eststo: bootstrap _b, size(`size')  noisily reps(`reps') seed(1)  : predictnoprezhat_runreg dem "conf_aft `vars_3d_`var'' `fe'" "`predict_4'" 1990  ;
	***We want sum stats for the relevant sample, which is not e(sample)==1 (that's just the last estimated bootstrapped sample) ;
	***Just use that noprez<. & predict<. & year<maxyear ;
	sum dem if insamp_4==1 & svy_year<1990 [aw=weight_scaled] ;
	estadd scalar Mean = `r(mean)' ;
	estadd scalar Observations = `r(N)' ;
	estadd local Controls "No" ;
	estadd local Dataset "Gallup" ;
	estadd local bsse "Yes" ;
	estadd local demog "Yes" ;
	estadd local views "No" ;
	estadd local intx "No" ;
	estadd local ex_miss "Yes" ;
	estadd scalar pred_r2=`bodie' ;
	estadd local max_yr "1986" ;

	* parsimonious predictors, but max year<1980 & detailed predictors non-missing ;
	***First, generate this subsample ;
	
	areg dem conf_aft `fe' if race==1 & svy_year<1980 & noprez~=. & svy_blkPres==1 & insamp_2==1 [pw=weight_scaled], cl(state) abs(state) ;
	gen insamp_det=1 if e(sample)==1 ;	

	* parsimonious predictors, but max year<1980 & detailed predictors non-missing ;
	eststo: areg dem conf_aft `fe' if race==1 & svy_year<1980 & noprez~=. & svy_blkPres==1 & insamp_4==1 & insamp_2==1 & insamp_det==1 [pw=weight_scaled], cl(state) abs(state) ;
	sum dem if e(sample) == 1 [aw=weight_scaled] ;
	estadd scalar Mean = `r(mean)' ;
	estadd scalar Observations = `e(N)' ;
	estadd local Controls "No" ;
	estadd local Dataset "Gallup" ;
	estadd local bsse "No" ;
	estadd local demog "N/A" ;
	estadd local views "N/A" ;
	estadd local intx "N/A" ;
	estadd local ex_miss "No" ;
	estadd local max_yr "1978" ;

	eststo: areg dem conf_aft `vars_3d' `fe' if race==1 & svy_year<1980 & noprez~=. & svy_blkPres==1 & insamp_2==1 & insamp_4==1 & insamp_det==1 [pw=weight_scaled], cl(state) abs(state) ;
	sum dem if e(sample) == 1 [aw=weight_scaled] ;
	estadd scalar Mean = `r(mean)' ;
	estadd scalar Observations = `e(N)' ;
	estadd local Controls "No" ;
	estadd local Dataset "Gallup" ;
	estadd local bsse "No" ;
	estadd local demog "N/A" ;
	estadd local views "N/A" ;
	estadd local intx "N/A" ;
	estadd local ex_miss "No" ;
	estadd local max_yr "1978" ;

	**Set number of draws equal to sample size of previous regression ;
	local size=`e(N)' ;
	di `size' ;
		
	****Drop all but the main sample for the bootstrap reps (or else it draws from non-useable data) ;
	*preserve ;
	keep if e(sample)==1 ;
			
	***Add R-squared first ;
	predict_S_nonS "`predict_4'" ;
	reg noprez predict if race==1 & svy_year<1962 & insamp_4==1 [pw=weight_scaled] ;
	local bodie=`e(r2)' ;
		
	eststo: bootstrap _b, size(`size')  noisily reps(`reps') seed(1)  : predictnoprezhat_runreg dem "conf_aft `vars_3d_`var'' `fe'" "`predict_4'" 1980  ;
	***We want sum stats for the relevant sample, which is not e(sample)==1 (that's just the last estimated bootstrapped sample) ;
	***Just use that noprez<. & predict<. & year<maxyear ;
	sum dem if insamp_2==1 & svy_year<1980 [aw=weight_scaled] ;
	estadd scalar Mean = `r(mean)' ;
	estadd scalar Observations = `r(N)' ;
	estadd local Controls "No" ;
	estadd local Dataset "Gallup" ;
	estadd local bsse "Yes" ;
	estadd local demog "Yes" ;
	estadd local views "No" ;
	estadd local intx "No" ;
	estadd local ex_miss "Yes" ;
	estadd scalar pred_r2=`bodie' ;
	estadd local max_yr "1978" ;

	**Set number of draws equal to sample size of previous regression ;
	local size=`e(N)' ;
	di `size' ;
		
	****Drop all but the main sample for the bootstrap reps (or else it draws from non-useable data) ;
	keep if e(sample)==1 ;

	***Add R-squared first ;
	predict_S_nonS "`predict_2'" ;
	reg noprez predict if race==1 & svy_year<1962 & insamp_2==1 [pw=weight_scaled] ;
	local bodie=`e(r2)' ;	
	
	eststo: bootstrap _b,  noisily size(`size') reps(`reps') seed(1) : predictnoprezhat_runreg dem "conf_aft `vars_3d_`var'' `fe'" "`predict_2'" 1980 ;
	sum dem if insamp_2==1 & svy_year<1980 [aw=weight_scaled] ;	
	estadd scalar Mean = `r(mean)' ;
	estadd scalar Observations = `r(N)' ;
	estadd local Controls "No" ;
	estadd local Dataset "Gallup" ;
	estadd local bsse "Yes" ;
	estadd local demog "Yes" ;
	estadd local views "Yes" ;
	estadd local intx "Yes" ;
	estadd local ex_miss "Yes" ;
	estadd scalar pred_r2=`bodie' ;
	estadd local max_yr "1978" ;
		
			
esttab using "$tables/`var'.tex", replace booktabs fragment keep(conf_aft `vars_3d' `vars_3d_`var'') nomtitles
stats(Mean blank  demog views pred_r2 bsse max_yr Observations, 
label("Mean, dept. var." "Prediction model:"  "\quad Background vars." "\quad Prejud. vars." "\quad R-squared" "SEs bootstrapped?" "Max year in samp." "Observations") ) 
nostar se brackets label wrap varwidth(43) varlabels(predict_01 "\$\widehat{No\, Bl.\, prez}\$" predict_01_aft "\$\widehat{No\, Bl.\, prez}\$ x Aft")
mgroups("Dep't var: Respondent identifies as Democrat ", pattern(1 0 0   0 0 0   0)
prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ;

} ;

esttab using "$tables/comp_table_ols_ik_temp.tex", replace booktabs fragment keep(conf_aft `vars_3d' `vars_3d_predict_01') 
stats(Mean ex_miss blank demog views intx pred_r2 bsse N, 
label("Mean, dept. var" "Fixed sample?" "\underline{Prediction vars}:" "\quad Background" "\quad Other views" "\quad Age interactions" "R-sq for prediction" "SEs bootstrapped?" "Observations") ) 
nostar se brackets label varwidth(25) wrap nomtitles   ;

#delimit cr

********************************************************************************;
********************************************************************************;
// Part 7: Using Gallup and GSS Data for Falsification Test

*** Data
use "$input/gallup_and_gss_extrayears.dta", clear 
summ svy_date
gen i_svy_date = svy_date - `r(min)'
	
***census weights ;
keep if noprez<. & svy_type==1 & svy_year<2000 
do "$do/make_gallup_cen_wgts.do" 
			
eststo clear 
local xxPres "woman jew cath" 

********************************************************************************
*Table 5: Do views toward other minority groups explain white Southern dealignment 
********************************************************************************

foreach xx of local xxPres {

	* Sample restriction
	local maxyear 1980
	local ifs = "race==1 & svy_year<=`maxyear' & `xx'President~=. & blkPresident ~= . & svy_type == 1"

	* New variables
	cap drop *xxprez*
	gen xxprez = `xx'President != 1 if !missing(`xx'President)
	foreach var of varlist xxprez {
		gen conf_`var' = confed*`var' if !missing(confed) & !missing(`var')
		gen `var'_aft = aft*`var' if !missing(aft) & !missing(`var')
		gen conf_`var'_aft = confed*`var'*aft if !missing(confed) & !missing(`var') & !missing(aft)
	}
	
	* Col. 1, 5, 9
	eststo: reg dem conf_aft i.i_svy_date i.state if `ifs' [pw=cen2_wgt], cl(state)
	sum dem if e(sample) == 1 [aw=cen2_wgt]
	estadd scalar Mean = r(mean)
	
	* Col. 2, 6, 10
	eststo: reg dem conf_aft xxprez conf_xxprez xxprez_aft conf_xxprez_aft ///
		i.i_svy_date i.state if `ifs' [pw=cen2_wgt], cl(state)
	sum dem if e(sample) == 1 [aw=cen2_wgt]
	estadd scalar Mean = r(mean)
	
	* Col. 3, 7, 11
	eststo: reg dem conf_aft noprez conf_noprez noprez_aft conf_noprez_aft ///
		i.i_svy_date i.state if `ifs'  [pw=cen2_wgt], cl(state)
	sum dem if e(sample) == 1 [aw=cen2_wgt]
	estadd scalar Mean = r(mean)
	
	* Col. 4, 8, 12
	eststo: reg dem conf_aft noprez conf_noprez noprez_aft conf_noprez_aft i.i_svy_date i.state ///
		xxprez conf_xxprez xxprez_aft conf_xxprez_aft ///
		if `ifs' [pw=cen2_wgt], cl(state)
	sum dem if e(sample) == 1 [aw=cen2_wgt]
	estadd scalar Mean = r(mean)
	di "CORR BETWEEN no blk prez and no `xx' prez"
	corr noprez xxprez if e(sample)==1
	
}

lab var confed "South"
lab var conf_aft "South x Aft"
lab var xxprez "No \xx president"
lab var conf_xxprez "South x No \xx prez"
lab var xxprez_aft "No \xx prez x Aft"
lab var conf_xxprez_aft "South x No \xx prez x Aft"
label var noprez "No Black president"

esttab using "$tables/falsification_regs_horserace_fmt2_cen_wgts.tex", ///
	replace se label wrap brackets ///
	varwidth(20) nomtitles booktabs fragment ///
	keep(conf_aft *noprez* *xxprez*) ///
	nocons stats(Mean N, label("Mean, dept. var." "Observations")) ///
	nostar ///
	mgroups(" $ G=Female$ "  " $ G=Jewish $" " $ G= Catholic $" , pattern(1 0 0 0 1 0 0 0 1 0 0 0) ///
	prefix(\multicolumn{@span}{c}{) suffix(}) ///
	span erepeat(\cmidrule(lr){@span}))

********************************************************************************;
********************************************************************************;
// Part 8: Using Gallup and GSS Data for Triple Interaction Results

*Use Gallup_and_gss_extrayears and create census weights
use "$input/gallup_and_gss_extrayears.dta", clear 
keep if svy_type==1 
keep if race==1 & noprez<. & svy_year<. 
do "$do/make_gallup_cen_wgts"

*** Change to svy_date fixed effects ;
summ svy_date 
gen i_svy_date = svy_date - `r(min)' 

capture program drop meanvar
program meanvar 
	sum `e(depvar)' if e(sample)==1 [aw `e(wexp)'] 
	estadd scalar dvar=`r(mean)' 
end 

*************************Democratic Dwnominate instead of After**************************************
* Appendix Table A.5: Main triple-interaction results, using Democratic legislators' average 
* voting scores in place of After binary variable

*Only columns (1)-(4) & (7) of the larger set of columns from below

*All Democrats, DW2 - House
eststo clear
preserve
generate congress = 85 if svy_year >=1957 & svy_year<=1958
forvalues i=86/96 {	
	local j=`i'-86
	replace congress = `i' if svy_year>=1959 +2*`j'& svy_year<=1960+2*`j'
}

merge m:1 congress using "$input/dwnominate_democrats_house.dta"

gen conf_dw1 = confed*mean_dim1 if !missing(confed) & !missing(mean_dim1)
gen conf_dw2 = confed*mean_dim2 if !missing(confed) & !missing(mean_dim2)
gen conf_diff_dw1 = confed*diff_dim1 if !missing(confed) & !missing(diff_dim1)
gen conf_diff_dw2 = confed*diff_dim2 if !missing(confed) & !missing(diff_dim2)


foreach var of varlist noprez {
	gen `var'_dw1 = mean_dim1*`var' if !missing(mean_dim1) & !missing(`var')
	gen conf_`var'_dw1 = confed*`var'*mean_dim1 if !missing(confed) & !missing(`var') & !missing(mean_dim1)
	gen `var'_dw2 = mean_dim2*`var' if !missing(mean_dim2) & !missing(`var')
	gen conf_`var'_dw2 = confed*`var'*mean_dim2 if !missing(confed) & !missing(`var') & !missing(mean_dim2)
	gen `var'_diff_dw1 = diff_dim1*`var' if !missing(diff_dim1) & !missing(`var')
	gen conf_`var'_diff_dw1 = confed*`var'*diff_dim1 if !missing(confed) & !missing(`var') & !missing(diff_dim1)
	gen `var'_diff_dw2 = diff_dim2*`var' if !missing(diff_dim2) & !missing(`var')
	gen conf_`var'_diff_dw2 = confed*`var'*diff_dim2 if !missing(confed) & !missing(`var') & !missing(diff_dim2)
}

lab var mean_dim1 "DW-Nominate 1"
lab var mean_dim2 "DW-Nominate 2"
lab var conf_dw1 "South x DW1" 
lab var conf_noprez_dw1 "South x No Bl prez x DW1" 
lab var noprez_dw1 "No Bl prez x DW1"
lab var conf_dw2 "South x DW2" 
lab var conf_noprez_dw2 "South x No Bl prez x DW2" 
lab var noprez_dw2 "No Bl prez x DW2"
lab var diff_dim1 "Diff DW-1"
lab var diff_dim2 "Diff DW-2"
lab var conf_diff_dw1 "South x Diff DW-1"
lab var conf_diff_dw2 "South x Diff DW-2"
lab var noprez_diff_dw1 "No Bl prez x Diff DW-1"
lab var noprez_diff_dw2 "No Bl prez x Diff DW-2"
lab var conf_noprez_diff_dw1 "South x No Bl prez x Diff DW-1" 
lab var conf_noprez_diff_dw2 "South x No Bl prez x Diff DW-2" 

eststo: reg dem  conf_dw2 noprez conf_noprez noprez_dw2 ///
	conf_noprez_dw2 i.state i.i_svy_date if race==1 & svy_year<=1980 & svy_type==1 [pw=cen2_wgt], cl(state) 
	
	meanvar
	estadd local gss "No" 
	estadd local Controls "No" 
	estadd local interact "No" 
	estadd local max_yr "1980" 
	estadd local state_fe "Yes" 
	estadd local state_yr "No" 
	estadd local democrats "All"
	estadd local congress "House"

tempfile allhouse
save "`allhouse'"
	
*All Democrats, DW2 - Senate
drop mean_dim1-conf_noprez_diff_dw2
merge m:1 congress using "$input/dwnominate_democrats_senate.dta"

gen conf_dw1 = confed*mean_dim1 if !missing(confed) & !missing(mean_dim1)
gen conf_dw2 = confed*mean_dim2 if !missing(confed) & !missing(mean_dim2)
gen conf_diff_dw1 = confed*diff_dim1 if !missing(confed) & !missing(diff_dim1)
gen conf_diff_dw2 = confed*diff_dim2 if !missing(confed) & !missing(diff_dim2)

foreach var of varlist noprez {
	gen `var'_dw1 = mean_dim1*`var' if !missing(mean_dim1) & !missing(`var')
	gen conf_`var'_dw1 = confed*`var'*mean_dim1 if !missing(confed) & !missing(`var') & !missing(mean_dim1)
	gen `var'_dw2 = mean_dim2*`var' if !missing(mean_dim2) & !missing(`var')
	gen conf_`var'_dw2 = confed*`var'*mean_dim2 if !missing(confed) & !missing(`var') & !missing(mean_dim2)
	gen `var'_diff_dw1 = diff_dim1*`var' if !missing(diff_dim1) & !missing(`var')
	gen conf_`var'_diff_dw1 = confed*`var'*diff_dim1 if !missing(confed) & !missing(`var') & !missing(diff_dim1)
	gen `var'_diff_dw2 = diff_dim2*`var' if !missing(diff_dim2) & !missing(`var')
	gen conf_`var'_diff_dw2 = confed*`var'*diff_dim2 if !missing(confed) & !missing(`var') & !missing(diff_dim2)
}

lab var mean_dim1 "DW-Nominate 1"
lab var mean_dim2 "DW-Nominate 2"
lab var conf_dw1 "South x DW1" 
lab var conf_noprez_dw1 "South x No Bl prez x DW1" 
lab var noprez_dw1 "No Bl prez x DW1"
lab var conf_dw2 "South x DW2" 
lab var conf_noprez_dw2 "South x No Bl prez x DW2" 
lab var noprez_dw2 "No Bl prez x DW2"
lab var diff_dim1 "Diff DW-1"
lab var diff_dim2 "Diff DW-2"
lab var conf_diff_dw1 "South x Diff DW-1"
lab var conf_diff_dw2 "South x Diff DW-2"
lab var noprez_diff_dw1 "No Bl prez x Diff DW-1"
lab var noprez_diff_dw2 "No Bl prez x Diff DW-2"
lab var conf_noprez_diff_dw1 "South x No Bl prez x Diff DW-1" 
lab var conf_noprez_diff_dw2 "South x No Bl prez x Diff DW-2" 

eststo: reg dem conf_dw2 noprez conf_noprez noprez_dw2 conf_noprez_dw2  ///
	  i.state i.i_svy_date if race==1 & svy_year<=1980 & svy_type==1 [pw=cen2_wgt], cl(state) 
	
	meanvar
	estadd local gss "No" 
	estadd local Controls "No" 
	estadd local interact "No" 
	estadd local max_yr "1980" 
	estadd local state_fe "Yes" 
	estadd local state_yr "No" 
	estadd local democrats "All"
	estadd local congress "Senate"	
	
tempfile allsenate
save "`allsenate'"
	
*All Democrats, DW1, DW2 - House
use `allhouse', clear

eststo: reg dem  conf_dw2 noprez conf_noprez noprez_dw2 conf_noprez_dw2 i.i_svy_date ///
	 mean_dim1 conf_dw1 noprez_dw1 conf_noprez_dw1 i.state if race==1 & svy_year<=1980 & svy_type==1 [pw=cen2_wgt], cl(state) 
	
	meanvar
	estadd local gss "No" 
	estadd local Controls "No" 
	estadd local interact "No" 
	estadd local max_yr "1980" 
	estadd local state_fe "Yes" 
	estadd local state_yr "No" 
	estadd local democrats "All"
	estadd local congress "House"
	
*All Democrats, DW2 - Senate
use `allsenate', clear

eststo: reg dem  conf_dw2 noprez conf_noprez noprez_dw2 conf_noprez_dw2 ///
	mean_dim1 conf_dw1 noprez_dw1 conf_noprez_dw1 i.state i.i_svy_date if race==1 & svy_year<=1980 & svy_type==1 [pw=cen2_wgt], cl(state) 
	
	meanvar
	estadd local gss "No" 
	estadd local Controls "No" 
	estadd local interact "No" 
	estadd local max_yr "1980" 
	estadd local state_fe "Yes" 
	estadd local state_yr "No" 
	estadd local democrats "All"
	estadd local congress "Senate"
	
*Non-South Democrats, DW1, DW2 - House
*Non-south Democrats, DW2 - House
drop mean_dim1-conf_noprez_diff_dw2
merge m:1 congress using "$input/dwnominate_north_house.dta"

gen conf_dw1 = confed*mean_dim1 if !missing(confed) & !missing(mean_dim1)
gen conf_dw2 = confed*mean_dim2 if !missing(confed) & !missing(mean_dim2)
gen conf_diff_dw1 = confed*diff_dim1 if !missing(confed) & !missing(diff_dim1)
gen conf_diff_dw2 = confed*diff_dim2 if !missing(confed) & !missing(diff_dim2)

foreach var of varlist noprez {
	gen `var'_dw1 = mean_dim1*`var' if !missing(mean_dim1) & !missing(`var')
	gen conf_`var'_dw1 = confed*`var'*mean_dim1 if !missing(confed) & !missing(`var') & !missing(mean_dim1)
	gen `var'_dw2 = mean_dim2*`var' if !missing(mean_dim2) & !missing(`var')
	gen conf_`var'_dw2 = confed*`var'*mean_dim2 if !missing(confed) & !missing(`var') & !missing(mean_dim2)
	gen `var'_diff_dw1 = diff_dim1*`var' if !missing(diff_dim1) & !missing(`var')
	gen conf_`var'_diff_dw1 = confed*`var'*diff_dim1 if !missing(confed) & !missing(`var') & !missing(diff_dim1)
	gen `var'_diff_dw2 = diff_dim2*`var' if !missing(diff_dim2) & !missing(`var')
	gen conf_`var'_diff_dw2 = confed*`var'*diff_dim2 if !missing(confed) & !missing(`var') & !missing(diff_dim2)
}

lab var mean_dim1 "DW-Nominate 1"
lab var mean_dim2 "DW-Nominate 2"
lab var conf_dw1 "South x DW1" 
lab var conf_noprez_dw1 "South x No Bl prez x DW1" 
lab var noprez_dw1 "No Bl prez x DW1"
lab var conf_dw2 "South x DW2" 
lab var conf_noprez_dw2 "South x No Bl prez x DW2" 
lab var noprez_dw2 "No Bl prez x DW2"
lab var diff_dim1 "Diff DW-1"
lab var diff_dim2 "Diff DW-2"
lab var conf_diff_dw1 "South x Diff DW-1"
lab var conf_diff_dw2 "South x Diff DW-2"
lab var noprez_diff_dw1 "No Bl prez x Diff DW-1"
lab var noprez_diff_dw2 "No Bl prez x Diff DW-2"
lab var conf_noprez_diff_dw1 "South x No Bl prez x Diff DW-1" 
lab var conf_noprez_diff_dw2 "South x No Bl prez x Diff DW-2" 


eststo: reg dem mean_dim2 conf_dw2 noprez conf_noprez noprez_dw2 conf_noprez_dw2 ///
	mean_dim1 conf_dw1 noprez_dw1 conf_noprez_dw1 i.state if race==1 & svy_year<=1980 & svy_type==1 [pw=cen2_wgt], cl(state) 
	meanvar
	estadd local gss "No" 
	estadd local Controls "No" 
	estadd local interact "No" 
	estadd local max_yr "1980" 
	estadd local state_fe "Yes" 
	estadd local state_yr "No" 
	estadd local democrats "Non-south"
	estadd local congress "House"

#delimit ;
esttab est1 est2 est3 est4 using "$tables/tab_dw_nom.tex", replace fragment booktabs 
keep(conf_dw1 conf_dw2 noprez conf_noprez noprez_dw1 noprez_dw2 conf_noprez_dw1 conf_noprez_dw2)
nostar se brackets nomtitles label varwidth(30) wrap
mgroups("Dep't var.: Identifies as Democrat", pattern(1 0 0 0)
prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
stats(dvar congress N, label("Mean, dep't var." "Chamber used for DW-nom. scores" "Observations")) ;



*******************************************************************************;
*******************************************************************************;
// Part 9: Using Gallup and GSS Data for Robutsness Check on Weights

#delimit ;
use "$input/gallup_and_GSS_extrayears.dta", clear ;
keep if race==1 ;
keep if svy_type==1 ;

*** svy_date fixed effects ;
summ svy_date ;
gen i_svy_date = svy_date - `r(min)' ;

capture program drop meanvar ;
program meanvar ;
	sum `e(depvar)' if e(sample)==1 [aw `e(wexp)'] ;
	estadd scalar dvar=`r(mean)' ;
end ;


*******************************************************************************;
* Appendix Table A.8: Main triple-interaction results under various weighting and clustering schemes;
*******************************************************************************;
eststo clear ; 
eststo: reg dem conf_aft i.i_svy_date i.state if race==1 & svy_year<=1980 & noprez~=. & svy_type==1 [pw=weight_scaled], cl(state) ;
	meanvar;
	estadd local gss "No" ;
	estadd local interact "No" ;
	estadd local Controls "No" ;
	estadd local max_yr "1980" ;
	estadd local state_fe "Yes" ;
	estadd local bootstr "No" ;

eststo: reg dem conf_aft noprez conf_noprez noprez_aft conf_noprez_aft i.i_svy_date i.state if race==1 & svy_year<=1980 & svy_type==1 [pw=weight_scaled], cl(state) ;
	meanvar;
	estadd local gss "No" ;
	estadd local Controls "No" ;
	estadd local interact "No" ;
	estadd local max_yr "1980" ;
	estadd local state_fe "Yes" ;
	estadd local bootstr "No" ;

replace dup_weight=1 if svy_year<1961 | svy_year>1967 ;
replace tag_dups=1 if svy_year<1961 | svy_year>1967 ;
gen weight_scaled_dups=weight_scaled*dup_weight ;

****USING GALLUP WEIGHTS WHENEVER POSSIBLE AND OTHERWISE NO WEIGHTING. CORRECT FOR DUPLICATES ;		
	eststo: reg dem conf_aft i.i_svy_date i.state if race==1 & svy_year<=1980 & noprez~=. & svy_type==1 & tag_dups==1 [pw=weight_scaled_dups] , cl(state) ;
	meanvar;
	estadd local gss "No" ;
	estadd local interact "No" ;
	estadd local Controls "No" ;
	estadd local max_yr "1980" ;
	estadd local state_fe "Yes" ;
	estadd local bootstr "No" ;

	eststo: reg dem conf_aft noprez conf_noprez noprez_aft conf_noprez_aft i.i_svy_date i.state if race==1 & svy_year<=1980 & svy_type==1 & tag_dups==1 [pw=weight_scaled_dups] , cl(state) ;
	meanvar;
	estadd local gss "No" ;
	estadd local Controls "No" ;
	estadd local interact "No" ;
	estadd local max_yr "1980" ;
	estadd local state_fe "Yes" ;
	estadd local bootstr "No" ;

		
*******NO WEIGHTING ;
**** i.e., drop duplicates and do not use any weights ;
gen all_one=1 ;	
	
eststo: reg dem conf_aft i.i_svy_date i.state if race==1 & svy_year<=1980 & noprez~=. & svy_type==1 & tag_dups==1 [pw=all_one]  , cl(state) ;
	meanvar;
	estadd local gss "No" ;
	estadd local interact "No" ;
	estadd local Controls "No" ;
	estadd local max_yr "1980" ;
	estadd local state_fe "Yes" ;
	estadd local bootstr "No" ;

eststo: reg dem conf_aft noprez conf_noprez noprez_aft conf_noprez_aft i.i_svy_date i.state if race==1 & svy_year<=1980 & svy_type==1 & tag_dups==1 [pw=all_one]  , cl(state) ;
	meanvar;
	estadd local gss "No" ;
	estadd local Controls "No" ;
	estadd local interact "No" ;
	estadd local max_yr "1980" ;
	estadd local state_fe "Yes" ;
	estadd local bootstr "No" ;
	
******Now generate Census weights ;
do "$do/make_gallup_cen_wgts" ;	
	
******** MAIN REGS WITH CENSUS WEIGHTS ;
eststo: reg dem conf_aft i.i_svy_date i.state if race==1 & svy_year<=1980 & noprez~=. & svy_type==1 & tag_dups==1 [pw=cen2_wgt]  , cl(state) ;
	meanvar;
	estadd local gss "No" ;
	estadd local interact "No" ;
	estadd local Controls "No" ;
	estadd local max_yr "1980" ;
	estadd local state_fe "Yes" ;
	estadd local bootstr "No" ;

eststo: reg dem conf_aft noprez conf_noprez noprez_aft conf_noprez_aft i.i_svy_date i.state if race==1 & svy_year<=1980 & svy_type==1 & tag_dups==1 [pw=cen2_wgt]  , cl(state) ;
	meanvar;
	estadd local gss "No" ;
	estadd local Controls "No" ;
	estadd local interact "No" ;
	estadd local max_yr "1980" ;
	estadd local state_fe "Yes" ;
	estadd local bootstr "No" ;

*******Add to this table robustness to alternative clustering ;
***First, need to manually add meanvar, as otherwise it will just take the mean of a randomly selected sample from the bootstrap ;
qui reg dem conf_aft i.i_svy_date i.state if race==1 & svy_year<=1980 & noprez~=. & svy_type==1 & tag_dups==1 [pw=all_one]  , cl(state)	 ;
qui sum dem if e(sample)==1 ;
local mean_temp=`r(mean)' ;

local reps=200 ;

eststo: areg dem confed conf_aft i.state if race==1 & svy_year<=1980 & noprez~=. & svy_type==1 , abs(i_svy_date) vce(bootstrap,  reps(`reps') seed(123) cluster(i_svy_date))     ;
	*meanvar;
	estadd local gss "No" ;
	estadd local interact "No" ;
	estadd local Controls "No" ;
	estadd local max_yr "1980" ;
	estadd local state_fe "Yes" ;
	estadd local bootstr "Yes" ;
	estadd scalar dvar=`mean_temp' ;	
	
eststo: areg dem  confed conf_aft noprez conf_noprez noprez_aft conf_noprez_aft i.state if race==1 & svy_year<=1980 & svy_type==1 , abs(i_svy_date) vce(bootstrap,  reps(`reps') seed(123) cluster(i_svy_date))  ;
	*meanvar;
	estadd local gss "No" ;
	estadd local Controls "No" ;
	estadd local interact "No" ;
	estadd local max_yr "1980" ;
	estadd local state_fe "Yes" ;
	estadd local bootstr "Yes" ;
	estadd scalar dvar=`mean_temp' ;	
	
esttab est3 est4 est5 est6 est7 est8 est9 est10 using  "$tables/main_result_wgts.tex" , replace fragment booktabs keep(conf_aft noprez conf_noprez noprez_aft conf_noprez_aft) nostar se brackets 
mgroups("Gallup wts." "Unweighted" "Census weights" "Clust. by svy.",
pattern(1 0   1 0   1 0   1 0  1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) nomtitles label varwidth(20) wrap
stats(dvar state_fe max_yr bootstr N, label("Mean, dept. var." "State FE?" "Max year in sample" "St. errs. bootstrapped?" "Observations")) ;
    
#d cr
*******************************************************************************;
*******************************************************************************;
// Part 10: Using Gallup and GSS Data for Graphs 
	
*** Preliminaries & Programs
clear
cap program drop _all

/*******************************************************************************
Appendix Figure A.12: Coefficient from regressing Democratic identi cation on No-
CatholicPrez ; by region and year (whites in Gallup)
*******************************************************************************/

program fig6 
	args spec wgt name
	
	* Calculate and store coefficients
	tab svy_date if `spec' ~=. & `wgt'<. & dem<., matrow(bodie)
	local max `r(r)'
	
	cap drop coeff_*
	forval c=0/1 {
		gen coeff_`spec'_confed`c' = .
		forval x = 1/`max' {
			reg dem `spec' if confed == `c' & svy_date == bodie[`x',1] & race == 1 [pw=`wgt']
			replace coeff_`spec'_confed`c' = _b[`spec'] if svy_date == bodie[`x',1]
		}
	}
	
	matrix drop bodie
	sort svy_date
	*cap drop tag
	egen tag = tag(svy_date)
	
	* Get min and max year for x-axis
	local spec = "noCathPrez"
	*summ svy_year if !missing(`spec')
	local minyear 1958
	local maxyear 1980
	
	* Graph
	format svy_date %tdCCYY
	#delimit ;
	twoway (connect coeff_`spec'* svy_date, m(circle_hollow triangle_hollow) mlw (thin thin) msize(medium medium) mc(blue red) lc(blue red) lp(solid dash) lw(thin thin))
		if tag==1 & inrange(svy_year,`minyear',`maxyear') , 
		legend(on order(2 1) label(1 "Non-South") label(2 "South") position(2) rows(2) ring(0) region(lstyle(none))) 
		xti("") yti("Coefficient value") xlabel(#4)
		scheme(aspen) xline(1096) ;
	
	graph export "$figures/dem_reg_`name'.pdf", replace ;
	#delimit cr
	drop tag
	
end

*** Data
use "$input/gallup_and_GSS_extrayears.dta", clear

lookfor dup
gen noCathPrez = cathPres != 1 if !missing(cathPres)

fig6 noCathPrez weight_scaled noCath_old_wgts

sum highschool

***Keep only years in the sample
keep if noCathPrez<.
keep if race==1
keep if svy_year<1980

do "$do/make_gallup_cen_wgts"

fig6 noCathPrez cen2_wgt noCath_cen_wgts

**********************************************************************************************************
// Appendix Figure A2: Percent of respondents identifying Civil Rights as the nation's most important issue

*Most important issue over time
import excel "$path/Input/Additional/Most_Imp_Problem_Civil_Rights.xlsx", ///
	sheet("Most Important Problem CR") firstrow clear

format BeginDate %tddd_Mon_YY
g begindm=mofd(BeginDate)
format begindm %tmMon_ccYY

graph twoway scatter pct_saying_cr_1 begindm , ///
	mcolor(navy) msymbol(o) msize(big) name(approach_most_imp_pb, replace) ///
	xtitle("") scheme(aspen) ///
	ytitle(Percent of respondents, size(medium)) ymlabel(, labsize(medium))  xmlabel(#7, angle(45) labsize(medium)) xlabel("")

graph export "$figures/approach_most_imp_pb.pdf", replace




