*********************************************************************************************************
// Why did the Democrats Lose the South? Bringing New Data to an Old Debate, Kuziemko & Washington (2018)
// This do file creates the main tables and graphs when using Media Data
// Note: Some of this tables and graphs required merging with Gallup Data (they are not available for publication). 
clear all
set more off
set matsize 11000
set maxvar 15000


if "`c(username)'"=="kuziemko"  {
cap cd ~/Dropbox/southern_strategy
global path ~/Dropbox/southern_strategy/Replication
global output "$path/Output"
global input "$path/Input/Media"
global add "$path/Input/Additional"
global do "$path/DoFiles"
}


else if "`c(username)'"=="fvivar" { 

cap cd ~/Dropbox/southern_strategy
global path ~/Dropbox/southern_strategy/Replication
global output "$path/Output"
global input "$path/Input/Media"
global add "$path/Input/Additional"
global do "$path/DoFiles"
}


else if "`c(username)'"=="falba" { 

cap cd "C:\Users\falba\Dropbox\southern_strategy"
global path "C:\Users\falba\Dropbox\southern_strategy\Replication\"
global output "$path/Output"
global do "$path/DoFiles"
global gallup "$path/DoFiles"
global input "$path/Input/Media"
global add "$path/Input/Additional"
}


****Programs 
program devmean 
	sum `e(depvar)' if e(sample)==1 [aw `e(wexp)']
	estadd scalar devmean=`r(mean)' 
end 

********************************************************************************
** 						     IMPORT CONTENT ANALYSIS			  			  **
********************************************************************************

* RA files (denoated by their initials, cm and ka)
local RAs	"cm ka"
foreach RA of local RAs {
	
	/// Set up temp file, import excel file
	tempfile temp_`RA'
	import excel "$input/jfk_nyt_content_analysis_`RA'.xlsx", ///
		firstrow clear
	cap drop E

	/// Format date variable
	tostring Date, gen(Date_str)
	gen date_stata = date(Date_str,"YMD")
	format date_stata %td
	order date_stata
	drop Date Date_str

	/// Generate indicators of content categories
	tab Response, gen(response_)
	rename response_1 A_`RA'
	rename response_2 F_`RA'
	rename response_3 M_`RA'
	rename response_4 P_`RA'
	
	/// Save file
	save "`temp_`RA''", replace
}

* Merge files
merge 1:1 date_stata Headline using `temp_cm'
drop _merge
tempfile temp
save `temp', replace

* Import narrowform articles
import excel "$input/jfk_nyt_content_analysis_narrowform.xlsx", ///
	firstrow clear
gen narrow = 1
drop Response

/// Format date variable
tostring Date, gen(Date_str)
gen date_stata = date(Date_str,"YMD")
format date_stata %td
order date_stata
drop Date Date_str

* Merge with RA files & clean
merge 1:1 date_stata Headline using `temp'
drop _merge
replace narrow = 0 if missing(narrow)
drop Headline URL Response

* Generate narrow and broad datasets for analysis later
/// Narrow
preserve
tempfile temp_narrow
keep if narrow == 1
drop narrow
collapse (sum) A* F* M* P*, by(date_stata)
tsset date_stata
tsfill
foreach x of varlist A_ka-P_cm {
	replace `x' = 0 if missing(`x')
}
gen pro = (P_cm + P_ka)/2
gen anti = (A_cm + A_ka)/2
gen mixed = (M_cm + M_ka)/2
foreach x of varlist pro anti mixed A* F* M* P* {
	tssmooth ma smooth_`x' = `x', window(3 1 3)
}
save `temp_narrow'
save "$input/ra_coding_articles_narrow", replace

restore

/// Broad
tempfile temp_broad
drop narrow
collapse (sum) A* F* M* P*, by(date_stata)
tsset date_stata
tsfill
foreach x of varlist A_ka-P_cm {
	replace `x' = 0 if missing(`x')
}
gen pro = (P_cm + P_ka)/2
gen anti = (A_cm + A_ka)/2
gen mixed = (M_cm + M_ka)/2
foreach x of varlist pro anti mixed A* F* M* P* {
	tssmooth ma smooth_`x' = `x', window(3 1 3)
}
save `temp_broad'
save $input/ra_coding_articles_broad, replace


/// Create table of summary statistics on broad set of articles
/// Note: need to manually change column header for total average

* Total hits:
gen total = A_cm + F_cm + M_cm + P_cm
gen total2 = A_ka + F_ka + M_ka + P_ka
egen total_N = sum(total)
egen total2_N = sum(total2)
tab total_N if _n == _N
tab total2_N if _n == _N

preserve
reshape long A F M P, i(date_stata) j(j) string
rename j ra

* Labels for table
replace ra = "Daily Average (RA1)" if ra == "_cm" 
replace ra = "Daily Average (RA2)" if ra == "_ka"

label var A "Anti"
label var F "False positive"
label var M "Mixed"
label var P "Pro"

estpost tabstat A F M P, by(ra) columns(statistics) 
esttab using "$output/jfk_nyt_stats.tex", ///
	cell(mean(fmt(a3))) replace fragment unstack ///
	label nomtitles noobs nonum nogap 
esttab using "$output/jfk_nyt_stats.tex", ///
	cell(mean(fmt(a3))) replace fragment unstack ///
	label nomtitles noobs nonum collabels(none)
restore

* Import new negro hits
/// Import RA coding
import excel "$input/negro_new_hits (version 1).xls", clear firstrow
tostring Date, replace
gen date_stata = date(Date, "YMD")
rename Classification classification
tempfile temp_negro
save `temp_negro', replace

/// Import full list of Negro articles (these don't have RA coding)
import delim "$input/Search2.csv", clear varnames(1)
tostring date, replace
gen date_stata = date(date, "YMD")
rename headline Headline
rename url URL
merge 1:1 date_stata Headline using `temp_negro'
keep date_stata Headline URL classification

/// Merge with existing classifications to get classifications for the other negro articles
merge 1:1 date_stata Headline using `temp', keep(1 3)
replace classification = Response if missing(classification)
drop Response
rename classification Response
keep date Response Headline URL 

/// Create counts of each classification
tab Response, gen(r_)
rename r_1 A
rename r_2 F
rename r_3 M
rename r_4 P
collapse (sum) A F M P, by(date_stata)
gen anti = A
gen pro = P
gen mixed = M

/// Smooth variables
tsset date_stata
tsfill
foreach var of varlist anti pro mixed A F M P{
	replace `var' = 0 if missing(`var')
	tssmooth ma smooth_`var' = `var', window(3 1 3)
}
save `temp_negro', replace

foreach type in narrow broad negro {
	* Import data on presidential approval and merge with content analysis
	do "$do/media_datamaker.do" jfk "" "3 1 3"

	merge m:1 date_stata using `temp_`type''
	tab _merge
	drop _merge

	* Label variables (for regression tables)
	la var smooth_pro "Pro"
	la var smooth_anti "Anti"
	la var smooth_mixed "Mixed"
	la var confed "Conf"
	
	saveold "$input/RA_coding_`type'.dta", replace
}
*/

********************************************************************************
** 					 SEPARATE ANALYSIS FOR EACH RA			  		  **
********************************************************************************

eststo clear
*** Broad/Narrow
local filetypes "broad narrow"
local RAs	"cm ka"
foreach RA of local RAs {
	foreach type of local filetypes {
		use "$input/RA_coding_`type'.dta", clear
		
		* Rename content dummy vars to make a cleaner table
		rename smooth_A_`RA' smooth_A
		rename smooth_F_`RA' smooth_F
		rename smooth_M_`RA' smooth_M
		rename smooth_P_`RA' smooth_P
		
		* Label variables for regression table
		la var smooth_A "Anti"
		la var smooth_F "False Positive"
		la var smooth_P "Pro"
		la var smooth_M "Mixed"
		
		* Regression
		eststo: reg approve_01 smooth_A smooth_F smooth_M smooth_P ///
			c.confed#c.smooth_A ///
			c.confed#c.smooth_F ///
			c.confed#c.smooth_M ///
			c.confed#c.smooth_P ///
			i.state ///
			if race == 1 [pw=weight_scaled], cluster(date)
		sum approve_01 if e(sample) == 1 [aw=weight_scaled]
		estadd scalar Mean = r(mean)
		if "`type'" == "broad" {
			local title = "Civil Rights Terms" 
		}
		else if "`type'" == "narrow" {
			local title = "Civil Rights"
		}
		estadd local Search "`title'"
	}
}

*** Negro (Only one set of RA coding available)
use "$input/RA_coding_negro.dta", clear

* Label variables for regression table
la var smooth_A "Anti"
la var smooth_F "False Positive"
la var smooth_P "Pro"
la var smooth_M "Mixed"
		
* Regression
eststo: reg approve_01 smooth_A smooth_F smooth_M smooth_P ///
			c.confed#c.smooth_A ///
			c.confed#c.smooth_F ///
			c.confed#c.smooth_M ///
			c.confed#c.smooth_P ///
			i.state ///
			if race == 1 [pw=weight_scaled], cluster(date)
		sum approve_01 if e(sample) == 1 [aw=weight_scaled]
		estadd scalar Mean = r(mean)
		estadd local Search "Negro"

*** Compile Table 
lab var confed "South"
esttab using "$output/media_additional_analysis_js_2.tex", ///
	replace se label wrap varwidth(15) nomtitles fragment booktabs noconstant nonotes star(* .1 ** .05 *** .01) ///
	keep(smooth_* c.confed#c.smooth_*) ///
	scalars(Search Mean) brackets ///
	mgroups(RA1 RA2, pattern(1 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))


********************************************************************************
********************************************************************************
// Part 1: JFK Analysis  

#delimit ;

do "$do/media_datamaker.do" jfk keep "3 1 3" ;
********************************************************************************;
* Figure 4: Count of NYT articles mentioning President Kennedy and Civil Rights terms ;
********************************************************************************;
***Format dates ;
format date_stata %tdMon_YY ;

graph twoway 
		(bar smooth_hits2 date_stata,  color(khaki) lw(thin) barw(.1)) 
		(line smooth_hits1 date_stata,  lcolor(blue) lpattern(solid) lwidth(medthin) ) 
		(pcarrowi 0 502 7.5 502, lcolor(red) mlw(vthin) lw(vthin)  msize(zero)) 
		(pcarrowi 0 1002.5 9.5 1002.5, lcolor(red) mcolor(black) lw(vthin)  msize(zero) legend(off)) 
		(pcarrowi 0 1218 7 1218, lcolor(red) mcolor(black) msize(zero) legend(off)) 
		(pcarrowi 0 1257 11.5 1257, lcolor(red) mcolor(black) msize(zero) legend(off)) 
		if date_stata>=date("1/20/1961", "MDY") & date_stata<=date("11/22/1963", "MDY"),
		text(8.4 506 "Freedom Riders", place(e) size(small)) 
		text(7.9 506 "May 21: JFK dispatched federal", place(e) size(vsmall)) 
		text(7.4 506 "marshals to protect", place(e) size(vsmall)) 
		text(6.9 506 "protestors in Alabama", place(e) size(vsmall)) 
		text(10 1007 "James Meredith", place(e) size(small)) 
		text(9.5 1007 "Sept 30: Ole Miss riots", place(e) size(vsmall)) 
		text(9 1007 "quelled by federal soldiers", place(e) size(vsmall)) 
		text(7.5 1216 "Birmingham", place(w) size(small)) 
		text(7 1216 "May 3: Bull Connor uses", place(w) size(vsmall)) 
		text(6.5 1216 "hoses, dogs v. protestors", place(w) size(vsmall)) 
		text(11.7 1261 "JFK TV address", place(e) size(small)) 
		text(11.2 1261 "June 11: Announces", place(e) size(vsmall)) 
		text(10.7 1261 "Civil Rights bill", place(e) size(vsmall)) 
		name(media_`prez'_1and2, replace) 
		tlabel(`rule',  angle(35) nogrid) 
		ytitle("Article Count") ylabel(0(2)12, axis(1)  nogrid) xti("") 
		xlabel(#10) 
		plotregion(style(none) lcolor(black)) graphregion(style(none) lcolor(white) fcolor(white)) scheme(aspen) 
		legend(on symx(*.5) order(1 2) cols(1) label(1 "Civil rights terms") label(2 `" "Civil Rights" "') pos(11) ring(0) region(lstyle(none))) scale(1.1)
		xsize(13) ysize(7);

graph export "$output/jfk_events.pdf", replace ;

*******************************************************************************;
* Figure 8: Predicted vs. actual regional approval differences for Kennedy (whites in Gallup) ;
*******************************************************************************;
****Do "share explained" analysis using RA coding ;

local filetypes "broad negro";

foreach type of local filetypes {;

	***Load file;
	use "$input/RA_coding_`type'.dta", clear;
	
	*****Do census weights ;
	keep if race==1 ;
	do "$do/make_gallup_cen_wgts.do" ;

	***Generate necessary variables;
	qui tab state, gen(sss) ;
	cap drop temp ;
	cap gen conf_smooth_pro = confed*smooth_pro;

	gen conf_smooth_anti=confed*smooth_anti ;

	***Generate actual means by South x Date ;
		egen temp=mean(approve_01) if race==1, by(svy_date confed) ;
		egen actual_cell=mean(temp), by(svy_date confed) ;
		drop temp ;

	***Generate predicted differences by South x Date ;
	/// No RA coding (using the broad measure - "civil rights")  ;
		qui reg approve_01 conf_smooth_hits2 smooth_hits2 sss* if race == 1;
		qui predict predict_noRA if e(sample) == 1 ;
		qui egen temp= mean(predict_noRA), by(svy_date confed) ;
		qui egen predict_noRA_cell = mean(temp), by(svy_date confed) ;
			#d;
		drop temp;

	/// RA Coding ;
		qui reg approve_01 conf_smooth_pro conf_smooth_anti smooth_anti smooth_pro sss*  if race==1  ;
		qui predict predict_RA  if e(sample)==1 ;
		qui egen temp=mean(predict_RA), by(svy_date confed) ;
		qui egen predict_RA_cell=mean(temp), by(svy_date confed) ;
		drop temp ;

		#d;
	/// Do a third regression that includes mixed as a regressor;
	gen conf_smooth_mixed = confed*smooth_mixed ;

		qui reg approve_01 conf_smooth_pro conf_smooth_anti conf_smooth_mixed
			smooth_anti smooth_pro smooth_mixed sss* if race == 1 ;
		qui predict predict_RA2 if e(sample) == 1 ;
		qui egen temp = mean(predict_RA2), by(svy_date confed);
		qui egen predict_RA2_cell = mean(temp), by(svy_date confed); 
		drop temp;

	sum predict_noRA_cell ;
	sum predict_RA_cell ;
	sum predict_RA2_cell ;
			
	****Generate actual and predicted South-nonSouth diffs by date ;
	foreach cat in actual predict_noRA predict_RA predict_RA2 { ;
		forval x=0/1 { ;
			qui egen temp=mean(`cat'_cell) if confed==`x', by(svy_date) ;
			qui egen `cat'_conf`x'=mean(temp), by(svy_date) ;
			drop temp ;
			} ; 
		qui gen `cat'_diff=`cat'_conf1 - `cat'_conf0 ;
		} ;


	egen tag=tag(svy_date) ;

	**** Graphs ;
	format svy_date %tdMon_YY;

	#d;
	twoway (connect predict_RA_diff predict_noRA_diff actual_diff svy_date, 
	m(circle_hollow triangle_hollow none) mc(red blue green) lc(red blue green) mlw(thin thin medthin) lw(thin thin medthin) msize(medium medium medium)) 
	 if tag == 1, scheme(aspen) scale(1.2)
		legend(
		on order(3 2 1) label(3 "Actual difference (South minus non-South)") label(2 "Predicted difference (no RA coding)") label(1 "Predicted difference (RA coding)") rows(3) ring(0) pos(7) region(lstyle(none))
		) 
		xti("") xsize(6) tlabel(#10, angle(35) nogrid) yti("Approval difference (South minus non-South)") ;
	graph export "$output/graph_media_analysis_RA_share_explained_`type'.png", replace;

};

cap log close;

#delimit cr

********************************************************************************
* Appendix Table A.10: Whites' approval of Kennedy as a function of NYT Civil Rights articles, 1961 to 1963 (additional regressions)
********************************************************************************
*** PREPARE DATA
* Merge JFK searches with MLK/Repub searches
do "$do/media_datamaker.do" jfk "" "3 1 3"
merge m:1 date using $input/mlk_republican_merged.dta
drop _merge

* Fix variable labels
local prefix " " "smooth_"
foreach p of local prefix {
	la var `p'hits1 "Civil Rights + JFK"
	la var `p'hits2 "Civil Rights Terms + JFK"
	la var `p'hits3 "Negro + JFK"
}

*****Do census weights 
	keep if race==1 
	run "$do/make_gallup_cen_wgts.do" 

*** REGRESSION TABLE
eststo clear
// Create "fakename" variable to save space
gen fakename=smooth_hits1
gen fakename_conf = conf_smooth_hits1
// Create new date variable w/o negative values (factor variables may not contain negative values)
summ date
local min = `r(min)'
gen date2 = date - `min'


** Col. (1): just being a repeat of Col. (2) of Table 4 in the paper (as a baseline).
eststo:  areg approve_01 fakename_conf conf_smooth_placebo_2 - conf_smooth_placebo_10 ///
	i.date2 if race==1 [pw=cen2_wgt], abs(state) cl(date2)
devmean
estadd local fe_date "Yes" 
estadd local ra_coding "No" 
estadd local placebo "Yes" 
estadd local depvar2 "Approval"
estadd local trend "No"
estadd local frac "Count"
estadd local events "No"

** Col. (2): Repeat of col. (2) Table 4 with South time trend
eststo:  areg approve_01 fakename_conf conf_smooth_placebo_2 - conf_smooth_placebo_10 ///
	i.date2##confed if race==1 [pw=cen2_wgt], abs(state) cl(date2)
devmean
estadd local fe_date "Yes" 
estadd local ra_coding "No" 
estadd local placebo "Yes" 
estadd local depvar2 "Approval"
estadd local trend "Yes"
estadd local frac "Count"
estadd local events "No"

** Col. (3): Repeat of col. (2) Table 4 using share of articles
preserve

* Prep data
local prez = "jfk"
import delimited "$input/`prez'ArticleCount.csv", clear
tostring date, gen(datestr)
gen date_stata = date(datestr,"YMD")
format date_stata %tdDD_Mon_YY
rename hits totalcount
tsset date_stata
tssmooth ma smooth_totalcount = totalcount, window(3 1 3)
tempfile `prez'totals
save ``prez'totals', replace
qui do "$do/media_datamaker.do" `prez' "" "3 1 3"
merge m:1 date_stata using ``prez'totals', nogenerate keep(1 3)
foreach var of varlist smooth_hits* conf_smooth_hits* smooth_placebo* conf_smooth_placebo* {
	replace `var' = `var'/smooth_totalcount
	}
	
* Gen non-negative date var
summ date
local min = `r(min)'
gen date2 = date - `min'

* fakename var
gen fakename=smooth_hits1
gen fakename_conf = conf_smooth_hits1

*****Do census weights 
	keep if race==1 
	run "$do/make_gallup_cen_wgts.do" 

* Regression
eststo:  areg approve_01 fakename_conf conf_smooth_placebo_2 - conf_smooth_placebo_10 ///
	i.date2 if race==1 [pw=cen2_wgt], abs(state) cl(date2)
devmean
estadd local fe_date "Yes" 
estadd local ra_coding "No" 
estadd local placebo "Yes" 
estadd local depvar2 "Approval"
estadd local trend "No"
estadd local frac "Share"
estadd local events "No"

restore

** Col. (4) add to that specification South x Civil Rights
* Gen south x civil rights variable
gen conf_smooth_hits_g1 = confed*smooth_hits_g1

* Regression
eststo:  areg approve_01 fakename_conf conf_smooth_placebo_2 - conf_smooth_placebo_10 ///
	i.date2 conf_smooth_hits_g1 if race==1 [pw=cen2_wgt], abs(state) cl(date2)
devmean
estadd local fe_date "Yes" 
estadd local ra_coding "No" 
estadd local placebo "Yes" 
estadd local depvar2 "Approval"
estadd local trend "No"
estadd local frac "Count"
estadd local events "No"


** Col. (5) add to col. (1) South x (Civil Rights + MLK)
* Gen South x (Civil Rights + MLK) variable
gen conf_smooth_hits_m1 = confed*smooth_hits_m1

* Regression
eststo:  areg approve_01 fakename_conf conf_smooth_placebo_2 - conf_smooth_placebo_10 ///
	i.date2 conf_smooth_hits_m1 if race==1 [pw=cen2_wgt], abs(state) cl(date2)
devmean
estadd local fe_date "Yes" 
estadd local ra_coding "No" 
estadd local placebo "Yes" 
estadd local depvar2 "Approval"
estadd local trend "No"
estadd local frac "Count"
estadd local events "No"

** Col. (6) add to col. (1) South x (Civil Rights + Republican)
* Gen South x (Civil Rights + Republican) variable
gen conf_smooth_hits_r1 = confed*smooth_hits_r1

* Regression
eststo:  areg approve_01 fakename_conf conf_smooth_placebo_2 - conf_smooth_placebo_10 ///
	i.date2 conf_smooth_hits_r1 if race==1 [pw=cen2_wgt], abs(state) cl(date2)
devmean
estadd local fe_date "Yes" 
estadd local ra_coding "No" 
estadd local placebo "Yes" 
estadd local depvar2 "Approval"
estadd local trend "No"
estadd local frac "Count"
estadd local events "No"

****Drop state/dates where *actual* demonstrations occurred **** 
*****Key events in JFK's adminstriation  ****
* Detroit Walk to Freedom, June 23, 1963 in Detroit, Michigan 
* March on Washington for Jobs and Freedom: Wednesday, August 28, 1963, DC 
* Albany campaign: https://en.wikipedia.org/wiki/Albany_Movement, Nov 1 1961 - July 1962 
* Birmingham campaign: April 1963 - June 1963 
* Largest Freedom Ride started in DC and ended in MS (DC, VA, NC, SC, GA, Al, MS) all in May 1961 
* Integration of Ole Miss: Sept & Oct 1962 
* Integration of U Alabama: Jun 1964 (already covered by Birmingham) 

************************************************************************
gen events=0 
**Detroit 
replace events=1 if svy_year==1963 & month(svy_date)==6 & state==32 
**Wash DC 
replace events=1 if svy_year==1963 & month(svy_date)==8 & state==27 
**Albany 
replace events=1 if svy_year==1961 & month(svy_date)>10 & month(svy_date)<13 & state==54 
replace events=1 if svy_year==1962 & month(svy_date)<8 & state==54 
**Birmingham 
replace events=1 if svy_year==1963 & month(svy_date)>3 & month(svy_date)<7 & state==58 
**Freedom ride 
replace events=1 if svy_year==1961 & month(svy_date)==5 & (state==51 | state==52 | state==53 | state==54 | state==58 | state==59) 
***Ole Miss 
replace events=1 if svy_year==1962 & (month(svy_date)==9 | month(svy_date)==10) & state==59 
***B'ham church bomging
replace events=1 if svy_year==1963 & month(svy_date)==9 & state==58

***Repeat baseline Col. (2) but dropping any state/date with a key event 

eststo:  areg approve_01 fakename_conf conf_smooth_placebo_2 - conf_smooth_placebo_10 ///
	i.date2 if race==1 & event==0 [pw=cen2_wgt], abs(state) cl(date2)
devmean
estadd local fe_date "Yes" 
estadd local ra_coding "No" 
estadd local placebo "Yes" 
estadd local depvar2 "Approval"
estadd local trend "No"
estadd local frac "Count"
estadd local events "Yes"

** Col. (7) And then repeat of col. (2) table 4 using dem ID as outcome
eststo:  areg dem fakename_conf conf_smooth_placebo_2 - conf_smooth_placebo_10 ///
	i.date2 if race==1 [pw=cen2_wgt], abs(state) cl(date2)
devmean
estadd local fe_date "Yes" 
estadd local ra_coding "No" 
estadd local placebo "Yes" 
estadd local depvar2 "Dem"
estadd local trend "No"
estadd local frac "Count"
estadd local events "No"


**** OUTPUT TABLE
la var fakename "JFK + Civil Rights" 
la var fakename_conf "South x (JFK + Civ. Rts.)" 
la var conf_smooth_hits_g1	"South x Civ. Rts."
la var conf_smooth_hits_m1	"South x (Civ. Rts. + MLK)"
la var conf_smooth_hits_r1	"South x (Civ. Rts. + Republican)"

#d;
	esttab using "$output/tab4_consolidated.tex", fragment replace booktabs se brackets 
	keep(fakename_conf conf_smooth_hits_?1) 
	order(fakename_conf conf_smooth_hits_?1)
	stats(devmean trend frac events N, 
	label("Mean, dept. var." "South time trend" 
	"Article measure" "Drop key events?" "Observations")) 
	nomtitles wrap label varwidth(17)
	star(* .1 ** .05 *** .01) 
	mgroups("Approval" "Dem ID", pattern(1 0 0   0 0 0   0 1) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}));

********************************************************************************
********************************************************************************
* Part 2: JFK Approval 
clear 
do "$do/media_datamaker.do" "jfk" keep "3 1 3"

****Original weighting 
#delimit ;
***Drop non-whites in Gallup;
drop if svy_year<. & race~=1 ;
egen app_sum_old_wgt = wtmean(approve_01) , weight(weight_scaled) by(svy_date confed) ;

forval c=0/1 { ;
	gen temp = app_sum_old_wgt if confed==`c' ;
	egen app_sum_conf`c'_old_wgt=mean(temp), by(svy_date) ;
	drop temp ;
	} ;

egen tag=tag(date_stata) ;	
format date_stata %tdMon_YY ;
gen diff_old_wgt=app_sum_conf1_old_wgt - app_sum_conf0_old_wgt ;

sort date_stata ;
merge date_stata using $input/ra_coding_articles_broad.dta ;
tab _merge ;
drop _merge ;

gen conf_smooth_pro = confed*smooth_pro ;	
	

****Parse var labels to rename ;
forval x=2/10 { ;
local temp: var l conf_smooth_placebo_`x' ;
local new_label=subinstr("`temp'", "x Placebo:", "x", 1) + " articles"  ;
label var conf_smooth_placebo_`x' "`new_label'" ;
} ;

des conf_smooth_placebo* ;

****To save space, generate a "fakename" variable and substitute each of the different searches for it ;
gen fakename=smooth_hits1 ;
gen fakename_conf = conf_smooth_hits1 ;

***We will first need to save all the media info as they will get dropped (as they don't have stuff we weight on) by the census-weights program ;

preserve ;
keep date_stata *smooth* *placebo* ;
egen tag=tag(date_stata) ;
keep if tag==1 ;
drop tag ;
sort date_stata ;
tempfile media_to_merge ;
save `media_to_merge' ;
restore ;

do "$gallup/make_gallup_cen_wgts" ;

sort date_stata ;
merge date_stata using `media_to_merge' ;
egen app_sum_cen_wgt = wtmean(approve_01) , weight(cen2_wgt) by(svy_date confed) ;

forval c=0/1 { ;
	gen temp = app_sum_cen_wgt if confed==`c' ;
	egen app_sum_conf`c'_cen_wgt=mean(temp), by(svy_date) ;
	drop temp ;
	} ;

drop tag ;
egen tag=tag(date_stata) ;		
format date_stata %tdMon_YY ;
gen diff_cen_wgt=app_sum_conf1_cen_wgt - app_sum_conf0_cen_wgt ;

*******************************************************************************;
* Figure 7: Whites approval of Kennedy versus articles linking him to Civil Rights;
*******************************************************************************;
#delimit ;
twoway (bar smooth_hits2 date_stata, yaxis(1) yscale(off) color(khaki) barwidth(0.05) lw(vthin))
(connect app_sum_conf1_cen_wgt app_sum_conf0_cen_wgt date_stata if tag==1, yaxis(2) mc(red blue) lc(red blue)  ) 
(line diff_cen_wgt date_stata  if tag==1, lw(medium) lc(green) lp(solid) yscale(alt axis(3)) yaxis(3) ) 
 if date_stata>date("1/20/1961", "MDY") , yline(0, axis(3) lc(gs8) lp(dash))
xti("") xlabel(#10, angle(45)) scheme(aspen)
yti("Share approving", axis(2))  yscale(titlegap(2) axis(2) ) yti("Difference (South minus non-South)", axis(3))
legend(on label(2 "South") label(3 "Non-South") label(4 "Difference") label (1 "Article Count") order( 2 3 4 1) symx(*.5) rows(1))  ;

graph export "$output/jfk_approval_cen_wgts.png", replace ;
graph export "$output/jfk_approval_cen_wgts.pdf", replace ;

*******************************************************************************;
* Table 2: Approval of Kennedy as function of Civil Rights coverage (whites in Gallup) ;
*******************************************************************************;
eststo clear ;
cap program drop dvmean ;
program dvmean ;
qui sum `e(depvar)' if e(sample)==1 [aw `e(wexp)'] ;
estadd scalar dvmean = `r(mean)' ;
end ;

replace fakename=smooth_hits1 ;
replace fakename_conf = conf_smooth_hits1 ;


* Column 1 ;
eststo:  areg approve_01 fakename fakename_conf if race==1 [pw=cen2_wgt], abs(state) cl(date) ;
dvmean ;
estadd local fe_date "No" ;
estadd local ra_coding "No" ;
estadd local placebo "No";

* Column 2 ;
eststo:  areg approve_01 fakename_conf conf_smooth_placebo_2 - conf_smooth_placebo_10 i.date if race==1 [pw=cen2_wgt], abs(state) cl(date) ;
dvmean ;
estadd local fe_date "Yes" ;
estadd local ra_coding "No" ;
estadd local placebo "Yes" ;

replace fakename_conf=conf_smooth_hits2 ;

* Column 3 ;
eststo:  areg approve_01 fakename_conf conf_smooth_placebo_2 - conf_smooth_placebo_10 i.date if race==1 [pw=cen2_wgt], abs(state) cl(date) ;
dvmean ;
estadd local fe_date "Yes" ;
estadd local ra_coding "No" ;
estadd local placebo "Yes" ;

replace fakename_conf=conf_smooth_pro ;

* Column 4 ;
eststo:  areg approve_01 fakename_conf conf_smooth_placebo_2 - conf_smooth_placebo_10 i.date if race==1 [pw=cen2_wgt], abs(state) cl(date) ;
dvmean ;
estadd local fe_date "Yes" ;
estadd local ra_coding "Yes" ;
estadd local placebo "Yes" ;

replace fakename_conf=conf_smooth_hits3 ;

* Column 5;
eststo:  areg approve_01 fakename_conf conf_smooth_placebo_2 - conf_smooth_placebo_10 i.date if race==1 [pw=cen2_wgt], abs(state) cl(date) ;
dvmean ;
estadd local fe_date "Yes" ;
estadd local ra_coding "No" ;
estadd local placebo "Yes" ;

label var fakename "Article count" ;
label var fakename_conf "Article count x South" ;

esttab using "$output/jfk_nyt_main_cen_wgts.tex", fragment replace booktabs se brackets 
keep(fakename fakename_conf conf_smooth_placebo_*) 
order(fakename fakename_conf conf_smooth_placebo_*) 
stats(dvmean fe_date ra_coding N, label("Mean, dept. var." "Survey date FE?" "RA coding?" "Observations")) 
nomtitles wrap label varwidth(25)
star(* .1 ** .05 *** .01)  ;

#delimit cr

********************************************************************************
********************************************************************************
* Part 3: Eisenhower Analysis 

*** MONTHLY GRAPHS ***
clear
foreach x in 4 3 2 {
	clear
	import excel "$input/Southern Strategy Newspapers CR Keyword Search 11.9.2014 - Tim.xlsx", sheet("`x'") firstrow case(lower)
	tempfile `x'
	save ``x'', replace
	}

clear
import excel "$input/Southern Strategy Newspapers CR Keyword Search 11.9.2014 - Tim.xlsx", sheet("1") firstrow case(lower)
append using `2' `3' `4'

drop month
egen month = seq(), f(1) t(12)
gen year=1963
gen date = ym(year, month) 
format %tmMon date
drop month year

encode newspaper,gen(papers)

forval paper=1/4 {
	#delimit;
	graph twoway bar
		results date if papers==`paper', color(blue) barwidth(0.8)
		name(media_monthly_`paper', replace)
		xtitle("") xlabel(#12, nogrid angle(45))
		ytitle("") ylabel(,  nogrid) 
		plotregion(style(none) lcolor(black)) graphregion(style(none) lcolor(white) fcolor(white)) scale(*1.8) xsize(6.5);
	#delimit cr
	graph export "$output/media_monthly_`paper'.png", replace
	window manage close graph _all
	}

	
clear
import excel "$input/Southern Strategy Newspapers CR Keyword Search 11.9.2014 - Tim.xlsx", sheet("5") firstrow case(lower)
gen date = mofd(month)
format %tmMon_YY date

	#delimit;
	graph twoway bar
		results date, color(gs9) barwidth(0.8)
		name(media_monthly_5, replace)
		xtitle(Month, size(small)) xlabel(#12, labsize(small) nogrid)
		ytitle("", size(small)) ylabel(, labsize(small) nogrid) 
		plotregion(style(none) lcolor(black)) graphregion(style(none) lcolor(white) fcolor(white));
	#delimit cr
	graph export "$output/media_monthly_5.png", replace
	window manage close graph _all

*** ANNUAL GRAPHS ***
use "$input/years_1.26.2015.dta", clear
rename startYear_endYear year
reshape wide hits, j(search) i(year)

forval i=1/3 {
	#delimit;
	graph twoway
		bar hits`i' year, color(gs7) barwidth(0.8)
		name(media_annual_`i', replace)
		xtitle(Year, size(small)) xlabel(1945(5)1980, labsize(small) nogrid)
		ytitle("", size(small)) ylabel(, labsize(small) nogrid) 
		plotregion(style(none) lcolor(black)) graphregion(style(none) lcolor(white) fcolor(white));
	#delimit cr
	graph export "$output/media_annual_`i'.png", replace
	window manage close graph _all
	} 

#delimit;
graph twoway
	(bar hits2 year, legend(lab(1 "Civil Rights and Segregation and Integration")) color(gs10) barwidth(0.8))
	(bar hits1 year, legend(lab(2 "Civil Rights")) lwidth(medthick) lcolor(black) fcolor(black) barwidth(0.8)),
	name(media_annual_1and2, replace)
	xtitle(Year, size(small)) xlabel(1945(5)1980, labsize(small) nogrid)
	ytitle("", size(small)) ylabel(, labsize(small) nogrid) 
	plotregion(style(none) lcolor(black)) graphregion(style(none) lcolor(white) fcolor(white))
	legend(on cols(2) size(small));
#delimit cr
graph export "$output/media_annual_1and2.png", replace
window manage close graph _all

*** DAILY GRAPHS ***
* Key dates for axis labels
local freedomrides = date("01may1961", "DMY")
local olemiss = date("29sep1962", "DMY")
local birmingham = date("01may1963", "DMY")
local craddress = date("11june1963", "DMY")
local lilrock = date("23sep1957", "DMY")
local ikeelec = date("06nov1956", "DMY")
local cra57 = date("09sep1957", "DMY")

* Graphs
#delimit ;

foreach prez in ike  { ;
do "$do/media_datamaker.do" `prez' keep "3 1 3" ; 
format date_stata %tdMon_YY ;

collapse (mean) approve_01 smooth_hits*, by(date_stata confed race) ;
bys date_stata race (confed): gen diff = approve_01[2] - approve_01[1] ;

local min = date_stata[1] ;
local max = date_stata[_N] ;
if "`prez'"=="ike" { ;
	local increment = 150 ;
	local rule = "#12" ;
	local range = "-2523(100)323" ;
	} ;
	
	graph twoway
		(bar smooth_hits2 date_stata,  color(khaki) lw(thin) barw(.1))
		(line smooth_hits1 date_stata,  lcolor(blue) lpattern(solid) lwidth(medthin) ),
		name(media_`prez'_1and2, replace)
		tlabel(`rule',  angle(35) nogrid)
		ytitle("Article Count") ylabel(0(2)10, axis(1)  nogrid) xti("")
		plotregion(style(none) lcolor(black)) graphregion(style(none) lcolor(white) fcolor(white)) scheme(aspen)
		legend(on cols(1) label(1 "Civil rights terms") label(2 `" "Civil Rights" "') pos(11) ring(0) region(lstyle(none))) scale(1.2) ;
	graph export "$output/media_`prez'_1and2_ik.png", replace ;
} ;
	

*****THE FORMATTING BELOW IS ESPECIALLY DESIGNED FOR IKE ;	

********************************************************************************;
* Appendix Figure A.16: Regional differences in whites' approval of Eisenhower (South minus non-South) versus articles linking him to Civil Rights ;
********************************************************************************;

local date=date("7/1/1953", "MDY") ;
local ike_date "`date'" ;

foreach m in 4 10 { ;
forval y=1954/1960 { ;
local date=date("`m'/1/`y'", "MDY") ;	
local ike_date "`ike_date' `date'" ;
} ;
} ;

di "`ike_date'" ;		

foreach prez in ike  { ;
	
forval i=1/3 { ;
	graph twoway
		(bar smooth_hits`i' date_stata, yaxis(1) color(khaki) barwidth(0.1) lw(thin))
		(connected diff date_stata if race==1, yaxis(2) lcolor(maroon) lpattern(solid) lwidth(medium) mcolor(maroon) msymbol(oh) mlw(thin))
		`arrows',
		name(media_`prez'_`i', replace)
		xtitle("") tlabel(`ike_date', angle(45) nogrid) xsize(7)
		ytitle("Article Count", axis(1)  ) ylabel(, axis(1)   nogrid) 
		ytitle("Difference in Approval (South minus non-South)", axis(2))  ylabel(, axis(2)  nogrid) 
		scheme(aspen) scale(1.1)
		legend(
		lab(1 "Article Count") lab(2 "Approval Difference" "(South minus Non-South)") order(1 2) on cols(1) ring(0) pos(9) symx(*.4) region(lstyle(none))
		);
	graph export "$output/media_`prez'_`i'`saveoption'_ik.png", replace ;
		
	} ;

} ;

#delimit cr

**********************************************************************************************
** Appendix Table A.19: White approval of Eisenhower as a function of Civil Rights coverage**
**********************************************************************************************
clear
local j = 1

foreach prez in ike  {

qui do "$do/media_datamaker.do" `prez' "" "3 1 3"

***Referee doesn't like the name "placebo" search, so do some work to rename all these var labels 

foreach var of varlist conf_smooth_placebo_* {
local temp: var label `var'
**Get rid of words " South x Placebo: " plus spaces, which should be first 17 characters 
local temp=substr("`temp'", 18, .)
di "`temp'"
label var `var' "South x `temp' articles"
}

des conf_smooth_placebo*

* Set full list of placebo labels for -esttab-
local list_placebo = "smooth_placebo_2 "
local list_placebo_int = "conf_smooth_placebo_2 "

if "`prez'"=="ike" local numhitvars=12
if "`prez'"=="jfk" local numhitvars=10
if "`prez'"=="lbj" local numhitvars=13

forval x=3/`numhitvars' {
	local list_placebo = "`list_placebo'" + "smooth_placebo_`x' "
	local list_placebo_int = "`list_placebo_int'" + "conf_smooth_placebo_`x' "
	}

*** ACTUAL REGRESSIONS FOR DRAFT PAPER ***

local outcome = "approve_01"
local subset = "race==1"

eststo clear
	
forval i=1/3 {

	* Define specifications
	local x1 = "smooth_hits`i' conf_smooth_hits`i'"
	local x2 = "conf_smooth_hits`i' `list_placebo' `list_placebo_int'"

	* Columns 1, 3, 5
	eststo: reg `outcome' `x1' i.state if `subset' [pw=weight_scaled], cluster(date)
	sum `outcome' if e(sample) == 1 [aw=weight_scaled]
	estadd scalar Mean = r(mean)
	estadd local sdatefe "No"
	estadd local Placebo "No"
	estadd local Period "Full"
	
	* Columns 2, 4, 6
	eststo: reg `outcome' `x2' i.state i.date if `subset' [pw=weight_scaled], cluster(date)
	sum `outcome' if e(sample) == 1 [aw=weight_scaled]
	estadd scalar Mean = r(mean)
	estadd local sdatefe "Yes"
	estadd local Period "Full"
	
	* Additional column for Kennedy as a diagnostic (pre-May 1963)
	if "`j'"=="3" {
	eststo: reg `outcome' `x2' i.state i.date if `subset' & svy_date<=date("01may1963","DMY") [pw=weight_scaled], cluster(date)
	sum `outcome' if e(sample) == 1 [aw=weight_scaled]
	estadd scalar Mean = r(mean)
	estadd local sdatefe "Yes"
	estadd local Period "Pre"
	}
	
	}

if "`j'"=="3" local period = "Period"
else local period = ""

****Ike table is too long to fit on page without tiny font, so this version shrinks gaps between coefficients 

if `j'==1 { 

#delimit ;

esttab using "$output/media_output_`prez'`period'_nogaps.tex", replace se label wrap varwidth(22) nomtitle fragment
	cells(b(fmt(a3) star) se(par([ ] ) ) ) collabels(none) nogap
	rename(smooth_hits1 article_count conf_smooth_hits1 conf_article_count 
	smooth_hits2 article_count conf_smooth_hits2 conf_article_count
	smooth_hits3 article_count conf_smooth_hits3 conf_article_count)
	varlabel(article_count "Article count" conf_article_count "South x Article count", end([3pt]))
	keep(article_count conf_article_count `list_placebo_int')
	order(article_count conf_article_count `list_placebo_int')
	booktabs nocons stats(Mean sdatefe N, label("Dept. var. mean" "Survey date FE?" "Observations")) star(* .1 ** .05 *** .01) ;
#delimit cr

local j = `j' + 1
}
}
********************************************************************************
********************************************************************************
* Part 4: Truman Analysis

clear
* Smoothing window
local smooth_option = "3 1 3" 

* Default is to drop newspaper search data from dates outside of Gallup surveys
local keep = "3"	// this is the "keep" option in the merge command; 3 = matched

global begin_office = "12apr1945"
global end_office = "20jan1953"


********************************************************************************
**					 PREPARE TRUMAN MEDIA HITS DATA						  **
********************************************************************************

*** MEDIA HITS DATA
* Import and merge media hits variables
local files "CivilRights CRIntegSegreg Negro"
local counter = 1	// for naming the "hits" variable;
					// (hits1 = civil rights; hits2 = civil rights terms; hits3 = negro)

foreach file of local files {

	disp "`file'"
	disp "`counter'"
	import delim "$input/trumanhits`file'.csv", delim(",") clear

	* Create Stata Date Variable
	tostring articledate, replace
	gen date = date(articledate,"YMD")
	drop articledate

	* Rename vars according to Kennedy convention 
	rename hits hits`counter'
	local counter = `counter' + 1

	* Save / merge
	if "`file'" == "CivilRights" {
		tempfile temp
		save `temp', replace
	}
	else {
		merge 1:1 date using `temp'
		drop _merge
		save `temp', replace
	}
}

* Missing vars means no hits; replace with zero
tsset date
tsfill
forval i = 1/3 {
	replace hits`i' = 0 if missing(hits`i')
}

* Label variables
cap lab var hits1 "Civil Rights"
cap lab var hits2 "Civil Rights Terms"
cap lab var hits3 "Negro"

* Smooth hits variables
tsset date
foreach var of varlist hits* {
	tssmooth ma smooth_`var'=`var', window(`smooth_option')
	local l_`var' : variable label `var'
	lab var smooth_`var' "`l_`var''"
}

* Rename date variable for merging with gallup data
rename date svy_date
save `temp', replace

********************************************************************************
**					  PREPARE PLACEBO DATA & MERGE 						  **
********************************************************************************
/*

Placebo topics: 

1) war, peace, “atomic bomb,” “Hydrogen bomb,” security, defense, foreign policy, international relations, international  tensions army, navy, air force
2) crime, juvenile delinquency, narcotics, murder
3) russia, soviet, soviets, russian, ussr, cold war
4) communism, socialism, communist, socialist
5) tax, taxes, budget, taxation
6) Employment, recession, unemployment, cost of living, wages, inflation, prices, depression
7) Social security, social services, welfare, old age, poor, Education, veterans 
8) farm, agriculture, agricultural, irrigation, flood control
9) Korea
10) highways, Transportation, roads, traffic, airplanes
11) Labor, strikes, unions, taft-hartley, management
12) Controls, shortages, veterans
13) Corruption, graft, scandal
14) China

*/

* Import hits & merge with media hits variables
forval i = 1/14 {

	* Import file; create date, placebo variables
	import delim "$input/fullSearch`i'", clear
	tostring articledate, replace
	gen svy_date = date(articledate,"YMD")
	keep svy_date
	gen placebo_`i' = 1
	collapse (sum) placebo_`i', by(svy_date)
	
	* Replace missing values as 0
	tsset svy_date
	tsfill
	replace placebo_`i' = 0 if missing(placebo_`i')
	
	* Merge
	merge 1:1 svy_date using `temp'
	drop _merge
	save `temp', replace
}

* Label variables
label var placebo_1 "Placebo: Foreign Policy, War"
label var placebo_2 "Placebo: Crime, Drugs"
label var placebo_3 "Placebo: USSR"
label var placebo_4 "Placebo: Communism, Socialism"
label var placebo_5 "Placebo: Taxes, Budget"
label var placebo_6 "Placebo: Employment"
label var placebo_7 "Placebo: Social Security"
label var placebo_8 "Placebo: Agriculture"
label var placebo_9 "Placebo: Korea"
label var placebo_10 "Placebo: Transportation"
label var placebo_11 "Placebo: Labor Unions"
label var placebo_12 "Placebo: Controls, Shortages, Veterans"
label var placebo_13 "Placebo: Corruption, Scandal"
label var placebo_14 "Placebo: China" 

* Smooth 
tsset svy_date
foreach var of varlist placebo* {
	tssmooth ma smooth_`var' = `var', window(`smooth_option')
	local l_`var' : variable label `var'
	lab var smooth_`var' "`l_`var''"
}

keep svy_date smooth*
save `temp', replace

*** MERGE WITH GALLUP DATA
use "$path/Input/gallup_and_gss_extrayears.dta", clear

* Merge with media hits data
merge m:1 svy_date using `temp', keep("`keep'")

* Drop dates outside the president's administration
keep if svy_date>=date("$begin_office","DMY") & svy_date<=date("$end_office","DMY")


********************************************************************************
**				 CREATE PREZ APPROVAL VARIABLE						  **
********************************************************************************

cap program drop prezApprovVars
program prezApprovVars
	* Encode head-to-head variables
	decode trumanDewey, gen(trumanDewey_str)
	decode trumanDeweyWallace, gen(trumanDeweyWallace_str)
	decode trumanDeweyWallaceThurmond_s, gen(trumanDeweyWallaceThurmond_str)

	* Gen vote intention variable
	gen would_vote_truman = . 

	replace would_vote_truman = (trumanDewey_str == "TRUMAN") if !missing(trumanDewey_str)
	replace would_vote_truman = (trumanDeweyWallace_str == "TRUMAN") if !missing(trumanDeweyWallace_str)
	replace would_vote_truman = (trumanDeweyWallaceThurmond_str == "TRUMAN") if !missing(trumanDeweyWallaceThurmond_str)

	* Create variables for regression
	gen approve_01 = (presApprovala==1) if !missing(presApprovala)
	lab var approve_01 "(0/1)"

	gen approve_123=1 if approve_01==1 
	replace approve_123=.5 if presApprovala==3 
	replace approve_123=0 if approve_01==0 
	lab var approve_123 "(0/0.5/1)"
end

prezApprovVars


* After
gen aft_truman = svy_date >= mdy(2,1,1948)
la var aft_truman "After 2/1/1948"

* Generate interactions with confed
foreach var of varlist aft_truman smooth_placebo* smooth_hits* {
	gen conf_`var' = confed * `var'
	local l_`var' : variable label `var'
	lab var conf_`var' "Conf x `l_`var''"
	}
	
* Create new date variable for FE (factor variables can't be negative)
summ svy_date 
gen date = svy_date - `r(min)'

********************************************************************************
*  FREQUENCY OF ARTICLES (CIVIL RIGHTS TERMS) V RELATIVE PRESIDENTIAL APPROVAL				  **
********************************************************************************

* Re-create dataset to include media hits that are NOT on survey dates
use $path/Input/gallup_and_gss_extrayears.dta, clear
prezApprovVars
merge m:1 svy_date using `temp', keep(2 3)
drop _merge

* Get means and reshape (need to do pres approval & media hits separately bc of weighting
/// pres approval
preserve
collapse (mean) approve_01 would_vote_truman dem [aw=weight_scaled] ///
	, by(svy_date confed race)
tempfile temp
save `temp', replace
restore

/// media
collapse (mean) smooth_hits*, by(svy_date)
merge 1:m svy_date using `temp'


* Gen difference variables
bys svy_date race (confed): gen diff_approve_01 = approve_01[2] - approve_01[1]
bys svy_date race (confed): gen diff_would_vote_truman = would_vote_truman[2] - would_vote_truman[1]
bys svy_date race (confed): gen diff_dem = dem[2] - dem[1]


* Graph inputs
local prez truman
local increment = 70
local rule = "#11"

/*****************************************************************************
* Appendix Figure A.13: White approval (South minus non-South) of Truman as a function
of NYT articles containing his name alongside Civil Rights terms

* Appendix Figure A.14: Share of whites (South minus non-South) who plan to vote for Truman
in 1948 election as a function of NYT articles containing his name alongside Civil Rights
terms
*****************************************************************************/

graph drop _all
format svy_date %tdMon_YY
local outcomes "approve_01 would_vote_truman dem"
foreach outcome of local outcomes {

*local lab: variable label smooth_hits`i'

	#delimit;
	graph twoway
		(area smooth_hits2 svy_date, yaxis(1) color(gs12) lc(gs12) lw(vthin))
		(area smooth_hits1 svy_date, yaxis(1) color(gs12*0.25) lc(gs12*0.25) lw(vthin) )
		(connected diff_`outcome' svy_date if race==1, yaxis(2) lcolor(red) lpattern(solid) lwidth(medium) mcolor(red) msymbol(oh) mlw(thin))
		if inrange(svy_date,date("$begin_office","DMY"),date("$end_office","DMY"))
		, name(media_`outcome'_`i', replace)
		/*title("`outcome'; `lab'", size(small))*/
		xti("") tlabel(#5,  angle(45) nogrid)
		ytitle("Article Count", axis(1)) ylabel(, axis(1)  nogrid) 
		ytitle("Difference (South minus non-South)", axis(2) ) ylabel(, axis(1)  nogrid)
		plotregion(style(none) lcolor(black)) graphregion(style(none) lcolor(white) fcolor(white))
		legend(lab(2 "Article Count (Civil Rights)") 
		lab(1 "Article Count (Civil Rights Terms)")
		lab(3 "Difference (South - Non-south)") order(2 1 3) on rows(3) pos(2) ring(0) symx(*.5) region(lstyle(none)) margin(zero)) scale(1.2) xsize(7);
	#delimit cr
	graph export "$output/media_`prez'_`outcome'_1_2_combined.png", replace

}


/*****************************************************************************
Appendix Figure A.15: Democratic identi cation among whites during Truman presidency
(vertical lines mark February 1948 Civil Rights message and June 1950 start of Korean War)
*****************************************************************************/

local feb011948 = mdy(2,1,1948)
local june251950 = mdy(6,25,1950)

#delimit;
	graph twoway 
	(connected dem svy_date if race == 1 & confed == 1, yaxis(1) color(maroon) lc(maroon) lw(vthin) mlw(thin) msymbol(oh))
	(connected dem svy_date if race == 1 & confed == 0, yaxis(1) color(navy) lc(navy) lw(vthin) mlw(thin) msymbol(dh))
	(line diff_dem svy_date if race == 1, yaxis(2) color(green) lc(dkgreen) lw(thin))
	, scheme(aspen) ytitle("Diff (South - Non-south)", axis(2) ) xtitle(Date,size(small))
	ytitle("Share of Dem ID", axis(1)) xline(`feb011948') xline(`june251950')
	legend(lab(1 "Dem ID, South") lab(2 "Dem ID, non-South")
	lab(3 "Diff in Dem ID, South - non-South") order(2 1 3) on rows(3));
#delimit cr

graph export "$output/truman_dem_diff_south_nonsouth.png", replace

********************************************************************************
********************************************************************************
// Additonal Analysis using Data from Voteview.com
clear
********************************
*** PROGRAM FOR ESTTAB FILES ***
********************************

program depmean 
qui sum `e(depvar)' if e(sample)==1 
estadd scalar depmean=`r(mean)'
end

program vote_var
gen any_yea = `1'<4 if `1'~=0 & `1'~=.
gen yea_pure =`1'==1 if `1'~=0 & `1'~=.
end

*** NOTES ***

*** Civil Rights Act of 1964 ***

	*CONGRESS   88th
	*HOUSE  	07/02/1964 : v182
	*SENATE 	06/19/1964 : v409

*** Voting Rights Act of 1965 ***

	*CONGRESS   89th
	*HOUSE  	08/03/1965 : v107
	*SENATE 	08/04/1965 : v178

*** Civil Rights Act of 1957 ***

	*CONGRESS   85th
	*HOUSE  	06/18/1957 : v42
	*SENATE 	08/07/1957 : v75

*** Civil Rights Act of 1960 ***
	
	*CONGRESS   86th
	*HOUSE  	04/21/1960 : v106
	*SENATE 	04/08/1960 : v284

*****************************************************************************************************************************************************


eststo clear 

****************
***	CRA 1957 ***
****************

*use House 85th roll call
use $add/hou85.dta, clear

*(1)
eststo: reg yea_pure democrat, cl(state)
depmean
estadd local branch = "House"
estadd local states "All"
estadd local state_fe "No"
estadd local yea_oth "Zero"
estadd local nea_oth "Zero"
estadd local abs_coded "Zero"
estadd local se_bs "No"  

*(2)
eststo: reg yea_pure democrat if south==1, vce(bootstrap,  reps(200) seed(123) cluster(state))
depmean
estadd local branch "House"
estadd local states "South"
estadd local state_fe "No"
estadd local yea_oth "Zero"
estadd local nea_oth "Zero"
estadd local abs_coded "Zero"
estadd local se_bs "Yes"  

*(3)
eststo: areg yea_pure democrat if south==1, abs(state) vce(bootstrap,  reps(200) seed(123) cluster(state))
depmean
estadd local branch "House"
estadd local states "South"
estadd local state_fe "Yes"
estadd local yea_oth "Zero"
estadd local nea_oth "Zero"
estadd local abs_coded "Zero"
estadd local se_bs "Yes"  



****************
***	CRA 1960 ***
****************

*use House 86th roll call
use $add/hou86.dta, clear

*(1)
eststo: reg yea_pure democrat, cl(state)
depmean
estadd local branch = "House"
estadd local states "All"
estadd local state_fe "No"
estadd local yea_oth "Zero"
estadd local nea_oth "Zero"
estadd local abs_coded "Zero"
estadd local se_bs "No"  

*(2)
eststo: reg yea_pure democrat if south==1, vce(bootstrap,  reps(200) seed(123) cluster(state))
depmean
estadd local branch "House"
estadd local states "South"
estadd local state_fe "No"
estadd local yea_oth "Zero"
estadd local nea_oth "Zero"
estadd local abs_coded "Zero"
estadd local se_bs "Yes"  

*(3)
eststo: areg yea_pure democrat if south==1, abs(state) vce(bootstrap,  reps(200) seed(123) cluster(state))
depmean
estadd local branch "House"
estadd local states "South"
estadd local state_fe "Yes"
estadd local yea_oth "Zero"
estadd local nea_oth "Zero"
estadd local abs_coded "Zero"
estadd local se_bs "Yes"  


****************
***	CRA 1964 ***
****************

*use House 88th roll call
use $add/hou88.dta, clear

*(1)
eststo: reg yea_pure democrat, cl(state)
depmean
estadd local branch = "House"
estadd local states "All"
estadd local state_fe "No"
estadd local yea_oth "Zero"
estadd local nea_oth "Zero"
estadd local abs_coded "Zero"
estadd local se_bs "No"  

*(2)
eststo: reg yea_pure democrat if south==1, vce(bootstrap,  reps(200) seed(123) cluster(state))
depmean
estadd local branch "House"
estadd local states "South"
estadd local state_fe "No"
estadd local yea_oth "Zero"
estadd local nea_oth "Zero"
estadd local abs_coded "Zero"
estadd local se_bs "Yes"  

*(3)
eststo: areg yea_pure democrat if south==1, abs(state) vce(bootstrap,  reps(200) seed(123) cluster(state))
depmean
estadd local branch "House"
estadd local states "South"
estadd local state_fe "Yes"
estadd local yea_oth "Zero"
estadd local nea_oth "Zero"
estadd local abs_coded "Zero"
estadd local se_bs "Yes"  

#delimit ;

label var south "South" ;
label var democrat "Democrat" ;

local est_cmd "keep(democrat) se brackets star(* .1 ** .05 *** .01) wrap label varwidth(18) nomtitles
stats(depmean states state_fe se_bs N, label("Dep. v. mean" "Regions" "State FE?" "BS st. errors?"  "Observations"))" ; 

esttab, `est_cmd'  ;

esttab using "$output/cra_votes.tex", replace fragment booktabs `est_cmd' 
mgroups("1957 CRA" "1960 CRA" "1964 CRA", pattern(1 0 0 1 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ;

