
*********************************************************************************************************
// Why did the Democrats Lose the South? Bringing New Data to an Old Debate, Kuziemko & Washington (2018)
// This do file cleans the ANES Raw Data

clear
clear matrix
clear mata
set more off
set maxvar 32767


else if "`c(username)'"=="kuziemko"  {
cap cd ~/Dropbox/southern_strategy
global path ~/Dropbox/southern_strategy/Replication
global output "$path/Output"
global input "$path/Input/Anes"
global do "$path/DoFiles"

}


else if "`c(username)'"=="fvivar" { 

cap cd ~/Dropbox/southern_strategy
global path ~/Dropbox/southern_strategy/Replication
global output "$path/Output"
global input "$path/Input/Anes"

}


use "$input/ANES_raw2008-1948.dta" ,clear
compress
capture noisily ssc inst oaxaca
/*******************************************************************************
Renaming and Generating Demographic and Geographic Variables
*******************************************************************************/

**The weight variable
/*
Comment on weights
						Type 0:		Type 1:		Type 2:
NOT POST-STRATIFIED: 	VCF0009 	VCF0010 	VCF0011
POST-STRATIFIED:		VCF0009a 	VCF0010a 	VCF0011a

Step 1) Determine if pre-election or post-election weights are needed, look at 
		the notes in the documentation that for the variable's post-1994 survey details
Step 2) If that variable is not missing in 1970, determine its type in 1970 by looking
		at the documentation, otherwise, use any of the types
*/

rename VCF0009 wgt_0np
label variable wgt_0np "Type 0 Not Post-Stratified Weight"
rename VCF0009A wgt_0ps
label variable wgt_0ps "Type 0 Post-Stratified Weight"
rename VCF0010 wgt_1np
label variable wgt_1np "Type 1 Not Post-Stratified Weight"
rename VCF0010A wgt_1ps
label variable wgt_1ps "Type 1 Post-Stratified Weight"
rename VCF0011 wgt_2np
label variable wgt_2np "Type 2 Not Post-Stratified Weight"
rename VCF0011A wgt_2ps
label variable wgt_2ps "Type 2 Post-Stratified Weight"
gen wgt = wgt_0ps //this is the current weight needed for all of our variables

**work flow variables

//Stata doesn't save local variables, so I'll use this to keep track of our 
//population groups
gen group = ""
label variable group "vector to store group variables"
gen popgroup = ""


**year
rename VCF0004 year
egen yr_id = tag(year)

**election year dummy variables
*presidential
local lc_prezelec 1948 1952 1956 1960 1964 1968 1972 1976 1980	1984 1988 1992 /// 
	1996 2000 2004 2008 2012
gen prezelecyr = 0
foreach val in `lc_prezelec'{
	replace prezelecyr = 1 if year == `val'
}

*midterm elections
local lc_mdyr 2006 2002 1998 1994 1990 1986 1982 1978 1974 1970 1966 1962 1958 ///
	1954 1950 
gen midtermyr = 0
foreach val in `lc_mdyr'{
	replace midtermyr = 1 if year == `val'
}

**State and Region
*state, alphabetical
rename VCF0901A state_n
label variable state_n "State Code- FIPS"

*state, numerical
rename VCF0901B state_a
label variable state_a "State Postal Abbrev"
replace state_a = "" if state_a == "99"
drop if state_a == "99"
drop if missing(state_a)
levelsof state_a, local(lc_state_a)

*creating a tag for each state

bysort year state_a : gen state_tag = _n 

*******Region
*North
local lc_north CT DE ME MA NH NJ NY PA RI VT
gen N = 0 if !missing(state_a)
label variable N "North"
foreach val in `lc_north'{
	replace N  = 1 if state_a == "`val'"
}

*South
local lc_south SC MS FL AL GA LA TX VA AR TN NC
gen S = 0 if !missing(state_a)
label variable S "South"
foreach val in `lc_south'{
	replace S  = 1 if state_a == "`val'"
}

gen NS = (S == 0) if !missing(S)

*Boarder
local lc_border DC KY OK MD WV
gen B = 0 if !missing(state_a)
label variable B "North/South border state"
foreach val in `lc_border' {
	replace B = 1 if state_a == "`val'" 
} 

*Deep South
local lc_dsouth AL GA LA MS SC
gen DS = 0 if !missing(state_a)
label variable DS "Deep South"
foreach val in `lc_dsouth'{
	replace DS  = 1 if state_a == "`val'"
}

*midwest 
local lc_midwest IL IN IA KS MI MN MO NE ND OH SD WI
gen M = 0 if !missing(state_a)
label variable M "Midwest"
foreach val in `lc_midwest'{
	replace M  = 1 if state_a == "`val'"
}

*West 
local lc_west AK AZ CA CO HI ID MT NV NM OR UT WA WY
gen W = 0 if !missing(state_a)
label variable W "West"
foreach val in `lc_west'{
	replace W  = 1 if state_a == "`val'"
}

*National
gen NT = 1

gen regionL = ""
label variable regionL "region, single letter"
local n = 1
foreach val in NT N S B M W {
	replace regionL = "`val'" if _n == `n'
	local n = `n' + 1
}

gen regionW = ""
label variable regionW "region, full word"
local n = 1
foreach val in US North South Border Midwest West {
	replace regionW = "`val'" if _n == `n'
	local n = `n' + 1
}

*state poverty data
sort year state_a 
merge m:m year state_a using "$path/Input/censuspov.dta"

drop if _merge == 2
drop if state_a == "HI" | state_a == "AK"
drop _merge
replace censuspov = censuspov/100

gen PNS = 0 
gen tempvar  = state_a if S == 0
levelsof(tempvar), local(nonsouth)
foreach st in `nonsouth' {
	//finding the min. year for which we have data for a state and determining
	//if its poverty rate is higher than the poorest Southern state in that year
	sum year if state_a == "`st'" & !missing(censuspov) 
	local minyr = r(min)
	sum censuspov if year == `minyr' & S == 1 & state_tag == 1
	local leastpoorSth = r(min)
	replace PNS = ((censuspov > `leastpoorSth')) if ((year == `minyr') & (state_a == "`st'"))
}
bysort state_a: egen PNS_a = max(PNS)
drop PNS
rename PNS_a PNS
label variable PNS "poor non-South states, 1960 base" 
drop tempvar
gen NPNS = (PNS == 0 & S == 0) if !missing(PNS) & !missing(S)
label variable NPNS "non-poor non-South states, 1960 base" 

gen SNSP = .
replace SNSP = 1 if S == 1
replace SNSP = 0 if S == 0 & PNS == 1
label variable SNSP "South or poor nonSouth"

**Demographic
*age
rename VCF0101 age
gen agelt40 = (age < 40) if !missing(age)
gen agegt40 = (age >= 40) if !missing(age)
label variable agelt40  "less than 40 years old"
label variable agegt40  "40 years old or older"
replace group = "agelt40" if _n == 1
replace group = "agegt40" if _n == 2
label define lbagelt40 0 "40yrs and older" 1 "Less than 40" 
label values agelt40 lbagelt40

gen elderly = (age >= 65) if !missing(age)
gen nelderly = (age < 65) if !missing(age)
replace popgroup = "elderly" if _n == 1
replace popgroup = "nelderly" if _n == 2

*gender
rename VCF0104 gender
gen male  = (gender == 1) if  !missing(gender)
gen fmale = (gender == 2) if  !missing(gender)
replace group = "male" if _n == 3
replace group = "fmale" if _n == 4

*race & ethnicity
rename VCF0106A race_eth
label variable race_eth "Racial or ethnic group"
gen blk = (race_eth == 2) if  !missing(race_eth)
gen wht = (race_eth == 1) if  !missing(race_eth)
gen hisp = (race_eth == 5) if  !missing(race_eth)
gen other = (race_eth == 3 | race_eth == 4 | race_eth == 7) if !missing(race_eth)
foreach race in wht blk {
	replace `race' = 0 if VCF0108 == 1
}
replace popgroup = "blk" if _n == 3
replace popgroup = "wht" if _n == 4
replace popgroup = "hisp" if _n == 5
replace popgroup = "other" if _n == 6


*family income
rename VCF0114 inc
label variable inc "Family income"
gen inc_0t16   = (inc == 1) if !missing(inc)
gen inc_17t33  = (inc == 2) if !missing(inc)
gen inc_34t67  = (inc == 3) if !missing(inc)
gen inc_68t95  = (inc == 4) if !missing(inc)
gen inc_96t100 = (inc == 5) if !missing(inc)
gen inc_0t33   = (inc == 1 | inc == 2) if !missing(inc)
gen inc_68t100 = (inc == 4 | inc == 5) if !missing(inc)
replace group = "inc_0t33" if _n == 5
replace group = "inc_34t67" if _n == 6
replace group = "inc_68t100" if _n == 7

*education
rename VCF0110 educ_4c
gen lhs =  (educ_4c == 1) if !missing(educ_4c)
gen hs =  (educ_4c == 2) if !missing(educ_4c)
gen smcllge =  (educ_4c == 3) if !missing(educ_4c)
gen cllgad =  (educ_4c == 4) if !missing(educ_4c)
gen nocllgad = (educ_4c < 4) if !missing(educ_4c)
gen anycllg = (educ_4c >=3) if !missing(educ_4c)
gen nocllg = (educ_4c <3) if !missing(educ_4c)
gen alsths = (educ_4c >=2) if !missing(educ_4c)
replace group = "cllgad" if _n == 8
replace group = "nocllgad" if _n == 9
replace group = "anycllg" if _n == 10
replace group = "nocllg" if _n == 11

*place of birth
rename VCF0142 birthpl
label variable birthpl "birth place"
gen brnS = 0 if !missing(birthpl)
label variable brnS "Born in South"
foreach val in 140 141 142 143 144 145 146 147 148 149 154 {
	replace brnS = 1 if birthpl == `val'
}
replace brnS = . if (birthpl >=182 & birthpl <=187) | (birthpl >=201) | (birthpl == 100)
gen brnNS = 1 if !missing(birthpl) 
label variable brnNS "Not Born in South, but born in the States"
replace brnNS = 1 if brnS == 0
replace brnNS = . if (birthpl >=182 & birthpl <=187) | (birthpl >=201) | (birthpl == 100)
gen brnPNS = 0
label variable brnPNS "Born in Poor Non-South"
replace brnPNS = 1 if brnS == 0 & PNS == 1
replace brnPNS = . if (birthpl >=182 & birthpl <=187) | (birthpl >=201) | (birthpl == 100)

gen brn = 0 if !missing(birthpl)
replace brn = 1 if brnS == 1
//replace brn = 2 if brnNS == 1
replace brn = 2 if brnPNS == 1
label variable brn "Birth Place Cat."
//label define lbbrn 0 "Not U.S." 1 "South" 2 "Non-South"
label define lbbrn 0 "Not U.S." 1 "South" 2 "Poor Non-South"
label values brn lbbrn
replace group = "brnS" if _n == 12
replace group = "brnPNS" if _n == 13

gen imgrnt = (brn == 0) if !missing(brn)
gen noimgrnt = (imgrnt == 0) if !missing(imgrnt)

gen firstgen = (imgrnt == 1 | VCF0143 == 5) if !missing(imgrnt) | !missing(VCF0143)
replace firstgen = . if missing(imgrnt) & VCF0143 == 1 //If I have no info on their immigration status, but no their parents are citizens, they are probably citizens, but I don't know 
replace firstgen = . if missing(VCF0143) & imgrnt == 0 //If I have no info on their parents and know they are citizens, I can't know if they are not first gens
gen nofirstgen = (firstgen == 0) if !missing(firstgen)

replace popgroup = "imgrnt" if _n == 7
replace popgroup = "noimgrnt" if _n == 8
replace popgroup = "firstgen" if _n == 9
replace popgroup = "nofirstgen" if _n == 10

*religion
rename VCF0128 religion_mj4
gen chrchatt = .
label variable chrchatt "church attendence"
replace chrchatt = 0 if VCF0131 == 7 | VCF0130 == 7
replace chrchatt = 1 if VCF0131 == 5 | VCF0130 == 5
replace chrchatt = 2 if VCF0131 == 4 | VCF0130 == 4
replace chrchatt = 3 if VCF0131 == 2 | VCF0130 == 3 | VCF0130 == 2
replace chrchatt = 4 if VCF0131 == 1 | VCF0130 == 1
label define lbchrchatt 0 "No Religious Preference" 1 "Never" 2 "A few times a year" 3 "Often" 4 "Every week"
label values chrchatt lbchrchatt
gen frqchrch = (chrchatt == 4 | chrchatt == 3) if !missing(chrchatt)
label variable frqchrch "frequent church attendence?"
gen infrqchrch = (frqchrch == 0) if !missing(frqchrch)
label variable infrqchrch "infrequent church attendence?"
replace group = "frqchrch" if _n == 14
replace group = "infrqchrch" if _n == 15

*grew up in country or farm
rename VCF0134 frmcntry
replace frmcntry = -1*(frmcntry - 2)
replace group = "frmcntry" if _n == 16

gen nofrmcntry = (frmcntry == 0) if !missing(frmcntry)
label variable nofrmcntry "didn't grow up in a farm or country"
replace group = "nofrmcntry" if _n == 17

*class identification
rename VCF0148 sclass
gen midclass = (sclass >= 4 & sclass <= 6) if !missing(sclass)
label variable midclass "Identify with the middle class"
replace group = "midclass" if _n == 18

gen wrkclass = (sclass >= 1 & sclass <= 3) if !missing(sclass)
label variable wrkclass "Identify with the working class"
replace group = "wrkclass" if _n == 19

*race relations
rename VCF0206 blk_therm
centile blk_therm, centile(70) //get 70th percentile
gen favorblk = (blk_therm >  r(c_1)) if !missing(blk_therm)
gen nofavorblk = (blk_therm <  r(c_1)) if !missing(blk_therm) 
replace group = "favorblk" if _n == 20
replace group = "nofavorblk" if _n == 21
foreach n of num 0(10)90 {
	local m = `n' + 9
	gen blk_therm`n't`m' = (blk_therm >= `n' & blk_therm <= `m') if !missing(blk_therm)
	label variable blk_therm`n't`m' "blk_therm: `n' to `m'"
	
	foreach rgn in NT S NS PNS NPNS B M W N {
		gen `rgn'_blk_therm`n't`m' = `rgn'*blk_therm`n't`m' if !missing(`rgn') & !missing(blk_therm`n't`m')
		label variable `rgn'_blk_therm`n't`m' "`rgn' & blk_therm interaction"
	}
}


*Voting variables
gen vote = (VCF0702 == 2) if !missing(VCF0702)
label variable vote "vote in november elections"

*Liberal and Conservative Proxies
gen lib = (VCF0801 < 49) if !missing(VCF0801)
label variable lib "proxy for liberal self identification"
gen con = (VCF0801 > 49) if !missing(VCF0801) 
label variable con "proxy for conservative self identification"
gen neu = (VCF0801 == 49) if !missing(VCF0801)
gen libcon = .
replace libcon = 1 if (VCF0801 < 49)  & !missing(VCF0801)
replace libcon = 2 if (VCF0801 > 49)  & !missing(VCF0801) 
replace libcon = 3 if (VCF0801 == 49) & !missing(VCF0801)
label define libcon_lb 1 "Liberal" 2 "Neutral" 3 "Conservative"
label values libcon libcon_lb

replace group = "lib" if _n == 22
replace group = "con" if _n == 23
replace group = "neu" if _n == 24

*Urbanism 
rename VCF0111 urbanism
gen city = (urbanism == 1) if  !missing(urbanism)
gen subur = (urbanism == 2) if  !missing(urbanism)
gen stwn = (urbanism == 3) if  !missing(urbanism)
replace group = "city" if _n == 25
replace group = "subur" if _n == 26
replace group = "stwn" if _n == 27

*Occupation
rename VCF0151 occuptype_a

gen prfmng = (occuptype_a == 1) if !missing(occuptype_a)
gen clrsale = (occuptype_a == 2) if !missing(occuptype_a)
gen sklwrk = (occuptype_a == 3) if !missing(occuptype_a)
gen unsklwrk = (occuptype_a == 4) if !missing(occuptype_a)
gen frmwrk = (occuptype_a == 5) if !missing(occuptype_a)
gen hmrknwrk = (occuptype_a == 6) if !missing(occuptype_a)
replace group = "prfmng" if _n == 28
replace group = "clrsale" if _n == 29
replace group = "sklwrk" if _n == 30
replace group = "unsklwrk" if _n == 31
replace group = "frmwrk" if _n == 32
replace group = "hmrknwrk" if _n == 33

*Opinion of government
*trust
rename VCF0604 govtrust
gen nvrtrustgov = (govtrust == 1) if !missing(govtrust)
label variable nvrtrustgov "never trust gov to do what is right"
gen somtrustgov = (govtrust == 2) if !missing(govtrust)
label variable somtrustgov "sometimes trust gov to do what is right"
gen msttrustgov = (govtrust == 3) if !missing(govtrust)
label variable msttrustgov "most of the time trust gov to do what is right"
gen alwytrustgov = (govtrust == 4) if !missing(govtrust)
label variable alwytrustgov "always trust gov to do what is right"
gen dptrustgov = (govtrust == 9) if !missing(govtrust)
label variable dptrustgov "trust gov to do what is right - depends"
gen ltttrustgov = (govtrust == 1 | govtrust == 2) if !missing(govtrust)
label variable ltttrustgov "Sometimes or never trust gov to do what is right"
gen lottrustgov = (govtrust == 3 | govtrust == 4) if !missing(govtrust)
label variable lottrustgov "Always or most of the trust gov to do what is right"

replace group = "nvrtrustgov" if _n == 34
replace group = "somtrustgov" if _n == 35
replace group = "msttrustgov" if _n == 36
replace group = "alwytrustgov" if _n == 37
replace group = "dptrustgov" if _n == 38
replace group = "ltttrustgov" if _n == 39
replace group = "lottrustgov" if _n == 40

*serves many or few
rename VCF0605 govallfew
gen govfew = (govallfew == 1) if !missing(govallfew)
label variable govfew "Fed gov run for few big interests"
gen govall = (govallfew == 2) if !missing(govallfew)
label variable govall "Fed gov run for benefit of all"
gen govother = (govallfew == 9) if !missing(govallfew)
label variable govother "mixed response to if gov is ran for benefit of all"

replace group = "govfew" if _n == 41
replace group = "govall" if _n == 42
replace group = "govother" if _n == 43

*People like me
rename VCF0613 govpplme
gen govpplmeagr = (govpplme == 1) if !missing(govpplme)
label variable govpplmeagr "agree that people like me have say in what gov does"
gen govpplmedisagr = (govpplme == 2) if !missing(govpplme)
label variable govpplmedisagr "disagree that people like me have say in what gov does"
gen govpplmeneit = (govpplme == 3) if !missing(govpplme)
label variable govpplmeneit "neither agree or disagree that people like me have say in what gov does"
gen govpplmeoth = (govpplme == 9) if !missing(govpplme)
label variable govpplmeoth "People like me have say in what gov does - other"

replace group = "govpplmeagr" if _n == 44
replace group = "govpplmedisagr" if _n == 45
replace group = "govpplmeneit" if _n == 46
replace group = "govpplmeoth" if _n == 47

*family economic pressure
rename VCF0880 famlastyr
gen fambttrlastyr = (famlastyr == 1) if !missing(famlastyr)
label variable fambttrlastyr "family better off in the past year"
gen famsmlastyr = (famlastyr == 2) if !missing(famlastyr) 
label variable famsmlastyr "family situation unchanged in the past year"
gen famwrslastyr = (famlastyr == 3) if !missing(famlastyr) 
label variable famwrslastyr "family worse off in the past year"

replace group = "fambttrlastyr" if _n == 48
replace group = "famsmlastyr" if _n == 49
replace group = "famwrslastyr" if _n == 50


/*******************************************************************************
Renaming and Generating UnWeighted Outcome Variables
*******************************************************************************/
gen outcome = ""
label variable outcome "vector to store outcome variables"

*Presidental candidate vote, more compariable with congressional vote
rename VCF0704A prezvote
gen demprevote = (prezvote == 1) if !missing(prezvote) & prezelecyr == 1
gen repprevote = (prezvote == 2) if !missing(prezvote) & prezelecyr == 1
replace outcome = "demprevote" if _n == 1

rename VCF0705 prezvote2
gen demprevote2 = (prezvote2 == 1) if !missing(prezvote2) & prezelecyr == 1
gen repprevote2 = (prezvote2 == 2) if !missing(prezvote2) & prezelecyr == 1
gen othprevote2 = (prezvote2 == 3) if !missing(prezvote2) & prezelecyr == 1

*House of Representatives
rename VCF0707 houvote
gen demhouvote = (houvote == 1) if !missing(houvote)
gen rephouvote = (houvote == 2) if !missing(houvote)
replace outcome = "demhouvote" if _n == 2

rename VCF0736 houvote2
gen demhouvote2 = (houvote2 == 1) if !missing(houvote)
gen rephouvote2 = (houvote2 == 5) if !missing(houvote)
gen othhouvote2 = (houvote2 == 7) if !missing(houvote)

*Senate
rename VCF0708 senvote 
gen demsenvote = (senvote == 1) if !missing(senvote)
gen repsenvote = (senvote == 2) if !missing(senvote)
replace outcome = "demsenvote" if _n == 3


*Party affiliation
rename VCF0301 partyid
gen dem = (partyid <= 3) if  !missing(partyid)
gen ind = (partyid == 4) if  !missing(partyid)
gen rep = (partyid >= 5) if  !missing(partyid)
replace outcome = "dem" if _n == 4

*Role of Gov
tab VCF0808
gen govjobinc = (VCF0808 == 1) if !missing(VCF0808) & year <=1968 //we ignore 2002
label variable govjobinc "gov should guarante jobs and income"
replace outcome = "govjobinc" if _n == 5

*Race relations
replace outcome = "blk_therm" if _n == 6

*Dem vote
gen demvote = (demprevote == 1) | (repprevote == 1) | (houvote == 1) if !(missing(demprevote) & missing(repprevote) & missing(houvote))
label variable demvote "vote democratic"
replace outcome = "demvote" if _n == 7

/*******************************************************************************
********************************************************************************
Graph Set 1: 
Demographic Variables of Interest:
	40 years and older vs inverse:	agelt40 agegt40
	Men vs Women:	male fmale
	Select income percentiles: inc_0t33 inc_34t67 inc_68t100
	College graduation or more vs inverse: cllgad nocllgad
	Any college vs inverse: anycllg nocllg

Outcome Variables of Interest:
	Democratic Presidential Vote: demprevote
	Democratic House Vote: demhouvote
	Democratic Senate Vote: demsenvote
	Party ID - Democrat: dem
	Agree gov should provide job and income security: govjobinc

********************************************************************************
*******************************************************************************/


/*******************************************************************************
Generating Weighted Variables
*******************************************************************************/
*Region and demographic group specific weighted voting trend outcome variable means
foreach vector in group outcome { //stata does save vectors	
	levelsof `vector', local(lc_`vector') // generates local variable from categories
}

foreach grp in `lc_group' {
	foreach rgn in NT S NS PNS NPNS B M W N  {
		foreach otcm in `lc_outcome' ind rep {
			egen temp_1 = sum(`otcm'*wgt) if `grp'==1 & `rgn' == 1 & wht == 1, by(year)
			egen temp_2 = sum(wgt) if `grp'==1 & `rgn' == 1 & wht == 1 & !missing(`otcm'), by(year)
			gen  temp_3 = temp_1/temp_2 if `grp'==1 & `rgn' == 1 & wht == 1
			egen `otcm'_`grp'`rgn' = mean(temp_3) if `grp'==1 & `rgn' == 1 & wht == 1, by(year)
			if ("`rgn'" == "NT") {
				local region = "US"
			}
			else if ("`rgn'" == "N") {
				local region = "North"
			}			
			else if ("`rgn'" == "S") {
				local region = "South"
			}
			else if ("`rgn'" == "B") {
				local region = "North/South Border"
			}
			else if ("`rgn'" == "M") {
				local region = "Midwest"
			}
			else if ("`rgn'" == "W") {
				local region = "West"
			}	
			else if ("`rgn'" == "PNS") {
				local region = "Poor NonSouth"
			}
			label variable `otcm'_`grp'`rgn' "Mean `otcm' of `grp' in `region'"
			drop temp_*
		}
	}
}
*Region specific weighted voting trend outcome variable means for the entire population
gen all = 1
levelsof outcome, local(lc_outcome)
foreach rgn in NT S NS PNS NPNS B M W N  {
	foreach otcm in `lc_outcome'  {
		foreach grp in all wht {
			egen temp_1 = sum(`otcm'*wgt) if `rgn' == 1 & `grp'==1, by(year)
			egen temp_2 = sum(wgt) if `rgn' == 1 & `grp'==1 & !missing(`otcm'), by(year)
			gen  temp_3 = temp_1/temp_2 if `rgn' == 1 & `grp'==1
			egen `otcm'_`grp'`rgn' = mean(temp_3) if `rgn' == 1 & `grp'==1, by(year)
			if ("`rgn'" == "NT") {
				local region = "US"
			}
			else if ("`rgn'" == "N") {
				local region = "North"
			}			
			else if ("`rgn'" == "S") {
				local region = "South"
			}
			else if ("`rgn'" == "B") {
				local region = "North/South Border"
			}
			else if ("`rgn'" == "M") {
				local region = "Midwest"
			}
			else if ("`rgn'" == "W") {
				local region = "West"
			}
			else if ("`rgn'" == "PNS") {
				local region = "Poor NonSouth"
			}			
			label variable `otcm'_`grp'`rgn' "`otcm' mean of `grp' population in `region'"
			drop temp_*
		}
	}
}

*Region and demographic group specific weighted population trend variables
gen resp = 1
*weighted population and voter totals: all and whites alone
foreach rgn in NT S NS PNS NPNS B M W N  {
	if ("`rgn'" == "NT") {
		local region = "US"
	}
	else if ("`rgn'" == "N") {
		local region = "North"
	}		
	else if ("`rgn'" == "S") {
		local region = "South"
	}
	else if ("`rgn'" == "B") {
		local region = "North/South Border"
	}
	else if ("`rgn'" == "M") {
		local region = "Midwest"
	}
	else if ("`rgn'" == "W") {
		local region = "West"
	}
	else if ("`rgn'" == "PNS") {
		local region = "Poor NonSouth"
		}	
	foreach pop in all wht blk {
		*General Population
		egen temp_1 = sum(resp*wgt) if `rgn' == 1 & `pop' == 1, by(year)
		egen temp_2 = sum(wgt) if `rgn' == 1 & `pop' == 1, by(year)
		gen  temp_3 = temp_1/temp_2 if `rgn' == 1 & `pop' == 1
		egen ptotal_`rgn'`pop' = sum(temp_3) if `rgn' == 1 & `pop' == 1, by(year)
		label variable ptotal_`rgn'`pop' "Weighted Population Total:`region', `pop' "
		drop temp_*
		*Voter Population
		egen temp_1 = sum(resp*wgt) if `rgn' == 1 & `pop' == 1 & vote == 1, by(year)
		egen temp_2 = sum(wgt) if `rgn' == 1 & `pop' == 1 & vote == 1, by(year)
		gen  temp_3 = temp_1/temp_2 if `rgn' == 1 & `pop' == 1 & vote == 1
		egen vtotal_`rgn'`pop' = sum(temp_3) if `rgn' == 1 & `pop' == 1 & vote == 1, by(year)
		label variable vtotal_`rgn'`pop' "Weighted Voter Population Total:`region', `pop' "
		drop temp_*
	}
}

*weighted subpopulation and voter totals: all and whites alone
levelsof group, local(lc_group)
levelsof popgroup, local(lc_popgroup)
foreach rgn in NT S NS PNS NPNS B M W N  {
	if ("`rgn'" == "NT") {
		local region = "US"
	}
	else if ("`rgn'" == "N") {
		local region = "North"
	}			
	else if ("`rgn'" == "S") {
		local region = "South"
	}
	else if ("`rgn'" == "B") {
		local region = "North/South Border"
	}
	else if ("`rgn'" == "M") {
		local region = "Midwest"
	}
	else if ("`rgn'" == "W") {
		local region = "West"
	}
	else if ("`rgn'" == "PNS") {
		local region = "Poor NonSouth"
	}
	foreach grp in `lc_group' `lc_popgroup' {
		foreach pop in all wht {
			*General Population
			egen temp_1 = sum(resp*wgt) if `rgn' == 1 & `grp'==1 & `pop' == 1, by(year)
			egen temp_2 = sum(wgt) if `rgn' == 1 & `grp'==1 & `pop' == 1, by(year)
			gen  temp_3 = temp_1/temp_2 if `rgn' == 1 & `grp'==1 & `pop' == 1
			egen ptotal_`grp'`rgn'`pop' = sum(temp_3) if `rgn' == 1 & `grp'==1 & `pop' == 1, by(year)
			label variable ptotal_`grp'`rgn'`pop' "Weighted Population Total: `grp' and `region', `pop' "
			gen pshare_`grp'`rgn'`pop' = (ptotal_`grp'`rgn'`pop')/(ptotal_`rgn'`pop')
			label variable pshare_`grp'`rgn'`pop' "Weighted Population Share: `grp' and `region', `pop' "
			drop temp_*
			*Voter Population
			egen temp_1 = sum(resp*wgt) if `rgn' == 1 & `grp'==1 & `pop' == 1 & vote == 1, by(year)
			egen temp_2 = sum(wgt) if `rgn' == 1 & `grp'==1 & `pop' == 1 & vote == 1, by(year)
			gen  temp_3 = temp_1/temp_2 if `rgn' == 1 & `grp'==1 & `pop' == 1 & vote == 1
			egen vtotal_`grp'`rgn'`pop' = sum(temp_3) if `rgn' == 1 & `grp'==1 & `pop' == 1 & vote == 1, by(year)
			label variable vtotal_`grp'`rgn'`pop' "Weighted Voter Population Total: `grp' and `region', `pop' "
			gen vshare_`grp'`rgn'`pop' = (vtotal_`grp'`rgn'`pop')/(vtotal_`rgn'`pop')
			label variable vshare_`grp'`rgn'`pop' "Weighted Voter Population Share: `grp' and `region', `pop' "
			drop temp_*
		}
	}
}


*Testing against what other authors have done
foreach grp in male fmale {
	if ("`grp'" == "male"){
		local gender men
	}
	else {
		local gender women
	}
	egen temp_1 = sum(dem*wgt) if `grp'==1 & wht == 1, by(year)
	egen temp_2 = sum(wgt) if `grp'==1 & wht == 1 & !missing(dem), by(year)
	gen  temp_3 = temp_1/temp_2 if `grp' ==1 & wht == 1
	egen dem_`grp' = mean(temp_3) if `grp' ==1 & wht == 1, by(year)
	label variable dem_`grp' "Democrat share: white `gender'"
	drop temp_*
}

/*******************************************************************************
Preparing for decomposition
*******************************************************************************/
gen dem_era = (year <= 1980) if !missing(year)
compress

***********Dealing with a sorting issues
  
count if !missing(outcome)
exit

local N = r(N)
foreach n of num 1/`N' {
	local temp = outcome[`n']
	local lc_outcome `lc_outcome' `temp'
}
count if !missing(group)
local N = r(N)
foreach n of num 1/`N' {
	local temp = group[`n']
	local lc_group `lc_group' `temp'
}
count if !missing(popgroup)
local N = r(N)
foreach n of num 1/`N' {
	local temp = popgroup[`n']
	local lc_popgroup `lc_popgroup' `temp'
}
sort year state_a
replace outcome = ""
local n = 1
foreach var in `lc_outcome' {
	replace outcome = "`var'" if _n == `n'
	local n = `n' + 1
}
replace group = ""
local n = 1
foreach var in `lc_group' {
	replace group = "`var'" if _n == `n'
	local n = `n' + 1
}
replace popgroup = ""
local n = 1
foreach var in `lc_popgroup' {
	replace popgroup = "`var'" if _n == `n'
	local n = `n' + 1
}
//browse year group popgroup outcome
**************************************************
**Chart Titles
*****************Share of those identifying as democrat


*Title variables
levelsof outcome, local(lc_outcome)
foreach otcm in `lc_outcome'{
	capture noisily gen title_`otcm' = "" if _n == 1
}

*Democrat id titles
replace title_dem = `""Share of whites younger than" "40 identifying as Democrats""' if _n == 1
replace title_dem = `""Share of whites 40 years or" "older identifying as Democrats""' if _n == 2
replace title_dem = `""Share of white men" "identifying as Democrats""' if _n == 3
replace title_dem = `""Share of white women" "identifying as Democrats""' if _n == 4
replace title_dem = `""Share of whites in the 0 to 33% family" "income percentile identifying as Democrats""' if _n == 5
replace title_dem = `""Share of whites in the 34 to 67% family" "income percentile identifying as Democrats""' if _n == 6
replace title_dem = `""Share of whites in the 68 to 100% family" "income percentile identifying as Democrats""' if _n == 7
replace title_dem = `""Share of whites with at least a bachelor" "degree identifying as Democrats""' if _n == 8
replace title_dem = `""Share of whites with no bachelor" "degree identifying as Democrats""' if _n == 9
replace title_dem = `""Share of whites with any college" "education identifying as Democrats""' if _n == 10
replace title_dem = `""Share of whites with no college" "education identifying as Democrats""' if _n == 11
replace title_dem = `""Share of whites born in the South that identify" "as Democrats""' if _n == 12
replace title_dem = `""Share of whites not born in the South that identify" "as Democrats""' if _n == 13
replace title_dem = `""Share of whites that attend church" "frequently that identify as Democrats""' if _n == 14
replace title_dem = `""Share of whites that attend church no more" "than a few times a year that identify as Democrats""' if _n == 15
replace title_dem = `""Share of whites that grew up in the country" "or a farm that identify as Democrats""' if _n == 16 
replace title_dem = `""Share of whites that did not grow up in the" "country or a farm that identify as Democrats""' if _n == 17
replace title_dem = `""Share of whites that identify with" "the middle class that identify as Democrats""' if _n == 18
replace title_dem = `""Share of whites that identify with" "the working class that identify as Democrats""' if _n == 19
replace title_dem = `""Share of whites that are warm towards" "blacks that identify as Democrats""' if _n == 20
replace title_dem = `""Share of whites that are cold towards" "blacks that identify as Democrats""' if _n == 21
replace title_dem = `""Share of white liberals" "that identify as Democrats""' if _n == 22
replace title_dem = `""Share of white conservatives" "that identify as Democrats""' if _n == 23
replace title_dem = `""Share of neutral whites" "that identify as Democrats""' if _n == 24
replace title_dem = `""Share of whites in central cities" "that identify as Democrats""' if _n == 25
replace title_dem = `""Share of whites in suburban areas" "that identify as Democrats""' if _n == 26
replace title_dem = `""Share of whites in rural or small towns" "that identify as Democrats""' if _n == 27
replace title_dem = `""Share of professional and managerial whites" "that identify as Democrats""' if _n == 28
replace title_dem = `""Share of clerical and sales worker whites" "that identify as Democrats""' if _n == 29
replace title_dem = `""Share of skilled, semi-skilled, and service worker" "whites that identify as Democrats""' if _n == 30
replace title_dem = `""Share of nonfarm white laborers" "that identify as Democrats""' if _n == 31
replace title_dem = `""Share of white farmers, farm managers," "and farm laborers that identify as Democrats""' if _n == 32
replace title_dem = `""Share of white homemarkers, unemployed, etc" "that identify as Democrats""' if _n == 33
replace title_dem = `""Share of whites that never trust gov to do" "what is right that identify as Democrats""' if _n == 34
replace title_dem = `""Share of whites that sometimes trust gov to" "do what is right that identify as Democrats""' if _n == 35
replace title_dem = `""Share of whites that trust gov to do what" "is right most of the time that identify as Democrats""' if _n == 36
replace title_dem = `""Share of whites that always trust gov to" "do what is right that identify as Democrats""' if _n == 37
replace title_dem = `""Share of whites whose trust in the gov to do" "what is right varies that identify as Democrats""' if _n == 38
replace title_dem = `""Share of whites that sometimes or never trust" "the gov to do what is right that identify as Democrats""' if _n == 39
replace title_dem = `""Share of whites that always or most of the trust" "the gov to do what is right that identify as Democrats""' if _n == 40
replace title_dem = `""Share of whites that believe that gov runs" "for few big interests that identify as Democrats""' if _n == 41
replace title_dem = `""Share of whites that believe that gov runs" "for benefit of all that identify as Democrats""' if _n == 42
replace title_dem = `""Share of whites with mixed response to who" "the gov runs for that identify as Democrats""' if _n == 43
replace title_dem = `""Share of whites that think people like them" "have say in what gov does that identify as Democrats""' if _n == 44
replace title_dem = `""Share of whites that do not think people like them" "have say in what gov does that identify as Democrats""' if _n == 45
replace title_dem = `""Share of whites that neither agree nor disagree that people" "like them have say in what gov does that identify as Democrats""' if _n == 46
replace title_dem = `""Share of whites with other responses to who has a say in" "what gov does that identify as Democrats""' if _n == 47
replace title_dem = `""Share of whites better off in the past year" "that identify as Democrats""' if _n == 48
replace title_dem = `""Share of whites with situations unchanged in" "the past year that identify as Democrats""' if _n == 49
replace title_dem = `""Share of whites worse off in the past year" "that identify as Democrats""' if _n == 50


*Democratic President titles
replace title_demprevote = `""Share of whites younger than 40" "voting for democratic presidents""' if _n == 1
replace title_demprevote = `""Share of whites 40 years or older" "voting for democratic presidents""' if _n == 2
replace title_demprevote = `""Share of white men voting" "for democratic presidents""' if _n == 3
replace title_demprevote = `""Share of white women voting" "for democratic presidents""' if _n == 4
replace title_demprevote = `""Share of whites in the 0% to 33% family income" "percentile voting for democratic presidents""' if _n == 5
replace title_demprevote = `""Share of whites in the 34% to 67% family income" "percentile voting for democratic presidents""' if _n == 6
replace title_demprevote = `""Share of whites in the 68% to 100% family" "income percentile voting for democratic presidents""' if _n == 7
replace title_demprevote = `""Share of whites with at least a bachelor" "degree voting for democratic presidents""' if _n == 8
replace title_demprevote = `""Share of whites with no bachelor" "degree voting for democratic presidents""' if _n == 9
replace title_demprevote = `""Share of whites with any college" "education voting for democratic presidents""' if _n == 10
replace title_demprevote = `""Share of whites with no college" "education voting for democratic presidents""' if _n == 11
replace title_demprevote = `""Share of whites born in the South that vote for democratic" "presidents""' if _n == 12
replace title_demprevote = `""Share of whites not born in the South that vote for" "democratic presidents""' if _n == 13
replace title_demprevote = `""Share of whites that attend church" "frequently that vote for democratic presidents""' if _n == 14
replace title_demprevote = `""Share of whites that attend church no more than a" "few times a year that vote for democratic presidents""' if _n == 15
replace title_demprevote = `""Share of whites that grew up in the country" "or a farm that vote for democratic presidents""' if _n == 16 
replace title_demprevote = `""Share of whites that did not grow up in the" "country or a farm that vote for democratic presidents""' if _n == 17
replace title_demprevote = `""Share of whites that identify with the" "middle class that vote for democratic presidents""' if _n == 18
replace title_demprevote = `""Share of whites that identify with the" "working class that vote for democratic presidents""' if _n == 19
replace title_demprevote = `""Share of whites that are warm towards blacks" "that vote for democratic presidents""' if _n == 20
replace title_demprevote = `""Share of whites that are cold towards blacks" "that vote for democratic presidents""' if _n == 21
replace title_demprevote = `""Share of white liberals that" "vote for democratic presidents""' if _n == 22
replace title_demprevote = `""Share of white conservatives that" "vote for democratic presidents""' if _n == 23
replace title_demprevote = `""Share of neutral whites that" "vote for democratic presidents""' if _n == 24
replace title_demprevote = `""Share of whites in central cities" "that vote for democratic presidents""' if _n == 25
replace title_demprevote = `""Share of whites in suburban areas" "that vote for democratic presidents""' if _n == 26
replace title_demprevote = `""Share of whites in rural or small towns" "that vote for democratic presidents""' if _n == 27
replace title_demprevote = `""Share of professional and managerial whites" "that vote for democratic presidents""' if _n == 28
replace title_demprevote = `""Share of clerical and sales worker whites" "that vote for democratic presidents""' if _n == 29
replace title_demprevote = `""Share of skilled, semi-skilled, and service worker" "whites that vote for democratic presidents""' if _n == 30
replace title_demprevote = `""Share of nonfarm white laborers" "that vote for democratic presidents""' if _n == 31
replace title_demprevote = `""Share of white farmers, farm managers," "and farm laborers that vote for democratic presidents""' if _n == 32
replace title_demprevote = `""Share of white homemarkers, unemployed, etc" "that vote for democratic presidents""' if _n == 33
replace title_demprevote = `""Share of whites that never trust gov to do" "what is right that vote for democratic presidents""' if _n == 34
replace title_demprevote = `""Share of whites that sometimes trust gov to" "do what is right that vote for democratic presidents""' if _n == 35
replace title_demprevote = `""Share of whites that trust gov to do what" "is right most of the time that vote for democratic presidents""' if _n == 36
replace title_demprevote = `""Share of whites that always trust gov to" "do what is right that vote for democratic presidents""' if _n == 37
replace title_demprevote = `""Share of whites whose trust in the gov to do" "what is right varies that vote for democratic presidents""' if _n == 38
replace title_demprevote = `""Share of whites that sometimes or never trust" "the gov to do what is right that vote for democratic presidents""' if _n == 39
replace title_demprevote = `""Share of whites that always or most of the trust" "the gov to do what is right that vote for democratic presidents""' if _n == 40
replace title_demprevote = `""Share of whites that believe that gov runs for few big interests" "that vote for democratic presidents""' if _n == 41
replace title_demprevote = `""Share of whites that believe that gov runs for benefit of all" "that vote for democratic presidents""' if _n == 42
replace title_demprevote = `""Share of whites with mixed response to who the gov runs for" "that vote for democratic presidents""' if _n == 43
replace title_demprevote = `""Share of whites that think people like them" "have say in what gov does that vote for democratic presidents""' if _n == 44
replace title_demprevote = `""Share of whites that do not think people like them" "have say in what gov does that vote for democratic presidents""' if _n == 45
replace title_demprevote = `""Share of whites that neither agree nor disagree that people" "like them have say in what gov does that vote for democratic presidents""' if _n == 46
replace title_demprevote = `""Share of whites with other responses to who has a say in" "what gov does that vote for democratic presidents""' if _n == 47
replace title_demprevote = `""Share of whites better off in the past year" "that vote for democratic presidents""' if _n == 48
replace title_demprevote = `""Share of whites with situations unchanged in" "the past year that vote for democratic presidents""' if _n == 49
replace title_demprevote = `""Share of whites worse off in the past year" "that vote for democratic presidents""' if _n == 50

*Democratic Representatives titles
replace title_demhouvote = `""Share of whites younger than 40" "voting for democratic representatives""' if _n == 1
replace title_demhouvote = `""Share of whites 40 years or older" "voting for democratic representatives""' if _n == 2
replace title_demhouvote = `""Share of white men voting" "for democratic representatives""' if _n == 3
replace title_demhouvote = `""Share of white women voting" "for democratic representatives""' if _n == 4
replace title_demhouvote = `""Share of whites in the 0% to 33% family income" "percentile voting for democratic representatives""' if _n == 5
replace title_demhouvote = `""Share of whites in the 34% to 67% family income" "percentile voting for democratic representatives""' if _n == 6
replace title_demhouvote = `""Share of whites in the 68% to 100% family income" "percentile voting for democratic representatives""' if _n == 7
replace title_demhouvote = `""Share of whites with at least a bachelor" "degree voting for democratic representatives""' if _n == 8
replace title_demhouvote = `""Share of whites with no bachelor degree" "voting for democratic representatives""' if _n == 9
replace title_demhouvote = `""Share of whites with any college education" "voting for democratic representatives""' if _n == 10
replace title_demhouvote = `""Share of whites with no college education" "voting for democratic representatives""' if _n == 11
replace title_demhouvote = `""Share of whites born in the South that vote for democratic" "representatives""' if _n == 12
replace title_demhouvote = `""Share of whites not born in the South that vote for" "democratic representatives""' if _n == 13
replace title_demhouvote = `""Share of whites that attend church frequently" "that vote for democratic representatives""' if _n == 14
replace title_demhouvote = `""Share of whites that attend church no more than a few" "times a year that vote for democratic representatives""' if _n == 15
replace title_demhouvote = `""Share of whites that grew up in the country" "or a farm that vote for democratic representatives""' if _n == 16 
replace title_demhouvote = `""Share of whites that did not grow up in the" "country or a farm that vote for democratic representatives""' if _n == 17
replace title_demhouvote = `""Share of whites that identify with the" "middle class that vote for democratic representatives""' if _n == 18
replace title_demhouvote = `""Share of whites that identify with the" "working class that vote for democratic representatives""' if _n == 19
replace title_demhouvote = `""Share of whites that are warm towards blacks" "that vote for democratic representatives""' if _n == 20
replace title_demhouvote = `""Share of whites that are cold towards blacks" "that vote for democratic representatives""' if _n == 21
replace title_demhouvote = `""Share of white liberals that vote" "for democratic representatives""' if _n == 22
replace title_demhouvote = `""Share of white conservatives that vote" "for democratic representatives""' if _n == 23
replace title_demhouvote = `""Share of neutral whites that vote" "for democratic representatives""' if _n == 24
replace title_demhouvote = `""Share of whites in central cities" "that vote for democratic representatives""' if _n == 25
replace title_demhouvote = `""Share of whites in suburban areas" "that vote for democratic representatives""' if _n == 26
replace title_demhouvote = `""Share of whites in rural or small towns" "that vote for democratic representatives""' if _n == 27
replace title_demhouvote = `""Share of professional and managerial whites" "that vote for democratic representatives""' if _n == 28
replace title_demhouvote = `""Share of clerical and sales worker whites" "that vote for democratic representatives""' if _n == 29
replace title_demhouvote = `""Share of skilled, semi-skilled, and service worker" "whites that vote for democratic representatives""' if _n == 30
replace title_demhouvote = `""Share of nonfarm white laborers" "that vote for democratic representatives""' if _n == 31
replace title_demhouvote = `""Share of white farmers, farm managers," "and farm laborers that vote for democratic representatives""' if _n == 32
replace title_demhouvote = `""Share of white homemarkers, unemployed, etc" "that vote for democratic representatives""' if _n == 33
replace title_demhouvote = `""Share of whites that never trust gov to do" "what is right that vote for democratic representatives""' if _n == 34
replace title_demhouvote = `""Share of whites that sometimes trust gov to" "do what is right that vote for democratic representatives""' if _n == 35
replace title_demhouvote = `""Share of whites that trust gov to do what" "is right most of the time that vote for democratic representatives""' if _n == 36
replace title_demhouvote = `""Share of whites that always trust gov to" "do what is right that vote for democratic representatives""' if _n == 37
replace title_demhouvote = `""Share of whites whose trust in the gov to do" "what is right varies that vote for democratic representatives""' if _n == 38
replace title_demhouvote = `""Share of whites that sometimes or never trust" "the gov to do what is right that vote for democratic representatives""' if _n == 39
replace title_demhouvote = `""Share of whites that always or most of the trust" "the gov to do what is right that vote for democratic representatives""' if _n == 40
replace title_demhouvote = `""Share of whites that believe that gov runs for few big interests" "that vote for democratic representatives""' if _n == 41
replace title_demhouvote = `""Share of whites that believe that gov runs for benefit of all" "that vote for democratic representatives""' if _n == 42
replace title_demhouvote = `""Share of whites with mixed response to who the gov runs for" "that vote for democratic representatives""' if _n == 43
replace title_demhouvote = `""Share of whites that think people like them" "have say in what gov does that vote for democratic representatives""' if _n == 44
replace title_demhouvote = `""Share of whites that do not think people like them" "have say in what gov does that vote for democratic representatives""' if _n == 45
replace title_demhouvote = `""Share of whites that neither agree nor disagree that people" "like them have say in what gov does that vote for democratic representatives""' if _n == 46
replace title_demhouvote = `""Share of whites with other responses to who has a say in" "what gov does that vote for democratic representatives""' if _n == 47
replace title_demhouvote = `""Share of whites better off in the past year" "that vote for democratic representatives""' if _n == 48
replace title_demhouvote = `""Share of whites with situations unchanged in" "the past year that vote for democratic representatives""' if _n == 49
replace title_demhouvote = `""Share of whites worse off in the past year" "that vote for democratic representatives""' if _n == 50

*Democratic Senators titles
replace title_demsenvote = `""Share of whites younger than 40" "voting for democratic senators""' if _n == 1
replace title_demsenvote = `""Share of whites 40 years or older" "voting for democratic senators""' if _n == 2
replace title_demsenvote = `""Share of white men voting" "for democratic senators""' if _n == 3
replace title_demsenvote = `""Share of white women voting" "for democratic senators""' if _n == 4
replace title_demsenvote = `""Share of whites in the 0% to 33% family income" "percentile voting for democratic senators""' if _n == 5
replace title_demsenvote = `""Share of whites in the 34% to 67% family income" "percentile voting for democratic senators""' if _n == 6
replace title_demsenvote = `""Share of whites in the 68% to 100% family income" "percentile voting for democratic senators""' if _n == 7
replace title_demsenvote = `""Share of whites with at least a bachelor" "degree voting for democratic senators""' if _n == 8
replace title_demsenvote = `""Share of whites with no bachelor degree" "voting for democratic senators""' if _n == 9
replace title_demsenvote = `""Share of whites with any college education" "voting for democratic senators""' if _n == 10
replace title_demsenvote = `""Share of whites with no college education" "voting for democratic senators""' if _n == 11
replace title_demsenvote = `""Share of whites born in the South that vote for democratic" "senators""' if _n == 12
replace title_demsenvote = `""Share of whites not born in the South that vote for" "democratic senators""' if _n == 13
replace title_demsenvote = `""Share of whites that attend church frequently" "that vote for democratic senators""' if _n == 14
replace title_demsenvote = `""Share of whites that attend church no more than a" "few times a year that vote for democratic senators""' if _n == 15
replace title_demsenvote = `""Share of whites that grew up in the country" "or a farm that vote for democratic senators""' if _n == 16 
replace title_demsenvote = `""Share of whites that did not grow up in the" "country or a farm that vote for democratic senators""' if _n == 17
replace title_demsenvote = `""Share of whites that identify with the" "middle class that vote for democratic senators""' if _n == 18
replace title_demsenvote = `""Share of whites that identify with the" "working class that vote for democratic senators""' if _n == 19
replace title_demsenvote = `""Share of whites that are warm towards" "blacks that vote for democratic senators""' if _n == 20
replace title_demsenvote = `""Share of whites that are cold towards" "blacks that vote for democratic senators""' if _n == 21
replace title_demsenvote = `""Share of white liberals that" "vote for democratic senators""' if _n == 22
replace title_demsenvote = `""Share of white conservaties that" "vote for democratic senators""' if _n == 23
replace title_demsenvote = `""Share of neutral whites that" "vote for democratic senators""' if _n == 24
replace title_demsenvote = `""Share of whites in central cities" "that vote for democratic senators""' if _n == 25
replace title_demsenvote = `""Share of whites in suburban areas" "that vote for democratic senators""' if _n == 26
replace title_demsenvote = `""Share of whites in rural or small towns" "that vote for democratic senators""' if _n == 27
replace title_demsenvote = `""Share of professional and managerial whites" "that vote for democratic senators""' if _n == 28
replace title_demsenvote = `""Share of clerical and sales worker whites" "that vote for democratic senators""' if _n == 29
replace title_demsenvote = `""Share of skilled, semi-skilled, and service worker" "whites that vote for democratic senators""' if _n == 30
replace title_demsenvote = `""Share of nonfarm white laborers" "that vote for democratic senators""' if _n == 31
replace title_demsenvote = `""Share of white farmers, farm managers," "and farm laborers that vote for democratic senators""' if _n == 32
replace title_demsenvote = `""Share of white homemarkers, unemployed, etc" "that vote for democratic senators""' if _n == 33
replace title_demsenvote = `""Share of whites that never trust gov to do" "what is right that vote for democratic senators""' if _n == 34
replace title_demsenvote = `""Share of whites that sometimes trust gov to" "do what is right that vote for democratic senators""' if _n == 35
replace title_demsenvote = `""Share of whites that trust gov to do what" "is right most of the time that vote for democratic senators""' if _n == 36
replace title_demsenvote = `""Share of whites that always trust gov to" "do what is right that vote for democratic senators""' if _n == 37
replace title_demsenvote = `""Share of whites whose trust in the gov to do" "what is right varies that vote for democratic senators""' if _n == 38
replace title_demsenvote = `""Share of whites that sometimes or never trust" "the gov to do what is right that vote for democratic senators""' if _n == 39
replace title_demsenvote = `""Share of whites that always or most of the trust" "the gov to do what is right that vote for democratic senators""' if _n == 40
replace title_demsenvote = `""Share of whites that believe that gov runs for few big interests" "that vote for democratic senators""' if _n == 41
replace title_demsenvote = `""Share of whites that believe that gov runs for benefit of all" "that vote for democratic senators""' if _n == 42
replace title_demsenvote = `""Share of whites with mixed response to who the gov runs for" "that vote for democratic senators""' if _n == 43
replace title_demsenvote = `""Share of whites that think people like them" "have say in what gov does that vote for democratic senators""' if _n == 44
replace title_demsenvote = `""Share of whites that do not think people like them" "have say in what gov does that vote for democratic senators""' if _n == 45
replace title_demsenvote = `""Share of whites that neither agree nor disagree that people" "like them have say in what gov does that vote for democratic senators""' if _n == 46
replace title_demsenvote = `""Share of whites with other responses to who has a say in" "what gov does that vote for democratic senators""' if _n == 47
replace title_demsenvote = `""Share of whites better off in the past year" "that vote for democratic senators""' if _n == 48
replace title_demsenvote = `""Share of whites with situations unchanged in" "the past year that vote for democratic senators""' if _n == 49
replace title_demsenvote = `""Share of whites worse off in the past year" "that vote for democratic senators""' if _n == 50

*Government role titles
replace title_govjobinc = `""Share of whites younger than 40 that believe that the" "government should guarantee jobs and basic income""' if _n == 1
replace title_govjobinc = `""Share of whites 40 years or older that believe that the" "government should guarantee jobs and basic income""' if _n == 2
replace title_govjobinc = `""Share of white men that believe that the" "government should guarantee jobs and basic income""' if _n == 3
replace title_govjobinc = `""Share of white women that believe that the" "government should guarantee jobs and basic income""' if _n == 4
replace title_govjobinc = `""Share of whites in the 0% to 33% family income percentile" "that believe that the government should guarantee jobs and" "basic income""' if _n == 5
replace title_govjobinc = `""Share of whites in the 34% to 67% family income" "percentile that believe that the government should" "guarantee jobs and basic income""' if _n == 6
replace title_govjobinc = `""Share of whites in the 68% to 100% family income" "percentile that believe that the government should" "guarantee jobs and basic income""' if _n == 7
replace title_govjobinc = `""Share of whites with at least a bachelor degree " "that believe that the government should guarantee " "jobs and basic income""' if _n == 8
replace title_govjobinc = `""Share of whites with no bachelor degree that believe" "that the government should guarantee jobs and basic" "income""' if _n == 9
replace title_govjobinc = `""Share of whites with any college education that believe" "that the government should guarantee jobs and basic" "income""' if _n == 10
replace title_govjobinc = `""Share of whites with no college education that believe" "that the government should guarantee jobs and basic" "income""' if _n == 11
replace title_govjobinc = `""Share of whites born in the South that believe that the" "government should guarantee jobs and basic income""' if _n == 12
replace title_govjobinc = `""Share of whites not born in the South that believe that" "the government should guarantee jobs and basic income""' if _n == 13
replace title_govjobinc = `""Share of whites that attend church frequently that believe" "that the government should guarantee jobs and basic" "income""' if _n == 14
replace title_govjobinc = `""Share of whites that attend church no more than a few" "times a year that believe that the government should" "guarantee jobs and basic income""' if _n == 15
replace title_govjobinc = `""Share of whites that grew up in the country or a farm" "that believe that the government should guarantee" "jobs and basic income""' if _n == 16 
replace title_govjobinc = `""Share of whites that did not grow up in the country" "or a farm that believe that the government should" "guarantee jobs and basic income""' if _n == 17
replace title_govjobinc = `""Share of whites that identify with the middle class" "that believe that the government should guarantee" "jobs and basic income""' if _n == 18
replace title_govjobinc = `""Share of whites that identify with the working class" "that believe that the government should guarantee" "jobs and basic income""' if _n == 19
replace title_govjobinc = `""Share of whites that are warm towards blacks that" "believe that the government should guarantee jobs" "and basic income""' if _n == 20
replace title_govjobinc = `""Share of whites that are cold towards blacks that" "believe that the government should guarantee jobs" "and basic income""' if _n == 21
replace title_govjobinc = `""Share of white liberals that believe that the" "government should guarantee jobs and basic income""' if _n == 22
replace title_govjobinc = `""Share of white conservatives that believe that" "the government should guarantee jobs and" "basic income""' if _n == 23
replace title_govjobinc = `""Share of neutral whites that believe that" "the government should guarantee jobs and" "basic income""' if _n == 24
replace title_govjobinc = `""Share of whites in central cities that believe that" "the government should guarantee jobs and" "basic income""' if _n == 25
replace title_govjobinc = `""Share of whites in suburban areas that believe that" "the government should guarantee jobs and" "basic income""' if _n == 26
replace title_govjobinc = `""Share of whites in rural or small towns that believe that" "the government should guarantee jobs and" "basic income""' if _n == 27
replace title_govjobinc = `""Share of professional and managerial whites that believe that" "the government should guarantee jobs and" "basic income""' if _n == 28
replace title_govjobinc = `""Share of clerical and sales worker whites that believe that" "the government should guarantee jobs and" "basic income""' if _n == 29
replace title_govjobinc = `""Share of skilled, semi-skilled, and service worker whites that believe that" "the government should guarantee jobs and" "basic income""' if _n == 30
replace title_govjobinc = `""Share of nonfarm white laborers that believe that" "the government should guarantee jobs and" "basic income""' if _n == 31
replace title_govjobinc = `""Share of white farmers, farm managers, and farm laborers that believe that" "the government should guarantee jobs and" "basic income""' if _n == 32
replace title_govjobinc = `""Share of white homemarkers, unemployed, etc that believe that" "the government should guarantee jobs and" "basic income""' if _n == 33
replace title_govjobinc = `""Share of whites that never trust gov to do" "what is right that believe that" "the government should guarantee jobs and" "basic income""' if _n == 34
replace title_govjobinc = `""Share of whites that sometimes trust gov to" "do what is right that believe that" "the government should guarantee jobs and" "basic income""' if _n == 35
replace title_govjobinc = `""Share of whites that trust gov to do what" "is right most of the time that believe that" "the government should guarantee jobs and" "basic income""' if _n == 36
replace title_govjobinc = `""Share of whites that always trust gov to" "do what is right that believe that" "the government should guarantee jobs and" "basic income""' if _n == 37
replace title_govjobinc = `""Share of whites whose trust in the gov to do" "what is right varies that believe that" "the government should guarantee jobs and" "basic income""' if _n == 38
replace title_govjobinc = `""Share of whites that sometimes or never trust" "the gov to do what is right that believe that" "the government should guarantee jobs and" "basic income""' if _n == 39
replace title_govjobinc = `""Share of whites that always or most of the trust" "the gov to do what is right that believe that" "the government should guarantee jobs and" "basic income""' if _n == 40
replace title_govjobinc = `""Share of whites that believe that gov runs for few big interests" "that believe that the government should guarantee" "jobs and basic income""' if _n == 41
replace title_govjobinc = `""Share of whites that believe that gov runs for benefit of all" "that believe that the government should guarantee" "jobs and basic income""' if _n == 42
replace title_govjobinc = `""Share of whites with mixed response to who the gov runs for" "that believe that the government should guarantee jobs and" "basic income""' if _n == 43
replace title_govjobinc = `""Share of whites that think people like them have say in what" "gov does that believe that the government should" "guarantee jobs and basic income""' if _n == 44
replace title_govjobinc = `""Share of whites that do not think people like them have say" "in what gov does that believe that the government should" "guarantee jobs and basic income""' if _n == 45
replace title_govjobinc = `""Share of whites that neither agree nor disagree that people" "like them have say in what gov does that believe that the" "government should guarantee jobs and basic income""' if _n == 46
replace title_govjobinc = `""Share of whites with other responses to who has a say in" "what gov does that believe that the government should" "guarantee jobs and basic income""' if _n == 47
replace title_govjobinc = `""Share of whites better off in the past year" "that believe that the government should guarantee jobs and" "basic income""' if _n == 48
replace title_govjobinc = `""Share of whites with situations unchanged in" "the past year that believe that the government" "should guarantee jobs and basic income""' if _n == 49
replace title_govjobinc = `""Share of whites worse off in the past year" "that believe that the government should guarantee jobs and" "basic income""' if _n == 50

*Warmth towards blacks
replace title_blk_therm = `""Average warmth towards blacks:" "whites younger than 40""' if _n == 1
replace title_blk_therm = `""Average warmth towards blacks:" "whites 40 years or older""' if _n == 2
replace title_blk_therm = `""Average warmth towards blacks:" "white men""' if _n == 3
replace title_blk_therm = `""Average warmth towards blacks:" "white women""' if _n == 4
replace title_blk_therm = `""Average warmth towards blacks:" "whites in the 0 to 33% family income percentile""' if _n == 5
replace title_blk_therm = `""Average warmth towards blacks:" "whites in the 34 to 67% family income percentile""' if _n == 6
replace title_blk_therm = `""Average warmth towards blacks:" "whites in the 68 to 100% family income percentile""' if _n == 7
replace title_blk_therm = `""Average warmth towards blacks:" "whites with at least a bachelor degree""' if _n == 8
replace title_blk_therm = `""Average warmth towards blacks:" "whites with no bachelor degree""' if _n == 9
replace title_blk_therm = `""Average warmth towards blacks:" "whites with any college education""' if _n == 10
replace title_blk_therm = `""Average warmth towards blacks:" "whites with no college education""' if _n == 11
replace title_blk_therm = `""Average warmth towards blacks:" "whites born in the South""' if _n == 12
replace title_blk_therm = `""Average warmth towards blacks:" "whites not born in the South""' if _n == 13
replace title_blk_therm = `""Average warmth towards blacks:" "whites that attend church frequently""' if _n == 14
replace title_blk_therm = `""Average warmth towards blacks:" "whites that attend church no more than a few times a year""' if _n == 15
replace title_blk_therm = `""Average warmth towards blacks:" "whites that grew up in the country or a farm""' if _n == 16 
replace title_blk_therm = `""Average warmth towards blacks:" "whites that did not grow up in the country or a farm""' if _n == 17
replace title_blk_therm = `""Average warmth towards blacks:" "whites that identify with the middle class""' if _n == 18
replace title_blk_therm = `""Average warmth towards blacks:" "whites that identify with the working class""' if _n == 19
replace title_blk_therm = `""Average warmth towards blacks:" "whites that are warm towards blacks""' if _n == 20
replace title_blk_therm = `""Average warmth towards blacks:" "whites that are cold towards blacks""' if _n == 21
replace title_blk_therm = `""Average warmth towards blacks:" "white liberals""' if _n == 22
replace title_blk_therm = `""Average warmth towards blacks:" "white conservatives""' if _n == 23
replace title_blk_therm = `""Average warmth towards blacks:" "neutral whites""' if _n == 24
replace title_blk_therm = `""Average warmth towards blacks:" "whites in central cities""' if _n == 25
replace title_blk_therm = `""Average warmth towards blacks:" "whites in suburban areas""' if _n == 26
replace title_blk_therm = `""Average warmth towards blacks:" "whites in rural or small towns""' if _n == 27
replace title_blk_therm = `""Average warmth towards blacks:" "professional and managerial whites""' if _n == 28
replace title_blk_therm = `""Average warmth towards blacks:" "clerical and sales worker whites""' if _n == 29
replace title_blk_therm = `""Average warmth towards blacks:" "skilled, semi-skilled, and service worker whites""' if _n == 30
replace title_blk_therm = `""Average warmth towards blacks:" "nonfarm white laborers""' if _n == 31
replace title_blk_therm = `""Average warmth towards blacks:" "white farmers, farm managers, and farm laborers""' if _n == 32
replace title_blk_therm = `""Average warmth towards blacks:" "white homemarkers, unemployed, etc""' if _n == 33
replace title_blk_therm = `""Average warmth towards blacks:" "never trust gov to do what is right""' if _n == 34
replace title_blk_therm = `""Average warmth towards blacks:" "sometimes trust gov to do what is right""' if _n == 35
replace title_blk_therm = `""Average warmth towards blacks:" "trust gov to do what is right most of the time""' if _n == 36
replace title_blk_therm = `""Average warmth towards blacks:" "always trust gov to do what is right""' if _n == 37
replace title_blk_therm = `""Average warmth towards blacks:" "trust in the gov to do what is right varies""' if _n == 38
replace title_blk_therm = `""Average warmth towards blacks:" "sometimes or never trust the gov to do what is right""' if _n == 39
replace title_blk_therm = `""Average warmth towards blacks:" "always or most of the trust the gov to do what is right""' if _n == 40
replace title_blk_therm = `""Average warmth towards blacks:" "believe that gov runs for few big interests""' if _n == 41
replace title_blk_therm = `""Average warmth towards blacks:" "believe that gov runs for benefit of all""' if _n == 42
replace title_blk_therm = `""Average warmth towards blacks:" "mixed response to who the gov runs for""' if _n == 43
replace title_blk_therm = `""Average warmth towards blacks:" "think people like them have say in what gov does""' if _n == 44
replace title_blk_therm = `""Average warmth towards blacks:" "do not think people like them have say in what gov does""' if _n == 45
replace title_blk_therm = `""Average warmth towards blacks:" "neither agree nor disagree that people like them" "have say in what gov does""' if _n == 46
replace title_blk_therm = `""Average warmth towards blacks:" "other responses to who has a say in what gov does""' if _n == 47
replace title_blk_therm = `""Average warmth towards blacks:" "better off in the past year""' if _n == 48
replace title_blk_therm = `""Average warmth towards blacks:" "situations unchanged in the past year""' if _n == 49
replace title_blk_therm = `""Average warmth towards blacks:" "worse off in the past year""' if _n == 50


gen gen_title = title_blk_therm
local n = length("Average warmth towards blacks")+length("whites") + 4
replace gen_title = substr(gen_title, `n',.)
qui tab gen_title
replace gen_title = substr(gen_title, 3,.) if _n < 3 | (_n > 4 & _n <= r(N))
replace gen_title = substr(gen_title, 6,.) if (_n >= 8 & _n <= 11)
replace gen_title = substr(gen_title, 6,.) if (_n >= 14 & _n <= r(N))
replace gen_title = trim(gen_title)
replace gen_title = substr(gen_title,1,length(gen_title)-1)

*Now Manually add the titles
replace gen_title = "men" if _n == 3
replace gen_title = "women" if _n == 4
replace gen_title = "liberal" if _n == 22
replace gen_title = "conservative" if _n == 23
replace gen_title = "neutral" if _n == 24
replace gen_title = "live in central cities" if _n == 25
replace gen_title = "live in suburban areas" if _n == 26
replace gen_title = "live in rural or small towns" if _n == 27
replace gen_title = "professional and managerial whites" if _n == 28
replace gen_title = "clerical and sales worker whites" if _n == 29
replace gen_title = "skilled, semi-skilled, and service worker whites" if _n == 30
replace gen_title = "nonfarm white laborers" if _n == 31
replace gen_title = "white farmers, farm managers, and farm laborers" if _n == 32
replace gen_title = "white homemarkers, unemployed, etc" if _n == 33
replace gen_title = "never trust gov to do what is right" if _n == 34
replace gen_title = "sometimes trust gov to do what is right" if _n == 35
replace gen_title = "trust gov to do what is right most of the time" if _n == 36
replace gen_title = "always trust gov to do what is right" if _n == 37
replace gen_title = "trust in the gov to do what is right varies" if _n == 38
replace gen_title = "sometimes or never trust the gov to do what is right" if _n == 39
replace gen_title = "always or most of the trust the gov to do what is right" if _n == 40
replace gen_title = "believe that gov runs for few big interests" if _n == 41
replace gen_title = "believe that gov runs for benefit of all" if _n == 42
replace gen_title = "mixed response to who the gov runs for" if _n == 43
replace gen_title = "think people like them have say in what gov does" if _n == 44
replace gen_title = "do not think people like them have say in what gov does" if _n == 45
replace gen_title = "neither agree nor disagree that people like them have say in what gov does" if _n == 46
replace gen_title = "other responses to who has a say in what gov does" if _n == 47
replace gen_title = "better off in the past year" if _n == 48
replace gen_title = "situations unchanged in the past year" if _n == 49
replace gen_title = "worse off in the past year" if _n == 50
replace gen_title = "the elderly" if _n == 51
replace gen_title = "the non-elderly" if _n == 52
replace gen_title = "blacks" if _n == 53
replace gen_title = "whites" if _n == 54
replace gen_title = "Hispanics" if _n == 55
replace gen_title = "other races and ethnicities" if _n == 56
replace gen_title = "immigrants" if _n == 57
replace gen_title = "non-immigrants" if _n == 58
replace gen_title = "first generation" if _n == 59
replace gen_title = "not first generation" if _n == 60

*Creating a new group variable for the populationa and voter trends charts
*by, through gen_group, appending popgroup onto group
gen gen_group = group 
count if !missing(gen_group)
local n1 = r(N)
count if !missing(popgroup)
local n2 = r(N)
//apending popgroup
foreach n of num 1/`n2' {
	replace gen_group = popgroup[`n'] if _n == (`n1'+`n') 
}




foreach rgn in NT S NS PNS NPNS B M W N  {
	if ("`rgn'" == "NT") {
		local region = "US"
	}
	else if ("`rgn'" == "N") {
		local region = "North"
	}			
	else if ("`rgn'" == "S") {
		local region = "South"
	}
	else if ("`rgn'" == "B") {
		local region = "North/South Border"
	}
	else if ("`rgn'" == "M") {
		local region = "Midwest"
	}
	else if ("`rgn'" == "W") {
		local region = "West"
	}
	else if ("`rgn'" == "PNS") {
		local region = "Poor NonSouth"
	}
	foreach pop in all wht blk {
		foreach grp in vote {
			*General Population
			egen temp_1 = sum(resp*wgt) if `rgn' == 1 & `grp'==1 & `pop' == 1, by(year)
			egen temp_2 = sum(wgt) if `rgn' == 1 & `grp'==1 & `pop' == 1, by(year)
			gen  temp_3 = temp_1/temp_2 if `rgn' == 1 & `grp'==1 & `pop' == 1
			egen ptotal_`grp'`rgn'`pop' = sum(temp_3) if `rgn' == 1 & `grp'==1 & `pop' == 1, by(year)
			label variable ptotal_`grp'`rgn'`pop' "Weighted Population Total: `grp' and `region', `pop' "
			gen pshare_`grp'`rgn'`pop' = (ptotal_`grp'`rgn'`pop')/(ptotal_`rgn'`pop')
			label variable pshare_`grp'`rgn'`pop' "Weighted Population Share: `grp' and `region', `pop' "
			drop temp_*
		}
	}
}


*Differences charts
levelsof outcome, local(lc_outcome)
replace gen_group = ""
replace gen_group = group
count if !missing(group)
local n = r(N)
count if !missing(popgroup)
local m = r(N)
foreach x of num 1/`m' {
	local var = popgroup[`x']
	replace gen_group = "`var'" if _n == `n' + `x'
} 

gen outcome_title = ""
replace outcome_title = "the percent voting for democratic presidents" if _n == 1
replace outcome_title = "the percent voting for democratic representatives" if _n == 2
replace outcome_title = "the percent voting for democratic senators" if _n == 3
replace outcome_title = "the percent identifying as democrats" if _n == 4
replace outcome_title = "the percent that support basic income and jobs" if _n == 5
replace outcome_title = "average warmth towards blacks" if _n == 6


replace outcome = trim(outcome)
replace gen_group = trim(gen_group)
replace group = "" if group == "all"
replace gen_title = "" if gen_title == "all"
capture noisily gen DoutcomeVars = ""
count if !missing(outcome)
local m1 = r(N)
count if !missing(gen_group)
local m2 = r(N)
 
compress
*saveold $input/ANES_descV1.dta, replace


