*********************************************************************************************************
// Why did the Democrats Lose the South? Bringing New Data to an Old Debate, Kuziemko & Washington (2018)
// This do file cleans the raw data from Gallup & GSS

set more off
set matsize 11000

else if "`c(username)'"=="kuziemko"  {
cap cd ~/Dropbox/southern_strategy
global path ~/Dropbox/southern_strategy
global output "$path/Replication/Output"
global input "$path/Replication/Input"
global add "$path/Replication/Input/Additional"
global do "$path/Replication/DoFiles"
}


else if "`c(username)'"=="fvivar" { 

cap cd ~/Dropbox/southern_strategy
global path ~/Dropbox/southern_strategy
global output "$path/Replication/Output"
global input "$path/Replication/Input"
global add "$path/Replication/Input/Additional"
global do "$path/Replication/DoFiles"

}
********************************************************************************


/* APPENDING GALLUP AND GSS SURVEYS & SHAPING THE RESULTING DATASET */

/*
This do file appends gallup.dta (created by reading_ascii_in_Stata.do) with
GSS_keyvar.dta (created by Shaping_GSS.do) --> gallup_and_GSS.dta
It then adds relevant variables later used in the analysis.

Additionally, it creates gallup_and_GSS_extrayears.dta, which results from
appending gallup_and_GSS.dta with
	- PresidentialApprovalQuestionsEisenhower9.8.2014.dta
(created by Meredith's PresidentialApprovalQuestionsEisenhower9.8.2014.do)
	- PresidentialApprovalQuestionsKennedy8.24.2014.dta (created by Meredith's
PresidentialApprovalQuestionsKennedy8.24.2014.do)
	- PartyID_1944_1952.dta (created by Sukhmani's PartyID_1944_1952.do)
	- PartyID_1963-1970.11.22.2014.dta (created by Meredith's PartyID_1963-1970.11.22.2014.do)
	- PartyID_1971_1980.dta (created by Sukhmani's PartyID_1971_1980.do)
	- PartyID_1981-2004.11.17.2014.dta (created by Meredith's PartyID_1981-2004.11.17.2014.do)
This dataset is used when plotting political variables over time (without
racial variables), and when studying Eisenhower and Kennedy's approval.
*/

/* APPENDING GALLUP AND GSS SURVEYS */

use "$input/gallup.dta", clear
	*harmonizing the age variable with GSS age
	replace age = 89 if age > 89 & !missing(age)
		lab def lb_age 89 "89 and older"
		lab val age lb_age
	*appending GSS surveys
	append using "$input/GSS_keyvar.dta"
	*dropping 18-20 year olds (cannot always vote)
	drop if age >= 18 & age <= 20
	*dropping AK and HI states (not sampled consistently)
	drop if state == 84 | state == 85
	*Set dup_weights=1 for years that gallup didn't duplicate data
	gen dup_weight=(svy_year<1961 | svy_year>1967)
	gen tag_dup=(svy_year<1961 | svy_year>1967)


/* ADDING RELEVANT VARIABLES FOR ANALYSIS */
*tracking data source (Gallup vs. GSS)
gen svy_type = 1
	replace svy_type = 2 if strpos(svy, "GSS") > 0
	lab var svy_type "Gallup or GSS survey"
	lab def lb_svy_type 1 "Gallup" 2 "GSS"
	lab val svy_type lb_svy_type

*tracking surveys with the "black President" question
bys svy: egen svy_blkPres = max(blkPresident)
	replace svy_blkPres = !missing(svy_blkPres)
	lab var svy_blkPres "Survey including the black President question"

*creating south, confed and deep_south variables
*** NOTE: confed & deep_south are currently missing for GSS ***
gen south = region == 3 if !missing(region)
	lab var south "South"
	lab def lb_south 0 "Non South" 1 "South"
	lab val south lb_south
gen confed = south if !missing(state)
	lab var confed "Confederate States"
	replace confed = 0 if state==24 | state==25 | state==26 | state==27 | state==56 | state==63
	lab def lb_confed 0 "Non CS state" 1 "CS state"
	lab val confed lb_confed
gen deep_south = (state==58 | state==54 | state==62 | state==59 | state==53) if !missing(state)
	lab var deep_south "Deep South"
	lab def lb_deep_south 0 "Non Deep South" 1 "Deep South"

*creating political dummies (dem, rep & demrep)
gen dem = poliPartyID == 2 if !missing(poliPartyID)
	lab var dem "Democrat vs. anyone else"
	lab def lb_dem 0 "Non Democrat" 1 "Democrat"
	lab val dem lb_dem
gen rep = poliPartyID == 1 if !missing(poliPartyID)
	lab var rep "Republican vs. anyone else"
	lab def lb_rep 0 "Non Republican" 1 "Republican"
	lab val rep lb_rep
gen demrep = .
	replace demrep = 1 if poliPartyID == 2
	replace demrep = 0 if poliPartyID == 1
	lab var demrep "Democrat vs. Republican"
	lab def lb_demrep 0 "Republican" 1 "Democrat"
	lab val demrep lb_demrep

*creating a female dummy variable
gen female = sex == 2 if !missing(sex)
	lab def lb_female 0 "Male" 1 "Female"
	lab val female lb_female

*creating age decade dummies, decade variable and decile variable
gen age20 = (age >=20 & age < 30) if !missing(age)
gen age30 = (age >=30 & age < 40) if !missing(age)
gen age40 = (age >=40 & age < 50) if !missing(age)
gen age50 = (age >=50 & age < 60) if !missing(age)
gen age60 = (age >=60 & age < 70) if !missing(age)
gen age70 = (age >=70 & age < 80) if !missing(age)
gen age80 = (age >=80 & age < 90) if !missing(age)
gen age_10 = round(age, 10) if !missing(age)
	lab var age_10 "Age rounded to nearest decade"
xtile age_decile = age, nq(10)
	lab var age_decile "Age decile"

*creating dummies and variables for city size
gen city_dummy = .
	replace city_dummy = 1 if (!missing(citySize) & citySize >= 1 & citySize <= 4) ///
		| (!missing(size) & size < 5)
	replace city_dummy = 2 if (!missing(citySize) & citySize >= 5 & citySize <= 7) ///
		| (!missing(size) & size >= 5 & size < 50)
	replace city_dummy = 3 if (!missing(citySize) & citySize >= 8) ///
		| (!missing(size) & size >= 50)
	lab def lb_city_dummy 1 "Less than 4,999" 2 "5,000 to 49,999" 3 "More than 50,000"
	lab val city_dummy lb_city_dummy
	lab var city_dummy "City size categorical variable, using 5,000 and 50,000 as thresholds"
gen urban = .
	replace urban = 0 if citySize >= 1 & citySize <= 3 & !missing(citySize)
	replace urban = 1 if citySize >= 4 & citySize <= 12 & !missing(citySize)
	replace urban = 0 if svy_type == 2 & size < 4 & !missing(size)
	replace urban = 1 if svy_type == 2 & size >= 4 & !missing(size)
	lab var urban "Urban/rural status"
	lab def urban_lbl 0 "Rural" 1 "Urban"
	lab val urban urban_lbl

*creating high school dummy
gen highschool = eduHarmonized >= 5 if !missing(eduHarmonized)
	lab def lb_highschool 0 "Less than high school" 1 "High school graduate or more"
	lab val highschool lb_highschool
	lab var highschool "Dummy for educational attainment (using high school as the threshold)"

*rescaling black President and black neighbor questions
recode blkPresident (2=-1) (3=0) (9=.)
	lab def lb_blkPresident -1 "No" 0 "Don't know" 1 "Yes"
	lab val blkPresident lb_blkPresident
recode blkNeighbor blkNeighborhood (1=-2) (2=-1) (4=0) (3=2)
	lab def lb_blkNeighbor -2 "Yes, definitely" -1 "Might do" 0 "Don't know" 2 "No", replace
	lab val blkNeighbor blkNeighborhood lb_blkNeighbor

*creating a weight variable:
*	wtssall*oversamp for GSS // wgt for Gallup post 1968 // 1 for Gallup polls pre 1968
*	weights are then rescaled so that all surveys have the same total weight
gen weight = wtssall*oversamp
	replace weight = wgt if svy_year >= 1968 & svy_type == 1
	replace weight = 1 if svy_year < 1968 & svy_type == 1
gen weight_scaled = weight
bys svy: egen weight_tot = sum(weight)
replace weight_scaled = weight_scaled/weight_tot

*adding mid-survey date for surveys with black president question
gen svy_date = mdy(8, 1, 1958) if svy == "1958-0602"
replace svy_date = mdy(9, 12, 1958) if svy == "1958-0604"
replace svy_date = mdy(12, 12, 1959) if svy == "1959-0622"
replace svy_date = mdy(8, 26, 1961) if svy == "1961-0649"
replace svy_date = mdy(8, 17, 1963) if svy == "1963-0676"
replace svy_date = mdy(7, 18, 1965) if svy == "1965-0714"
replace svy_date = mdy(4, 21, 1967) if svy == "1967-0744"
replace svy_date = mdy(3, 14, 1969) if svy == "1969-0776"
replace svy_date = mdy(10, 9, 1971) if svy == "1971-0838"
replace svy_date = mdy(7, 22, 1978) if svy == "1978-1107"
replace svy_date = mdy(3, 12, 1983) if svy == "1983-1211"
replace svy_date = mdy(7, 28, 1984) if svy == "1984-1239"
replace svy_date = mdy(7, 11, 1987) if svy == "1987-1278"
replace svy_date = mdy(2, 20, 1999) if svy == "1999-9902012"
replace svy_date = mdy(5, 31, 2003) if svy == "2003-32"
replace svy_date = mdy(3, 1, svy_year) if svy_type == 2 & svy_blkPres & svy_year <= 2002
replace svy_date = mdy(5, 1, svy_year) if svy_type == 2 & svy_blkPres & svy_year >= 2006 & svy_year <= 2012
lab var svy_date "Midpoint between the survey's start date and the survey's end date"
format svy_date %td

*adding mid-survey date for surveys with black neighbor question
replace svy_date = mdy(9, 26, 1958) if svy == "1958-0605"
replace svy_date = mdy(5, 25, 1963) if svy == "1963-0673"
replace svy_date = mdy(4, 25, 1965) if svy == "1965-0710"
replace svy_date = mdy(5, 21, 1966) if svy == "1966-0729"
replace svy_date = mdy(6, 18, 1966) if svy == "1966-0730"
replace svy_date = mdy(8, 5, 1967) if svy == "1967-0749"
replace svy_date = mdy(7, 8, 1978) if svy == "1978-1106"

/* ADDING PRESIDENTIAL APPROVAL & POLITICAL PARTY DATASETS */

append using "$add/PresidentialApprovalQuestionsEisenhower6.18.2016.dta"
append using "$add/PresidentialApprovalQuestionsKennedy6.18.2016.dta"
append using "$add/PartyID_1944_1952_Detailed.dta"
append using "$add/PartyID_1963-1970.6.18.2016.dta"
append using "$add/PartyID_1971_1980.dta"
append using "$add/PartyID_1981-2004.11.17.2014.dta"

*Extend the highschool dummy to the just appended surveys
replace highschool = 1 if eduHarmonized >= 5 & !missing(eduHarmonized)
replace highschool = 0 if eduHarmonized <5 & !missing(eduHarmonized)

*tracking new surveys added
bys svy: egen temp_newsvy1 = max(state_orig)
bys svy: egen temp_newsvy2 = max(age_orig)
gen new_svy = !missing(temp_newsvy1) | !missing(temp_newsvy2)
drop temp_newsvy*

*tracking surveys with the president approval question
bys svy: egen temp_presapp = max(presApprovala)
gen svy_approval = !missing(temp_presapp)
drop temp_presapp

*harmonizing survey year (named differently by Meredith)
replace svy_year = svy_yr if missing(svy_year)

*harmonizing age
drop if age >= 18 & age <= 20
replace age = 89 if !missing(age) & age > 89

*correcting state variable to harmonize Meredith's polls with mine
replace state = state + 20 if new_svy == 1 & (state == 81 | state == 82 | state == 83 | state == 84)
replace state = state + 10 if new_svy == 1 & (state == 71 | state == 72 | state == 73)
replace state = state + 10 if new_svy == 1 & (state == 61 | state == 62 | state == 63 | state == 64 | state == 65 | state == 66 | state == 67 | state == 68)
replace state = state - 40 if new_svy == 1 & (state == 101 | state == 102 | state == 103 | state == 104)
drop if state == 84 | state == 85

*filling in confed variable
replace confed = 0 if new_svy == 1 & !missing(state)
replace confed = 1 if new_svy == 1 & (state == 51 | state == 52 | state == 53 | state == 54  ///
	| state == 55 | state == 57 | state == 58 | state == 59 | state == 61 | state == 62 | state == 64)

*filling in race and sex variables
lab def lb_race 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE (SURVEYS 1955-1956)", replace
lab val race lb_race
replace race = 1 if new_svy == 1 & missing(race) & (raceSex == 1 | raceSex == 2)
replace race = 2 if new_svy == 1 & missing(race) & (raceSex == 3 | raceSex == 4)
replace race = 3 if new_svy == 1 & missing(race) & (raceSex == 5 | raceSex == 6)
replace sex = 1 if new_svy == 1 & missing(sex) & (raceSex == 1 | raceSex == 3 | raceSex == 5)
replace sex = 2 if new_svy == 1 & missing(sex) & (raceSex == 2 | raceSex == 4 | raceSex == 6)

*merging "both" and "no opinion" in presApprovala
replace presApprovala = 3 if presApprovala == 4
lab def lb_presApprovala 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION / UNDECIDED", replace
lab val presApprovala lb_presApprovala

*filling in dem (Democrat dummy)
replace dem = 0 if new_svy == 1 & !missing(poliPartyID)
replace dem = 1 if new_svy == 1 & poliPartyID == 2

*adding mid-survey date for Eisenhower & Kennedy presidential approval surveys
replace svy_date = round((mdy( 3, 5,1948) + mdy( 3,10,1948))/2) if svy == "1948-0414"
replace svy_date = round((mdy( 3,19,1949) + mdy( 3,24,1949))/2) if svy == "1949-0439"
replace svy_date = round((mdy(11,27,1949) + mdy(12, 1,1949))/2) if svy == "1949-0450"
replace svy_date = round((mdy( 2, 1,1953) + mdy( 2, 5,1953))/2) if svy == "1953-0511"
replace svy_date = mdy(2, 3, 1953) if svy == "1953-0511"
replace svy_date = mdy(3, 30, 1953) if svy == "1953-0513"
replace svy_date = mdy(8, 17, 1953) if svy == "1953-0519"
replace svy_date = mdy(10, 11, 1953) if svy == "1953-0521"
replace svy_date = mdy(11, 3, 1953) if svy == "1953-0522"
replace svy_date = mdy(4, 10, 1954) if svy == "1954-0529"
replace svy_date = mdy(5, 23, 1954) if svy == "1954-0531"
replace svy_date = mdy(6, 14, 1954) if svy == "1954-0532"
replace svy_date = mdy(7, 18, 1954) if svy == "1954-0534"
replace svy_date = mdy(9, 18, 1954) if svy == "1954-0537"
replace svy_date = mdy(1, 2, 1955) if svy == "1955-0541"
replace svy_date = mdy(4, 16, 1955) if svy == "1955-0546"
replace svy_date = mdy(5, 14, 1955) if svy == "1955-0547"
replace svy_date = mdy(11, 19, 1955) if svy == "1955-0556"
replace svy_date = mdy(2, 18, 1956) if svy == "1956-0560"
replace svy_date = mdy(3, 31, 1956) if svy == "1956-0562"
replace svy_date = mdy(8, 25, 1956) if svy == "1956-0569"
replace svy_date = mdy(9, 11, 1956) if svy == "1956-0570"
replace svy_date = mdy(9, 22, 1956) if svy == "1956-0571"
replace svy_date = mdy(12, 16, 1956) if svy == "1956-0576"
replace svy_date = mdy(1, 19, 1957) if svy == "1957-0577"
replace svy_date = mdy(2, 7, 1957) if svy == "1957-0578"
replace svy_date = mdy(3, 2, 1957) if svy == "1957-0579"
replace svy_date = mdy(3, 17, 1957) if svy == "1957-0580"
replace svy_date = mdy(4, 8, 1957) if svy == "1957-0581"
replace svy_date = mdy(4, 27, 1957) if svy == "1957-0582"
replace svy_date = mdy(6, 8, 1957) if svy == "1957-0584"
replace svy_date = mdy(7, 20, 1957) if svy == "1957-0586"
replace svy_date = mdy(9, 1, 1957) if svy == "1957-0588"
replace svy_date = mdy(9, 21, 1957) if svy == "1957-0589"
replace svy_date = mdy(10, 12, 1957) if svy == "1957-0590"
replace svy_date = mdy(11, 9, 1957) if svy == "1957-0591"
replace svy_date = mdy(2, 16, 1958) if svy == "1958-0595"
replace svy_date = mdy(5, 9, 1958) if svy == "1958-0599"
replace svy_date = mdy(8, 1, 1958) if svy == "1958-0602"
replace svy_date = mdy(8, 22, 1958) if svy == "1958-0603"
replace svy_date = mdy(9, 12, 1958) if svy == "1958-0604"
replace svy_date = mdy(9, 26, 1958) if svy == "1958-0605"
replace svy_date = mdy(11, 9, 1958) if svy == "1958-0607"
replace svy_date = mdy(12, 5, 1958) if svy == "1958-0608"
replace svy_date = mdy(1, 9, 1959) if svy == "1959-0609"
replace svy_date = mdy(2, 6, 1959) if svy == "1959-0610"
replace svy_date = mdy(3, 6, 1959) if svy == "1959-0611"
replace svy_date = mdy(5, 31, 1959) if svy == "1959-0614"
replace svy_date = mdy(6, 27, 1959) if svy == "1959-0615"
replace svy_date = mdy(7, 25, 1959) if svy == "1959-0616"
replace svy_date = mdy(12, 5, 1959) if svy == "1959-0621"
replace svy_date = mdy(12, 12, 1959) if svy == "1959-0622"
replace svy_date = mdy(1, 8, 1960) if svy == "1960-0623"
replace svy_date = mdy(2, 6, 1960) if svy == "1960-0624"
replace svy_date = mdy(3, 4, 1960) if svy == "1960-0625"
replace svy_date = mdy(8, 27, 1960) if svy == "1960-0634"
replace svy_date = mdy(9, 11, 1960) if svy == "1960-0635"
replace svy_date = mdy(10, 20, 1960) if svy == "1960-0637"
replace svy_date = mdy(11, 19, 1960) if svy == "1960-0638"
replace svy_date = mdy(2, 12, 1961) if svy == "1961-0641"
replace svy_date = mdy(3, 12, 1961) if svy == "1961-0642"
replace svy_date = mdy(5, 6, 1961) if svy == "1961-0644"
replace svy_date = mdy(5, 30, 1961) if svy == "1961-0646"
replace svy_date = mdy(8, 26, 1961) if svy == "1961-0649"
replace svy_date = mdy(10, 21, 1961) if svy == "1961-0651"
replace svy_date = mdy(1, 13, 1962) if svy == "1962-0654"
replace svy_date = mdy(2, 10, 1962) if svy == "1962-0655"
replace svy_date = mdy(6, 30, 1962) if svy == "1962-0660"
replace svy_date = mdy(7, 28, 1962) if svy == "1962-0661"
replace svy_date = mdy(8, 25, 1962) if svy == "1962-0662"
replace svy_date = mdy(9, 22, 1962) if svy == "1962-0663"
replace svy_date = mdy(10, 21, 1962) if svy == "1962-0664"
replace svy_date = mdy(11, 18, 1962) if svy == "1962-0665"
replace svy_date = mdy(12, 15, 1962) if svy == "1962-0666"
replace svy_date = mdy(1, 13, 1963) if svy == "1963-0667"
replace svy_date = mdy(2, 9, 1963) if svy == "1963-0668"
replace svy_date = mdy(3, 10, 1963) if svy == "1963-0669"
replace svy_date = mdy(4, 6, 1963) if svy == "1963-0670"
replace svy_date = mdy(5, 4, 1963) if svy == "1963-0671"
replace svy_date = mdy(5, 25, 1963) if svy == "1963-0673"
replace svy_date = mdy(6, 23, 1963) if svy == "1963-0674"
replace svy_date = mdy(7, 20, 1963) if svy == "1963-0675"
replace svy_date = mdy(8, 17, 1963) if svy == "1963-0676"
replace svy_date = mdy(11, 10, 1963) if svy == "1963-0679"
replace svy_date = mdy(12, 7, 1963) if svy == "1963-0681"
replace svy_date = mdy(12, 14, 1963) if svy == "1963-0682"
replace svy_date = mdy(1, 4, 1964) if svy == "1964-0683"
replace svy_date = mdy(2, 2, 1964) if svy == "1964-0684"
replace svy_date = mdy(3, 2, 1964) if svy == "1964-0686"
replace svy_date = mdy(3, 15, 1964) if svy == "1964-0687"
replace svy_date = mdy(3, 30, 1964) if svy == "1964-0688"
replace svy_date = mdy(4, 26, 1964) if svy == "1964-0689"
replace svy_date = mdy(6, 13, 1964) if svy == "1964-0693"
replace svy_date = mdy(6, 27, 1964) if svy == "1964-0694"
replace svy_date = mdy(10, 10, 1964) if svy == "1964-0699"
replace svy_date = mdy(11, 8, 1964) if svy == "1964-0701"
replace svy_date = mdy(11, 22, 1964) if svy == "1964-0702"
replace svy_date = mdy(1, 9, 1965) if svy == "1965-0704"
replace svy_date = mdy(1, 30, 1965) if svy == "1965-0705"
replace svy_date = mdy(2, 21, 1965) if svy == "1965-0706"
replace svy_date = mdy(4, 4, 1965) if svy == "1965-0709"
replace svy_date = mdy(4, 25, 1965) if svy == "1965-0710"
replace svy_date = mdy(5, 15, 1965) if svy == "1965-0711"
replace svy_date = mdy(6, 6, 1965) if svy == "1965-0712"
replace svy_date = mdy(6, 26, 1965) if svy == "1965-0713"
replace svy_date = mdy(8, 7, 1965) if svy == "1965-0715"
replace svy_date = mdy(8, 29, 1965) if svy == "1965-0716"
replace svy_date = mdy(9, 18, 1965) if svy == "1965-0717"
replace svy_date = mdy(10, 10, 1965) if svy == "1965-0718"
replace svy_date = mdy(10, 31, 1965) if svy == "1965-0719"
replace svy_date = mdy(12, 13, 1965) if svy == "1965-0721"
replace svy_date = mdy(1, 2, 1966) if svy == "1966-0722"
replace svy_date = mdy(1, 23, 1966) if svy == "1966-0723"
replace svy_date = mdy(2, 12, 1966) if svy == "1966-0724"
replace svy_date = mdy(4, 16, 1966) if svy == "1966-0727"
replace svy_date = mdy(5, 7, 1966) if svy == "1966-0728"
replace svy_date = mdy(5, 21, 1966) if svy == "1966-0729"
replace svy_date = mdy(6, 18, 1966) if svy == "1966-0730"
replace svy_date = mdy(7, 10, 1966) if svy == "1966-0731"
replace svy_date = mdy(7, 31, 1966) if svy == "1966-0732"
replace svy_date = mdy(8, 20, 1966) if svy == "1966-0733"
replace svy_date = mdy(9, 10, 1966) if svy == "1966-0734"
replace svy_date = mdy(10, 3, 1966) if svy == "1966-0735"
replace svy_date = mdy(10, 23, 1966) if svy == "1966-0736"
replace svy_date = mdy(11, 12, 1966) if svy == "1966-0737"
replace svy_date = mdy(12, 10, 1966) if svy == "1966-0738"
replace svy_date = mdy(1, 28, 1967) if svy == "1967-0740"
replace svy_date = mdy(2, 18, 1967) if svy == "1967-0741"
replace svy_date = mdy(3, 11, 1967) if svy == "1967-0742"
replace svy_date = mdy(4, 1, 1967) if svy == "1967-0743"
replace svy_date = mdy(5, 13, 1967) if svy == "1967-0745"
replace svy_date = mdy(6, 4, 1967) if svy == "1967-0746"
replace svy_date = mdy(6, 24, 1967) if svy == "1967-0747"
replace svy_date = mdy(7, 15, 1967) if svy == "1967-0748"
replace svy_date = mdy(8, 5, 1967) if svy == "1967-0749"
replace svy_date = mdy(8, 26, 1967) if svy == "1967-0750"
replace svy_date = mdy(9, 16, 1967) if svy == "1967-0751"
replace svy_date = mdy(10, 8, 1967) if svy == "1967-0752"
replace svy_date = mdy(10, 29, 1967) if svy == "1967-0753"
replace svy_date = mdy(11, 18, 1967) if svy == "1967-0754"
replace svy_date = mdy(12, 9, 1967) if svy == "1967-0755"
replace svy_date = mdy(1, 6, 1968) if svy == "1968-0756"
replace svy_date = mdy(2, 4, 1968) if svy == "1968-0757"
replace svy_date = mdy(2, 24, 1968) if svy == "1968-0758"
replace svy_date = mdy(4, 6, 1968) if svy == "1968-0760"
replace svy_date = mdy(5, 4, 1968) if svy == "1968-0761"
replace svy_date = mdy(5, 25, 1968) if svy == "1968-0762"
replace svy_date = mdy(6, 15, 1968) if svy == "1968-0763"
replace svy_date = mdy(6, 28, 1968) if svy == "1968-0764"
replace svy_date = mdy(7, 20, 1968) if svy == "1968-0765"
replace svy_date = mdy(8, 9, 1968) if svy == "1968-0766"
replace svy_date = mdy(9, 3, 1968) if svy == "1968-0767"
replace svy_date = mdy(9, 21, 1968) if svy == "1968-0768"
replace svy_date = mdy(9, 28, 1968) if svy == "1968-0769"
replace svy_date = mdy(10, 19, 1968) if svy == "1968-0770"
replace svy_date = mdy(11, 11, 1968) if svy == "1968-0771"
replace svy_date = mdy(12, 7, 1968) if svy == "1968-0772"
replace svy_date = mdy(1, 3, 1969) if svy == "1969-0773"

*adding mid-survey date for truman presidential approval surveys
saveold "$input/gallup_and_GSS_extrayears.dta", replace

use "$input/gallup_gss_truman_dates.dta", clear
merge 1:m svy using "$input/gallup_and_GSS_extrayears.dta"
drop _merge

*filling in weight and weight_scaled
	*checking that wgt is never missing when available in a survey
	/* gen temp_wgt = !missing(wgt)
	tab svy temp_wgt
	survey 1969-0791 has both non missing and missing wgt values => should be 5 according to the codebook */
	replace wgt = 5 if svy == "1969-0791" & missing(wgt)
replace weight = wgt if new_svy == 1 & svy_year >= 1968
replace weight = 1 if new_svy == 1 & (svy_year < 1968 | (svy_year >= 1968 & missing(wgt)))
bys svy: egen weight_tot2 = sum(weight) if new_svy == 1
replace weight_tot = weight_tot2 if new_svy == 1
drop weight_tot2
replace weight_scaled = weight/weight_tot if new_svy == 1

*Set dup_weights=1 for years that gallup didn't duplicate data
	replace dup_weight=1 if (svy_year<1961 | svy_year>1967)
	replace tag_dup=1 if (svy_year<1961 | svy_year>1967)

****Generate main analysis vars 
gen aft = svy_year >= 1963 if!missing(svy_year) 
gen conf_aft = (confed == 1 & aft == 1) if !missing(confed) & !missing(aft) 
gen noprez = blkPresident != 1 if !missing(blkPresident) 
foreach var of varlist noprez { 
	gen conf_`var' = confed*`var' if !missing(confed) & !missing(`var') 
	gen `var'_aft = aft*`var' if !missing(aft) & !missing(`var') 
	gen conf_`var'_aft = confed*`var'*aft if !missing(confed) & !missing(`var') & !missing(aft) 
} 

lab var confed "South" 
lab var conf_aft "South x Aft" 
lab var noprez "No Bl prez" 
lab var conf_noprez "South x No Bl prez" 
lab var noprez_aft "No Bl prez x Aft" 
lab var conf_noprez_aft "South x No Bl prez x Aft" 

saveold "$input/gallup_and_gss_extrayears.dta", replace
