

#delimit ;
set more off ;

***This file can be run on any subsample of Gallup-GSS-extra-years ;
***It takes whatever subsample you want and creates weights to match them to the (interpolated) Census values for Confed x Highschool cells [FOR WHITES ONLY!!!] ;
***Run this after already opening Gallup-GSS-extra-years and creating whatever subsample you want ;

keep if tag_dups==1 ;
keep if race==1 ;

cap drop cen2* ;
cap drop wgt_group* ;
cap drop cen_year* ;


tab highschool ;

****Crate a variable that is the previous census year and next census year for each Gallup obs. ;
gen cen_year_upper=10*ceil(svy_year/10) ;
gen cen_year_lower=10*floor(svy_year/10) ;


****This creates a vector of the years in the sample to loop over later ;
	
tab svy_year, matrow(yrs_in_samp) ;	
local numyears=`r(r)' ;	


***We create wgt_group2_by_yr which is simply the cell sizes of the 2 x 2 weights, separately by years in the sample ;
	
****Loop over the years in our sample;
gen wgt_group2_by_yr=. ;
cap drop temp ;
forval x=1/`numyears' { ;
local y=yrs_in_samp[`x', 1] ;
egen temp=group(confed highschool) if svy_year==`y', label ;
replace wgt_group2_by_yr=temp if svy_year==`y' ;
tab temp, matcell(gallup_shares2_`y') ;
matrix gallup_shares2_`y'=gallup_shares2_`y'/`r(N)' ;
matrix list gallup_shares2_`y' ;
drop temp ;
} ;


***We should have pretty few missing as Confed & Highschool should be non-missing for almost all observations ;

count if wgt_group2_by_yr==. ;

tempfile gallup_wgts ;

save `gallup_wgts' ;

preserve ;

use "$path/Input/ipums_wgt_vectors" , clear ;

forval y=1940(10)2010 { ;
mkmat ipums_shares_`y'1, matrix(temp) ;
matrix ipums_shares_`y'=temp[1..8, 1] ;
mkmat ipums_shares2_`y'1, matrix(temp2) ;
matrix ipums_shares2_`y'=temp2[1..4, 1] ;
matrix drop temp temp2 ;
} ;


***Note that these vectors will all be 9 x 1 so we extract only the non-missing rows ;

restore ;


***Create a vector of years in the working Gallup sample ;

gen cen2_wgt=. ;

forval x=1/`numyears' { ;
	***Grab the actual year ;
		local y=yrs_in_samp[`x', 1] ;
	****Tag the census year above and below each Gallup year ;
		foreach c in upper lower { ;
			sum cen_year_`c' if svy_year==`y' ;
			local yr_`c'=`r(mean)' ;
		} ;
	di "Inspect how Gallup shares and Census shares differ." ;
	di "They shouldn't be HUGELY different as unweighted Gallup is not terribly unrepresentative)" ;
	di "Gallup shares in year `y' (unweighted)" ;
	tab wgt_group2_by_yr if tag_dups== 1 & svy_year==`y' ;
	di "IPUMS shares in Census before year `y'" ;
	matrix list ipums_shares2_`yr_lower' ;
	di "IPUMS shares in Census after year `y' [will equal survey year if year itself a Census year]" ;
	matrix list ipums_shares2_`yr_upper' ;
	forval g=1/4 { ;	
		replace cen2_wgt=((`yr_upper'-`y')/10)*ipums_shares2_`yr_lower'[`g',1] + ((`y'- `yr_lower')/10)*ipums_shares2_`yr_upper'[`g',1] if wgt_group2_by_yr==`g' & svy_year==`y';
		***Now, just divied by Gallup share that year ;
		replace cen2_wgt=cen2_wgt/gallup_shares2_`y'[`g', 1] if wgt_group2_by_yr==`g' & svy_year==`y' ;
		****The code above is wrong for years that ACTUALLY fall in a census year bc cen_yr_upper==cen_yr_lower.  Fix below ;
		if `y'==1940 | `y'==1950 | `y'==1960 | `y'==1970 | `y'==1980 | `y'==1990 |`y'==2000 | `y'==2010 { ;		
			replace cen2_wgt=ipums_shares2_`y'[`g',1] if wgt_group2_by_yr==`g' & svy_year==`y' & cen_year_upper==cen_year_lower ;
			replace cen2_wgt=cen2_wgt/gallup_shares2_`y'[`g', 1] if wgt_group2_by_yr==`g' & svy_year==`y' & cen_year_upper==cen_year_lower ;
		} ;	
	} ;
	di "Gallup shares in year `y' (weighted)" ;
	tab wgt_group2_by_yr if  svy_year==`y' [aw=cen2_wgt] ;
	matrix temp_compare=((`yr_upper'-`y')/10)*ipums_shares2_`yr_lower'+ ((`y'- `yr_lower')/10)*ipums_shares2_`yr_upper' ;
	di "Interpolated IPUMS shares for year `y'" ;
	matrix list temp_compare ;
	matrix drop temp_compare ;
} ;

