*NOTE: for the 1944-1952 files, the variable form_num will be dropped at the end of all files after they have been appended. This variable is a check to ensure the data gets coded correctly when there are 2 forms.
*The svy_year variable for the files 1944-1952 will be changed to numeric at the end of all files having been appended as well. 

clear
set more off
capture cd "/Users/`c(username)'/Dropbox/southern_strategy/Gallup&GSS/PartyFiles1944_1952"
*log using PartyID_1944_1952_Detailed.log, replace

********************************
******** AIPO 1952-0508 ********
********************************

infile using Dictionaries_Detailed/aipo1952-0508.dct

*Create a variable for survey code
gen svy = "1952-0508"

*Create a variable for survey year
gen svy_year = "1952"

*Create a variable for survey month
gen svy_month = "November"

*Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization
*Check var
tab race_orig
*frequency matches
*Generate new var
gen race = race_orig

****** SEX ******
*1 MALE 2 FEMALE harmonization 
tab sex_orig
*frequency matches only for man; woman in the codebook is
*1496 and 1483 in the data. Went back to dictionary and it is
*column 74 in dicitionary: card 2 
*Also numbers in the dataset equal the # of observations
gen sex = sex_orig

****** STATE ******
*Check the variable 
tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
*46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
replace state = 53 if state_orig == 81
replace state = 54 if state_orig == 82
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 53
replace state = 57 if state_orig == 54
replace state = 58 if state_orig == 83
replace state = 59 if state_orig == 84
replace state = 81 if state_orig == 86
replace state = 82 if state_orig == 85
replace state = 83 if state_orig == 55
replace state = 84 if state_orig == 56
tab state

****** AGE ******
*Check the variable
tab age_orig
*Frequencies match*
gen age = age_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
tab poliPartyID_orig
*Frequencies don't match; Went back and checked the data
*dictionary and the columns and the #'s add up. 
*Need to recode
gen poliPartyID = poliPartyID_orig
*also non standard party id questions
gen nonStandPartyVar = 1
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*For this file poliPartyID_orig =4 is never voted and changed to missing
*Replace to harmonize
replace poliPartyID = 1 if poliPartyID_orig == 2
replace poliPartyID = 2 if poliPartyID_orig == 1
replace poliPartyID = 4 if poliPartyID_orig == 3
replace poliPartyID = . if poliPartyID_orig == 4
replace poliPartyID = 3 if poliPartyID_orig >= 5 & poliPartyID_orig <=9
tab poliPartyID

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 10 if occupation_orig == 7
replace occupation = 12 if occupation_orig == 11
replace occupation = 2 if occupation_orig == 9

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** UNION ******
tab union_orig
gen union = union_orig

****** RELIGION ******
tab religion_orig
gen religion = religion_orig

****** MARST ******
tab marst_orig
gen marst = marst_orig

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig
replace citySize = 4 if citySize_orig == 5 | citySize_orig == 6
replace citySize = 5 if citySize_orig == 7
replace citySize = 6 if citySize_orig == 8

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1952-0508.dta, replace
clear



********************************
******** AIPO 1952-0507 ********
********************************

infile using Dictionaries_Detailed/aipo1952-0507.dct

*Create a variable for survey code
gen svy = "1952-0507"

*Create a variable for survey year
gen svy_year = "1952"

*Create a variable for survey month
gen svy_month = "October"

*Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization
*Check var
tab race_orig
*frequency matches
*Generate new var
gen race = race_orig

****** SEX ******
*1 MALE 2 FEMALE harmonization 
tab sex_orig
*frequency matches 
gen sex = sex_orig

****** STATE ******
*Check the variable 
tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
* 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 53 if state_orig == 81
replace state = 54 if state_orig == 82
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 53
replace state = 57 if state_orig == 54
replace state = 58 if state_orig == 83
replace state = 59 if state_orig == 84
replace state = 81 if state_orig == 86
replace state = 82 if state_orig == 85
replace state = 83 if state_orig == 55
replace state = 84 if state_orig == 56
tab state

****** AGE *******
*Check the variable
tab age_orig
*Freq match
gen age = age_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
tab poliPartyID_orig
*Need to recode
gen poliPartyID = poliPartyID_orig
*also non standard party id questions
gen nonStandPartyVar = 1
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
replace poliPartyID = 1 if poliPartyID_orig == 2
replace poliPartyID = 2 if poliPartyID_orig == 1
replace poliPartyID = 4 if poliPartyID_orig == 3
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <=9
tab poliPartyID

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 10 if occupation_orig == 7
replace occupation = 12 if occupation_orig == 11
replace occupation = 2 if occupation_orig == 9

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** UNION ******
tab union_orig
gen union = union_orig

****** RELIGION ******
tab religion_orig
gen religion = religion_orig
replace religion = 4 if religion_orig==9

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig
replace citySize = 4 if citySize_orig == 5 | citySize_orig == 6
replace citySize = 5 if citySize_orig == 7
replace citySize = 6 if citySize_orig == 8

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1952-0507.dta, replace
clear



********************************
******** AIPO 1952-0486 ********
********************************

*There are 2 forms for this study: Form K and Form S. Each form has a separate data file. We will read in the files individually, add a variable to identify the correct form, and then append together.
*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1952-0486K; February 9, 1952 - February 14, 1952)
infile using Dictionaries_Detailed/aipo1952-0486k.dct
gen form = "Form K"

*Save the file
saveold FormattedData_Detailed/1952-0486k.dta, replace
clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1952-0486S; February 9, 1952 - February 14, 1952)
infile using Dictionaries_Detailed/aipo1952-0486s.dct
gen form = "Form S"

*Save the file
saveold FormattedData_Detailed/1952-0486s.dta, replace

*Append the files
append using FormattedData_Detailed/1952-0486k.dta

*Count the number of observations
count

*The sample size in the codebook - 2,030 - does not match the number of observations read into Stata

*Create a variable for survey code
gen svy = "1952-0486"

*Create a variable for survey year
gen svy_year = "1952"

*Create a variable for survey month
gen svy_month = "February"

*Begin harmonization of variables
*WEIGHT
*Harmonization Plan: This variable is available only in files dated 1968 or later, and thus, for the set of files containing the tax level question, it can only be found in USAIPO1969-0776 (March 12, 1969 - March 17, 1969) and USAIPO1973-0864 (February 16, 1973 - February 19, 1973). USAIPO1969-0776 was harmonized for a previous study, so it is not included here. In file USAIPO1973-0684, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

****** RACE AND SEX ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"
*Race and gender are in two variables for this survey
*Check the race variable - tab it and compare with frequency distribution in the codebook
bys form: tab race_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig
*Check the sex variable - tab it and compare with frequency distribution in the codebook
bys form: tab sex_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig

****** STATE ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0686 (February 28, 1964 - March 5, 1964), so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC"
*Check the variable - tab it and compare with frequency distribution in the codebook
bys form: tab state_orig
*The frequency distribution for this variable matches that in the codebook
*Values are not coded consistently with harmonization plan; recode variable
*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82

****** AGE ******
*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"
*Check the variable - tab it and compare with frequency distribution in the codebook
bys form: tab age_orig
*The variable age_orig does not have frequencies displayed next to it in the codebook
*Create two new variables for each form to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10) if form == "Form K"
gen second = age_orig - (first*10) if form == "Form K"
tab first
tab second
*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second
gen first = int(age_orig/10) if form == "Form S"
gen second = age_orig - (first*10) if form == "Form S"
tab first
tab second
*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second
*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig

****** APPROVAL OF CURRENT PRESIDENT ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." If a survey has a response option of "APPROVE AND DISAPPROVE," it is recoded to "BOTH."
*Check the variable - tab it and compare with frequency distribution in the codebook
bys form: tab presApprovala_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig

****** PARTY ID IN POLITICS TODAY ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording. If a survey does not use the standard wording -- as in USAIPO1951-0471 (February 4, 1951 - February 9, 1951) -- we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable.
*Check the variable - tab it and compare with frequency distribution in the codebook
bys form: tab poliPartyID_orig
*The frequency distribution for this variable matches that in the codebook
*Values are not coded consistently with harmonization plan; recode variable
*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig
*Replace values
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3

****** LEVEL OF PERSONAL FEDERAL INCOME TAX ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is not included in USAIPO1964-0702 (November 20, 1964 - November 25, 1964).
*Check the variable - tab it and compare with frequency distribution in the codebook
bys form: tab fedIncomeTax_orig
*The frequency distribution for this variable matches that in the codebook
*Values are not coded consistently with harmonization plan; recode variable
*Generate a new variable to ensure synchronization of variable name across surveys
gen fedIncomeTax = fedIncomeTax_orig
*Replace values
replace fedIncomeTax = 2 if fedIncomeTax_orig == 3
replace fedIncomeTax = 3 if fedIncomeTax_orig == 2

****** GOVERNMENT WELFARE SPENDING ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONíT KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1961-0651 was harmonized for the presidential approval study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1964-0702 for this set of polls.

****** EDUC ******
tab educ_orig
gen educ = educ_orig

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 2 if occupation_orig == 9

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** INCOME ******
tab income_orig
gen income = income_orig

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig
replace citySize = 4 if citySize_orig == 5 | citySize_orig == 6
replace citySize = 5 if citySize_orig == 7
replace citySize = 6 if citySize_orig == 8

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1952-0486.dta, replace
clear



********************************
******** AIPO 1951-0483 ********
********************************

infile using Dictionaries_Detailed/aipo1951-0483.dct

*Create a variable for survey code
gen svy = "1951-0483"

*Create a variable for survey year
gen svy_year = "1951"

*Create a variable for survey month
gen svy_month = "December"

*Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
tab race_orig
*frequency matches
*Generate new var
gen race = race_orig

****** SEX ******
*1 MALE 2 FEMALE harmonization 
tab sex_orig
*frequency matches 
gen sex = sex_orig

****** STATE ******
*STATE THE RESPONDENT LIVES IN
**Check the variable 
tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
* 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

****** AGE ******
*Check the variable
tab age_orig
*Frequencies match*
gen age = age_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
tab poliPartyID_orig
*Need to recode other and independent
gen poliPartyID = poliPartyID_orig
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*Replace to harmonize
replace poliPartyID = 4 if poliPartyID_orig == 3
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <=9
tab poliPartyID

****** EDUC ******
tab educ_orig
gen educ = educ_orig

****** OCCUPATION ******
tab occupation_orig
replace occupation = 2 if occupation_orig == 9
gen occupation = occupation_orig

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig
replace citySize = 4 if citySize_orig == 5 | citySize_orig == 6
replace citySize = 5 if citySize_orig == 7
replace citySize = 6 if citySize_orig == 8

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1951-0483.dta, replace
clear



********************************
******** AIPO 1951-0482 ********
********************************

infile using Dictionaries_Detailed/aipo1951-0482.dct

*Create a variable for survey code
gen svy = "1951-0482"

*Create a variable for survey year
gen svy_year = "1951"

*Create a variable for survey month
gen svy_month = "November"

*Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
tab race_orig
*frequency matches
*Generate new var
gen race = race_orig
replace race = . if race == 3

****** SEX ******
*1 MALE 2 FEMALE harmonization 
tab sex_orig
*frequency matches 
gen sex = sex_orig
replace sex =. if sex == 3

****** STATE ******
tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
*46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

****** AGE ******
*Check the variable
tab age_orig
*Frequencies match*
gen age = age_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
tab poliPartyID_orig
*Need to recode other and independent
gen poliPartyID = poliPartyID_orig
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*Replace to harmonize
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3
tab poliPartyID

****** APPROVAL OF CURRENT PRESIDENT ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." If a survey has a response option of "APPROVE AND DISAPPROVE," it is recoded to "BOTH."
*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig

****** EDUC ******
tab educ_orig
gen educ = educ_orig

****** OCCUPATION ******
tab occupation_orig
replace occupation = 2 if occupation_orig == 9
gen occupation = occupation_orig

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** RELIGION ******
tab religion_orig
gen religion = religion_orig
replace religion = 9 if religion == 5

****** MARST ******
tab marst_orig
gen marst = marst_orig

****** INCOME ******
tab income_orig
gen income = income_orig

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1951-0482.dta, replace
clear



********************************
******** AIPO 1951-0475 ********
********************************

infile using Dictionaries_Detailed/aipo1951-0475.dct

*Create a variable for survey code
gen svy = "1951-0475"

*Create a variable for survey year
gen svy_year = "1951"

*Create a variable for survey month
gen svy_month = "May"

*Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
tab race_orig
*frequency matches
*Generate new var
gen race =race_orig

****** SEX ******
*1 MALE 2 FEMALE harmonization 
tab sex_orig
*frequency matches 
gen sex = sex_orig

****** STATE ******
*Check the variable 
tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
* 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

***** AGE ******
*Check the variable
tab age_orig
*Frequencies match*
gen age = age_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
tab poliPartyID_orig
*Need to recode independent and progressive; 3 in this file is 
*progressive: gets coded as 4 for other
gen poliPartyID = poliPartyID_orig
gen nonStandPartyVar = 1
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*Replace to harmonize
replace poliPartyID = 4 if poliPartyID_orig == 3
replace poliPartyID = 3 if poliPartyID_orig >= 5 & poliPartyID_orig <=9
tab poliPartyID

****** APPROVAL OF CURRENT PRESIDENT ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." If a survey has a response option of "APPROVE AND DISAPPROVE," it is recoded to "BOTH."
*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig

****** EDUC ******
tab educ_orig
gen educ = educ_orig

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** INCOME ******
tab income_orig
gen income = income_orig

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1951-0475.dta, replace
clear



********************************
******** AIPO 1951-0471 ********
********************************

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1951-0471; February 4, 1951 - February 9, 1951)

infile using Dictionaries_Detailed/aipo1951-0471.dct

*The sample size in the codebook - 1,403 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1951-0471"

*Create a variable for survey year
gen svy_year = "1951"

*Create a variable for survey month
gen svy_month = "February"

*Begin harmonization of variables
*WEIGHT
*Harmonization Plan: This variable is available only in files dated 1968 or later, and thus, for the set of files containing the tax level question, it can only be found in USAIPO1969-0776 (March 12, 1969 - March 17, 1969) and USAIPO1973-0864 (February 16, 1973 - February 19, 1973). USAIPO1969-0776 was harmonized for a previous study, so it is not included here. In file USAIPO1973-0684, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

****** RACE AND SEX ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"
*Race and gender are in two variables for this survey
*Check the race variable - tab it and compare with frequency distribution in the codebook
tab race_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig
*Check the sex variable - tab it and compare with frequency distribution in the codebook
tab sex_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig

***** STATE ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0686 (February 28, 1964 - March 5, 1964), so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC"
*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig
*The frequency distribution for this variable matches that in the codebook
*Values are not coded consistently with harmonization plan; recode variable
*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82

****** AGE ******
*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"
*Check the variable - tab it and compare with frequency distribution in the codebook
tab age_orig
*The variable age_orig does not have frequencies displayed next to it in the codebook
*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second
*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second
*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig

****** PARTY ID IN POLITICS TODAY ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording. If a survey does not use the standard wording -- as in USAIPO1951-0471 (February 4, 1951 - February 9, 1951) -- we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable.
*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig
*The frequency distribution for this variable matches that in the codebook
*Values are not coded consistently with harmonization plan; recode variable
*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig
*Replace values
replace poliPartyID = 3 if poliPartyID_orig >= 5 & poliPartyID_orig <= 9
replace poliPartyID = 4 if poliPartyID_orig == 3 | poliPartyID_orig == 4
*Create indicator for non-standard question wording
gen nonStandPartyVar = 1

****** APPROVAL OF CURRENT PRESIDENT ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." If a survey has a response option of "APPROVE AND DISAPPROVE," it is recoded to "BOTH."
*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig
*The frequency distribution for this variable matches that in the codebook
*Values are not coded consistently with harmonization plan; recode variable
*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig
*Replace values
replace presApprovala = 3 if presApprovala_orig == 4
replace presApprovala = 4 if presApprovala_orig == 3

****** LEVEL OF PERSONAL FEDERAL INCOME TAX ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is not included in USAIPO1964-0702 (November 20, 1964 - November 25, 1964).
*Check the variable - tab it and compare with frequency distribution in the codebook
tab fedIncomeTax_orig
*The frequency distribution for this variable matches that in the codebook
*Values are not coded consistently with harmonization plan; recode variable
*Generate a new variable to ensure synchronization of variable name across surveys
gen fedIncomeTax = fedIncomeTax_orig
*Replace values
replace fedIncomeTax = 2 if fedIncomeTax_orig == 3
replace fedIncomeTax = 3 if fedIncomeTax_orig == 2

****** GOVERNMENT WELFARE SPENDING ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONíT KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1961-0651 was harmonized for the presidential approval study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1964-0702 for this set of polls.

****** EDUC ******
tab educ_orig
gen educ = educ_orig

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** UNION ******
tab union_orig
gen union = union_orig

****** INCOME ******
tab income_orig
gen income = income_orig

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1951-0471.dta, replace
clear



********************************
******** AIPO 1951-0470 ********
********************************

infile using Dictionaries_Detailed/aipo1951-0470.dct

*Create a variable for survey code
gen svy = "1951-0470"

*Create a variable for survey year
gen svy_year = "1951"

*Create a variable for survey month
gen svy_month = "January"

*Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
tab race_orig
*frequency matches
*Generate new var
gen race = race_orig

****** SEX ******
*1 MALE 2 FEMALE harmonization 
tab sex_orig
*frequency matches 
gen sex = sex_orig

****** STATE ******
*Check the variable 
tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
* 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

****** AGE ******
*Check the variable
tab age_orig
*Frequencies match, although as per frequency there is a 6 year old
*went back to dictionary and re-checked. age also matches 18-20 year old
*80-89 year old distributions**
gen age = age_orig
*Replace value for six year old
replace age = . if age_orig == 6

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
tab poliPartyID_orig
*Need to recode independent and progressive; 3 in this file is 
*progressive. To be coded as 4 for Other
gen poliPartyID = poliPartyID_orig
gen nonStandPartyVar = 1
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*Replace to harmonize
replace poliPartyID = 4 if poliPartyID_orig == 3
replace poliPartyID = 3 if poliPartyID_orig >= 5 & poliPartyID_orig <=9
tab poliPartyID

****** EDUC ******
tab educ_orig
gen educ = educ_orig

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** RELIGION ******
tab religion_orig
gen religion = religion_orig
replace religion = 9 if religion_orig==5

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1951-0470.dta, replace
clear



********************************
******** AIPO 1950-0467 ********
********************************

infile using Dictionaries_Detailed/aipo1950-0467.dct

*Create a variable for survey code
gen svy = "1950-0467"

*Create a variable for survey year
gen svy_year = "1950"

*Create a variable for survey month
gen svy_month = "November"

*Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
tab race_orig
*frequency matches
*Generate new var
gen race = race_orig

****** SEX ******
*1 MALE 2 FEMALE harmonization 
tab sex_orig
*frequency matches 
gen sex = sex_orig

****** STATE ******
*Check the variable 
tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
* 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

****** AGE ******
*Check the variable
tab age_orig
*Frequencies match*
gen age = age_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
tab poliPartyID_orig
*Need to recode independent and progressive; 3 in this file is 
*progressive: gets recoded as 4 for other
gen nonStandPartyVar = 1
gen poliPartyID = poliPartyID_orig
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*Replace to harmonize
replace poliPartyID = 4 if poliPartyID_orig == 3
replace poliPartyID = 3 if poliPartyID_orig >= 5 & poliPartyID_orig <=9
tab poliPartyID

****** EDUC ******
tab educ_orig
gen educ = educ_orig

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** RELIGION ******
tab religion_orig
gen religion = religion_orig
replace religion = 0 if religion_orig == 5

****** UNION ******
tab union_orig
gen union = union_orig

****** INCOME ******
tab income_orig
gen income = income_orig

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1950-0467.dta, replace
clear



********************************
******** AIPO 1950-0457 ********
********************************

infile using Dictionaries_Detailed/aipo1950-0457.dct

*Create a variable for survey code
gen svy = "1950-0457"

*Create a variable for survey year
gen svy_year = "1950"

*Create a variable for survey month
gen svy_month = "June-July"

*Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
tab race_orig
*frequency matches
*Generate new var
gen race = race_orig

****** SEX ******
*1 MALE 2 FEMALE harmonization 
tab sex_orig
*frequency matches 
gen sex = sex_orig

****** STATE ******
*Check the variable 
tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
*46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

****** AGE ******
*Check the variable
tab age_orig
*Frequencies match*
gen age = age_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
tab poliPartyID_orig
*Need to recode independent, other and progressive; 3 in this file is 
*progressive: recode to 4 for Other
gen poliPartyID = poliPartyID_orig
gen nonStandPartyVar = 1
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*Replace to harmonize
replace poliPartyID = 3 if poliPartyID_orig == 4
replace poliPartyID = 4 if poliPartyID_orig == 3 | poliPartyID_orig == 5
tab poliPartyID

****** EDUC ******
tab educ_orig
gen educ = educ_orig

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** MARST ******
tab marst_orig
gen marst = marst_orig

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1950-0457.dta, replace
clear



********************************
******** AIPO 1950-0456 ********
********************************

infile using Dictionaries_Detailed/aipo1950-0456.dct

*Create a variable for survey code
gen svy = "1950-0456"

*Create a variable for survey year
gen svy_year = "1950"

*Create a variable for survey month
gen svy_month = "June"

***The frequency in the codebook first page does not match but I
**don't see a mistake in the dictionary yet...
*Went back and replaced the data file to check
**post check still says 1357 is the N
**Frequency matches when I check the race and gender tab*

*Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
tab race_orig
*frequency matches
*Generate new var
gen race = race_orig
**frequency matches

****** SEX ******
*1 MALE 2 FEMALE harmonization 
tab sex_orig
*frequency matches 
gen sex = sex_orig

****** STATE ******
*Check the variable 
tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
*46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

****** AGE ******
*Check the variable
tab age_orig
*Frequencies match*
gen age = age_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
tab poliPartyID_orig
gen nonStandPartyVar = 1
gen poliPartyID = poliPartyID_orig
**This file has Dixiecrat, Progressive, Conservative: setting these to 
**4 for "other." This file also has 8 for none, neither. That gets set
**to missing***
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*Replace to harmonize
replace poliPartyID = 3 if poliPartyID_orig == 4
replace poliPartyID = 4 if poliPartyID_orig == 3
replace poliPartyID = 4 if poliPartyID_orig >=5 & poliPartyID_orig <=7
replace poliPartyID = . if poliPartyID_orig == 8
tab poliPartyID

****** APPROVAL OF CURRENT PRESIDENT ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." If a survey has a response option of "APPROVE AND DISAPPROVE," it is recoded to "BOTH."
*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig

****** EDUC ******
tab educ_orig
gen educ = educ_orig

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** INCOME ******
tab income_orig
gen income = income_orig

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1950-0456.dta, replace
clear



********************************
******** AIPO 1950-0455 ********
********************************

infile using Dictionaries_Detailed/aipo1950-0455.dct

*Create a variable for survey code
gen svy = "1950-0455"

*Create a variable for survey year
gen svy_year = "1950"

*Create a variable for survey month
gen svy_month = "May"

*Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
tab race_orig
*frequency matches
*Generate new var
gen race = race_orig

****** SEX ******
*1 MALE 2 FEMALE harmonization 
tab sex_orig
*frequency matches 
gen sex = sex_orig

****** STATE ******
*Check the variable 
tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
*46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

****** AGE ******
*Check the variable
tab age_orig
*Frequencies match*
gen age = age_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
tab poliPartyID_orig
gen nonStandPartyVar = 1
gen poliPartyID = poliPartyID_orig
**This file has 3 has progressive: coded to 4 for harmonization
*6 and 9 are set to missing as they are none and no answer
*Republican and democract are coded the same as harmonization plan
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*Replace to harmonize
replace poliPartyID = 4 if poliPartyID_orig == 3 | poliPartyID_orig == 5
replace poliPartyID = 3 if poliPartyID_orig == 4
replace poliPartyID = . if poliPartyID_orig == 6 | poliPartyID_orig == 9
tab poliPartyID

****** APPROVAL OF CURRENT PRESIDENT ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." If a survey has a response option of "APPROVE AND DISAPPROVE," it is recoded to "BOTH."
*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig

****** EDUC ******
tab educ_orig
gen educ = educ_orig

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1950-0455.dta, replace
clear



********************************
******** AIPO 1950-0454 ********
********************************

infile using Dictionaries_Detailed/aipo1950-0454.dct

*Create a variable for survey code
gen svy = "1950-0454"

*Create a variable for survey year
gen svy_year = "1950"

*Create a variable for survey month
gen svy_month = "March"

**Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
tab race_orig
*frequency matches
*Generate new var
gen race = race_orig

****** SEX ******
*1 MALE 2 FEMALE harmonization 
tab sex_orig
*frequency matches 
gen sex = sex_orig

****** STATE ******
*Check the variable 
tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
* 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

****** AGE ******
*Check the variable
tab age_orig
*Frequencies match*
gen age = age_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
tab poliPartyID_orig
gen nonStandPartyVar = 1
gen poliPartyID = poliPartyID_orig
**This file has 3 has progressive: coded to 4 for harmonization
*5 is other and is recoded to 4 for harmonization
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*Replace to harmonize
replace poliPartyID = 4 if poliPartyID_orig == 3 | poliPartyID_orig == 5
replace poliPartyID = 3 if poliPartyID_orig == 4
tab poliPartyID

****** EDUC ******
tab educ_orig
gen educ = educ_orig

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** RELIGION ******
tab religion_orig
gen religion = religion_orig
replace religion = 10 if religion_orig == 4
replace religion = 11 if religion_orig == 6
replace religion = 8 if religion_orig >= 7 & religion_orig <= 9
replace religion = 9 if religion_orig == 10
replace religion = 4 if religion_orig == 11

****** UNION ******
tab union_orig
gen union = union_orig

****** INCOME ******
tab income_orig
gen income = income_orig

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1950-0454.dta, replace
clear



********************************
******** AIPO 1950-0452 ********
********************************

*There are 2 forms for this study: Form K and Form TPS. 
*Read in files individually, add a variable to identify the correct form, and then append together.

*Read in dictionary file 
infile using Dictionaries_Detailed/aipo1950-0452k.dct

gen form = "Form K"

gen form_num = 1

*Save the file
saveold FormattedData_Detailed/1950-0452k.dta, replace
clear

*Read in dictionary file 
infile using Dictionaries_Detailed/aipo1950-0452tp.dct

gen form = "Form TPS"

gen form_num = 2

*Save the file
saveold FormattedData_Detailed/1950-0452tp.dta, replace

*Both files read correctly

*Append the files
append using FormattedData_Detailed/1950-0452k.dta

*Count the number of observations
count

*count matches the codebook

*Create a variable for survey code
gen svy = "1950-0452"

*Create a variable for survey year
gen svy_year = "1950"

*Create a variable for survey month
gen svy_month = "January-February"

*Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
bys form_num: tab race_orig
*frequency matches both forms: for this file
*Generate new var
gen race = race_orig
*3 is coded as not recorded: set to missing
replace race = . if race == 3
*correctly done: 284 set to missing

****** SEX ******
*1 MALE 2 FEMALE harmonization 
bys form_num: tab sex_orig
*frequency matches 
*3 is coded as not recorded: set to missing
gen sex = sex_orig
replace sex = . if sex == 3
*correctly done

****** STATE ******
*Check the variable 
bys form_num: tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
*46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

****** AGE ******
*Check the variable
bys form_num: tab age_orig
*Frequencies match*
gen age = age_orig

****** PARTY ID IN POLITICS TODAY ******
bys form_num: tab poliPartyID_orig
gen nonStandPartyVar = 1
*coded differently by form
*recoding for form K
*10 is none don't vote, so set to missing
gen poliPartyID = poliPartyID_orig if form_num == 1
replace poliPartyID = 3 if poliPartyID_orig == 04 & form_num == 1
replace poliPartyID = 4 if poliPartyID_orig == 03 & form_num == 1
replace poliPartyID = 4 if poliPartyID_orig >=05 & poliPartyID_orig <=09 & form_num == 1
replace poliPartyID = . if poliPartyID_orig == 10 & form_num == 1
tab poliPartyID
***now for form tp
***turn the missing into 
bys form_num: tab poliPartyID_orig
replace poliPartyID = 55 if poliPartyID == . & form_num == 2
**Will recode progressive, socialist, and rump
**as other (4). 8 is none/ don't vote so that gets
*set to missing
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*Replace to harmonize
replace poliPartyID = 1 if poliPartyID_orig == 1 & form_num == 2
replace poliPartyID = 2 if poliPartyID_orig == 2 & form_num == 2
replace poliPartyID = 3 if poliPartyID_orig == 4 & form_num == 2
replace poliPartyID = 4 if poliPartyID_orig == 3 | poliPartyID_orig == 5 | poliPartyID_orig == 6 | poliPartyID_orig == 7 & form_num == 2
replace poliPartyID = . if poliPartyID_orig == 8 | poliPartyID == 55 & form_num == 2
bys form_num: tab poliPartyID
count

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** UNION ******
tab union_orig
gen union = union_orig

****** INCOME ******
tab income_orig
gen income = income_orig

****** RELIGION ******
tab religion_orig
gen religion = religion_orig
replace religion = 10 if religion_orig==5
replace religion = 8 if (religion_orig>=6 & religion_orig<=9)
replace religion = 9 if religion_orig==10
replace religion = 4 if religion_orig==11

****** MARST ******
tab marst_orig
gen marst = marst_orig

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1950-0452.dta, replace
clear



********************************
******** AIPO 1949-0450 ********
********************************

*There are 2 forms for this study: Form K and Form T. 
*Read in files individually
*add a variable to identify the correct form, and then append together.

*Read in dictionary file 
infile using Dictionaries_Detailed/aipo1949-0450k.dct

gen form = "Form K"

gen form_num = 1

**correct N***

*Save the file
saveold FormattedData_Detailed/1949-0450k.dta, replace
clear

*Read in dictionary file 
infile using Dictionaries_Detailed/aipo1949-0450t.dct

gen form = "Form T"

gen form_num = 2

**Correct N

*Save the file
saveold FormattedData_Detailed/1949-0450t.dta, replace

*Both Files read correctly

*Append the files
append using FormattedData_Detailed/1949-0450k.dta

**count does not match the # in the front page of codebook
*but matches the individual codebooks
count

*Create a variable for survey code
gen svy = "1949-0450"

*Create a variable for survey year
gen svy_year = "1949"

*Create a variable for survey month
gen svy_month = "November-December"

**Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
**Check var
bys form_num: tab race_orig
*frequency matches
*Generate new var
gen race = race_orig

****** SEX ******
*1 MALE 2 FEMALE harmonization 
bys form_num: tab sex_orig
*frequency matches 
gen sex = sex_orig

****** STATE ******
*Check the variable 
bys form_num: tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
*46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

****** AGE ******
*Check the variable
bys form_num: tab age_orig
*Frequencies match*
gen age = age_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
bys form_num: tab poliPartyID_orig
**frequencies and coding matches**
gen nonStandPartyVar = 1
gen poliPartyID = poliPartyID_orig
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*Replace to harmonize
replace poliPartyID = 4 if poliPartyID_orig == 3 | poliPartyID_orig == 5 
replace poliPartyID = 3 if poliPartyID_orig == 4
bys form_num: tab poliPartyID

****** POLL TAX ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO" 3 "NO OPINION." Note that surveys USAIPO1948-0414 (March 5, 1948 - March 10, 1948) and USAIPO1949-0439 (March 19, 1949 - March 24, 1949) use "Yes/No/No Opinion" as response options, while surveys USAIPO1949-0450 (November 27, 1949 - December 2, 1949) and USAIPO1953-0511 (February 1, 1953 - February 5, 1953) use "Should/Should Not/No Opinion" as response options. Thus, in the latter two surveys, "Should" is treated as "Yes," and "Should Not" is treated as "No."
*Check the variable - tab it and compare with frequency distribution in the codebook
tab pollTax_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen pollTax = pollTax_orig

****** EQUAL OPPORTUNITY EMPLOYMENT ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ALL THE WAY" 2 "NONE OF THE WAY" 3 "PART OF THE WAY" 4 "LEAVE TO STATES" 5 "QUALIFIED AS TO RACE, RELIGION, ETC." 6 "CREED BUT NOT RACE" 7 "DOESN'T MATTER-LAW CAN BE EVADED" 8 "HIRE, SEPARATE BUT EQUAL" 9 "DON'T KNOW/NO ANSWER"
*Check the variable - tab it and compare with frequency distribution in the codebook
tab fedEmployment_orig
*The frequency distribution for this variable matches that in the codebook
*Values are not coded consistently with harmonization plan; recode variable
*Generate a new variable to ensure synchronization of variable name across surveys
gen fedEmployment = fedEmployment_orig
*Replace values
replace fedEmployment = 9 if fedEmployment_orig == 0

****** SEGREGATION IN INTERSTATE TRAVEL ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION"
*Check the variable - tab it and compare with frequency distribution in the codebook
tab segregationTravel_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen segregationTravel = segregationTravel_orig

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** UNION ******
tab union_orig
gen union = union_orig

****** INCOME ******
tab income_orig
gen income = income_orig

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1949-0450.dta, replace
clear



********************************
******** AIPO 1949-0448 ********
********************************

*Read in dictionary file
*There are two forms of this poll

infile using Dictionaries_Detailed/aipo1949-0448k.dct

gen form = "Form K"

gen form_num = 1

**correct N***

*Save the file
saveold FormattedData_Detailed/1949-0448k.dta, replace
clear

*Read in dictionary file 
infile using Dictionaries_Detailed/aipo1949-0448t.dct

gen form = "Form T"

gen form_num = 2

**Correct N

*Save the file
saveold FormattedData_Detailed/1949-0448t.dta, replace

*Both Files read correctly

*Append the files
append using FormattedData_Detailed/1949-0448k.dta

*Count the number of observations
count

*count matches the codebook

*Create a variable for survey code
gen svy = "1949-0448"

*Create a variable for survey year
gen svy_year = "1949"

*Create a variable for survey month
gen svy_month = "September"

gen nonStandPartyVar = 1

**Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
bys form_num: tab race_orig
*frequency matches
*Generate new var
gen race = race_orig

****** SEX ******
*1 MALE 2 FEMALE harmonization 
bys form_num: tab sex_orig
*frequency matches 
gen sex = sex_orig

****** STATE ******
*Check the variable 
bys form_num: tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
*46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

****** AGE ******
*Check the variable
bys form_num: tab age_orig
*Frequencies match*
gen age = age_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
bys form_num: tab poliPartyID_orig
**Frequencies match here**but need to recode
*progressive to other
gen poliPartyID = poliPartyID_orig
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*Replace to harmonize
replace poliPartyID = 4 if poliPartyID_orig == 3 | poliPartyID_orig == 5 
replace poliPartyID = 3 if poliPartyID_orig == 4
bys form_num: tab poliPartyID

****** APPROVAL OF CURRENT PRESIDENT ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." If a survey has a response option of "APPROVE AND DISAPPROVE," it is recoded to "BOTH."
*Check the variable - tab it and compare with frequency distribution in the codebook
bys form_num: tab presApprovala_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** UNION ******
tab union_orig
gen union = union_orig

****** INCOME ******
tab income_orig
gen income = income_orig

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1949-0448.dta, replace
clear



********************************
******** AIPO 1949-0445 ********
********************************

*Read in dictionary file
*There are two forms of this poll, but only one dataset and the form T is used for 5 specific questions,
* which do not matter to us since all our information is in Form K since there is a single data file, the form variable is not used

infile using Dictionaries_Detailed/aipo1949-0445.dct

**correct N***

*Create a variable for survey code
gen svy = "1949-0445"

*Create a variable for survey year
gen svy_year = "1949"

*Create a variable for survey month
gen svy_month = "July"

gen nonStandPartyVar = 1

**Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
tab race_orig
*frequency matches
*Generate new var
gen race = race_orig

****** SEX ******
*1 MALE 2 FEMALE harmonization 
tab sex_orig
*frequency matches 
gen sex = sex_orig

****** STATE ******
*Check the variable 
tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
* 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

****** AGE ******
*Check the variable
tab age_orig
*Frequencies match*
gen age = age_orig

***** PARTY ID IN POLITICS TODAY ******
*Check the variable 
tab poliPartyID_orig
**Frequencies match here but need to recode progressive to other
gen poliPartyID = poliPartyID_orig
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*Replace to harmonize
replace poliPartyID = 4 if poliPartyID_orig == 3 | poliPartyID_orig == 5 
replace poliPartyID = 3 if poliPartyID_orig == 4
tab poliPartyID

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** UNION ******
tab union_orig
gen union = union_orig

****** INCOME ******
tab income_orig
gen income = income_orig

****** RELIGION ******
tab religion_orig
gen religion = religion_orig
replace religion = 9 if religion_orig==5

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1949-0445.dta, replace
clear



********************************
******** AIPO 1949-0442 ********
********************************

*Read in dictionary file
*There are two forms of this poll

infile using Dictionaries_Detailed/aipo1949-0442k.dct

gen form = "Form K"

gen form_num = 1

**correct N***

*Save the file
saveold FormattedData_Detailed/1949-0442k.dta, replace
clear

*Read in dictionary file 
infile using Dictionaries_Detailed/aipo1949-0442t.dct

gen form = "Form T"

gen form_num = 2

**Correct N

*Save the file
saveold FormattedData_Detailed/1949-0442t.dta, replace

*Both Files read correctly

*Append the files
append using FormattedData_Detailed/1949-0442k.dta

*Count the number of observations
count

*count does not match the codebook which says only 1378
*but it matches the information in the forms; correctly done

*Create a variable for survey code
gen svy = "1949-0442"

*Create a variable for survey year
gen svy_year = "1949"

*Create a variable for survey month
gen svy_month = "May"

gen nonStandPartyVar = 1

**Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
bys form_num: tab race_orig
*frequency matches
*Generate new var
gen race = race_orig

****** SEX ******
*1 MALE 2 FEMALE harmonization 
bys form_num: tab sex_orig
*frequency matches 
gen sex = sex_orig

****** STATE ******
*Check the variable 
bys form_num: tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
*46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

****** AGE ******
*Check the variable
bys form_num: tab age_orig
*Frequencies match*
gen age = age_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
bys form_num: tab poliPartyID_orig
**Frequencies match here**but need to recode
*progressive to other
gen poliPartyID = poliPartyID_orig
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*Replace to harmonize
replace poliPartyID = 4 if poliPartyID_orig == 3 | poliPartyID_orig == 5 
replace poliPartyID = 3 if poliPartyID_orig == 4
bys form_num: tab poliPartyID

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** UNION ******
tab union_orig
gen union = union_orig

****** INCOME ******
tab income_orig
gen income = income_orig

****** RELIGION ******
tab religion_orig
gen religion = religion_orig
replace religion = 13 if religion_orig==4
replace religion = 4 if religion_orig==5
replace religion = 9 if religion_orig==6 | religion_orig==8
replace religion = 6 if religion_orig==9
replace religion = 8 if religion_orig==7

****** MARST ******
tab marst_orig
gen marst = marst_orig

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1949-0442.dta, replace
clear



********************************
******** AIPO 1949-0439 ********
********************************

*Read in dictionary file **There are two forms of this poll

infile using Dictionaries_Detailed/aipo1949-0439k.dct

gen form = "Form K"

gen form_num = 1

*Save the file
saveold FormattedData_Detailed/1949-0439k.dta, replace
clear

*Read in dictionary file 
infile using Dictionaries_Detailed/aipo1949-0439t.dct

gen form = "Form T"

gen form_num = 2

*Save the file
saveold FormattedData_Detailed/1949-0439t.dta, replace

*Both Files read correctly

*Append the files
append using FormattedData_Detailed/1949-0439k.dta

*Count the number of observations
count

*count matches the codebook***

*Create a variable for survey code
gen svy = "1949-0439"

*Create a variable for survey year
gen svy_year = "1949"

*Create a variable for survey month
gen svy_month = "March"

**Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
bys form_num: tab race_orig
*frequency matches both forms: for this file
*Generate new var
gen race = race_orig

****** SEX ******
*1 MALE 2 FEMALE harmonization 
bys form_num: tab sex_orig
*frequency matches 
gen sex = sex_orig

****** STATE ******
*Check the variable 
bys form_num: tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
*46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

****** AGE ******
*AGE OF THE RESPONDENT
*Check the variable
bys form_num: tab age_orig
*Frequencies match*
gen age = age_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
bys form_num: tab poliPartyID_orig
gen nonStandPartyVar = 1
**Frequencies match but need to recode slightly differently per form
gen poliPartyID = poliPartyID_orig
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*Replace to harmonize
replace poliPartyID = 4 if poliPartyID_orig == 3 & form_num == 1
replace poliPartyID = 3 if poliPartyID_orig == 4 & form_num == 1
replace poliPartyID = 4 if poliPartyID_orig == 3 | poliPartyID_orig == 5 & form_num == 2
replace poliPartyID = 3 if poliPartyID_orig == 4 & form_num == 2
bys form_num: tab poliPartyID

****** VOTE FOR DEWEY, TRUMAN, WALLACE, OR THURMOND IN 1948 ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TRUMAN" 2 "DEWEY" 3 "WALLACE" 4 "THURMOND" 5 "OTHER" 6 "YES, VOTED-NO ANSWER" 7 "NO, DIDN'T VOTE" 8 "NO, TOO YOUNG TO VOTE" 9 "DON'T REMEMBER"
*Check the variable - tab it and compare with frequency distribution in the codebook
bys form_num: tab voteElection1948_orig
*The frequency distribution for this variable matches that in the codebook
*Values are not coded consistently with harmonization plan; recode variable
*Generate a new variable to ensure synchronization of variable name across surveys
gen voteElection1948 = voteElection1948_orig
*Replace values
replace voteElection1948 = 1 if voteElection1948_orig == 2
replace voteElection1948 = 2 if voteElection1948_orig == 1

****** LYNCHING ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "FEDERAL" 2 "STATE" 3 "BOTH" 4 "QUALIFIED FEDERAL" 5 "QUALIFIED STATE" 6 "NO OPINION" 7 "QUALIFIED NO OPINION" 8 "MISCELLANEOUS"
*Check the variable - tab it and compare with frequency distribution in the codebook
bys form_num: tab stateLynching_orig
*The frequency distribution for this variable matches that in the codebook
*Values are not coded consistently with harmonization plan; recode variable
*Generate a new variable to ensure synchronization of variable name across surveys
gen stateLynching = stateLynching_orig
*Replace values
replace stateLynching = 3 if stateLynching_orig == 7
replace stateLynching = 6 if stateLynching_orig == 3
replace stateLynching = 7 if stateLynching_orig == 6

****** POLL TAX ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO" 3 "NO OPINION." Note that surveys USAIPO1948-0414 (March 5, 1948 - March 10, 1948) and USAIPO1949-0439 (March 19, 1949 - March 24, 1949) use "Yes/No/No Opinion" as response options, while surveys USAIPO1949-0450 (November 27, 1949 - December 2, 1949) and USAIPO1953-0511 (February 1, 1953 - February 5, 1953) use "Should/Should Not/No Opinion" as response options. Thus, in the latter two surveys, "Should" is treated as "Yes," and "Should Not" is treated as "No."
*Check the variable - tab it and compare with frequency distribution in the codebook
bys form_num: tab pollTax_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen pollTax = pollTax_orig

****** EQUAL OPPORTUNITY EMPLOYMENT ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ALL THE WAY" 2 "NONE OF THE WAY" 3 "PART OF THE WAY" 4 "LEAVE TO STATES" 5 "QUALIFIED AS TO RACE, RELIGION, ETC." 6 "CREED BUT NOT RACE" 7 "DOESN'T MATTER-LAW CAN BE EVADED" 8 "HIRE, SEPARATE BUT EQUAL" 9 "DON'T KNOW/NO ANSWER"
*Check the variable - tab it and compare with frequency distribution in the codebook
bys form_num: tab fedEmployment_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen fedEmployment = fedEmployment_orig

****** SEGREGATION IN INTERSTATE TRAVEL ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION"
*Check the variable - tab it and compare with frequency distribution in the codebook
bys form_num: tab segregationTravel_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen segregationTravel = segregationTravel_orig

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** UNION ******
tab union_orig
gen union = union_orig

****** INCOME ******
tab income_orig
gen income = income_orig

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1949-0439.dta, replace
clear



********************************
******** AIPO 1948-0434 ********
********************************

*There are 2 forms for this study: Form K and Form T. 
*Read in files individually
*add a variable to identify the correct form, and then append together.

*Read in dictionary file 
infile using Dictionaries_Detailed/aipo1948-0434k.dct

gen form = "Form K"

gen form_num = 1

**correct N***

*Save the file
saveold FormattedData_Detailed/1948-0434k.dta, replace
clear

*Read in dictionary file 
infile using Dictionaries_Detailed/aipo1948-0434t.dct

gen form = "Form T"

gen form_num = 2

**Correct N

*Save the file
saveold FormattedData_Detailed/1948-0434t.dta, replace

*Both Files read correctly

*Append the files
append using FormattedData_Detailed/1948-0434k.dta

*Count the number of observations
count

*count matches the codebook

*Create a variable for survey code
gen svy = "1948-0434"

*Create a variable for survey year
gen svy_year = "1948"

*Create a variable for survey month
gen svy_month = "December"

gen nonStandPartyVar = 1

**Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
bys form_num: tab race_orig
*frequency matches both forms: for this file
*Generate new var
gen race = race_orig

****** SEX ******
*1 MALE 2 FEMALE harmonization 
bys form_num: tab sex_orig
*frequency matches 
gen sex = sex_orig

****** STATE *******
*Check the variable 
bys form_num: tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
*46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

****** AGE ******
*Check the variable
bys form_num: tab age_orig
*Frequencies match*
gen age = age_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
bys form_num: tab poliPartyID_orig
**Frequencies match here**but need to recode
*progressive to other and also republican and democrat
gen poliPartyID = poliPartyID_orig
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*Replace to harmonize
replace poliPartyID = 1 if poliPartyID_orig == 2
replace poliPartyID = 2 if poliPartyID_orig == 1
replace poliPartyID = 4 if poliPartyID_orig == 3 
replace poliPartyID = 3 if poliPartyID_orig == 4
bys form_num: tab poliPartyID

****** VOTE FOR DEWEY, TRUMAN, WALLACE, OR THURMOND IN 1948 ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TRUMAN" 2 "DEWEY" 3 "WALLACE" 4 "THURMOND" 5 "OTHER" 6 "YES, VOTED-NO ANSWER" 7 "NO, DIDN'T VOTE" 8 "NO, TOO YOUNG TO VOTE" 9 "DON'T REMEMBER"
*Check the variable - tab it and compare with frequency distribution in the codebook
bys form_num: tab voteElection1948_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen voteElection1948 = voteElection1948_orig

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** UNION ******
tab union_orig
gen union = union_orig
replace union = 5 if union_orig == 1
replace union = 6 if union_orig == 2
replace union = 7 if union_orig == 3
replace union = 8 if union_orig == 4
replace union = 4 if union_orig == 5

****** MARST ******
tab marst_orig
gen marst = marst_orig

****** INCOME ******
tab income_orig
gen income = income_orig

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1948-0434.dta, replace
clear



********************************
******** AIPO 1948-0429 ********
********************************

*Read in dictionary file **There are two forms of this poll

infile using Dictionaries_Detailed/aipo1948-0429.dct

*count matches the codebook

*Create a variable for survey code
gen svy = "1948-0429"

*Create a variable for survey year
gen svy_year = "1948"

*Create a variable for survey month
gen svy_month = "September-October"

gen form = ""

replace form = "Regular (Non-South)" if form_num == "1"
replace form = "Sec. V. (South)" if form_num == "2"

destring form_num, replace


**Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
tab race_orig
*matched
*Generate new var
gen race = race_orig
replace race = . if race == 3

****** SEX ******
*1 MALE 2 FEMALE harmonization 
tab sex_orig
*frequency matches : 3 is not recorded; set to missing
gen sex = sex_orig
replace sex = . if sex == 3

****** STATE ******
*Check the variable 
tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
*46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

****** AGE ******
*Check the variable
tab age_orig
*Frequencies match*
gen age = age_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
tab poliPartyID_orig
gen nonStandPartyVar = 1
**Frequencies match here**but need to recode
*progressive to other, and democrat and republican need to be harmonied
gen poliPartyID = poliPartyID_orig
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*Replace to harmonize
replace poliPartyID = 1 if poliPartyID_orig == 2
replace poliPartyID = 2 if poliPartyID_orig == 1
replace poliPartyID = 4 if poliPartyID_orig == 3 
replace poliPartyID = 3 if poliPartyID_orig == 4
tab poliPartyID

****** PRESIDENTIAL ELECTION CHOICE: TRUMAN VS DEWEY VS WALLACE VS THURMOND ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TRUMAN" 2 "DEWEY" 3 "WALLACE" 4 "THURMOND" 5 "OTHER" 6 "UNDECIDED" 7 "NO OPINION" 8 "WOULDN'T VOTE/NONE"
*This variable is in two variables: one for southerners, and one for non-southerners. We will combine them into a single variable, but first, we'll check each individually to compare with the codebook.
*Check the variables - tab them and compare with frequency distributions in the codebook
tab trumanDewWallThurms1_orig
tab trumanDewWallThurms2_orig
*The frequency distribution for these variable match that in the codebook
*Generate a new variable to ensure synchronization of variable name across surveys
gen trumanDeweyWallaceThurmond_s = .
*Values are not coded consistently with harmonization plan; recode variable
*Replace values
replace trumanDeweyWallaceThurmond_s = 1 if trumanDewWallThurms1_orig == 2 | trumanDewWallThurms2_orig == 2
replace trumanDeweyWallaceThurmond_s = 2 if trumanDewWallThurms1_orig == 1 | trumanDewWallThurms2_orig == 1
replace trumanDeweyWallaceThurmond_s = 3 if trumanDewWallThurms1_orig == 3 | trumanDewWallThurms2_orig == 3
replace trumanDeweyWallaceThurmond_s = 4 if trumanDewWallThurms1_orig == 5 | trumanDewWallThurms2_orig == 5
replace trumanDeweyWallaceThurmond_s = 5 if trumanDewWallThurms1_orig == 6 | trumanDewWallThurms2_orig == 6 | trumanDewWallThurms1_orig == 7 | trumanDewWallThurms2_orig == 7 | trumanDewWallThurms1_orig == 10 | trumanDewWallThurms2_orig == 10 | trumanDewWallThurms1_orig == 11 | trumanDewWallThurms2_orig == 11
replace trumanDeweyWallaceThurmond_s = 6 if trumanDewWallThurms1_orig == 4 | trumanDewWallThurms2_orig == 4
replace trumanDeweyWallaceThurmond_s = 8 if trumanDewWallThurms1_orig == 8 | trumanDewWallThurms2_orig == 8 | trumanDewWallThurms1_orig == 9 | trumanDewWallThurms2_orig == 9

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** UNION ******
tab union_orig
gen union = union_orig
replace union = 5 if union_orig == 1
replace union = 6 if union_orig == 2
replace union = 7 if union_orig == 3
replace union = 8 if union_orig == 4
replace union = 4 if union_orig == 5
replace union = 0 if union_orig == 9

****** INCOME ******
tab income_orig
gen income = income_orig

****** RELIGION ******
tab religion
gen religion = religion_orig
replace religion = 9 if religion_orig==4
replace religion = 4 if religion_orig==5
replace religion = 9 if religion_orig==6
replace religion = 13 if religion_orig==7
replace religion = 8 if religion_orig==8
replace religion = 7 if religion_orig==9
replace religion = 6 if religion_orig==10
replace religion = 4 if religion_orig==11
							
****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1948-0429.dta, replace
clear



********************************
******** AIPO 1948-0425 ********
********************************

*Read in dictionary file **

infile using Dictionaries_Detailed/aipo1948-0425k.dct

gen form = "Form K"

gen form_num = 1

**correct N***

*Save the file
saveold FormattedData_Detailed/1948-0425k.dta, replace
clear

*Read in dictionary file 
infile using Dictionaries_Detailed/aipo1948-0425t.dct

gen form = "Form T"

gen form_num = 2

**Correct N

*Save the file
saveold FormattedData_Detailed/1948-0425t.dta, replace

*Both Files read correctly

*Append the files
append using FormattedData_Detailed/1948-0425k.dta

*Count the number of observations
count

*Create a variable for survey code
gen svy = "1948-0425"

*Create a variable for survey year
gen svy_year = "1948"

*Create a variable for survey month
gen svy_month = "September"

gen nonStandPartyVar = 1

**Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
bys form_num: tab race_orig
*frequency matches both forms: for this file
*Generate new var
gen race = race_orig

****** SEX ******
*1 MALE 2 FEMALE harmonization 
bys form_num: tab sex_orig
*frequency matches 
gen sex = sex_orig

****** STATE ******
*Check the variable 
bys form_num: tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
*46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

****** AGE ******
**Check the variable
bys form_num: tab age_orig
*Frequencies match*
gen age = age_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
bys form_num: tab poliPartyID_orig
**Frequencies match here**but the party options in Form K 
**are different from party options in Form T
gen poliPartyID = poliPartyID_orig if form_num == 1
**The numbers line up but have to recode as per harmonization plan
replace poliPartyID = 1 if poliPartyID_orig == 2 & form_num == 1
replace poliPartyID = 2 if poliPartyID_orig == 1 & form_num == 1
replace poliPartyID = 4 if poliPartyID_orig == 3 & form_num == 1
replace poliPartyID = 3 if poliPartyID_orig == 4 & form_num == 1
tab poliPartyID
replace poliPartyID = 55 if poliPartyID == . & form_num == 2
**Will recode progressive, socialist, and rump
**as other (4). 8 is none/ don't vote so that gets
*set to missing
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*Replace to harmonize
replace poliPartyID = 1 if poliPartyID_orig == 02 & form_num == 2
replace poliPartyID = 2 if poliPartyID_orig == 01 & form_num == 2
replace poliPartyID = 4 if poliPartyID_orig == 03 | poliPartyID_orig == 05 | poliPartyID_orig == 06 | poliPartyID_orig == 08 | poliPartyID_orig == 09 | poliPartyID_orig == 10 & form_num == 2
replace poliPartyID = 3 if poliPartyID_orig == 04
*set 07 to missing
replace poliPartyID = . if poliPartyID_orig == 07 & form_num == 2
replace poliPartyID = . if poliPartyID == 55 & form_num == 2
bys form_num: tab poliPartyID

****** PRESIDENTIAL ELECTION CHOICE: TRUMAN VS DEWEY VS WALLACE ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TRUMAN" 2 "DEWEY" 3 "WALLACE" 4 "THURMOND" 5 "OTHER" 6 "UNDECIDED" 7 "NO OPINION" 8 "WOULDN'T VOTE/NONE"
*Check the variable - tab it and compare with frequency distribution in the codebook
bys form_num: tab trumanDeweyWallace_orig
*The frequency distribution for this variable matches that in the codebook
*Values are not coded consistently with harmonization plan; recode variable
*Generate a new variable to ensure synchronization of variable name across surveys
gen trumanDeweyWallace = trumanDeweyWallace_orig
*Replace values
replace trumanDeweyWallace = 1 if trumanDeweyWallace_orig == 2
replace trumanDeweyWallace = 2 if trumanDeweyWallace_orig == 1
replace trumanDeweyWallace = 4 if trumanDeweyWallace_orig == 5
replace trumanDeweyWallace = 5 if trumanDeweyWallace_orig == 6 | trumanDeweyWallace_orig == 7 | trumanDeweyWallace_orig == 8 | trumanDeweyWallace_orig == 9
replace trumanDeweyWallace = 6 if trumanDeweyWallace_orig == 4
replace trumanDeweyWallace = 8 if trumanDeweyWallace_orig == 10 | trumanDeweyWallace_orig == 11

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** UNION ******
tab union_orig
gen union = union_orig
replace union = 5 if union_orig == 1
replace union = 6 if union_orig == 2
replace union = 7 if union_orig == 3
replace union = 8 if union_orig == 4
replace union = 4 if union_orig == 5

****** INCOME ******
tab income_orig
gen income = income_orig

****** RELIGION ******
tab religion_orig
gen religion = religion_orig
replace religion = 9 if religion_orig==4 | religion_orig==6
replace religion = 4 if religion_orig==5
replace religion = 13 if religion_orig==7
replace religion = 8 if religion_orig==8
replace religion = 7 if religion_orig==9
replace religion = 8 if religion_orig==10
							
****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1948-0425.dta, replace
clear



********************************
******** AIPO 1948-0414 ********
********************************

*Read in dictionary file **There are two forms of this poll

infile using Dictionaries_Detailed/aipo1948-0414k.dct

gen form = "Form K"

gen form_num = 1

**correct N***

*Save the file
saveold FormattedData_Detailed/1948-0414k.dta, replace
clear

*Read in dictionary file 
infile using Dictionaries_Detailed/aipo1948-0414t.dct

gen form = "Form T"

gen form_num = 2

**Correct N

*Save the file
saveold FormattedData_Detailed/1948-0414t.dta, replace

*Both Files read correctly

*Append the files
append using FormattedData_Detailed/1948-0414k.dta

*Count the number of observations
count

*count matches

*Create a variable for survey code
gen svy = "1948-0414"

*Create a variable for survey year
gen svy_year = "1948"

*Create a variable for survey month
gen svy_month = "March"


**Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
bys form_num: tab race_orig
*frequency matches 
*Generate new var
gen race = race_orig

****** SEX ******
*1 MALE 2 FEMALE harmonization 
bys form_num: tab sex_orig
*frequency matches 
gen sex = sex_orig

****** STATE ******
*Check the variable 
bys form_num: tab state_orig
*Frequencies  dont' fully line up and needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
*46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state
**frequencies in codebook are a bit off but overall N matches

****** AGE ******
*Check the variable
bys form_num: tab age_orig
*Frequencies match*
gen age = age_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
bys form_num: tab poliPartyID_orig
gen nonStandPartyVar = 1
**Frequencies match here**but need to recode
*socialist to other
gen poliPartyID = poliPartyID_orig
**democrat and republican need only to be harmonized for form 2
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*Replace to harmonize
replace poliPartyID = 1 if poliPartyID_orig == 2 & form_num == 2
replace poliPartyID = 2 if poliPartyID_orig == 1 & form_num == 2
replace poliPartyID = 4 if poliPartyID_orig == 3 
replace poliPartyID = 3 if poliPartyID_orig == 4
bys form_num: tab poliPartyID

****** PRESIDENTIAL ELECTION CHOICE: TRUMAN VS DEWEY VS WALLACE ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TRUMAN" 2 "DEWEY" 3 "WALLACE" 4 "THURMOND" 5 "OTHER" 6 "UNDECIDED" 7 "NO OPINION" 8 "WOULDN'T VOTE/NONE"
*Check the variable - tab it and compare with frequency distribution in the codebook
bys form_num: tab trumanDeweyWallace_orig
*The frequency distribution for this variable matches that in the codebook
*Values are not coded consistently with harmonization plan; recode variable
*Generate a new variable to ensure synchronization of variable name across surveys
gen trumanDeweyWallace = trumanDeweyWallace_orig
*Replace values
replace trumanDeweyWallace = 7 if trumanDeweyWallace_orig == 4

****** LYNCHING ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "FEDERAL" 2 "STATE" 3 "BOTH" 4 "QUALIFIED FEDERAL" 5 "QUALIFIED STATE" 6 "NO OPINION" 7 "QUALIFIED NO OPINION" 8 "MISCELLANEOUS"
*Check the variable - tab it and compare with frequency distribution in the codebook
bys form_num: tab stateLynching_orig
*The frequency distribution for this variable matches that in the codebook
*Values are not coded consistently with harmonization plan; recode variable
*Generate a new variable to ensure synchronization of variable name across surveys
gen stateLynching = stateLynching_orig
*Replace values
replace stateLynching = 3 if stateLynching_orig == 8
replace stateLynching = 4 if stateLynching_orig == 5 | stateLynching_orig == 6 | stateLynching_orig == 9
replace stateLynching = 5 if stateLynching_orig == 7
replace stateLynching = 6 if stateLynching_orig == 3
replace stateLynching = 8 if stateLynching_orig == 10

****** POLL TAX ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO" 3 "NO OPINION." Note that surveys USAIPO1948-0414 (March 5, 1948 - March 10, 1948) and USAIPO1949-0439 (March 19, 1949 - March 24, 1949) use "Yes/No/No Opinion" as response options, while surveys USAIPO1949-0450 (November 27, 1949 - December 2, 1949) and USAIPO1953-0511 (February 1, 1953 - February 5, 1953) use "Should/Should Not/No Opinion" as response options. Thus, in the latter two surveys, "Should" is treated as "Yes," and "Should Not" is treated as "No."
*Check the variable - tab it and compare with frequency distribution in the codebook
bys form_num: tab pollTax_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen pollTax = pollTax_orig

****** EQUAL OPPORTUNITY EMPLOYMENT ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ALL THE WAY" 2 "NONE OF THE WAY" 3 "PART OF THE WAY" 4 "LEAVE TO STATES" 5 "QUALIFIED AS TO RACE, RELIGION, ETC." 6 "CREED BUT NOT RACE" 7 "DOESN'T MATTER-LAW CAN BE EVADED" 8 "HIRE, SEPARATE BUT EQUAL" 9 "DON'T KNOW/NO ANSWER"
*Check the variable - tab it and compare with frequency distribution in the codebook
bys form_num: tab fedEmployment_orig
*The frequency distribution for this variable matches that in the codebook
*Values are not coded consistently with harmonization plan; recode variable
*Generate a new variable to ensure synchronization of variable name across surveys
gen fedEmployment = fedEmployment_orig
*Replace values
replace fedEmployment = 9 if fedEmployment_orig == 8

****** SEGREGATION IN INTERSTATE TRAVEL ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION"
*Check the variable - tab it and compare with frequency distribution in the codebook
bys form_num: tab segregationTravel_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen segregationTravel = segregationTravel_orig

****** EDUC ******
tab educ_orig
gen educ = educ_orig

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** UNION ******
tab union_orig
gen union = union_orig
replace union = 5 if union_orig == 1
replace union = 6 if union_orig == 2
replace union = 7 if union_orig == 3
replace union = 8 if union_orig == 4
replace union = 4 if union_orig == 5

****** INCOME ******
tab income_orig
gen income = income_orig

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1948-0414.dta, replace
clear



********************************
******** AIPO 1947-0408 ********
********************************

infile using Dictionaries_Detailed/aipo1947-0408.dct

*Create a variable for survey code
gen svy = "1947-0408"

*Create a variable for survey year
gen svy_year = "1947"

*Create a variable for survey month
gen svy_month = "November-December"

*Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
tab race_orig
*frequency matches
*Generate new var
gen race = race_orig

****** SEX ******
*1 MALE 2 FEMALE harmonization 
tab sex_orig
*matches
gen sex = sex_orig

****** STATE ******
*Check the variable 
tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
*46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

****** AGE ******
*Check the variable
tab age_orig
*Frequencies match*
gen age = age_orig

****** APPROVAL OF CURRENT PRESIDENT ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." If a survey has a response option of "APPROVE AND DISAPPROVE," it is recoded to "BOTH."
*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
tab poliPartyID_orig
**frequencies match: need to recode
gen poliPartyID = poliPartyID_orig
*also non standard party id questions
gen nonStandPartyVar = 1
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*For this file poliPartyID_orig =4 is never voted and changed to missing
*Replace to harmonize
replace poliPartyID = 4 if poliPartyID_orig == 3
replace poliPartyID = 3 if poliPartyID_orig == 4
tab poliPartyID

****** PRESIDENTIAL ELECTION CHOICE: TRUMAN VS DEWEY ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TRUMAN" 2 "DEWEY" 7 "NO OPINION"
*Check the variable - tab it and compare with frequency distribution in the codebook
tab trumanDewey_orig
*The frequency distribution for this variable matches that in the codebook
*Values are not coded consistently with harmonization plan; recode variable
*Generate a new variable to ensure synchronization of variable name across surveys
gen trumanDewey = trumanDewey_orig
*Replace values
replace trumanDewey = 7 if trumanDewey_orig == 3

****** EDUC ******
tab educ_orig
gen educ = educ_orig

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** UNION ******
tab union_orig
gen union = union_orig
replace union = 5 if union_orig == 1
replace union = 6 if union_orig == 2
replace union = 7 if union_orig == 3
replace union = 8 if union_orig == 4
replace union = 4 if union_orig == 5
replace union = 0 if union_orig == 9

****** INCOME ******
tab income_orig
gen income = income_orig

****** RELIGION ******
tab religion_orig
gen religion = religion_orig
replace religion = 1 if religion_orig==2 | religion_orig==7
replace religion = 2 if religion_orig==1 | religion_orig==6
replace religion = 3 if religion_orig==3 | religion_orig==8
replace religion = 12 if religion_orig==5
replace religion = 4 if religion_orig==4 | religion_orig==9
replace religion = 9 if religion_orig==10
replace religion = 0 if religion_orig==11

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1947-0408.dta, replace
clear



********************************
******** AIPO 1947-0400 ********
********************************

infile using Dictionaries_Detailed/aipo1947-0400.dct

*Create a variable for survey code
gen svy = "1947-0400"

*Create a variable for survey year
gen svy_year = "1947"

*Create a variable for survey month
gen svy_month = "July"

*Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
tab race_orig
*frequency matches
*Generate new var
gen race = race_orig

****** SEX ******
*1 MALE 2 FEMALE harmonization 
tab sex_orig
*matches
gen sex = sex_orig

****** STATE ******
*Check the variable 
tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
*46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

****** AGE ******
*Check the variable
tab age_orig
*Frequencies match*
gen age = age_orig

****** APPROVAL OF CURRENT PRESIDENT ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." If a survey has a response option of "APPROVE AND DISAPPROVE," it is recoded to "BOTH."
*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
tab poliPartyID_orig
**frequencies match: need to recode
gen poliPartyID = poliPartyID_orig
*also non standard party id questions
gen nonStandPartyVar = 1
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*For this file poliPartyID_orig =4 is never voted and changed to missing
*Replace to harmonize
replace poliPartyID = 4 if poliPartyID_orig == 3
replace poliPartyID = 3 if poliPartyID_orig == 4
tab poliPartyID

****** PRESIDENTIAL ELECTION CHOICE: TRUMAN VS DEWEY ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TRUMAN" 2 "DEWEY" 7 "NO OPINION"
*Check the variable - tab it and compare with frequency distribution in the codebook
tab trumanDewey_orig
*The frequency distribution for this variable matches that in the codebook
*Values are not coded consistently with harmonization plan; recode variable
*Generate a new variable to ensure synchronization of variable name across surveys
gen trumanDewey = trumanDewey_orig
*Replace values
replace trumanDewey = 1 if trumanDewey_orig == 2
replace trumanDewey = 2 if trumanDewey_orig == 1
replace trumanDewey = 7 if trumanDewey_orig == 3

****** EDUC ******
tab educ_orig
gen educ = educ_orig
tab educ

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** UNION ******
tab union_orig
gen union = union_orig
replace union = 5 if union_orig == 1
replace union = 6 if union_orig == 2
replace union = 7 if union_orig == 3
replace union = 8 if union_orig == 4
replace union = 4 if union_orig == 5

****** INCOME ******
tab income_orig
gen income = income_orig

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1947-0400.dta, replace
clear



********************************
******** AIPO 1947-0397 ********
********************************

infile using Dictionaries_Detailed/aipo1947-0397.dct

*Create a variable for survey code
gen svy = "1947-0397"

*Create a variable for survey year
gen svy_year = "1947"

*Create a variable for survey month
gen svy_month = "May"

*Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
tab race_orig
*frequency matches
*Generate new var
gen race = race_orig

****** SEX ******
*1 MALE 2 FEMALE harmonization 
tab sex_orig
*matches
gen sex = sex_orig

****** STATE ******
*Check the variable 
tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
*46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

****** AGE ******
*Check the variable
tab age_orig
*Frequencies match*
gen age = age_orig

****** APPROVAL OF CURRENT PRESIDENT ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." If a survey has a response option of "APPROVE AND DISAPPROVE," it is recoded to "BOTH."
*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
tab poliPartyID_orig
**frequencies match: need to recode
gen poliPartyID = poliPartyID_orig
*alSo non standard party id questions
gen nonStandPartyVar = 1
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*For this file poliPartyID_orig =4 is never voted and changed to missing
*Replace to harmonize
replace poliPartyID = 4 if poliPartyID_orig == 3
replace poliPartyID = 3 if poliPartyID_orig == 4
tab poliPartyID

****** EDUC ******
tab educ_orig
gen educ = educ_orig

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** UNION ******
tab union_orig
gen union = union_orig
replace union = 5 if union_orig == 1
replace union = 6 if union_orig == 2
replace union = 7 if union_orig == 3
replace union = 8 if union_orig == 4
replace union = 4 if union_orig == 5

****** INCOME ******
tab income_orig
gen income = income_orig

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1947-0397.dta, replace
clear



********************************
******** AIPO 1947-0392 ********
********************************

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1947-0392; March 14, 1947 - March 19, 1947)

infile using Dictionaries_Detailed/aipo1947-0392.dct

*The sample size in the codebook - 2,884 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1947-0392"

*Create a variable for survey year
gen svy_yr = 1947

*Create a variable for survey month
gen svy_month = "March"


*Begin harmonization of variables

****** APPROVAL OF CURRENT PRESIDENT ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." If a survey has a response option of "APPROVE AND DISAPPROVE," it is recoded to "BOTH."
*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig

****** RACE ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. Label will be defined as: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE"
*Check the variable - tab it and compare with frequency distribution in the codebook
tab race_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

****** STATE ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"
*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig
*The frequency distribution for this variable matches that in the codebook
*Values are not coded consistently with harmonization plan; recode variable
*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82

****** AGE ******
*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"
*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1947-0392" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1947-0392" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1947-0392" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1947-0392" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1947-0392" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1947-0392" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1947-0392" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1947-0392" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1947-0392" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1947-0392" & age_orig == 0
*The frequency distribution for this variable matches that in the codebook
*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig

****** EDUC ******
tab educ_orig
gen educ = educ_orig
tab educ

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** INCOME ******
tab income_orig
gen income = income_orig

****** RELIGION ******
tab religion
gen religion = religion_orig
replace religion = 2 if religion_orig==1
replace religion = 1 if religion_orig==2
replace religion = 9 if religion_orig==6
replace religion = 12 if religion_orig==5
							
****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1947-0392.dta, replace
clear



********************************
******** AIPO 1947-0387 ********
********************************

*Read in dictionary file **There are two forms of this poll

infile using Dictionaries_Detailed/aipo1947-0387k.dct

gen form = "Form K"

gen form_num = 1

*Save the file
saveold FormattedData_Detailed/1947-0387k.dta, replace
clear

*Read in dictionary file 
infile using Dictionaries_Detailed/aipo1947-0387t.dct

gen form = "Form T"

gen form_num = 2

*Save the file
saveold FormattedData_Detailed/1947-0387t.dta, replace

*Both Files read correctly

*Append the files
append using FormattedData_Detailed/1947-0387k.dta

*Count the number of observations
count

*count matches the codebook***

*Create a variable for survey code
gen svy = "1947-0387"

*Create a variable for survey year
gen svy_year = "1947"

*Create a variable for survey month
gen svy_month = "January"


**Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
bys form_num: tab race_orig
*frequency matches both forms: for this file
*Generate new var
gen race = race_orig

****** SEX ******
*1 MALE 2 FEMALE harmonization 
bys form_num: tab sex_orig
*frequency matches 
gen sex = sex_orig

****** STATE ******
*Check the variable 
bys form_num: tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
* 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

***** AGE ******
*AGE OF THE RESPONDENT
*Check the variable
bys form_num: tab age_orig
*Frequencies match*
gen age = age_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
bys form_num: tab poliPartyID_orig
gen nonStandPartyVar = 1
**Frequencies match but need to recode slightly differently per form
gen poliPartyID = poliPartyID_orig
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*Replace to harmonize
replace poliPartyID = 4 if poliPartyID_orig == 3 & form_num == 1
replace poliPartyID = 3 if poliPartyID_orig == 4 & form_num == 1
replace poliPartyID = 4 if poliPartyID_orig == 3 & form_num == 2
replace poliPartyID = 3 if poliPartyID_orig == 4 & form_num == 2
bys form_num: tab poliPartyID

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** UNION ******
tab union_orig
gen union = union_orig
replace union = 5 if union_orig == 1
replace union = 6 if union_orig == 2
replace union = 7 if union_orig == 3
replace union = 8 if union_orig == 4
replace union = 4 if union_orig == 5

****** INCOME ******
tab income_orig
gen income = income_orig

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1947-0387.dta, replace
clear



********************************
******** AIPO 1946-0384 ********
********************************

infile using Dictionaries_Detailed/aipo1946-0384.dct

*Create a variable for survey code
gen svy = "1946-0384"

*Create a variable for survey year
gen svy_year = "1946"

*Create a variable for survey month
gen svy_month = "November"

*Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
tab race_orig
*frequency matches
*Generate new var
gen race = race_orig

****** SEX ******
*1 MALE 2 FEMALE harmonization 
tab sex_orig
*matches
gen sex = sex_orig

****** STATE ******
*Check the variable 
tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
*46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

****** AGE ******
*Check the variable
tab age_orig
*Frequencies match* but there is a 17 year old who is being counted as 18
gen age = age_orig

****** APPROVAL OF CURRENT PRESIDENT ******
*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." If a survey has a response option of "APPROVE AND DISAPPROVE," it is recoded to "BOTH."
*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig
*The frequency distribution for this variable matches that in the codebook
*Values are coded consistently with harmonization plan, so no need to recode
*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
tab poliPartyID_orig
**frequencies match: need to recode
gen poliPartyID = poliPartyID_orig
*also non standard party id questions
gen nonStandPartyVar = 1
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*Replace to harmonize
replace poliPartyID = 4 if poliPartyID_orig == 3
replace poliPartyID = 3 if poliPartyID_orig == 4
tab poliPartyID

****** EDUC ******
tab educ_orig
gen educ = educ_orig
tab educ

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** UNION ******
tab union_orig
gen union = union_orig
replace union = 5 if union_orig == 1
replace union = 6 if union_orig == 2
replace union = 7 if union_orig == 3
replace union = 8 if union_orig == 4
replace union = 4 if union_orig == 5

****** INCOME ******
tab income_orig
gen income = income_orig

****** RELIGION ******
tab religion
gen religion = religion_orig
replace religion = 12 if religion_orig==1
replace religion = 1 if religion_orig==3 | religion_orig==9
replace religion = 2 if religion_orig==2 | religion_orig==8
replace religion = 3 if religion_orig==4 | religion_orig==10
replace religion = 4 if religion_orig==5 | religion_orig==11
replace religion = 0 if religion_orig==6
replace religion = 9 if religion_orig==7
							
****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1946-0384.dta, replace
clear



********************************
******** AIPO 1944-0328 ********
********************************

** This survey is in two forms, but only form P
*has the political party variable so that is the only one read in
*becauase the second form is a secret ballot
*not generating a form variable for this data set since only
*one form is being used

infile using Dictionaries_Detailed/aipo1944-0328p.dct

**count matches the codebook

*Create a variable for survey code
gen svy = "1944-0328"

*Create a variable for survey year
gen svy_year = "1944"

*Create a variable for survey month
gen svy_month = "September"

*Begin harmonization of variables

****** RACE ******
*1 WHITE 2 BLACK 3 OTHER harmonization for race
*Check var
tab race_orig
*frequency matches
*Generate new var
gen race = race_orig
*set 3 to missing since it is "not recorded"
replace race = . if race == 3

****** SEX ******
*1 MALE 2 FEMALE harmonization 
tab sex_orig
*matches
gen sex = sex_orig
*set 3 to missing since it is "not recorded"
replace sex = . if sex == 3

****** STATE ******
*Check the variable 
tab state_orig
*Frequencies line up, but needs some recoding
gen state = state_orig
*Harmonization Codes
*11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 
*15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 
*23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" *
*27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 
*41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA"
* 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 
*52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 
*56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 
*81 "ARKANSAS" 82 "LOUISIA2NA" 83 "OKLAHOMA" 84 "TEXAS" 
*61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 
*66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 
*73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
*Replace values
replace state = 51 if state_orig == 53
replace state = 52 if state_orig == 51
replace state = 53 if state_orig == 52
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 58
replace state = 57 if state_orig == 83
replace state = 58 if state_orig == 55
replace state = 59 if state_orig == 81
replace state = 81 if state_orig == 56
replace state = 82 if state_orig == 59
replace state = 83 if state_orig == 82
tab state

****** AGE ******
*Check the variable
tab age_orig
*Frequencies match* but there is a 17 year old who is being counted as 18
gen age = age_orig

****** PARTY ID IN POLITICS TODAY ******
*Check the variable 
tab poliPartyID_orig
**frequencies match: need to recode
gen poliPartyID = poliPartyID_orig
*also non standard party id questions
gen nonStandPartyVar = 1
**1 REPUBLICAN 2 DEMOCRAT 3 INDEPENDENT 4 OTHER PARTY
*(so if the variable in the particular survey has independent leaners, 
*recodes them as independents)
*Replace to harmonize
*5 in this codebook is undesignated: set to missing
replace poliPartyID = 4 if poliPartyID_orig == 3
replace poliPartyID = 3 if poliPartyID_orig == 4
replace poliPartyID = . if poliPartyID_orig == 5
tab poliPartyID

****** EDUC ******
tab educ_orig
gen educ=educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 9 if educ_orig == 8
replace educ = 7 if educ_orig == 9
replace educ = 8 if educ_orig == 10
tab educ

****** OCCUPATION ******
tab occupation_orig
gen occupation = occupation_orig
replace occupation = 13 if occupation_orig == 2
replace occupation = 2 if occupation_orig == 3
replace occupation = 3 if occupation_orig == 4
replace occupation = 14 if occupation_orig == 5
replace occupation = 8 if occupation_orig == 9
replace occupation = 8 if occupation_orig == 10
replace occupation = 15 if occupation_orig == 11
replace occupation = 10 if occupation_orig == 12
replace occupation = 12 if occupation_orig == 13

****** EMPLOYMENT ******
tab employment_orig
gen employment = employment_orig

****** UNION ******
tab union_orig
gen union = union_orig
replace union = 5 if union_orig == 1
replace union = 6 if union_orig == 2
replace union = 7 if union_orig == 3
replace union = 8 if union_orig == 4
replace union = 4 if union_orig == 5

****** INCOME ******
tab income_orig
gen income = income_orig

****** CITYSIZE ******
tab citySize_orig
gen citySize = citySize_orig

****** REGION ******
tab region_orig
gen region = region_orig

*Save the data
saveold FormattedData_Detailed/1944-0328.dta, replace
clear



****************************************************************
****************************************************************
****************************************************************
****************************************************************
****************************************************************
****************************************************************

****** append files ******
use FormattedData_Detailed/1952-0508.dta
append using FormattedData_Detailed/1952-0507.dta
append using FormattedData_Detailed/1952-0486.dta
append using FormattedData_Detailed/1951-0483.dta
append using FormattedData_Detailed/1951-0482.dta
append using FormattedData_Detailed/1951-0475.dta
append using FormattedData_Detailed/1951-0471.dta
append using FormattedData_Detailed/1951-0470.dta
append using FormattedData_Detailed/1950-0467.dta
append using FormattedData_Detailed/1950-0457.dta
append using FormattedData_Detailed/1950-0456.dta
append using FormattedData_Detailed/1950-0455.dta
append using FormattedData_Detailed/1950-0454.dta
append using FormattedData_Detailed/1950-0452.dta
append using FormattedData_Detailed/1949-0450.dta
append using FormattedData_Detailed/1949-0448.dta
append using FormattedData_Detailed/1949-0445.dta
append using FormattedData_Detailed/1949-0442.dta
append using FormattedData_Detailed/1949-0439.dta
append using FormattedData_Detailed/1948-0434.dta
append using FormattedData_Detailed/1948-0429.dta
append using FormattedData_Detailed/1948-0425.dta
append using FormattedData_Detailed/1948-0414.dta
append using FormattedData_Detailed/1947-0408.dta
append using FormattedData_Detailed/1947-0400.dta
append using FormattedData_Detailed/1947-0397.dta
append using FormattedData_Detailed/1947-0392.dta
append using FormattedData_Detailed/1947-0387.dta
append using FormattedData_Detailed/1946-0384.dta
append using FormattedData_Detailed/1944-0328.dta

****** replace observations set to 0 ("NO CODE OR NO DATA") ******
replace race = . if race == 0 | race == 9
replace sex = . if sex == 0 | sex == 9
replace state = . if state == 0 | state == 9
replace age = . if age == 0 | age == 9
replace educ = . if educ == 0
replace age = . if age == 0 | age == 9
replace religion = . if religion == 0
replace presApprovala = . if presApprovala == 0 | presApprovala == 9
replace poliPartyID = . if poliPartyID == 0 | poliPartyID == 9
replace trumanDewey = . if trumanDewey == 0 | trumanDewey == 9
replace trumanDeweyWallace = . if trumanDeweyWallace == 0 | trumanDeweyWallace == 9
replace trumanDeweyWallaceThurmond_s = . if trumanDeweyWallaceThurmond_s == 0 | trumanDeweyWallaceThurmond_s == 9
replace voteElection1948 = . if voteElection1948 == 0
replace fedIncomeTax = . if fedIncomeTax == 0 | fedIncomeTax == 9
replace stateLynching = . if stateLynching == 0 | stateLynching == 9
replace pollTax = . if pollTax == 0 | pollTax == 9
replace fedEmployment = . if fedEmployment == 0
replace segregationTravel = . if segregationTravel == 0 | segregationTravel == 9

destring svy_year, replace
drop form_num

****** add labels ******

label variable svy "SURVEY CODE"

label variable svy_year "SURVEY YEAR"

label variable svy_month "SURVEY MONTH(S)"

label variable race "RACE OF THE RESPONDENT"
label define lb_race 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE"
label values race lb_race

label variable sex "GENDER OF THE RESPONDENT"
label define lb_sex 1 "MALE" 2 "FEMALE"
label values sex lb_sex

label variable state "STATE THE RESPONDENT LIVES IN"
label define lb_state 	11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" ///
						15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" ///
						23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" ///
						27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" ///
						41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" ///
						46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" ///
						52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" ///
						56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" ///
						81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" ///
						61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" ///
						66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" ///
						73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"
label values state lb_state

label variable age "AGE OF THE RESPONDENT"

label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 
label values poliPartyID lb_poliPartyID


*EDUCATION
gen educ2 = educ
replace educ2 = 1 if (educ == 1 | educ == 2) //None or Grade 1-8
replace educ2 = 4 if (educ == 3) //HS Incomplete
replace educ2 = 5 if (educ == 4) //HS Grad
replace educ2 = 6 if (educ == 7 | educ ==8 | educ ==9) //Technical, Trade or Business
replace educ2 = 7 if (educ == 5) //College, Uni., Incomplete
replace educ2 = 8 if (educ == 6) //College, Uni., Graduate
replace educ2 = 0 if (educ == 0) //No Code

drop educ
rename educ2 educ
label variable educ "EDUCATION OF THE RESPONDENT"
label define lb_edu 1 "NONE, OR GRADES 1-8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE" 9 "POST-GRAD" 0 "NO CODE OR NO DATA"
label values educ lb_edu

/*label variable educ "EDUCATION"
label define lb_educ 	01 "NO SCHOOLING" ///
						02 "GRAMMAR SCHOOL (GRADES 1-8)" ///
						03 "HIGH SCHOOL, INCOMPLETE (9TH, 10TH, OR 11TH GRADE)" ///
						04 "HIGH SCHOOL, GRADUATED (12TH GRADE)" ///
						05 "HIGH SCHOOL, GRADUATED, YES, COLLEGE, INCOMPLETE" ///
						06 "HIGH SCHOOL, GRADUATED, YES, COLLEGE, GRADUATED" ///
						07 "HIGH SCHOOL, GRADUATED, YES, NURSES TRAINING" ///
						08 "HIGH SCHOOL, GRADUATED, YES, TRADE SCHOOL, BEAUTY SCHOOL" ///
						09 "HIGH SCHOOL, GRADUATED, YES, BUSINESS SCHOOL, BUSINESS COLLEGE" ///
						00 "NO CODE OR NO DATA"
label values educ lb_educ*/
	
label variable occupation "OCCUPATION"
*** note no 09 label
label define lb_occupation	00 "NO CODE OR NO DATA" ///
							01 "PROFESSIONAL" ///
							02 "FARMERS, FARM MANAGERS, FARM LABORERS" /// 
							03 "BUSINESS" ///
							04 "CLERICAL" ///
							05 "SALES" ///
							06 "SKILLED WORKERS" ///
							07 "SEMI-SKILLED WORKERS" ///
							08 "SERVICE WORKERS" ///
							10 "UNSKILLED WORKERS" ///
							11 "NON-LABOR FORCE" ///
							12 "UNDESIGNATED" ///
							13 "SEMI-PROFESSIONAL" ///
							14 "WHITE COLLAR" ///
							15 "SMALL BUSINESS" 
label values occupation lb_occupation

label variable employment "EMPLOYMENT STATUS OR POSITION IN FAMILY"
label define lb_employment	1 "EMPLOYED FULL OR PART TIME, EMPLOYERS" ///
							2 "HOUSEWIVES, MOTHERS, WIDOWS" ///
							3 "STUDENTS (25 YEARS OR YOUNGER)" ///
							4 "RETIRED" ///
							5 "UNEMPLOYED" ///
							6 "SONS AND DAUGHTERS (26 YEARS OR OLDER)" ///
							7 "UNDESIGNATED" ///
							9 "RESPONDENT HEAD OF FAMILY" ///
							0 "NO CODE OR NO DATA"
label values employment lb_employment

label variable union "MEMBER OF LABOR UNION?"
label define lb_union	1 "YES, I AM" ///
						2 "YES, HE IS" ///
						3 "YES, BOTH ARE" ///
						4 "NO" ///
						5 "YES, CIO" ///
						6 "YES, AF OF L" ///
						7 "YES, OTHER UNION" ///
						8 "YES, NO ANSWER TO WHICH UNION" ///
						0 "NO CODE OR NO DATA OR INAPPLICABLE"
label values union lb_union
 
label variable income "WEALTH STATUS"
label define lb_income	1 "WEALTHY" ///
						2 "AVERAGE PLUS" ///
						3 "AVERAGE" ///
						4 "POOR" ///
						5 "OLD AGE ASSISTANCE" ///
						6 "ON RELIEF" ///
						0 "NO CODE OR NO DATA"
label values income lb_income

label variable religion "RELIGION"
label define lb_religion	1 "PROTESTANT" ///
							2 "CATHOLIC" ///
							3 "JEWISH" ///
							4 "OTHER, UNSPECIFIED" ///
							5 "GREEK OR RUSSIAN ORTHODOX" ///
							6 "MOHAMMEDAN, MOSLEM" ///
							7 "BUDDHIST" ///
							8 "OTHER, SPECIFIED, CHRISTIAN SCIENTIST, SEVENTH DAY ADVENTIST, JEHOVAH WITNESSES, MORMONS, HOLY ROLLER, PENTACOSTAL, ASSEMBLY OF GOD, ETC." ///
							9 "NONE, ATHEIST" ///
						   10 "CHRISTIAN" ///
						   11 "INTERDENOMINATIONAL" ///
						   12 "BELONG TO A CHURCH (NO ANSWER TO WHICH CHURCH)" ///
						   13 "AGNOSTIC" ///
							0 "NO ANSWER"
label values religion lb_religion

label variable marst "MARITAL STATUS"
label define lb_marst	1 "MARRIED" ///
						2 "SINGLE" ///
						3 "WIDOWED" ///
						4 "DIVORCED" ///
						0 "NO CODE OR NO DATA"
label values marst lb_marst

label variable citySize "URBAN WITH CITY SIZE OR RURAL"
label define lb_citySize	1 "FARM" ///
							2 "TOWNS UNDER 2,500" ///
							3 "2,500 TO 10,000" ///
							4 "10,000 TO 100,000" ///
							5 "100,000 TO 500,000" ///
							6 "500,000 AND OVER" ///
							7 "RURAL, NON-FARM" ///
							0 "NO CODE OR NO DATA"
label values citySize lb_citySize

label variable region "REGION"
label define lb_region	1 "NEW ENGLAND" ///
						2 "MIDDLE ATLANTIC" ///
						3 "EAST CENTRAL" ///
						4 "WEST CENTRAL" ///
						5 "SOUTHERN" ///
						6 "ROCKY MOUNTAIN" ///
						7 "PACIFIC" ///
						8 "SOUTHERN" ///
						0 "NO CODE OR NO DATA"
label values region lb_region

label variable presApprovala "APPROVAL OF CURRENT PRESIDENT"
label define lb_presApprovala 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH"
label values presApprovala lb_presApprovala

label variable trumanDewey "PRESIDENTIAL ELECTION CHOICE: TRUMAN VS DEWEY"
label define lb_trumanDewey 1 "TRUMAN" 2 "DEWEY" 7 "NO OPINION"
label values trumanDewey lb_trumanDewey

label variable trumanDeweyWallace "PRESIDENTIAL ELECTION CHOICE: TRUMAN VS DEWEY VS WALLACE"
label define lb_trumanDeweyWallace 1 "TRUMAN" 2 "DEWEY" 3 "WALLACE" 4 "THURMOND" 5 "OTHER" 6 "UNDECIDED" 7 "NO OPINION" 8 "WOULDN'T VOTE/NONE"
label values trumanDeweyWallace lb_trumanDeweyWallace

label variable trumanDeweyWallaceThurmond_s "PRESIDENTIAL ELECTION CHOICE: TRUMAN VS DEWEY VS WALLACE VS THURMOND"
label define lb_trumanDeweyWallaceThurmond_s 1 "TRUMAN" 2 "DEWEY" 3 "WALLACE" 4 "THURMOND" 5 "OTHER" 6 "UNDECIDED" 7 "NO OPINION" 8 "WOULDN'T VOTE/NONE"
label values trumanDeweyWallaceThurmond_s lb_trumanDeweyWallaceThurmond_s

label variable voteElection1948 "VOTE FOR DEWEY, TRUMAN, WALLACE, OR THURMOND IN 1948"
label define lb_voteElection1948 1 "TRUMAN" 2 "DEWEY" 3 "WALLACE" 4 "THURMOND" 5 "OTHER" 6 "YES, VOTED-NO ANSWER" 7 "NO, DIDN'T VOTE" 8 "NO, TOO YOUNG TO VOTE" 9 "DON'T REMEMBER"
label values voteElection1948 lb_voteElection1948

label variable fedIncomeTax "LEVEL OF PERSONAL FEDERAL INCOME TAX"
label define lb_fedIncomeTax 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION"
label values fedIncomeTax lb_fedIncomeTax

label variable stateLynching "LYNCHING HANDLED BY STATE OR FEDS"
label define lb_stateLynching 1 "FEDERAL" 2 "STATE" 3 "BOTH" 4 "QUALIFIED FEDERAL" 5 "QUALIFIED STATE" 6 "NO OPINION" 7 "QUALIFIED NO OPINION" 8 "MISCELLANEOUS"
label values stateLynching lb_stateLynching

label variable pollTax "SHOULD POLL TAX BE ABOLISHED"
label define lb_pollTax 1 "YES" 2 "NO" 3 "NO OPINION"
label values pollTax lb_pollTax 

label variable fedEmployment "HOW FAR SHOULD FEDS GO FOR EQUAL EMPLOYMENT"
label define lb_fedEmployment 1 "ALL THE WAY" 2 "NONE OF THE WAY" 3 "PART OF THE WAY" 4 "LEAVE TO STATES" 5 "QUALIFIED AS TO RACE, RELIGION, ETC." 6 "CREED BUT NOT RACE" 7 "DOESN'T MATTER-LAW CAN BE EVADED" 8 "HIRE, SEPARATE BUT EQUAL" 9 "DON'T KNOW/NO ANSWER"
label values fedEmployment lb_fedEmployment

label variable segregationTravel "SHOULD NEGROES BY SEGREGATED IN INTERSTATE TRAVEL"
label define lb_segregationTravel 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION"
label values segregationTravel lb_segregationTravel

label variable form "MULTI-FORM SURVEY IDENTIFIER (MORE THAN ONE RAW DATA FILE USED EXCEPT FOR #429)"

label variable nonStandPartyVar "INDICATOR FOR PARTY ID NOT TAKEN FROM OUR STANDARD PARTY VARIABLE"



****************************************************************
****************************************************************
****************************************************************

*Check the data

*Count observations in the dataset
count

*Add numeric values to value labels to help check the data
numlabel, add

*Check each variable
bys svy form: tab svy_year
bys svy form: tab svy_month
bys svy form: tab race
bys svy form: tab sex
bys svy form: tab state
bys svy form: tab age
bys svy form: sum age

bys svy form: tab educ
bys svy form: tab occupation
bys svy form: tab employment
bys svy form: tab income
bys svy form: tab union
bys svy form: tab religion
bys svy form: tab marst
bys svy form: tab citySize
bys svy form: tab region

bys svy form: tab presApprovala
bys svy form: tab poliPartyID
bys svy form: tab nonStandPartyVar
bys svy form: tab trumanDewey
bys svy form: tab trumanDeweyWallace
bys svy form: tab trumanDeweyWallaceThurmond_s
bys svy form: tab voteElection1948
bys svy form: tab fedIncomeTax
bys svy form: tab stateLynching
bys svy form: tab pollTax
bys svy form: tab fedEmployment
bys svy form: tab segregationTravel
bys svy: tab form

*Remove the numeric values from value labels
numlabel, remove

*Sort the data
sort svy_year svy

*Order the variables
order svy svy_year svy_month state state_orig poliPartyID poliPartyID_orig nonStandPartyVar presApprovala presApprovala_orig trumanDewey trumanDewey_orig trumanDeweyWallace trumanDeweyWallace_orig trumanDeweyWallaceThurmond_s trumanDewWallThurms1_orig trumanDewWallThurms2_orig voteElection1948 voteElection1948_orig race race_orig sex sex_orig age age_orig religion religion_orig educ educ_orig occupation occupation_orig employment employment_orig income income_orig union union_orig religion religion_orig marst marst_orig citySize citySize_orig region region_orig fedIncomeTax fedIncomeTax_orig stateLynching stateLynching_orig pollTax pollTax_orig fedEmployment fedEmployment_orig segregationTravel segregationTravel_orig form

*Compress data in memory
compress

*Rename educ so that I can merge it later
rename educ eduHarmonized

*Save the data
saveold PartyID_1944_1952_Detailed.dta, replace

*log close
exit, clear


