set more off

*Change directory so others can use the do file

cd "/Users/`c(username)'/Dropbox/southern_strategy/Gallup&GSS/PresidentialApprovalKennedy"

log using PresidentialApprovalQuestionsKennedy6.18.2016.log, replace

********VARIABLE CREATION, ADJUSTMENT, AND HARMONIZATION********

****USAIPO1961-0641****
clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1961-0641; February 10, 1961 - February 15, 1961)
infile using DictionaryFiles\aipo1961-0641.dct

*The sample size in the codebook - 2,873 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1961-0641"

*Create a variable for survey year
gen svy_yr = 1961

*Create a variable for survey month
gen svy_month = "February"

*Create a variable to indicate whether or not the original file was converted from a binary file (label is defined as: 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION")
*The codebook does not indicate that USAIPO1961-0641 was converted from a binary file
gen binary = 2


*Begin harmonization of variables


*WEIGHT: TIMES AT HOME

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_timesAtHome

*The frequency distribution displayed next to the variable in the codebook shows a total that exceeds the total number of observations in the dataset; the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.


*WEIGHT: EDUCATION

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_edu

*The frequency distribution for this variable matches that in the codebook


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files,we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for all eight (non-binary) surveys that year: USAIPO1963-0667 (January 11, 1963 - January 16, 1963), USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for seven of the eight (non-binary) surveys that year: USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*KNOWLEDGE OF POTENTIAL REPUBLICAN CANDIDATES IN 1964 PRESIDENTIAL ELECTION

*Harmonization Plan: Survey-by-survey synchronization of variable names (knowledge of potential Republican candidates in the 1964 presidential election) and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA." Note that these variables are only included for surveys conducted in 1963 and are available for only one of the eight (non-binary) surveys compiled here: USAIPO1963-0669 (March 8, 1963 - March 13, 1963). The variables are also included in USAIPO1963-0676 (August 15, 1963 - August 20, 1963), but that dataset was read into Stata separately as part of the racial tolerance study. As such, consistent naming is required, even though the variables appear in only one survey in this dataset. For USAIPO1963-0669, there are four variables for four potential Republican presidential candidates: Nelson Rockefeller, Barry Goldwater, George Romney, and William Scranton.

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab age_orig

*The variable age_orig does not have frequencies displayed next to it in the codebook
*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESS–STATE, CONGRESSIONAL DISTRICT, OR EITHER (partyState, partyCD, or partyStateCD)

*Note: Question wording for preferred party for Congress varies in the Kennedy-era surveys, asking either: (1) which party would you like to see win in this state, or (2) which party would you like to see win in this congressional district. Moreover, one survey (USAIPO1963-0667) does not differentiate between the two, with the codebook stating that some of the respondents were asked the question with regard to state and the others with regard to congressional district (it is not clear whether there is some way to tell which respondents received which question). As such, there are three variables reflecting preferred party for Congress: partyState (preferred party for Congress in state), partyCD (preferred party for Congress in congressional district), and partyStateCD (preferred party for Congress in either state or congressional district).

*Harmonization Plan: Survey-by-survey synchronization of variable names and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variables. Label for all three variables will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 but are available for all eight of the (non-binary) surveys that year. The variables are distributed as follows: partyState in USAIPO1963-0674 (June 21, 1963 - June 26, 1963) and USAIPO1963-0675 (July 18, 1963 - July 23, 1963); partyCD in USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963); and partyStateCD in USAIPO1963-0667 (January 11, 1963 - January 16, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that there are only three surveys in this do file that contain the question on level of personal federal income tax: USAIPO1961-0641 (February 10, 1961 - February 15, 1961), USAIPO1962-660 (June 28, 1962 - July 3, 1962), and USAIPO1963-0667 (January 11, 1963 - January 16, 1963). The rest are read in/harmonized in the do file AdditionalTaxQuestions.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab fedIncomeTax_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen fedIncomeTax = fedIncomeTax_orig


*GOVERNMENT WELFARE SPENDING

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1964-0702 was harmonized for the additional tax files study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1961-0651 for this set of polls.

*N/A: This variable is not available in this file.


*MOST IMPORTANT PROBLEM–CIVIL RIGHTS

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab mostImpProbCivRights_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen mostImpProbCivRights = mostImpProbCivRights_orig


*OPINION: SPEED OF RACIAL INTEGRATION

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in nine surveys over the Kennedy years. Four surveys with this variable are included in this dataset: USAIPO1962-0664 (October 19, 1962 - October 24, 1962), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963). Two surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1963-0673 (May 23, 1963 - May 28, 1963) and USAIPO1963-0676 (August 15, 1963 - August 20, 1963). And three surveys containing this variable are in binary files and thus could not be read in: USAIPO1962-0658 (May 3, 1962 - May 8, 1962), USAIPO1963-0677 (September 12, 1963 - September 17, 1963), and USAIPO1963-0678 (October 11, 1963 - October 16, 1963).

*N/A: This variable is not available in this file.


*Save the data
saveold FormattedData\1961-0641.dta, replace

clear


****USAIPO1961-0642****

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1961-0642; March 10, 1961 - March 15, 1961)
infile using DictionaryFiles\aipo1961-0642.dct

*The sample size in the codebook - 3,511 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1961-0642"

*Create a variable for survey year
gen svy_yr = 1961

*Create a variable for survey month
gen svy_month = "March"

*Create a variable to indicate whether or not the original file was converted from a binary file (label is defined as: 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION")
*The codebook does not indicate that USAIPO1961-0642 was converted from a binary file
gen binary = 2


*Begin harmonization of variables


*WEIGHT: TIMES AT HOME

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_timesAtHome

*The frequency distribution for this variable matches that in the codebook


*WEIGHT: EDUCATION

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_edu

*The frequency distribution for this variable matches that in the codebook


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files,we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for all eight (non-binary) surveys that year: USAIPO1963-0667 (January 11, 1963 - January 16, 1963), USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for seven of the eight (non-binary) surveys that year: USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*KNOWLEDGE OF POTENTIAL REPUBLICAN CANDIDATES IN 1964 PRESIDENTIAL ELECTION

*Harmonization Plan: Survey-by-survey synchronization of variable names (knowledge of potential Republican candidates in the 1964 presidential election) and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA." Note that these variables are only included for surveys conducted in 1963 and are available for only one of the eight (non-binary) surveys compiled here: USAIPO1963-0669 (March 8, 1963 - March 13, 1963). The variables are also included in USAIPO1963-0676 (August 15, 1963 - August 20, 1963), but that dataset was read into Stata separately as part of the racial tolerance study. As such, consistent naming is required, even though the variables appear in only one survey in this dataset. For USAIPO1963-0669, there are four variables for four potential Republican presidential candidates: Nelson Rockefeller, Barry Goldwater, George Romney, and William Scranton.

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab age_orig

*The variable age_orig does not have frequencies displayed next to it in the codebook
*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESS–STATE, CONGRESSIONAL DISTRICT, OR EITHER (partyState, partyCD, or partyStateCD)

*Note: Question wording for preferred party for Congress varies in the Kennedy-era surveys, asking either: (1) which party would you like to see win in this state, or (2) which party would you like to see win in this congressional district. Moreover, one survey (USAIPO1963-0667) does not differentiate between the two, with the codebook stating that some of the respondents were asked the question with regard to state and the others with regard to congressional district (it is not clear whether there is some way to tell which respondents received which question). As such, there are three variables reflecting preferred party for Congress: partyState (preferred party for Congress in state), partyCD (preferred party for Congress in congressional district), and partyStateCD (preferred party for Congress in either state or congressional district).

*Harmonization Plan: Survey-by-survey synchronization of variable names and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variables. Label for all three variables will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 but are available for all eight of the (non-binary) surveys that year. The variables are distributed as follows: partyState in USAIPO1963-0674 (June 21, 1963 - June 26, 1963) and USAIPO1963-0675 (July 18, 1963 - July 23, 1963); partyCD in USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963); and partyStateCD in USAIPO1963-0667 (January 11, 1963 - January 16, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that there are only three surveys in this do file that contain the question on level of personal federal income tax: USAIPO1961-0641 (February 10, 1961 - February 15, 1961), USAIPO1962-660 (June 28, 1962 - July 3, 1962), and USAIPO1963-0667 (January 11, 1963 - January 16, 1963). The rest are read in/harmonized in the do file AdditionalTaxQuestions.

*N/A: This variable is not available in this file.


*GOVERNMENT WELFARE SPENDING

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1964-0702 was harmonized for the additional tax files study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1961-0651 for this set of polls.

*N/A: This variable is not available in this file.


*MOST IMPORTANT PROBLEM–CIVIL RIGHTS

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO"

*N/A: This variable is not available in this file.


*OPINION: SPEED OF RACIAL INTEGRATION

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in nine surveys over the Kennedy years. Four surveys with this variable are included in this dataset: USAIPO1962-0664 (October 19, 1962 - October 24, 1962), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963). Two surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1963-0673 (May 23, 1963 - May 28, 1963) and USAIPO1963-0676 (August 15, 1963 - August 20, 1963). And three surveys containing this variable are in binary files and thus could not be read in: USAIPO1962-0658 (May 3, 1962 - May 8, 1962), USAIPO1963-0677 (September 12, 1963 - September 17, 1963), and USAIPO1963-0678 (October 11, 1963 - October 16, 1963).

*N/A: This variable is not available in this file.


*Save the data
saveold FormattedData\1961-0642.dta, replace

clear


/*


****USAIPO1961-0643****

*Note on this file: The codebook for USAIPO1961-0643 indicates that the dataset was converted from a binary file and that the column locations in the questionnaire portion of the codebook refer to binary column data only, not the ASCII file. The codebook thus indicates that the column guide should be used, rather than the information from the questionnaires. We perform a check that suggests that the recoded columns are correct. The Roper site provides both formatted data (in SPSS but converted to Stata via StatTransfer) and an ASCII text file (requiring a dictionary file to be written into Stata) that we can compare. Below, we read in the ASCII file first and then tabulate the variables. Then, we open the Stata file and check the same variables. Once that check is complete, though, we do use the formatted Stata file for the rest of the checks/harmonization, rather than the ASCII with dictionary, to minimize any error that may accompany the extra step of writing the dictionary file. Note, too, that we cannot perform a similar check in all cases of binary files, as formatted data isn't always provided. However, our review of codebooks for those data files converted from the binary - in particular, we looked at frequency distributions for specific questions - suggests that recoded columns, where indicated, should be correct.

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1961-0643; April 6, 1961 - April 11, 1961)
*Most (if not all) variables in ASCII files converted from binary files contain odd characters/symbols, so we read them in as strings and later convert them to numeric per harmonization plan(s)
infile using DictionaryFiles\aipo1961-0643.dct

*The sample size in the codebook - 2,974 - matches the number of observations read into Stata

*Check the variables
tab wgt_timesAtHome
tab raceSex_orig
tab state_orig
tab presApprovala_orig
tab age_orig
tab poliPartyID_orig

clear

*Read in the formatted Stata file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1961-0643; April 6, 1961 - April 11, 1961)
use RawData\aipo1961-0643.dta

*Count the number of observations
count

*The sample size in the codebook - 2,974 - matches the total number of observations in the Stata dataset

*Check the variables
*Variable: wgt_timesAtHome
tab times
*Variable: raceSex_orig
tab racesex
*Variable: state_orig
tab state
*Variable: presApprovala_orig
tab Q1
*Variable: age_orig
tab Q112
*Variable: poliPartyID_orig
tab Q101

*The variables from the formatted Stata file match those from the ASCII file, suggesting that the recoded columns are correct

*Create a variable for survey code
gen svy = "1961-0643"

*Create a variable for survey year
gen svy_yr = 1961

*Create a variable for survey month
gen svy_month = "April"

*Create a variable to indicate whether or not the original file was converted from a binary file (label is defined as: 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION")
*The codebook indicates that USAIPO1961-0643 was converted from a binary file
gen binary = 1

*Keep only the relevant variables from the formatted Stata file
keep times racesex state Q1 Q112 Q101 svy* binary

*Rename the variables to ensure consistency in original variables with datasets written in using ASCII files/dictionaries
rename times wgt_timesAtHome
rename racesex raceSex_orig
rename state state_orig
rename Q1 presApprovala_orig
rename Q112 age_orig
rename Q101 poliPartyID_orig


*Begin harmonization of variables


*WEIGHT: TIMES AT HOME

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Note on weight for USAIPO1961-0643: the first page of the codebook states, "Weight Location: None." However, the paragraph on page 17 of 22 implies that a weight based on times at home is reported in column 79 (i.e., recoded column 133).

*Check the variable - tab it and compare with frequency table in the back of the codebook
tab wgt_timesAtHome

*The frequency distribution for this variable matches that in the codebook


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, After appending files,we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency table in the back of the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys 
*Some observations have odd characters/symbols mixed with the numbers, as expected with data from a binary file; use the real command to retain only numeric values
gen raceSex = real(raceSex_orig)

*Compare the new variable to the original variable to ensure that the number of missing in the new variable equals the number of observations with odd characters/symbols in the original variable
tab raceSex


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency table in the back of the codebook
tab state_orig

*Since state has a width of two, create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen state_orig_check = state_orig

*Convert the numeric values to strings
tostring state_orig_check, replace

*Replace those observations that are set to zero to double zero so that zeroes are accurate in each column after using the substr command
replace state_orig_check = "00" if state_orig_check == "0"

*Obtain the first and second entries in each column of data using the substr command
gen state_orig_check1 = substr(state_orig_check,1,1)
gen state_orig_check2 = substr(state_orig_check,2,1)

*Tabulate the variables and compare to frequency table in the back of the codebook
tab state_orig_check1
tab state_orig_check2

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop state_orig_check*

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
*Some observations have odd characters/symbols mixed with the numbers, as expected with data from a binary file; use the real command to retain only numeric values
gen state = real(state_orig)

*Compare the new variable to the original variable to ensure that the number of missing in the new variable equals the number of observations with odd characters/symbols in the original variable
tab state


*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"

*Check the variable - tab it and compare with frequency table in the back of the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
*Some observations have odd characters/symbols mixed with the numbers, as expected with data from a binary file; use the real command to retain only numeric values
gen presApprovala = real(presApprovala_orig)

*Compare the new variable to the original variable to ensure that the number of missing in the new variable equals the number of observations with odd characters/symbols in the original variable
tab presApprovala


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for all eight (non-binary) surveys that year: USAIPO1963-0667 (January 11, 1963 - January 16, 1963), USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for seven of the eight (non-binary) surveys that year: USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*KNOWLEDGE OF POTENTIAL REPUBLICAN CANDIDATES IN 1964 PRESIDENTIAL ELECTION

*Harmonization Plan: Survey-by-survey synchronization of variable names (knowledge of potential Republican candidates in the 1964 presidential election) and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA." Note that these variables are only included for surveys conducted in 1963 and are available for only one of the eight (non-binary) surveys compiled here: USAIPO1963-0669 (March 8, 1963 - March 13, 1963). The variables are also included in USAIPO1963-0676 (August 15, 1963 - August 20, 1963), but that dataset was read into Stata separately as part of the racial tolerance study. As such, consistent naming is required, even though the variables appear in only one survey in this dataset. For USAIPO1963-0669, there are four variables for four potential Republican presidential candidates: Nelson Rockefeller, Barry Goldwater, George Romney, and William Scranton.

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab it and compare with frequency table in the back of the codebook
tab age_orig

*Since age has a width of two, create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen age_orig_check = age_orig

*Convert the numeric values to strings
tostring age_orig_check, replace

*Replace those observations that are set to zero to double zero so that zeroes are accurate in each column after using the substr command
replace age_orig_check = "00" if age_orig_check == "0"

*Obtain the first and second entries in each column of data using the substr command
gen age_orig_check1 = substr(age_orig_check,1,1)
gen age_orig_check2 = substr(age_orig_check,2,1)

*Tabulate the variables and compare to frequency table in the back of the codebook
tab age_orig_check1
tab age_orig_check2

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop age_orig_check*

*Generate a new variable to ensure synchronization of variable name across surveys
*Some observations have odd characters/symbols mixed with the numbers, as expected with data from a binary file; use the real command to retain only numeric values
gen age = real(age_orig)

*Compare the new variable to the original variable to ensure that the number of missing in the new variable equals the number of observations with odd characters/symbols in the original variable
tab age


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"

*Check the variable - tab it and compare with frequency table in the back of the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
*Some observations have odd characters/symbols mixed with the numbers, as expected with data from a binary file; use the real command to retain only numeric values
gen poliPartyID = real(poliPartyID_orig)

*Compare the new variable to the original variable to ensure that the number of missing in the new variable equals the number of observations with odd characters/symbols in the original variable
tab poliPartyID


*PREFERRED PARTY FOR CONGRESS–STATE, CONGRESSIONAL DISTRICT, OR EITHER (partyState, partyCD, or partyStateCD)

*Note: Question wording for preferred party for Congress varies in the Kennedy-era surveys, asking either: (1) which party would you like to see win in this state, or (2) which party would you like to see win in this congressional district. Moreover, one survey (USAIPO1963-0667) does not differentiate between the two, with the codebook stating that some of the respondents were asked the question with regard to state and the others with regard to congressional district (it is not clear whether there is some way to tell which respondents received which question). As such, there are three variables reflecting preferred party for Congress: partyState (preferred party for Congress in state), partyCD (preferred party for Congress in congressional district), and partyStateCD (preferred party for Congress in either state or congressional district).

*Harmonization Plan: Survey-by-survey synchronization of variable names and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variables. Label for all three variables will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 but are available for all eight of the (non-binary) surveys that year. The variables are distributed as follows: partyState in USAIPO1963-0674 (June 21, 1963 - June 26, 1963) and USAIPO1963-0675 (July 18, 1963 - July 23, 1963); partyCD in USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963); and partyStateCD in USAIPO1963-0667 (January 11, 1963 - January 16, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that there are only three surveys in this do file that contain the question on level of personal federal income tax: USAIPO1961-0641 (February 10, 1961 - February 15, 1961), USAIPO1962-660 (June 28, 1962 - July 3, 1962), and USAIPO1963-0667 (January 11, 1963 - January 16, 1963). The rest are read in/harmonized in the do file AdditionalTaxQuestions.

*N/A: This variable is not available in this file.


*GOVERNMENT WELFARE SPENDING

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1964-0702 was harmonized for the additional tax files study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1961-0651 for this set of polls.

*N/A: This variable is not available in this file.


*MOST IMPORTANT PROBLEM–CIVIL RIGHTS

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO"

*N/A: This variable is not available in this file.


*OPINION: SPEED OF RACIAL INTEGRATION

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in nine surveys over the Kennedy years. Four surveys with this variable are included in this dataset: USAIPO1962-0664 (October 19, 1962 - October 24, 1962), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963). Two surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1963-0673 (May 23, 1963 - May 28, 1963) and USAIPO1963-0676 (August 15, 1963 - August 20, 1963). And three surveys containing this variable are in binary files and thus could not be read in: USAIPO1962-0658 (May 3, 1962 - May 8, 1962), USAIPO1963-0677 (September 12, 1963 - September 17, 1963), and USAIPO1963-0678 (October 11, 1963 - October 16, 1963).

*N/A: This variable is not available in this file.


*Save the data
saveold FormattedData\1961-0643.dta, replace

clear


*/


****USAIPO1961-0644****

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1961-0644; May 4, 1961 - May 9, 1961)
infile using DictionaryFiles\aipo1961-0644.dct

*The sample size in the codebook - 3,545 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1961-0644"

*Create a variable for survey year
gen svy_yr = 1961

*Create a variable for survey month
gen svy_month = "May"

*Create a variable to indicate whether or not the original file was converted from a binary file (label is defined as: 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION")
*The codebook does not indicate that USAIPO1961-0644 was converted from a binary file
gen binary = 2


*Begin harmonization of variables


*WEIGHT: TIMES AT HOME

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_timesAtHome

*The frequency distribution for this variable matches that in the codebook


*WEIGHT: EDUCATION

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_edu

*The frequency distribution for this variable matches that in the codebook


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files,we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for all eight (non-binary) surveys that year: USAIPO1963-0667 (January 11, 1963 - January 16, 1963), USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for seven of the eight (non-binary) surveys that year: USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*KNOWLEDGE OF POTENTIAL REPUBLICAN CANDIDATES IN 1964 PRESIDENTIAL ELECTION

*Harmonization Plan: Survey-by-survey synchronization of variable names (knowledge of potential Republican candidates in the 1964 presidential election) and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA." Note that these variables are only included for surveys conducted in 1963 and are available for only one of the eight (non-binary) surveys compiled here: USAIPO1963-0669 (March 8, 1963 - March 13, 1963). The variables are also included in USAIPO1963-0676 (August 15, 1963 - August 20, 1963), but that dataset was read into Stata separately as part of the racial tolerance study. As such, consistent naming is required, even though the variables appear in only one survey in this dataset. For USAIPO1963-0669, there are four variables for four potential Republican presidential candidates: Nelson Rockefeller, Barry Goldwater, George Romney, and William Scranton.

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab age_orig

*The variable age_orig does not have frequencies displayed next to it in the codebook
*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESS–STATE, CONGRESSIONAL DISTRICT, OR EITHER (partyState, partyCD, or partyStateCD)

*Note: Question wording for preferred party for Congress varies in the Kennedy-era surveys, asking either: (1) which party would you like to see win in this state, or (2) which party would you like to see win in this congressional district. Moreover, one survey (USAIPO1963-0667) does not differentiate between the two, with the codebook stating that some of the respondents were asked the question with regard to state and the others with regard to congressional district (it is not clear whether there is some way to tell which respondents received which question). As such, there are three variables reflecting preferred party for Congress: partyState (preferred party for Congress in state), partyCD (preferred party for Congress in congressional district), and partyStateCD (preferred party for Congress in either state or congressional district).

*Harmonization Plan: Survey-by-survey synchronization of variable names and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variables. Label for all three variables will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 but are available for all eight of the (non-binary) surveys that year. The variables are distributed as follows: partyState in USAIPO1963-0674 (June 21, 1963 - June 26, 1963) and USAIPO1963-0675 (July 18, 1963 - July 23, 1963); partyCD in USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963); and partyStateCD in USAIPO1963-0667 (January 11, 1963 - January 16, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that there are only three surveys in this do file that contain the question on level of personal federal income tax: USAIPO1961-0641 (February 10, 1961 - February 15, 1961), USAIPO1962-660 (June 28, 1962 - July 3, 1962), and USAIPO1963-0667 (January 11, 1963 - January 16, 1963). The rest are read in/harmonized in the do file AdditionalTaxQuestions.

*N/A: This variable is not available in this file.


*GOVERNMENT WELFARE SPENDING

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1964-0702 was harmonized for the additional tax files study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1961-0651 for this set of polls.

*N/A: This variable is not available in this file.


*MOST IMPORTANT PROBLEM–CIVIL RIGHTS

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO"

*N/A: This variable is not available in this file.


*OPINION: SPEED OF RACIAL INTEGRATION

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in nine surveys over the Kennedy years. Four surveys with this variable are included in this dataset: USAIPO1962-0664 (October 19, 1962 - October 24, 1962), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963). Two surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1963-0673 (May 23, 1963 - May 28, 1963) and USAIPO1963-0676 (August 15, 1963 - August 20, 1963). And three surveys containing this variable are in binary files and thus could not be read in: USAIPO1962-0658 (May 3, 1962 - May 8, 1962), USAIPO1963-0677 (September 12, 1963 - September 17, 1963), and USAIPO1963-0678 (October 11, 1963 - October 16, 1963).

*N/A: This variable is not available in this file.


*Save the data
saveold FormattedData\1961-0644.dta, replace

clear


****USAIPO1961-0646****

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1961-0646; May 28, 1961 - June 2, 1961)
infile using DictionaryFiles\aipo1961-0646.dct

*The sample size in the codebook - 3,521 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1961-0646"

*Create a variable for survey year
gen svy_yr = 1961

*Create a variable for survey month
gen svy_month = "May-June"

*Create a variable to indicate whether or not the original file was converted from a binary file (label is defined as: 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION")
*The codebook does not indicate that USAIPO1961-0646 was converted from a binary file
gen binary = 2


*Begin harmonization of variables


*WEIGHT: TIMES AT HOME

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_timesAtHome

*The frequency distribution for this variable matches that in the codebook


*WEIGHT: EDUCATION

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_edu

*The frequency distribution for this variable matches that in the codebook


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files,we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for all eight (non-binary) surveys that year: USAIPO1963-0667 (January 11, 1963 - January 16, 1963), USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for seven of the eight (non-binary) surveys that year: USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*KNOWLEDGE OF POTENTIAL REPUBLICAN CANDIDATES IN 1964 PRESIDENTIAL ELECTION

*Harmonization Plan: Survey-by-survey synchronization of variable names (knowledge of potential Republican candidates in the 1964 presidential election) and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA." Note that these variables are only included for surveys conducted in 1963 and are available for only one of the eight (non-binary) surveys compiled here: USAIPO1963-0669 (March 8, 1963 - March 13, 1963). The variables are also included in USAIPO1963-0676 (August 15, 1963 - August 20, 1963), but that dataset was read into Stata separately as part of the racial tolerance study. As such, consistent naming is required, even though the variables appear in only one survey in this dataset. For USAIPO1963-0669, there are four variables for four potential Republican presidential candidates: Nelson Rockefeller, Barry Goldwater, George Romney, and William Scranton.

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab age_orig

*The variable age_orig does not have frequencies displayed next to it in the codebook
*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESS–STATE, CONGRESSIONAL DISTRICT, OR EITHER (partyState, partyCD, or partyStateCD)

*Note: Question wording for preferred party for Congress varies in the Kennedy-era surveys, asking either: (1) which party would you like to see win in this state, or (2) which party would you like to see win in this congressional district. Moreover, one survey (USAIPO1963-0667) does not differentiate between the two, with the codebook stating that some of the respondents were asked the question with regard to state and the others with regard to congressional district (it is not clear whether there is some way to tell which respondents received which question). As such, there are three variables reflecting preferred party for Congress: partyState (preferred party for Congress in state), partyCD (preferred party for Congress in congressional district), and partyStateCD (preferred party for Congress in either state or congressional district).

*Harmonization Plan: Survey-by-survey synchronization of variable names and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variables. Label for all three variables will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 but are available for all eight of the (non-binary) surveys that year. The variables are distributed as follows: partyState in USAIPO1963-0674 (June 21, 1963 - June 26, 1963) and USAIPO1963-0675 (July 18, 1963 - July 23, 1963); partyCD in USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963); and partyStateCD in USAIPO1963-0667 (January 11, 1963 - January 16, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that there are only three surveys in this do file that contain the question on level of personal federal income tax: USAIPO1961-0641 (February 10, 1961 - February 15, 1961), USAIPO1962-660 (June 28, 1962 - July 3, 1962), and USAIPO1963-0667 (January 11, 1963 - January 16, 1963). The rest are read in/harmonized in the do file AdditionalTaxQuestions.

*N/A: This variable is not available in this file.


*GOVERNMENT WELFARE SPENDING

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1964-0702 was harmonized for the additional tax files study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1961-0651 for this set of polls.

*N/A: This variable is not available in this file.


*MOST IMPORTANT PROBLEM–CIVIL RIGHTS

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO"

*N/A: This variable is not available in this file.


*OPINION: SPEED OF RACIAL INTEGRATION

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in nine surveys over the Kennedy years. Four surveys with this variable are included in this dataset: USAIPO1962-0664 (October 19, 1962 - October 24, 1962), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963). Two surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1963-0673 (May 23, 1963 - May 28, 1963) and USAIPO1963-0676 (August 15, 1963 - August 20, 1963). And three surveys containing this variable are in binary files and thus could not be read in: USAIPO1962-0658 (May 3, 1962 - May 8, 1962), USAIPO1963-0677 (September 12, 1963 - September 17, 1963), and USAIPO1963-0678 (October 11, 1963 - October 16, 1963).

*N/A: This variable is not available in this file.


*Save the data
saveold FormattedData\1961-0646.dta, replace

clear


****USAIPO1961-0651****

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1961-0651; October 19, 1961 - October 24, 1961)
infile using DictionaryFiles\aipo1961-0651.dct

*The sample size in the codebook - 3,753 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1961-0651"

*Create a variable for survey year
gen svy_yr = 1961

*Create a variable for survey month
gen svy_month = "October"

*Create a variable to indicate whether or not the original file was converted from a binary file (label is defined as: 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION")
*The codebook does not indicate that USAIPO1961-0651 was converted from a binary file
gen binary = 2


*Begin harmonization of variables


*WEIGHT: TIMES AT HOME

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*N/A: This variable is not available in USAIPO1961-0651


*WEIGHT: EDUCATION

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*N/A: This variable is not available in USAIPO1961-0651


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files,we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for all eight (non-binary) surveys that year: USAIPO1963-0667 (January 11, 1963 - January 16, 1963), USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for seven of the eight (non-binary) surveys that year: USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*KNOWLEDGE OF POTENTIAL REPUBLICAN CANDIDATES IN 1964 PRESIDENTIAL ELECTION

*Harmonization Plan: Survey-by-survey synchronization of variable names (knowledge of potential Republican candidates in the 1964 presidential election) and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA." Note that these variables are only included for surveys conducted in 1963 and are available for only one of the eight (non-binary) surveys compiled here: USAIPO1963-0669 (March 8, 1963 - March 13, 1963). The variables are also included in USAIPO1963-0676 (August 15, 1963 - August 20, 1963), but that dataset was read into Stata separately as part of the racial tolerance study. As such, consistent naming is required, even though the variables appear in only one survey in this dataset. For USAIPO1963-0669, there are four variables for four potential Republican presidential candidates: Nelson Rockefeller, Barry Goldwater, George Romney, and William Scranton.

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*There is no frequency table in the codebook, so check this variable using the age distribution table provided in the codebook

*Tab the variable to scan for odd or unexpected observations
tab age_orig

*Compare to age distribution table
*18-20 years
tab age_orig if svy == "1961-0651" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1961-0651" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1961-0651" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1961-0651" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1961-0651" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1961-0651" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1961-0651" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1961-0651" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1961-0651" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1961-0651" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESS–STATE, CONGRESSIONAL DISTRICT, OR EITHER (partyState, partyCD, or partyStateCD)

*Note: Question wording for preferred party for Congress varies in the Kennedy-era surveys, asking either: (1) which party would you like to see win in this state, or (2) which party would you like to see win in this congressional district. Moreover, one survey (USAIPO1963-0667) does not differentiate between the two, with the codebook stating that some of the respondents were asked the question with regard to state and the others with regard to congressional district (it is not clear whether there is some way to tell which respondents received which question). As such, there are three variables reflecting preferred party for Congress: partyState (preferred party for Congress in state), partyCD (preferred party for Congress in congressional district), and partyStateCD (preferred party for Congress in either state or congressional district).

*Harmonization Plan: Survey-by-survey synchronization of variable names and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variables. Label for all three variables will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 but are available for all eight of the (non-binary) surveys that year. The variables are distributed as follows: partyState in USAIPO1963-0674 (June 21, 1963 - June 26, 1963) and USAIPO1963-0675 (July 18, 1963 - July 23, 1963); partyCD in USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963); and partyStateCD in USAIPO1963-0667 (January 11, 1963 - January 16, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that there are only three surveys in this do file that contain the question on level of personal federal income tax: USAIPO1961-0641 (February 10, 1961 - February 15, 1961), USAIPO1962-660 (June 28, 1962 - July 3, 1962), and USAIPO1963-0667 (January 11, 1963 - January 16, 1963). The rest are read in/harmonized in the do file AdditionalTaxQuestions.

*N/A: This variable is not available in this file.


*GOVERNMENT WELFARE SPENDING

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1964-0702 was harmonized for the additional tax files study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1961-0651 for this set of polls.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab welfSpend_orig

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen welfSpend = welfSpend_orig


*MOST IMPORTANT PROBLEM–CIVIL RIGHTS

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO"

*N/A: This variable is not available in this file.


*OPINION: SPEED OF RACIAL INTEGRATION

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in nine surveys over the Kennedy years. Four surveys with this variable are included in this dataset: USAIPO1962-0664 (October 19, 1962 - October 24, 1962), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963). Two surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1963-0673 (May 23, 1963 - May 28, 1963) and USAIPO1963-0676 (August 15, 1963 - August 20, 1963). And three surveys containing this variable are in binary files and thus could not be read in: USAIPO1962-0658 (May 3, 1962 - May 8, 1962), USAIPO1963-0677 (September 12, 1963 - September 17, 1963), and USAIPO1963-0678 (October 11, 1963 - October 16, 1963).

*N/A: This variable is not available in this file.


*Save the data
saveold FormattedData\1961-0651.dta, replace

clear


****USAIPO1962-0654****

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1962-0654; January 11, 1962 - January 16, 1962)
infile using DictionaryFiles\aipo1962-0654.dct

*The sample size in the codebook - 3,421 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1962-0654"

*Create a variable for survey year
gen svy_yr = 1962

*Create a variable for survey month
gen svy_month = "January"

*Create a variable to indicate whether or not the original file was converted from a binary file (label is defined as: 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION")
*The codebook does not indicate that USAIPO1962-0654 was converted from a binary file
gen binary = 2


*Begin harmonization of variables


*WEIGHT: TIMES AT HOME

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_timesAtHome

*The frequency distribution for this variable matches that in the codebook


*WEIGHT: EDUCATION

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_edu

*The frequency distribution for this variable matches that in the codebook


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files,we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for all eight (non-binary) surveys that year: USAIPO1963-0667 (January 11, 1963 - January 16, 1963), USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for seven of the eight (non-binary) surveys that year: USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*KNOWLEDGE OF POTENTIAL REPUBLICAN CANDIDATES IN 1964 PRESIDENTIAL ELECTION

*Harmonization Plan: Survey-by-survey synchronization of variable names (knowledge of potential Republican candidates in the 1964 presidential election) and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA." Note that these variables are only included for surveys conducted in 1963 and are available for only one of the eight (non-binary) surveys compiled here: USAIPO1963-0669 (March 8, 1963 - March 13, 1963). The variables are also included in USAIPO1963-0676 (August 15, 1963 - August 20, 1963), but that dataset was read into Stata separately as part of the racial tolerance study. As such, consistent naming is required, even though the variables appear in only one survey in this dataset. For USAIPO1963-0669, there are four variables for four potential Republican presidential candidates: Nelson Rockefeller, Barry Goldwater, George Romney, and William Scranton.

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab age_orig

*The variable age_orig does not have frequencies displayed next to it in the codebook
*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESS–STATE, CONGRESSIONAL DISTRICT, OR EITHER (partyState, partyCD, or partyStateCD)

*Note: Question wording for preferred party for Congress varies in the Kennedy-era surveys, asking either: (1) which party would you like to see win in this state, or (2) which party would you like to see win in this congressional district. Moreover, one survey (USAIPO1963-0667) does not differentiate between the two, with the codebook stating that some of the respondents were asked the question with regard to state and the others with regard to congressional district (it is not clear whether there is some way to tell which respondents received which question). As such, there are three variables reflecting preferred party for Congress: partyState (preferred party for Congress in state), partyCD (preferred party for Congress in congressional district), and partyStateCD (preferred party for Congress in either state or congressional district).

*Harmonization Plan: Survey-by-survey synchronization of variable names and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variables. Label for all three variables will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 but are available for all eight of the (non-binary) surveys that year. The variables are distributed as follows: partyState in USAIPO1963-0674 (June 21, 1963 - June 26, 1963) and USAIPO1963-0675 (July 18, 1963 - July 23, 1963); partyCD in USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963); and partyStateCD in USAIPO1963-0667 (January 11, 1963 - January 16, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that there are only three surveys in this do file that contain the question on level of personal federal income tax: USAIPO1961-0641 (February 10, 1961 - February 15, 1961), USAIPO1962-660 (June 28, 1962 - July 3, 1962), and USAIPO1963-0667 (January 11, 1963 - January 16, 1963). The rest are read in/harmonized in the do file AdditionalTaxQuestions.

*N/A: This variable is not available in this file.


*GOVERNMENT WELFARE SPENDING

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1964-0702 was harmonized for the additional tax files study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1961-0651 for this set of polls.

*N/A: This variable is not available in this file.


*MOST IMPORTANT PROBLEM–CIVIL RIGHTS

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO"

*N/A: This variable is not available in this file.


*OPINION: SPEED OF RACIAL INTEGRATION

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in nine surveys over the Kennedy years. Four surveys with this variable are included in this dataset: USAIPO1962-0664 (October 19, 1962 - October 24, 1962), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963). Two surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1963-0673 (May 23, 1963 - May 28, 1963) and USAIPO1963-0676 (August 15, 1963 - August 20, 1963). And three surveys containing this variable are in binary files and thus could not be read in: USAIPO1962-0658 (May 3, 1962 - May 8, 1962), USAIPO1963-0677 (September 12, 1963 - September 17, 1963), and USAIPO1963-0678 (October 11, 1963 - October 16, 1963).

*N/A: This variable is not available in this file.


*Save the data
saveold FormattedData\1962-0654.dta, replace

clear


****USAIPO1962-0660****

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1962-0660; June 28, 1962 - July 3, 1962)
infile using DictionaryFiles\aipo1962-0660.dct

*The sample size in the codebook - 3,275 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1962-0660"

*Create a variable for survey year
gen svy_yr = 1962

*Create a variable for survey month
gen svy_month = "June-July"

*Create a variable to indicate whether or not the original file was converted from a binary file (label is defined as: 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION")
*The codebook does not indicate that USAIPO1962-0660 was converted from a binary file
gen binary = 2


*Begin harmonization of variables


*WEIGHT: TIMES AT HOME

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_timesAtHome

*The frequency distribution for this variable matches that in the codebook


*WEIGHT: EDUCATION

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_edu

*The frequency distribution for this variable matches that in the codebook


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files,we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for all eight (non-binary) surveys that year: USAIPO1963-0667 (January 11, 1963 - January 16, 1963), USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for seven of the eight (non-binary) surveys that year: USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*KNOWLEDGE OF POTENTIAL REPUBLICAN CANDIDATES IN 1964 PRESIDENTIAL ELECTION

*Harmonization Plan: Survey-by-survey synchronization of variable names (knowledge of potential Republican candidates in the 1964 presidential election) and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA." Note that these variables are only included for surveys conducted in 1963 and are available for only one of the eight (non-binary) surveys compiled here: USAIPO1963-0669 (March 8, 1963 - March 13, 1963). The variables are also included in USAIPO1963-0676 (August 15, 1963 - August 20, 1963), but that dataset was read into Stata separately as part of the racial tolerance study. As such, consistent naming is required, even though the variables appear in only one survey in this dataset. For USAIPO1963-0669, there are four variables for four potential Republican presidential candidates: Nelson Rockefeller, Barry Goldwater, George Romney, and William Scranton.

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*There is no frequency table in the codebook, so check this variable using the age distribution table provided in the codebook

*Tab the variable to scan for odd or unexpected observations
tab age_orig

*Compare to age distribution table
*18-20 years
tab age_orig if svy == "1962-0660" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1962-0660" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1962-0660" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1962-0660" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1962-0660" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1962-0660" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1962-0660" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1962-0660" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1962-0660" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1962-0660" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESS–STATE, CONGRESSIONAL DISTRICT, OR EITHER (partyState, partyCD, or partyStateCD)

*Note: Question wording for preferred party for Congress varies in the Kennedy-era surveys, asking either: (1) which party would you like to see win in this state, or (2) which party would you like to see win in this congressional district. Moreover, one survey (USAIPO1963-0667) does not differentiate between the two, with the codebook stating that some of the respondents were asked the question with regard to state and the others with regard to congressional district (it is not clear whether there is some way to tell which respondents received which question). As such, there are three variables reflecting preferred party for Congress: partyState (preferred party for Congress in state), partyCD (preferred party for Congress in congressional district), and partyStateCD (preferred party for Congress in either state or congressional district).

*Harmonization Plan: Survey-by-survey synchronization of variable names and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variables. Label for all three variables will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 but are available for all eight of the (non-binary) surveys that year. The variables are distributed as follows: partyState in USAIPO1963-0674 (June 21, 1963 - June 26, 1963) and USAIPO1963-0675 (July 18, 1963 - July 23, 1963); partyCD in USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963); and partyStateCD in USAIPO1963-0667 (January 11, 1963 - January 16, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that there are only three surveys in this do file that contain the question on level of personal federal income tax: USAIPO1961-0641 (February 10, 1961 - February 15, 1961), USAIPO1962-660 (June 28, 1962 - July 3, 1962), and USAIPO1963-0667 (January 11, 1963 - January 16, 1963). The rest are read in/harmonized in the do file AdditionalTaxQuestions.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab fedIncomeTax_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen fedIncomeTax = fedIncomeTax_orig


*GOVERNMENT WELFARE SPENDING

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1964-0702 was harmonized for the additional tax files study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1961-0651 for this set of polls.

*N/A: This variable is not available in this file.


*MOST IMPORTANT PROBLEM–CIVIL RIGHTS

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab mostImpProbCivRights_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen mostImpProbCivRights = mostImpProbCivRights_orig


*OPINION: SPEED OF RACIAL INTEGRATION

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in nine surveys over the Kennedy years. Four surveys with this variable are included in this dataset: USAIPO1962-0664 (October 19, 1962 - October 24, 1962), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963). Two surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1963-0673 (May 23, 1963 - May 28, 1963) and USAIPO1963-0676 (August 15, 1963 - August 20, 1963). And three surveys containing this variable are in binary files and thus could not be read in: USAIPO1962-0658 (May 3, 1962 - May 8, 1962), USAIPO1963-0677 (September 12, 1963 - September 17, 1963), and USAIPO1963-0678 (October 11, 1963 - October 16, 1963).

*N/A: This variable is not available in this file.


*Save the data
saveold FormattedData\1962-0660.dta, replace

clear


****USAIPO1962-0661****

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1962-0661; July 26, 1962 - July 31, 1962)
infile using DictionaryFiles\aipo1962-0661.dct

*The sample size in the codebook - 4,040 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1962-0661"

*Create a variable for survey year
gen svy_yr = 1962

*Create a variable for survey month
gen svy_month = "July"

*Create a variable to indicate whether or not the original file was converted from a binary file (label is defined as: 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION")
*The codebook does not indicate that USAIPO1962-0661 was converted from a binary file
gen binary = 2


*Begin harmonization of variables


*WEIGHT: TIMES AT HOME

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_timesAtHome

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.


*WEIGHT: EDUCATION

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_edu

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files,we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches the frequency table in the back of the codebook; drop the unnecessary variables
drop first second

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for all eight (non-binary) surveys that year: USAIPO1963-0667 (January 11, 1963 - January 16, 1963), USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for seven of the eight (non-binary) surveys that year: USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*KNOWLEDGE OF POTENTIAL REPUBLICAN CANDIDATES IN 1964 PRESIDENTIAL ELECTION

*Harmonization Plan: Survey-by-survey synchronization of variable names (knowledge of potential Republican candidates in the 1964 presidential election) and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA." Note that these variables are only included for surveys conducted in 1963 and are available for only one of the eight (non-binary) surveys compiled here: USAIPO1963-0669 (March 8, 1963 - March 13, 1963). The variables are also included in USAIPO1963-0676 (August 15, 1963 - August 20, 1963), but that dataset was read into Stata separately as part of the racial tolerance study. As such, consistent naming is required, even though the variables appear in only one survey in this dataset. For USAIPO1963-0669, there are four variables for four potential Republican presidential candidates: Nelson Rockefeller, Barry Goldwater, George Romney, and William Scranton.

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab age_orig

*The variable age_orig does not have frequencies displayed next to it in the codebook
*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESS–STATE, CONGRESSIONAL DISTRICT, OR EITHER (partyState, partyCD, or partyStateCD)

*Note: Question wording for preferred party for Congress varies in the Kennedy-era surveys, asking either: (1) which party would you like to see win in this state, or (2) which party would you like to see win in this congressional district. Moreover, one survey (USAIPO1963-0667) does not differentiate between the two, with the codebook stating that some of the respondents were asked the question with regard to state and the others with regard to congressional district (it is not clear whether there is some way to tell which respondents received which question). As such, there are three variables reflecting preferred party for Congress: partyState (preferred party for Congress in state), partyCD (preferred party for Congress in congressional district), and partyStateCD (preferred party for Congress in either state or congressional district).

*Harmonization Plan: Survey-by-survey synchronization of variable names and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variables. Label for all three variables will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 but are available for all eight of the (non-binary) surveys that year. The variables are distributed as follows: partyState in USAIPO1963-0674 (June 21, 1963 - June 26, 1963) and USAIPO1963-0675 (July 18, 1963 - July 23, 1963); partyCD in USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963); and partyStateCD in USAIPO1963-0667 (January 11, 1963 - January 16, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that there are only three surveys in this do file that contain the question on level of personal federal income tax: USAIPO1961-0641 (February 10, 1961 - February 15, 1961), USAIPO1962-660 (June 28, 1962 - July 3, 1962), and USAIPO1963-0667 (January 11, 1963 - January 16, 1963). The rest are read in/harmonized in the do file AdditionalTaxQuestions.

*N/A: This variable is not available in this file.


*GOVERNMENT WELFARE SPENDING

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1964-0702 was harmonized for the additional tax files study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1961-0651 for this set of polls.

*N/A: This variable is not available in this file.


*MOST IMPORTANT PROBLEM–CIVIL RIGHTS

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO"

*N/A: This variable is not available in this file.


*OPINION: SPEED OF RACIAL INTEGRATION

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in nine surveys over the Kennedy years. Four surveys with this variable are included in this dataset: USAIPO1962-0664 (October 19, 1962 - October 24, 1962), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963). Two surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1963-0673 (May 23, 1963 - May 28, 1963) and USAIPO1963-0676 (August 15, 1963 - August 20, 1963). And three surveys containing this variable are in binary files and thus could not be read in: USAIPO1962-0658 (May 3, 1962 - May 8, 1962), USAIPO1963-0677 (September 12, 1963 - September 17, 1963), and USAIPO1963-0678 (October 11, 1963 - October 16, 1963).

*N/A: This variable is not available in this file.


*Save the data
saveold FormattedData\1962-0661.dta, replace

clear


****USAIPO1962-0662****

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1962-0662; August 23, 1962 - August 28, 1962)
infile using DictionaryFiles\aipo1962-0662.dct

*The sample size in the codebook - 3,350 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1962-0662"

*Create a variable for survey year
gen svy_yr = 1962

*Create a variable for survey month
gen svy_month = "August"

*Create a variable to indicate whether or not the original file was converted from a binary file (label is defined as: 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION")
*The codebook does not indicate that USAIPO1962-0662 was converted from a binary file
gen binary = 2


*Begin harmonization of variables


*WEIGHT: TIMES AT HOME

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_timesAtHome

*The frequency distribution for this variable matches that in the codebook


*WEIGHT: EDUCATION

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_edu

*The frequency distribution for this variable matches that in the codebook


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files,we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for all eight (non-binary) surveys that year: USAIPO1963-0667 (January 11, 1963 - January 16, 1963), USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for seven of the eight (non-binary) surveys that year: USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*KNOWLEDGE OF POTENTIAL REPUBLICAN CANDIDATES IN 1964 PRESIDENTIAL ELECTION

*Harmonization Plan: Survey-by-survey synchronization of variable names (knowledge of potential Republican candidates in the 1964 presidential election) and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA." Note that these variables are only included for surveys conducted in 1963 and are available for only one of the eight (non-binary) surveys compiled here: USAIPO1963-0669 (March 8, 1963 - March 13, 1963). The variables are also included in USAIPO1963-0676 (August 15, 1963 - August 20, 1963), but that dataset was read into Stata separately as part of the racial tolerance study. As such, consistent naming is required, even though the variables appear in only one survey in this dataset. For USAIPO1963-0669, there are four variables for four potential Republican presidential candidates: Nelson Rockefeller, Barry Goldwater, George Romney, and William Scranton.

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*There is no frequency table in the codebook, so check this variable using the age distribution table provided in the codebook

*Tab the variable to scan for odd or unexpected observations
tab age_orig

*Compare to age distribution table
*18-20 years
tab age_orig if svy == "1962-0662" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1962-0662" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1962-0662" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1962-0662" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1962-0662" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1962-0662" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1962-0662" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1962-0662" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1962-0662" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1962-0662" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESS–STATE, CONGRESSIONAL DISTRICT, OR EITHER (partyState, partyCD, or partyStateCD)

*Note: Question wording for preferred party for Congress varies in the Kennedy-era surveys, asking either: (1) which party would you like to see win in this state, or (2) which party would you like to see win in this congressional district. Moreover, one survey (USAIPO1963-0667) does not differentiate between the two, with the codebook stating that some of the respondents were asked the question with regard to state and the others with regard to congressional district (it is not clear whether there is some way to tell which respondents received which question). As such, there are three variables reflecting preferred party for Congress: partyState (preferred party for Congress in state), partyCD (preferred party for Congress in congressional district), and partyStateCD (preferred party for Congress in either state or congressional district).

*Harmonization Plan: Survey-by-survey synchronization of variable names and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variables. Label for all three variables will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 but are available for all eight of the (non-binary) surveys that year. The variables are distributed as follows: partyState in USAIPO1963-0674 (June 21, 1963 - June 26, 1963) and USAIPO1963-0675 (July 18, 1963 - July 23, 1963); partyCD in USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963); and partyStateCD in USAIPO1963-0667 (January 11, 1963 - January 16, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that there are only three surveys in this do file that contain the question on level of personal federal income tax: USAIPO1961-0641 (February 10, 1961 - February 15, 1961), USAIPO1962-660 (June 28, 1962 - July 3, 1962), and USAIPO1963-0667 (January 11, 1963 - January 16, 1963). The rest are read in/harmonized in the do file AdditionalTaxQuestions.

*N/A: This variable is not available in this file.


*GOVERNMENT WELFARE SPENDING

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1964-0702 was harmonized for the additional tax files study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1961-0651 for this set of polls.

*N/A: This variable is not available in this file.


*MOST IMPORTANT PROBLEM–CIVIL RIGHTS

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO"

*N/A: This variable is not available in this file.


*OPINION: SPEED OF RACIAL INTEGRATION

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in nine surveys over the Kennedy years. Four surveys with this variable are included in this dataset: USAIPO1962-0664 (October 19, 1962 - October 24, 1962), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963). Two surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1963-0673 (May 23, 1963 - May 28, 1963) and USAIPO1963-0676 (August 15, 1963 - August 20, 1963). And three surveys containing this variable are in binary files and thus could not be read in: USAIPO1962-0658 (May 3, 1962 - May 8, 1962), USAIPO1963-0677 (September 12, 1963 - September 17, 1963), and USAIPO1963-0678 (October 11, 1963 - October 16, 1963).

*N/A: This variable is not available in this file.


*Save the data
saveold FormattedData\1962-0662.dta, replace

clear


****USAIPO1962-0663****

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1962-0663; September 20, 1962 - September 25, 1962)
infile using DictionaryFiles\aipo1962-0663.dct

*The sample size in the codebook - 3,948 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1962-0663"

*Create a variable for survey year
gen svy_yr = 1962

*Create a variable for survey month
gen svy_month = "September"

*Create a variable to indicate whether or not the original file was converted from a binary file (label is defined as: 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION")
*The codebook does not indicate that USAIPO1962-0663 was converted from a binary file
gen binary = 2


*Begin harmonization of variables


*WEIGHT: TIMES AT HOME

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_timesAtHome

*The frequency distribution for this variable matches that in the codebook


*WEIGHT: EDUCATION

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_edu

*The frequency distribution for this variable matches that in the codebook


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files,we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for all eight (non-binary) surveys that year: USAIPO1963-0667 (January 11, 1963 - January 16, 1963), USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for seven of the eight (non-binary) surveys that year: USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*KNOWLEDGE OF POTENTIAL REPUBLICAN CANDIDATES IN 1964 PRESIDENTIAL ELECTION

*Harmonization Plan: Survey-by-survey synchronization of variable names (knowledge of potential Republican candidates in the 1964 presidential election) and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA." Note that these variables are only included for surveys conducted in 1963 and are available for only one of the eight (non-binary) surveys compiled here: USAIPO1963-0669 (March 8, 1963 - March 13, 1963). The variables are also included in USAIPO1963-0676 (August 15, 1963 - August 20, 1963), but that dataset was read into Stata separately as part of the racial tolerance study. As such, consistent naming is required, even though the variables appear in only one survey in this dataset. For USAIPO1963-0669, there are four variables for four potential Republican presidential candidates: Nelson Rockefeller, Barry Goldwater, George Romney, and William Scranton.

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab age_orig

*The variable age_orig does not have frequencies displayed next to it in the codebook
*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESS–STATE, CONGRESSIONAL DISTRICT, OR EITHER (partyState, partyCD, or partyStateCD)

*Note: Question wording for preferred party for Congress varies in the Kennedy-era surveys, asking either: (1) which party would you like to see win in this state, or (2) which party would you like to see win in this congressional district. Moreover, one survey (USAIPO1963-0667) does not differentiate between the two, with the codebook stating that some of the respondents were asked the question with regard to state and the others with regard to congressional district (it is not clear whether there is some way to tell which respondents received which question). As such, there are three variables reflecting preferred party for Congress: partyState (preferred party for Congress in state), partyCD (preferred party for Congress in congressional district), and partyStateCD (preferred party for Congress in either state or congressional district).

*Harmonization Plan: Survey-by-survey synchronization of variable names and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variables. Label for all three variables will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 but are available for all eight of the (non-binary) surveys that year. The variables are distributed as follows: partyState in USAIPO1963-0674 (June 21, 1963 - June 26, 1963) and USAIPO1963-0675 (July 18, 1963 - July 23, 1963); partyCD in USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963); and partyStateCD in USAIPO1963-0667 (January 11, 1963 - January 16, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that there are only three surveys in this do file that contain the question on level of personal federal income tax: USAIPO1961-0641 (February 10, 1961 - February 15, 1961), USAIPO1962-660 (June 28, 1962 - July 3, 1962), and USAIPO1963-0667 (January 11, 1963 - January 16, 1963). The rest are read in/harmonized in the do file AdditionalTaxQuestions.

*N/A: This variable is not available in this file.


*GOVERNMENT WELFARE SPENDING

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1964-0702 was harmonized for the additional tax files study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1961-0651 for this set of polls.

*N/A: This variable is not available in this file.


*MOST IMPORTANT PROBLEM–CIVIL RIGHTS

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO"

*N/A: This variable is not available in this file.


*OPINION: SPEED OF RACIAL INTEGRATION

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in nine surveys over the Kennedy years. Four surveys with this variable are included in this dataset: USAIPO1962-0664 (October 19, 1962 - October 24, 1962), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963). Two surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1963-0673 (May 23, 1963 - May 28, 1963) and USAIPO1963-0676 (August 15, 1963 - August 20, 1963). And three surveys containing this variable are in binary files and thus could not be read in: USAIPO1962-0658 (May 3, 1962 - May 8, 1962), USAIPO1963-0677 (September 12, 1963 - September 17, 1963), and USAIPO1963-0678 (October 11, 1963 - October 16, 1963).

*N/A: This variable is not available in this file.


*Save the data
saveold FormattedData\1962-0663.dta, replace

clear


****USAIPO1962-0664****

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1962-0664; October 19, 1962 - October 24, 1962)
infile using DictionaryFiles\aipo1962-0664.dct

*The sample size in the codebook - 4,248 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1962-0664"

*Create a variable for survey year
gen svy_yr = 1962

*Create a variable for survey month
gen svy_month = "October"

*Create a variable to indicate whether or not the original file was converted from a binary file (label is defined as: 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION")
*The codebook does not indicate that USAIPO1962-0664 was converted from a binary file
gen binary = 2


*Begin harmonization of variables


*WEIGHT: TIMES AT HOME

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_timesAtHome

*The frequency distribution for this variable matches that in the codebook


*WEIGHT: EDUCATION

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_edu

*The frequency distribution for this variable matches that in the codebook


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files,we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for all eight (non-binary) surveys that year: USAIPO1963-0667 (January 11, 1963 - January 16, 1963), USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for seven of the eight (non-binary) surveys that year: USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*KNOWLEDGE OF POTENTIAL REPUBLICAN CANDIDATES IN 1964 PRESIDENTIAL ELECTION

*Harmonization Plan: Survey-by-survey synchronization of variable names (knowledge of potential Republican candidates in the 1964 presidential election) and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA." Note that these variables are only included for surveys conducted in 1963 and are available for only one of the eight (non-binary) surveys compiled here: USAIPO1963-0669 (March 8, 1963 - March 13, 1963). The variables are also included in USAIPO1963-0676 (August 15, 1963 - August 20, 1963), but that dataset was read into Stata separately as part of the racial tolerance study. As such, consistent naming is required, even though the variables appear in only one survey in this dataset. For USAIPO1963-0669, there are four variables for four potential Republican presidential candidates: Nelson Rockefeller, Barry Goldwater, George Romney, and William Scranton.

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab age_orig

*The variable age_orig does not have frequencies displayed next to it in the codebook
*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESS–STATE, CONGRESSIONAL DISTRICT, OR EITHER (partyState, partyCD, or partyStateCD)

*Note: Question wording for preferred party for Congress varies in the Kennedy-era surveys, asking either: (1) which party would you like to see win in this state, or (2) which party would you like to see win in this congressional district. Moreover, one survey (USAIPO1963-0667) does not differentiate between the two, with the codebook stating that some of the respondents were asked the question with regard to state and the others with regard to congressional district (it is not clear whether there is some way to tell which respondents received which question). As such, there are three variables reflecting preferred party for Congress: partyState (preferred party for Congress in state), partyCD (preferred party for Congress in congressional district), and partyStateCD (preferred party for Congress in either state or congressional district).

*Harmonization Plan: Survey-by-survey synchronization of variable names and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variables. Label for all three variables will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 but are available for all eight of the (non-binary) surveys that year. The variables are distributed as follows: partyState in USAIPO1963-0674 (June 21, 1963 - June 26, 1963) and USAIPO1963-0675 (July 18, 1963 - July 23, 1963); partyCD in USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963); and partyStateCD in USAIPO1963-0667 (January 11, 1963 - January 16, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that there are only three surveys in this do file that contain the question on level of personal federal income tax: USAIPO1961-0641 (February 10, 1961 - February 15, 1961), USAIPO1962-660 (June 28, 1962 - July 3, 1962), and USAIPO1963-0667 (January 11, 1963 - January 16, 1963). The rest are read in/harmonized in the do file AdditionalTaxQuestions.

*N/A: This variable is not available in this file.


*GOVERNMENT WELFARE SPENDING

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1964-0702 was harmonized for the additional tax files study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1961-0651 for this set of polls.

*N/A: This variable is not available in this file.


*MOST IMPORTANT PROBLEM–CIVIL RIGHTS

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO"

*N/A: This variable is not available in this file.


*OPINION: SPEED OF RACIAL INTEGRATION

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in nine surveys over the Kennedy years. Four surveys with this variable are included in this dataset: USAIPO1962-0664 (October 19, 1962 - October 24, 1962), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963). Two surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1963-0673 (May 23, 1963 - May 28, 1963) and USAIPO1963-0676 (August 15, 1963 - August 20, 1963). And three surveys containing this variable are in binary files and thus could not be read in: USAIPO1962-0658 (May 3, 1962 - May 8, 1962), USAIPO1963-0677 (September 12, 1963 - September 17, 1963), and USAIPO1963-0678 (October 11, 1963 - October 16, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab integrationRate_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen integrationRate = integrationRate_orig


*Save the data
saveold FormattedData\1962-0664.dta, replace

clear


****USAIPO1962-0665****

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1962-0665; November 16, 1962 - November 21, 1962)
infile using DictionaryFiles\aipo1962-0665.dct

*The sample size in the codebook - 4,426 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1962-0665"

*Create a variable for survey year
gen svy_yr = 1962

*Create a variable for survey month
gen svy_month = "November"

*Create a variable to indicate whether or not the original file was converted from a binary file (label is defined as: 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION")
*The codebook does not indicate that USAIPO1962-0665 was converted from a binary file
gen binary = 2


*Begin harmonization of variables


*WEIGHT: TIMES AT HOME

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_timesAtHome

*The frequency distribution for this variable matches that in the codebook


*WEIGHT: EDUCATION

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_edu

*The frequency distribution for this variable matches that in the codebook


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files,we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for all eight (non-binary) surveys that year: USAIPO1963-0667 (January 11, 1963 - January 16, 1963), USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for seven of the eight (non-binary) surveys that year: USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*KNOWLEDGE OF POTENTIAL REPUBLICAN CANDIDATES IN 1964 PRESIDENTIAL ELECTION

*Harmonization Plan: Survey-by-survey synchronization of variable names (knowledge of potential Republican candidates in the 1964 presidential election) and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA." Note that these variables are only included for surveys conducted in 1963 and are available for only one of the eight (non-binary) surveys compiled here: USAIPO1963-0669 (March 8, 1963 - March 13, 1963). The variables are also included in USAIPO1963-0676 (August 15, 1963 - August 20, 1963), but that dataset was read into Stata separately as part of the racial tolerance study. As such, consistent naming is required, even though the variables appear in only one survey in this dataset. For USAIPO1963-0669, there are four variables for four potential Republican presidential candidates: Nelson Rockefeller, Barry Goldwater, George Romney, and William Scranton.

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab age_orig

*The variable age_orig does not have frequencies displayed next to it in the codebook
*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESS–STATE, CONGRESSIONAL DISTRICT, OR EITHER (partyState, partyCD, or partyStateCD)

*Note: Question wording for preferred party for Congress varies in the Kennedy-era surveys, asking either: (1) which party would you like to see win in this state, or (2) which party would you like to see win in this congressional district. Moreover, one survey (USAIPO1963-0667) does not differentiate between the two, with the codebook stating that some of the respondents were asked the question with regard to state and the others with regard to congressional district (it is not clear whether there is some way to tell which respondents received which question). As such, there are three variables reflecting preferred party for Congress: partyState (preferred party for Congress in state), partyCD (preferred party for Congress in congressional district), and partyStateCD (preferred party for Congress in either state or congressional district).

*Harmonization Plan: Survey-by-survey synchronization of variable names and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variables. Label for all three variables will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 but are available for all eight of the (non-binary) surveys that year. The variables are distributed as follows: partyState in USAIPO1963-0674 (June 21, 1963 - June 26, 1963) and USAIPO1963-0675 (July 18, 1963 - July 23, 1963); partyCD in USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963); and partyStateCD in USAIPO1963-0667 (January 11, 1963 - January 16, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that there are only three surveys in this do file that contain the question on level of personal federal income tax: USAIPO1961-0641 (February 10, 1961 - February 15, 1961), USAIPO1962-660 (June 28, 1962 - July 3, 1962), and USAIPO1963-0667 (January 11, 1963 - January 16, 1963). The rest are read in/harmonized in the do file AdditionalTaxQuestions.

*N/A: This variable is not available in this file.


*GOVERNMENT WELFARE SPENDING

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1964-0702 was harmonized for the additional tax files study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1961-0651 for this set of polls.

*N/A: This variable is not available in this file.


*MOST IMPORTANT PROBLEM–CIVIL RIGHTS

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO"

*N/A: This variable is not available in this file.


*OPINION: SPEED OF RACIAL INTEGRATION

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in nine surveys over the Kennedy years. Four surveys with this variable are included in this dataset: USAIPO1962-0664 (October 19, 1962 - October 24, 1962), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963). Two surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1963-0673 (May 23, 1963 - May 28, 1963) and USAIPO1963-0676 (August 15, 1963 - August 20, 1963). And three surveys containing this variable are in binary files and thus could not be read in: USAIPO1962-0658 (May 3, 1962 - May 8, 1962), USAIPO1963-0677 (September 12, 1963 - September 17, 1963), and USAIPO1963-0678 (October 11, 1963 - October 16, 1963).

*N/A: This variable is not available in this file.


*Save the data
saveold FormattedData\1962-0665.dta, replace

clear


****USAIPO1962-0666****

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1962-0666; December 13, 1962 - December 18, 1962)
infile using DictionaryFiles\aipo1962-0666.dct

*The sample size in the codebook - 3,193 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1962-0666"

*Create a variable for survey year
gen svy_yr = 1962

*Create a variable for survey month
gen svy_month = "December"

*Create a variable to indicate whether or not the original file was converted from a binary file (label is defined as: 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION")
*The codebook does not indicate that USAIPO1962-0666 was converted from a binary file
gen binary = 2


*Begin harmonization of variables


*WEIGHT: TIMES AT HOME

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_timesAtHome

*The frequency distribution for this variable matches that in the codebook


*WEIGHT: EDUCATION

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_edu

*The frequency distribution for this variable matches that in the codebook


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files,we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for all eight (non-binary) surveys that year: USAIPO1963-0667 (January 11, 1963 - January 16, 1963), USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for seven of the eight (non-binary) surveys that year: USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*KNOWLEDGE OF POTENTIAL REPUBLICAN CANDIDATES IN 1964 PRESIDENTIAL ELECTION

*Harmonization Plan: Survey-by-survey synchronization of variable names (knowledge of potential Republican candidates in the 1964 presidential election) and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA." Note that these variables are only included for surveys conducted in 1963 and are available for only one of the eight (non-binary) surveys compiled here: USAIPO1963-0669 (March 8, 1963 - March 13, 1963). The variables are also included in USAIPO1963-0676 (August 15, 1963 - August 20, 1963), but that dataset was read into Stata separately as part of the racial tolerance study. As such, consistent naming is required, even though the variables appear in only one survey in this dataset. For USAIPO1963-0669, there are four variables for four potential Republican presidential candidates: Nelson Rockefeller, Barry Goldwater, George Romney, and William Scranton.

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab age_orig

*The variable age_orig does not have frequencies displayed next to it in the codebook
*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESS–STATE, CONGRESSIONAL DISTRICT, OR EITHER (partyState, partyCD, or partyStateCD)

*Note: Question wording for preferred party for Congress varies in the Kennedy-era surveys, asking either: (1) which party would you like to see win in this state, or (2) which party would you like to see win in this congressional district. Moreover, one survey (USAIPO1963-0667) does not differentiate between the two, with the codebook stating that some of the respondents were asked the question with regard to state and the others with regard to congressional district (it is not clear whether there is some way to tell which respondents received which question). As such, there are three variables reflecting preferred party for Congress: partyState (preferred party for Congress in state), partyCD (preferred party for Congress in congressional district), and partyStateCD (preferred party for Congress in either state or congressional district).

*Harmonization Plan: Survey-by-survey synchronization of variable names and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variables. Label for all three variables will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 but are available for all eight of the (non-binary) surveys that year. The variables are distributed as follows: partyState in USAIPO1963-0674 (June 21, 1963 - June 26, 1963) and USAIPO1963-0675 (July 18, 1963 - July 23, 1963); partyCD in USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963); and partyStateCD in USAIPO1963-0667 (January 11, 1963 - January 16, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that there are only three surveys in this do file that contain the question on level of personal federal income tax: USAIPO1961-0641 (February 10, 1961 - February 15, 1961), USAIPO1962-660 (June 28, 1962 - July 3, 1962), and USAIPO1963-0667 (January 11, 1963 - January 16, 1963). The rest are read in/harmonized in the do file AdditionalTaxQuestions.

*N/A: This variable is not available in this file.


*GOVERNMENT WELFARE SPENDING

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1964-0702 was harmonized for the additional tax files study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1961-0651 for this set of polls.

*N/A: This variable is not available in this file.


*MOST IMPORTANT PROBLEM–CIVIL RIGHTS

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO"

*N/A: This variable is not available in this file.


*OPINION: SPEED OF RACIAL INTEGRATION

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in nine surveys over the Kennedy years. Four surveys with this variable are included in this dataset: USAIPO1962-0664 (October 19, 1962 - October 24, 1962), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963). Two surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1963-0673 (May 23, 1963 - May 28, 1963) and USAIPO1963-0676 (August 15, 1963 - August 20, 1963). And three surveys containing this variable are in binary files and thus could not be read in: USAIPO1962-0658 (May 3, 1962 - May 8, 1962), USAIPO1963-0677 (September 12, 1963 - September 17, 1963), and USAIPO1963-0678 (October 11, 1963 - October 16, 1963).

*N/A: This variable is not available in this file.


*Save the data
saveold FormattedData\1962-0666.dta, replace

clear


****USAIPO1963-0667****

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1963-0667; January 11, 1963 - January 16, 1963)
infile using DictionaryFiles\aipo1963-0667.dct

*The sample size in the codebook - 4,389 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1963-0667"

*Create a variable for survey year
gen svy_yr = 1963

*Create a variable for survey month
gen svy_month = "January"

*Create a variable to indicate whether or not the original file was converted from a binary file (label is defined as: 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION")
*The codebook does not indicate that USAIPO1963-0667 was converted from a binary file
gen binary = 2


*Begin harmonization of variables


*WEIGHT: TIMES AT HOME

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_timesAtHome

*The frequency distribution for this variable matches that in the codebook


*WEIGHT: EDUCATION

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_edu

*The frequency distribution for this variable matches that in the codebook


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files,we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for all eight (non-binary) surveys that year: USAIPO1963-0667 (January 11, 1963 - January 16, 1963), USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab rockefellerKennedy_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen rockefellerKennedy = rockefellerKennedy_orig

*Replace values
replace rockefellerKennedy = 4 if rockefellerKennedy_orig == 6
replace rockefellerKennedy = 5 if rockefellerKennedy_orig == 4
replace rockefellerKennedy = 6 if rockefellerKennedy_orig == 5


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for seven of the eight (non-binary) surveys that year: USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*KNOWLEDGE OF POTENTIAL REPUBLICAN CANDIDATES IN 1964 PRESIDENTIAL ELECTION

*Harmonization Plan: Survey-by-survey synchronization of variable names (knowledge of potential Republican candidates in the 1964 presidential election) and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA." Note that these variables are only included for surveys conducted in 1963 and are available for only one of the eight (non-binary) surveys compiled here: USAIPO1963-0669 (March 8, 1963 - March 13, 1963). The variables are also included in USAIPO1963-0676 (August 15, 1963 - August 20, 1963), but that dataset was read into Stata separately as part of the racial tolerance study. As such, consistent naming is required, even though the variables appear in only one survey in this dataset. For USAIPO1963-0669, there are four variables for four potential Republican presidential candidates: Nelson Rockefeller, Barry Goldwater, George Romney, and William Scranton.

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab age_orig

*The variable age_orig does not have frequencies displayed next to it in the codebook
*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESS–STATE, CONGRESSIONAL DISTRICT, OR EITHER (partyState, partyCD, or partyStateCD)

*Note: Question wording for preferred party for Congress varies in the Kennedy-era surveys, asking either: (1) which party would you like to see win in this state, or (2) which party would you like to see win in this congressional district. Moreover, one survey (USAIPO1963-0667) does not differentiate between the two, with the codebook stating that some of the respondents were asked the question with regard to state and the others with regard to congressional district (it is not clear whether there is some way to tell which respondents received which question). As such, there are three variables reflecting preferred party for Congress: partyState (preferred party for Congress in state), partyCD (preferred party for Congress in congressional district), and partyStateCD (preferred party for Congress in either state or congressional district).

*Harmonization Plan: Survey-by-survey synchronization of variable names and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variables. Label for all three variables will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 but are available for all eight of the (non-binary) surveys that year. The variables are distributed as follows: partyState in USAIPO1963-0674 (June 21, 1963 - June 26, 1963) and USAIPO1963-0675 (July 18, 1963 - July 23, 1963); partyCD in USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963); and partyStateCD in USAIPO1963-0667 (January 11, 1963 - January 16, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab partyStateCD_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen partyStateCD = partyStateCD_orig

*Replace values
replace partyStateCD = 1 if partyStateCD_orig == 2
replace partyStateCD = 2 if partyStateCD_orig == 1
replace partyStateCD = 4 if partyStateCD_orig == 5
replace partyStateCD = 5 if partyStateCD_orig == 4
replace partyStateCD = 7 if partyStateCD_orig == 8 | partyStateCD_orig == 9 | partyStateCD_orig == 99


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that there are only three surveys in this do file that contain the question on level of personal federal income tax: USAIPO1961-0641 (February 10, 1961 - February 15, 1961), USAIPO1962-660 (June 28, 1962 - July 3, 1962), and USAIPO1963-0667 (January 11, 1963 - January 16, 1963). The rest are read in/harmonized in the do file AdditionalTaxQuestions.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab fedIncomeTax_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen fedIncomeTax = fedIncomeTax_orig


*GOVERNMENT WELFARE SPENDING

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1964-0702 was harmonized for the additional tax files study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1961-0651 for this set of polls.

*N/A: This variable is not available in this file.


*MOST IMPORTANT PROBLEM–CIVIL RIGHTS

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO"

*N/A: This variable is not available in this file.


*OPINION: SPEED OF RACIAL INTEGRATION

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in nine surveys over the Kennedy years. Four surveys with this variable are included in this dataset: USAIPO1962-0664 (October 19, 1962 - October 24, 1962), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963). Two surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1963-0673 (May 23, 1963 - May 28, 1963) and USAIPO1963-0676 (August 15, 1963 - August 20, 1963). And three surveys containing this variable are in binary files and thus could not be read in: USAIPO1962-0658 (May 3, 1962 - May 8, 1962), USAIPO1963-0677 (September 12, 1963 - September 17, 1963), and USAIPO1963-0678 (October 11, 1963 - October 16, 1963).

*N/A: This variable is not available in this file.


*Save the data
saveold FormattedData\1963-0667.dta, replace

clear


****USAIPO1963-0668****

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1963-0668; February 7, 1963 - February 12, 1963)
infile using DictionaryFiles\aipo1963-0668.dct

*The sample size in the codebook - 3,652 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1963-0668"

*Create a variable for survey year
gen svy_yr = 1963

*Create a variable for survey month
gen svy_month = "February"

*Create a variable to indicate whether or not the original file was converted from a binary file (label is defined as: 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION")
*The codebook does not indicate that USAIPO1963-0668 was converted from a binary file
gen binary = 2


*Begin harmonization of variables


*WEIGHT: TIMES AT HOME

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_timesAtHome

*The frequency distribution for this variable matches that in the codebook


*WEIGHT: EDUCATION

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_edu

*The frequency distribution for this variable matches that in the codebook


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files,we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for all eight (non-binary) surveys that year: USAIPO1963-0667 (January 11, 1963 - January 16, 1963), USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab rockefellerKennedy_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen rockefellerKennedy = rockefellerKennedy_orig

*Replace values
replace rockefellerKennedy = 4 if rockefellerKennedy_orig == 6 | rockefellerKennedy_orig == 7
replace rockefellerKennedy = 5 if rockefellerKennedy_orig == 4
replace rockefellerKennedy = 6 if rockefellerKennedy_orig == 5


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for seven of the eight (non-binary) surveys that year: USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab goldwaterKennedy_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen goldwaterKennedy = goldwaterKennedy_orig

*Replace values
replace goldwaterKennedy = 4 if goldwaterKennedy_orig == 6 | goldwaterKennedy_orig == 7
replace goldwaterKennedy = 5 if goldwaterKennedy_orig == 4
replace goldwaterKennedy = 6 if goldwaterKennedy_orig == 5


*KNOWLEDGE OF POTENTIAL REPUBLICAN CANDIDATES IN 1964 PRESIDENTIAL ELECTION

*Harmonization Plan: Survey-by-survey synchronization of variable names (knowledge of potential Republican candidates in the 1964 presidential election) and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA." Note that these variables are only included for surveys conducted in 1963 and are available for only one of the eight (non-binary) surveys compiled here: USAIPO1963-0669 (March 8, 1963 - March 13, 1963). The variables are also included in USAIPO1963-0676 (August 15, 1963 - August 20, 1963), but that dataset was read into Stata separately as part of the racial tolerance study. As such, consistent naming is required, even though the variables appear in only one survey in this dataset. For USAIPO1963-0669, there are four variables for four potential Republican presidential candidates: Nelson Rockefeller, Barry Goldwater, George Romney, and William Scranton.

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab age_orig

*The variable age_orig does not have frequencies displayed next to it in the codebook
*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESS–STATE, CONGRESSIONAL DISTRICT, OR EITHER (partyState, partyCD, or partyStateCD)

*Note: Question wording for preferred party for Congress varies in the Kennedy-era surveys, asking either: (1) which party would you like to see win in this state, or (2) which party would you like to see win in this congressional district. Moreover, one survey (USAIPO1963-0667) does not differentiate between the two, with the codebook stating that some of the respondents were asked the question with regard to state and the others with regard to congressional district (it is not clear whether there is some way to tell which respondents received which question). As such, there are three variables reflecting preferred party for Congress: partyState (preferred party for Congress in state), partyCD (preferred party for Congress in congressional district), and partyStateCD (preferred party for Congress in either state or congressional district).

*Harmonization Plan: Survey-by-survey synchronization of variable names and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variables. Label for all three variables will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 but are available for all eight of the (non-binary) surveys that year. The variables are distributed as follows: partyState in USAIPO1963-0674 (June 21, 1963 - June 26, 1963) and USAIPO1963-0675 (July 18, 1963 - July 23, 1963); partyCD in USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963); and partyStateCD in USAIPO1963-0667 (January 11, 1963 - January 16, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab partyCD_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen partyCD = partyCD_orig

*Replace values
replace partyCD = 1 if partyCD_orig == 2
replace partyCD = 2 if partyCD_orig == 1
replace partyCD = 4 if partyCD_orig == 5
replace partyCD = 5 if partyCD_orig == 4
replace partyCD = 7 if partyCD_orig == 8 | partyCD_orig == 9


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that there are only three surveys in this do file that contain the question on level of personal federal income tax: USAIPO1961-0641 (February 10, 1961 - February 15, 1961), USAIPO1962-660 (June 28, 1962 - July 3, 1962), and USAIPO1963-0667 (January 11, 1963 - January 16, 1963). The rest are read in/harmonized in the do file AdditionalTaxQuestions.

*N/A: This variable is not available in this file.


*GOVERNMENT WELFARE SPENDING

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1964-0702 was harmonized for the additional tax files study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1961-0651 for this set of polls.

*N/A: This variable is not available in this file.


*MOST IMPORTANT PROBLEM–CIVIL RIGHTS

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO"

*N/A: This variable is not available in this file.


*OPINION: SPEED OF RACIAL INTEGRATION

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in nine surveys over the Kennedy years. Four surveys with this variable are included in this dataset: USAIPO1962-0664 (October 19, 1962 - October 24, 1962), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963). Two surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1963-0673 (May 23, 1963 - May 28, 1963) and USAIPO1963-0676 (August 15, 1963 - August 20, 1963). And three surveys containing this variable are in binary files and thus could not be read in: USAIPO1962-0658 (May 3, 1962 - May 8, 1962), USAIPO1963-0677 (September 12, 1963 - September 17, 1963), and USAIPO1963-0678 (October 11, 1963 - October 16, 1963).

*N/A: This variable is not available in this file.


*Save the data
saveold FormattedData\1963-0668.dta, replace

clear


****USAIPO1963-0669****

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1963-0669; March 8, 1963 - March 13, 1963)
infile using DictionaryFiles\aipo1963-0669.dct

*The sample size in the codebook - 4,337 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1963-0669"

*Create a variable for survey year
gen svy_yr = 1963

*Create a variable for survey month
gen svy_month = "March"

*Create a variable to indicate whether or not the original file was converted from a binary file (label is defined as: 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION")
*The codebook does not indicate that USAIPO1963-0669 was converted from a binary file
gen binary = 2


*Begin harmonization of variables


*WEIGHT: TIMES AT HOME

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_timesAtHome

*The frequency distribution for this variable matches that in the codebook


*WEIGHT: EDUCATION

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_edu

*The frequency distribution for this variable matches that in the codebook


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files,we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for all eight (non-binary) surveys that year: USAIPO1963-0667 (January 11, 1963 - January 16, 1963), USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab rockefellerKennedy_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen rockefellerKennedy = rockefellerKennedy_orig

*Replace values
replace rockefellerKennedy = 4 if rockefellerKennedy_orig == 6 | rockefellerKennedy_orig == 7
replace rockefellerKennedy = 5 if rockefellerKennedy_orig == 4
replace rockefellerKennedy = 6 if rockefellerKennedy_orig == 5


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for seven of the eight (non-binary) surveys that year: USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab goldwaterKennedy_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen goldwaterKennedy = goldwaterKennedy_orig

*Replace values
replace goldwaterKennedy = 4 if goldwaterKennedy_orig == 6
replace goldwaterKennedy = 5 if goldwaterKennedy_orig == 4
replace goldwaterKennedy = 6 if goldwaterKennedy_orig == 5


*KNOWLEDGE OF POTENTIAL REPUBLICAN CANDIDATES IN 1964 PRESIDENTIAL ELECTION

*Harmonization Plan: Survey-by-survey synchronization of variable names (knowledge of potential Republican candidates in the 1964 presidential election) and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA." Note that these variables are only included for surveys conducted in 1963 and are available for only one of the eight (non-binary) surveys compiled here: USAIPO1963-0669 (March 8, 1963 - March 13, 1963). The variables are also included in USAIPO1963-0676 (August 15, 1963 - August 20, 1963), but that dataset was read into Stata separately as part of the racial tolerance study. As such, consistent naming is required, even though the variables appear in only one survey in this dataset. For USAIPO1963-0669, there are four variables for four potential Republican presidential candidates: Nelson Rockefeller, Barry Goldwater, George Romney, and William Scranton.

*Check the first variable - tab it and compare with frequency distribution in the codebook
tab whoRockefeller_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen whoRockefeller = whoRockefeller_orig

*Replace values
replace whoRockefeller = 3 if whoRockefeller_orig == 2
replace whoRockefeller = 4 if whoRockefeller_orig == 3


*Check the second variable - tab it and compare with frequency distribution in the codebook
tab whoGoldwater_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen whoGoldwater = whoGoldwater_orig

*Replace values
replace whoGoldwater = 3 if whoGoldwater_orig == 2
replace whoGoldwater = 4 if whoGoldwater_orig == 3


*Check the third variable - tab it and compare with frequency distribution in the codebook
tab whoRomney_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen whoRomney = whoRomney_orig

*Replace values
replace whoRomney = 3 if whoRomney_orig == 2
replace whoRomney = 4 if whoRomney_orig == 3


*Check the fourth variable - tab it and compare with frequency distribution in the codebook
tab whoScranton_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen whoScranton = whoScranton_orig

*Replace values
replace whoScranton = 3 if whoScranton_orig == 2
replace whoScranton = 4 if whoScranton_orig == 3


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab age_orig

*The variable age_orig does not have frequencies displayed next to it in the codebook
*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESS–STATE, CONGRESSIONAL DISTRICT, OR EITHER (partyState, partyCD, or partyStateCD)

*Note: Question wording for preferred party for Congress varies in the Kennedy-era surveys, asking either: (1) which party would you like to see win in this state, or (2) which party would you like to see win in this congressional district. Moreover, one survey (USAIPO1963-0667) does not differentiate between the two, with the codebook stating that some of the respondents were asked the question with regard to state and the others with regard to congressional district (it is not clear whether there is some way to tell which respondents received which question). As such, there are three variables reflecting preferred party for Congress: partyState (preferred party for Congress in state), partyCD (preferred party for Congress in congressional district), and partyStateCD (preferred party for Congress in either state or congressional district).

*Harmonization Plan: Survey-by-survey synchronization of variable names and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variables. Label for all three variables will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 but are available for all eight of the (non-binary) surveys that year. The variables are distributed as follows: partyState in USAIPO1963-0674 (June 21, 1963 - June 26, 1963) and USAIPO1963-0675 (July 18, 1963 - July 23, 1963); partyCD in USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963); and partyStateCD in USAIPO1963-0667 (January 11, 1963 - January 16, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab partyCD_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen partyCD = partyCD_orig

*Replace values
replace partyCD = 1 if partyCD_orig == 2
replace partyCD = 2 if partyCD_orig == 1
replace partyCD = 4 if partyCD_orig == 5
replace partyCD = 5 if partyCD_orig == 4
replace partyCD = 7 if partyCD_orig == 8


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that there are only three surveys in this do file that contain the question on level of personal federal income tax: USAIPO1961-0641 (February 10, 1961 - February 15, 1961), USAIPO1962-660 (June 28, 1962 - July 3, 1962), and USAIPO1963-0667 (January 11, 1963 - January 16, 1963). The rest are read in/harmonized in the do file AdditionalTaxQuestions.

*N/A: This variable is not available in this file.


*GOVERNMENT WELFARE SPENDING

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1964-0702 was harmonized for the additional tax files study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1961-0651 for this set of polls.

*N/A: This variable is not available in this file.


*MOST IMPORTANT PROBLEM–CIVIL RIGHTS

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO"

*N/A: This variable is not available in this file.


*OPINION: SPEED OF RACIAL INTEGRATION

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in nine surveys over the Kennedy years. Four surveys with this variable are included in this dataset: USAIPO1962-0664 (October 19, 1962 - October 24, 1962), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963). Two surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1963-0673 (May 23, 1963 - May 28, 1963) and USAIPO1963-0676 (August 15, 1963 - August 20, 1963). And three surveys containing this variable are in binary files and thus could not be read in: USAIPO1962-0658 (May 3, 1962 - May 8, 1962), USAIPO1963-0677 (September 12, 1963 - September 17, 1963), and USAIPO1963-0678 (October 11, 1963 - October 16, 1963).

*N/A: This variable is not available in this file.


*Save the data
saveold FormattedData\1963-0669.dta, replace

clear


****USAIPO1963-0670****

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1963-0670; April 4, 1963 - April 9, 1963)
infile using DictionaryFiles\aipo1963-0670.dct

*The sample size in the codebook - 3,252 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1963-0670"

*Create a variable for survey year
gen svy_yr = 1963

*Create a variable for survey month
gen svy_month = "April"

*Create a variable to indicate whether or not the original file was converted from a binary file (label is defined as: 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION")
*The codebook does not indicate that USAIPO1963-0670 was converted from a binary file
gen binary = 2


*Begin harmonization of variables


*WEIGHT: TIMES AT HOME

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_timesAtHome

*The frequency distribution for this variable matches that in the codebook


*WEIGHT: EDUCATION

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_edu

*The frequency distribution for this variable matches that in the codebook


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files,we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for all eight (non-binary) surveys that year: USAIPO1963-0667 (January 11, 1963 - January 16, 1963), USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab rockefellerKennedy_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen rockefellerKennedy = rockefellerKennedy_orig

*Replace values
replace rockefellerKennedy = 4 if rockefellerKennedy_orig == 7


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for seven of the eight (non-binary) surveys that year: USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab goldwaterKennedy_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen goldwaterKennedy = goldwaterKennedy_orig

*Replace values
replace goldwaterKennedy = 4 if goldwaterKennedy_orig == 7


*KNOWLEDGE OF POTENTIAL REPUBLICAN CANDIDATES IN 1964 PRESIDENTIAL ELECTION

*Harmonization Plan: Survey-by-survey synchronization of variable names (knowledge of potential Republican candidates in the 1964 presidential election) and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA." Note that these variables are only included for surveys conducted in 1963 and are available for only one of the eight (non-binary) surveys compiled here: USAIPO1963-0669 (March 8, 1963 - March 13, 1963). The variables are also included in USAIPO1963-0676 (August 15, 1963 - August 20, 1963), but that dataset was read into Stata separately as part of the racial tolerance study. As such, consistent naming is required, even though the variables appear in only one survey in this dataset. For USAIPO1963-0669, there are four variables for four potential Republican presidential candidates: Nelson Rockefeller, Barry Goldwater, George Romney, and William Scranton.

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab age_orig

*The variable age_orig does not have frequencies displayed next to it in the codebook
*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESS–STATE, CONGRESSIONAL DISTRICT, OR EITHER (partyState, partyCD, or partyStateCD)

*Note: Question wording for preferred party for Congress varies in the Kennedy-era surveys, asking either: (1) which party would you like to see win in this state, or (2) which party would you like to see win in this congressional district. Moreover, one survey (USAIPO1963-0667) does not differentiate between the two, with the codebook stating that some of the respondents were asked the question with regard to state and the others with regard to congressional district (it is not clear whether there is some way to tell which respondents received which question). As such, there are three variables reflecting preferred party for Congress: partyState (preferred party for Congress in state), partyCD (preferred party for Congress in congressional district), and partyStateCD (preferred party for Congress in either state or congressional district).

*Harmonization Plan: Survey-by-survey synchronization of variable names and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variables. Label for all three variables will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 but are available for all eight of the (non-binary) surveys that year. The variables are distributed as follows: partyState in USAIPO1963-0674 (June 21, 1963 - June 26, 1963) and USAIPO1963-0675 (July 18, 1963 - July 23, 1963); partyCD in USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963); and partyStateCD in USAIPO1963-0667 (January 11, 1963 - January 16, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab partyCD_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen partyCD = partyCD_orig

*Replace values
replace partyCD = 1 if partyCD_orig == 2
replace partyCD = 2 if partyCD_orig == 1
replace partyCD = 4 if partyCD_orig == 6
replace partyCD = 6 if partyCD_orig == 7
replace partyCD = 7 if partyCD_orig == 4 | partyCD_orig == 8 | partyCD_orig == 9


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that there are only three surveys in this do file that contain the question on level of personal federal income tax: USAIPO1961-0641 (February 10, 1961 - February 15, 1961), USAIPO1962-660 (June 28, 1962 - July 3, 1962), and USAIPO1963-0667 (January 11, 1963 - January 16, 1963). The rest are read in/harmonized in the do file AdditionalTaxQuestions.

*N/A: This variable is not available in this file.


*GOVERNMENT WELFARE SPENDING

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1964-0702 was harmonized for the additional tax files study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1961-0651 for this set of polls.

*N/A: This variable is not available in this file.


*MOST IMPORTANT PROBLEM–CIVIL RIGHTS

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO"

*N/A: This variable is not available in this file.


*OPINION: SPEED OF RACIAL INTEGRATION

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in nine surveys over the Kennedy years. Four surveys with this variable are included in this dataset: USAIPO1962-0664 (October 19, 1962 - October 24, 1962), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963). Two surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1963-0673 (May 23, 1963 - May 28, 1963) and USAIPO1963-0676 (August 15, 1963 - August 20, 1963). And three surveys containing this variable are in binary files and thus could not be read in: USAIPO1962-0658 (May 3, 1962 - May 8, 1962), USAIPO1963-0677 (September 12, 1963 - September 17, 1963), and USAIPO1963-0678 (October 11, 1963 - October 16, 1963).

*N/A: This variable is not available in this file.


*Save the data
saveold FormattedData\1963-0670.dta, replace

clear


****USAIPO1963-0671****

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1963-0671; May 2, 1963 - May 7, 1963)
infile using DictionaryFiles\aipo1963-0671.dct

*The sample size in the codebook - 3,890 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1963-0671"

*Create a variable for survey year
gen svy_yr = 1963

*Create a variable for survey month
gen svy_month = "May"

*Create a variable to indicate whether or not the original file was converted from a binary file (label is defined as: 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION")
*The codebook does not indicate that USAIPO1963-0671 was converted from a binary file
gen binary = 2


*Begin harmonization of variables


*WEIGHT: TIMES AT HOME

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_timesAtHome

*The frequency distribution for this variable matches that in the codebook


*WEIGHT: EDUCATION

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_edu

*The frequency distribution for this variable matches that in the codebook


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files,we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for all eight (non-binary) surveys that year: USAIPO1963-0667 (January 11, 1963 - January 16, 1963), USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab rockefellerKennedy_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen rockefellerKennedy = rockefellerKennedy_orig

*Replace values
replace rockefellerKennedy = 4 if rockefellerKennedy_orig == 7


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for seven of the eight (non-binary) surveys that year: USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab goldwaterKennedy_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen goldwaterKennedy = goldwaterKennedy_orig

*Replace values
replace goldwaterKennedy = 4 if goldwaterKennedy_orig == 7


*KNOWLEDGE OF POTENTIAL REPUBLICAN CANDIDATES IN 1964 PRESIDENTIAL ELECTION

*Harmonization Plan: Survey-by-survey synchronization of variable names (knowledge of potential Republican candidates in the 1964 presidential election) and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA." Note that these variables are only included for surveys conducted in 1963 and are available for only one of the eight (non-binary) surveys compiled here: USAIPO1963-0669 (March 8, 1963 - March 13, 1963). The variables are also included in USAIPO1963-0676 (August 15, 1963 - August 20, 1963), but that dataset was read into Stata separately as part of the racial tolerance study. As such, consistent naming is required, even though the variables appear in only one survey in this dataset. For USAIPO1963-0669, there are four variables for four potential Republican presidential candidates: Nelson Rockefeller, Barry Goldwater, George Romney, and William Scranton.

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab age_orig

*The variable age_orig does not have frequencies displayed next to it in the codebook
*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESS–STATE, CONGRESSIONAL DISTRICT, OR EITHER (partyState, partyCD, or partyStateCD)

*Note: Question wording for preferred party for Congress varies in the Kennedy-era surveys, asking either: (1) which party would you like to see win in this state, or (2) which party would you like to see win in this congressional district. Moreover, one survey (USAIPO1963-0667) does not differentiate between the two, with the codebook stating that some of the respondents were asked the question with regard to state and the others with regard to congressional district (it is not clear whether there is some way to tell which respondents received which question). As such, there are three variables reflecting preferred party for Congress: partyState (preferred party for Congress in state), partyCD (preferred party for Congress in congressional district), and partyStateCD (preferred party for Congress in either state or congressional district).

*Harmonization Plan: Survey-by-survey synchronization of variable names and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variables. Label for all three variables will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 but are available for all eight of the (non-binary) surveys that year. The variables are distributed as follows: partyState in USAIPO1963-0674 (June 21, 1963 - June 26, 1963) and USAIPO1963-0675 (July 18, 1963 - July 23, 1963); partyCD in USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963); and partyStateCD in USAIPO1963-0667 (January 11, 1963 - January 16, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab partyCD_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen partyCD = partyCD_orig

*Replace values
replace partyCD = 1 if partyCD_orig == 2
replace partyCD = 2 if partyCD_orig == 1
replace partyCD = 4 if partyCD_orig == 6
replace partyCD = 6 if partyCD_orig == 7
replace partyCD = 7 if partyCD_orig == 4 | partyCD_orig == 8 | partyCD_orig == 9


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that there are only three surveys in this do file that contain the question on level of personal federal income tax: USAIPO1961-0641 (February 10, 1961 - February 15, 1961), USAIPO1962-660 (June 28, 1962 - July 3, 1962), and USAIPO1963-0667 (January 11, 1963 - January 16, 1963). The rest are read in/harmonized in the do file AdditionalTaxQuestions.

*N/A: This variable is not available in this file.


*GOVERNMENT WELFARE SPENDING

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1964-0702 was harmonized for the additional tax files study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1961-0651 for this set of polls.

*N/A: This variable is not available in this file.


*MOST IMPORTANT PROBLEM–CIVIL RIGHTS

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO"

*N/A: This variable is not available in this file.


*OPINION: SPEED OF RACIAL INTEGRATION

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in nine surveys over the Kennedy years. Four surveys with this variable are included in this dataset: USAIPO1962-0664 (October 19, 1962 - October 24, 1962), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963). Two surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1963-0673 (May 23, 1963 - May 28, 1963) and USAIPO1963-0676 (August 15, 1963 - August 20, 1963). And three surveys containing this variable are in binary files and thus could not be read in: USAIPO1962-0658 (May 3, 1962 - May 8, 1962), USAIPO1963-0677 (September 12, 1963 - September 17, 1963), and USAIPO1963-0678 (October 11, 1963 - October 16, 1963).

*N/A: This variable is not available in this file.


*Save the data
saveold FormattedData\1963-0671.dta, replace

clear


****USAIPO1963-0674****

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1963-0674; June 21, 1963 - June 26, 1963)
infile using DictionaryFiles\aipo1963-0674.dct

*The sample size in the codebook - 3,487 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1963-0674"

*Create a variable for survey year
gen svy_yr = 1963

*Create a variable for survey month
gen svy_month = "June"

*Create a variable to indicate whether or not the original file was converted from a binary file (label is defined as: 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION")
*The codebook does not indicate that USAIPO1963-0674 was converted from a binary file
gen binary = 2


*Begin harmonization of variables


*WEIGHT: TIMES AT HOME

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_timesAtHome

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.


*WEIGHT: EDUCATION

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_edu

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files,we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches the frequency table in the back of the codebook; drop the unnecessary variables
drop first second

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for all eight (non-binary) surveys that year: USAIPO1963-0667 (January 11, 1963 - January 16, 1963), USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab rockefellerKennedy_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen rockefellerKennedy = rockefellerKennedy_orig

*Replace values
replace rockefellerKennedy = 4 if rockefellerKennedy_orig == 7


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for seven of the eight (non-binary) surveys that year: USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab goldwaterKennedy_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen goldwaterKennedy = goldwaterKennedy_orig

*Replace values
replace goldwaterKennedy = 4 if goldwaterKennedy_orig == 7


*KNOWLEDGE OF POTENTIAL REPUBLICAN CANDIDATES IN 1964 PRESIDENTIAL ELECTION

*Harmonization Plan: Survey-by-survey synchronization of variable names (knowledge of potential Republican candidates in the 1964 presidential election) and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA." Note that these variables are only included for surveys conducted in 1963 and are available for only one of the eight (non-binary) surveys compiled here: USAIPO1963-0669 (March 8, 1963 - March 13, 1963). The variables are also included in USAIPO1963-0676 (August 15, 1963 - August 20, 1963), but that dataset was read into Stata separately as part of the racial tolerance study. As such, consistent naming is required, even though the variables appear in only one survey in this dataset. For USAIPO1963-0669, there are four variables for four potential Republican presidential candidates: Nelson Rockefeller, Barry Goldwater, George Romney, and William Scranton.

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab age_orig

*The variable age_orig does not have frequencies displayed next to it in the codebook
*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESS–STATE, CONGRESSIONAL DISTRICT, OR EITHER (partyState, partyCD, or partyStateCD)

*Note: Question wording for preferred party for Congress varies in the Kennedy-era surveys, asking either: (1) which party would you like to see win in this state, or (2) which party would you like to see win in this congressional district. Moreover, one survey (USAIPO1963-0667) does not differentiate between the two, with the codebook stating that some of the respondents were asked the question with regard to state and the others with regard to congressional district (it is not clear whether there is some way to tell which respondents received which question). As such, there are three variables reflecting preferred party for Congress: partyState (preferred party for Congress in state), partyCD (preferred party for Congress in congressional district), and partyStateCD (preferred party for Congress in either state or congressional district).

*Harmonization Plan: Survey-by-survey synchronization of variable names and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variables. Label for all three variables will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 but are available for all eight of the (non-binary) surveys that year. The variables are distributed as follows: partyState in USAIPO1963-0674 (June 21, 1963 - June 26, 1963) and USAIPO1963-0675 (July 18, 1963 - July 23, 1963); partyCD in USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963); and partyStateCD in USAIPO1963-0667 (January 11, 1963 - January 16, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab partyState_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen partyState = partyState_orig

*Replace values
replace partyState = 1 if partyState_orig == 2
replace partyState = 2 if partyState_orig == 1
replace partyState = 4 if partyState_orig == 6
replace partyState = 6 if partyState_orig == 7
replace partyState = 7 if partyState_orig == 4 | partyState_orig == 8 | partyState_orig == 9


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that there are only three surveys in this do file that contain the question on level of personal federal income tax: USAIPO1961-0641 (February 10, 1961 - February 15, 1961), USAIPO1962-660 (June 28, 1962 - July 3, 1962), and USAIPO1963-0667 (January 11, 1963 - January 16, 1963). The rest are read in/harmonized in the do file AdditionalTaxQuestions.

*N/A: This variable is not available in this file.


*GOVERNMENT WELFARE SPENDING

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1964-0702 was harmonized for the additional tax files study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1961-0651 for this set of polls.

*N/A: This variable is not available in this file.


*MOST IMPORTANT PROBLEM–CIVIL RIGHTS

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO"

*N/A: This variable is not available in this file.


*OPINION: SPEED OF RACIAL INTEGRATION

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in nine surveys over the Kennedy years. Four surveys with this variable are included in this dataset: USAIPO1962-0664 (October 19, 1962 - October 24, 1962), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963). Two surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1963-0673 (May 23, 1963 - May 28, 1963) and USAIPO1963-0676 (August 15, 1963 - August 20, 1963). And three surveys containing this variable are in binary files and thus could not be read in: USAIPO1962-0658 (May 3, 1962 - May 8, 1962), USAIPO1963-0677 (September 12, 1963 - September 17, 1963), and USAIPO1963-0678 (October 11, 1963 - October 16, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab integrationRate_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen integrationRate = integrationRate_orig


*Save the data
saveold FormattedData\1963-0674.dta, replace

clear


****USAIPO1963-0675****

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1963-0675; July 18, 1963 - July 23, 1963)
infile using DictionaryFiles\aipo1963-0675.dct

*The sample size in the codebook - 3,668 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1963-0675"

*Create a variable for survey year
gen svy_yr = 1963

*Create a variable for survey month
gen svy_month = "July"

*Create a variable to indicate whether or not the original file was converted from a binary file (label is defined as: 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION")
*The codebook does not indicate that USAIPO1963-0675 was converted from a binary file
gen binary = 2


*Begin harmonization of variables


*WEIGHT: TIMES AT HOME

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_timesAtHome

*The frequency distribution for this variable matches that in the codebook


*WEIGHT: EDUCATION

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_edu

*The frequency distribution for this variable matches that in the codebook


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files,we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for all eight (non-binary) surveys that year: USAIPO1963-0667 (January 11, 1963 - January 16, 1963), USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab rockefellerKennedy_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen rockefellerKennedy = rockefellerKennedy_orig

*Replace values
replace rockefellerKennedy = 4 if rockefellerKennedy_orig == 7


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for seven of the eight (non-binary) surveys that year: USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab goldwaterKennedy_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen goldwaterKennedy = goldwaterKennedy_orig

*Replace values
replace goldwaterKennedy = 4 if goldwaterKennedy_orig == 7


*KNOWLEDGE OF POTENTIAL REPUBLICAN CANDIDATES IN 1964 PRESIDENTIAL ELECTION

*Harmonization Plan: Survey-by-survey synchronization of variable names (knowledge of potential Republican candidates in the 1964 presidential election) and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA." Note that these variables are only included for surveys conducted in 1963 and are available for only one of the eight (non-binary) surveys compiled here: USAIPO1963-0669 (March 8, 1963 - March 13, 1963). The variables are also included in USAIPO1963-0676 (August 15, 1963 - August 20, 1963), but that dataset was read into Stata separately as part of the racial tolerance study. As such, consistent naming is required, even though the variables appear in only one survey in this dataset. For USAIPO1963-0669, there are four variables for four potential Republican presidential candidates: Nelson Rockefeller, Barry Goldwater, George Romney, and William Scranton.

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab age_orig

*The variable age_orig does not have frequencies displayed next to it in the codebook
*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESS–STATE, CONGRESSIONAL DISTRICT, OR EITHER (partyState, partyCD, or partyStateCD)

*Note: Question wording for preferred party for Congress varies in the Kennedy-era surveys, asking either: (1) which party would you like to see win in this state, or (2) which party would you like to see win in this congressional district. Moreover, one survey (USAIPO1963-0667) does not differentiate between the two, with the codebook stating that some of the respondents were asked the question with regard to state and the others with regard to congressional district (it is not clear whether there is some way to tell which respondents received which question). As such, there are three variables reflecting preferred party for Congress: partyState (preferred party for Congress in state), partyCD (preferred party for Congress in congressional district), and partyStateCD (preferred party for Congress in either state or congressional district).

*Harmonization Plan: Survey-by-survey synchronization of variable names and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variables. Label for all three variables will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 but are available for all eight of the (non-binary) surveys that year. The variables are distributed as follows: partyState in USAIPO1963-0674 (June 21, 1963 - June 26, 1963) and USAIPO1963-0675 (July 18, 1963 - July 23, 1963); partyCD in USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963); and partyStateCD in USAIPO1963-0667 (January 11, 1963 - January 16, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab partyState_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen partyState = partyState_orig

*Replace values
replace partyState = 1 if partyState_orig == 2
replace partyState = 2 if partyState_orig == 1
replace partyState = 4 if partyState_orig == 6
replace partyState = 6 if partyState_orig == 7
replace partyState = 7 if partyState_orig == 4 | partyState_orig == 8 | partyState_orig == 9


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that there are only three surveys in this do file that contain the question on level of personal federal income tax: USAIPO1961-0641 (February 10, 1961 - February 15, 1961), USAIPO1962-660 (June 28, 1962 - July 3, 1962), and USAIPO1963-0667 (January 11, 1963 - January 16, 1963). The rest are read in/harmonized in the do file AdditionalTaxQuestions.

*N/A: This variable is not available in this file.


*GOVERNMENT WELFARE SPENDING

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1964-0702 was harmonized for the additional tax files study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1961-0651 for this set of polls.

*N/A: This variable is not available in this file.


*MOST IMPORTANT PROBLEM–CIVIL RIGHTS

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO"

*N/A: This variable is not available in this file.


*OPINION: SPEED OF RACIAL INTEGRATION

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in nine surveys over the Kennedy years. Four surveys with this variable are included in this dataset: USAIPO1962-0664 (October 19, 1962 - October 24, 1962), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963). Two surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1963-0673 (May 23, 1963 - May 28, 1963) and USAIPO1963-0676 (August 15, 1963 - August 20, 1963). And three surveys containing this variable are in binary files and thus could not be read in: USAIPO1962-0658 (May 3, 1962 - May 8, 1962), USAIPO1963-0677 (September 12, 1963 - September 17, 1963), and USAIPO1963-0678 (October 11, 1963 - October 16, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab integrationRate_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen integrationRate = integrationRate_orig


*Save the data
saveold FormattedData\1963-0675.dta, replace

clear


****USAIPO1963-0679****

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1963-0679; November 8, 1963 - November 13, 1963)
infile using DictionaryFiles\aipo1963-0679.dct

*The sample size in the codebook - 4,276 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1963-0679"

*Create a variable for survey year
gen svy_yr = 1963

*Create a variable for survey month
gen svy_month = "November"

*Create a variable to indicate whether or not the original file was converted from a binary file (label is defined as: 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION")
*The codebook does not indicate that USAIPO1963-0679 was converted from a binary file
gen binary = 2


*Begin harmonization of variables


*WEIGHT: TIMES AT HOME

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_timesAtHome

*The frequency distribution for this variable matches that in the codebook


*WEIGHT: EDUCATION

*Harmonization Plan: This variable is inconsistent across surveys and is occasionally omitted entirely. Variable name is synchronized across surveys already, and no additional adjustments, e.g., recoding, labeling, etc., are required unless the data is originally from a binary file. For variables in these (binary) files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). We also check the variable and include any additional notes from the codebook - as necessary - that may be useful for future reference.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt_edu

*The frequency distribution for this variable matches that in the codebook


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files,we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for all eight (non-binary) surveys that year: USAIPO1963-0667 (January 11, 1963 - January 16, 1963), USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab rockefellerKennedy_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen rockefellerKennedy = rockefellerKennedy_orig

*Replace values
replace rockefellerKennedy = 4 if rockefellerKennedy_orig == 7


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and is available for seven of the eight (non-binary) surveys that year: USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab goldwaterKennedy_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen goldwaterKennedy = goldwaterKennedy_orig

*Replace values
replace goldwaterKennedy = 4 if goldwaterKennedy_orig == 7


*KNOWLEDGE OF POTENTIAL REPUBLICAN CANDIDATES IN 1964 PRESIDENTIAL ELECTION

*Harmonization Plan: Survey-by-survey synchronization of variable names (knowledge of potential Republican candidates in the 1964 presidential election) and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA." Note that these variables are only included for surveys conducted in 1963 and are available for only one of the eight (non-binary) surveys compiled here: USAIPO1963-0669 (March 8, 1963 - March 13, 1963). The variables are also included in USAIPO1963-0676 (August 15, 1963 - August 20, 1963), but that dataset was read into Stata separately as part of the racial tolerance study. As such, consistent naming is required, even though the variables appear in only one survey in this dataset. For USAIPO1963-0669, there are four variables for four potential Republican presidential candidates: Nelson Rockefeller, Barry Goldwater, George Romney, and William Scranton.

*N/A: This variable is only included for (non-binary) surveys conducted in 1963 and only if available for that year


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab age_orig

*The variable age_orig does not have frequencies displayed next to it in the codebook
*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For variables in binary files, we use the real command to keep only numeric values (some observations in binary files have odd characters/symbols mixed with the numbers, and these observations are set to missing via the real command). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESS–STATE, CONGRESSIONAL DISTRICT, OR EITHER (partyState, partyCD, or partyStateCD)

*Note: Question wording for preferred party for Congress varies in the Kennedy-era surveys, asking either: (1) which party would you like to see win in this state, or (2) which party would you like to see win in this congressional district. Moreover, one survey (USAIPO1963-0667) does not differentiate between the two, with the codebook stating that some of the respondents were asked the question with regard to state and the others with regard to congressional district (it is not clear whether there is some way to tell which respondents received which question). As such, there are three variables reflecting preferred party for Congress: partyState (preferred party for Congress in state), partyCD (preferred party for Congress in congressional district), and partyStateCD (preferred party for Congress in either state or congressional district).

*Harmonization Plan: Survey-by-survey synchronization of variable names and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variables. Label for all three variables will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 but are available for all eight of the (non-binary) surveys that year. The variables are distributed as follows: partyState in USAIPO1963-0674 (June 21, 1963 - June 26, 1963) and USAIPO1963-0675 (July 18, 1963 - July 23, 1963); partyCD in USAIPO1963-0668 (February 7, 1963 - February 12, 1963), USAIPO1963-0669 (March 8, 1963 - March 13, 1963), USAIPO1963-0670 (April 4, 1963 - April 9, 1963), USAIPO1963-0671 (May 2, 1963 - May 7, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963); and partyStateCD in USAIPO1963-0667 (January 11, 1963 - January 16, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab partyCD_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen partyCD = partyCD_orig

*Replace values
replace partyCD = 1 if partyCD_orig == 2
replace partyCD = 2 if partyCD_orig == 1
replace partyCD = 4 if partyCD_orig == 6
replace partyCD = 6 if partyCD_orig == 7
replace partyCD = 7 if partyCD_orig == 4 | partyCD_orig == 8 | partyCD_orig == 9


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that there are only three surveys in this do file that contain the question on level of personal federal income tax: USAIPO1961-0641 (February 10, 1961 - February 15, 1961), USAIPO1962-660 (June 28, 1962 - July 3, 1962), and USAIPO1963-0667 (January 11, 1963 - January 16, 1963). The rest are read in/harmonized in the do file AdditionalTaxQuestions.

*N/A: This variable is not available in this file.


*GOVERNMENT WELFARE SPENDING

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW." Note that this variable is available only in files USAIPO1961-0651 (October 19, 1961 - October 24, 1961), USAIPO1961-0652 (November 17, 1961 - November 22, 1961), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964). USAIPO1964-0702 was harmonized for the additional tax files study, so it is excluded here to avoid redundancy. USAIPO1961-0652 was converted from a binary file to ASCII, resulting in several data problems that have not been resolved by Roper, so this file is omitted entirely. In sum, the variable is only available in USAIPO1961-0651 for this set of polls.

*N/A: This variable is not available in this file.


*MOST IMPORTANT PROBLEM–CIVIL RIGHTS

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO"

*N/A: This variable is not available in this file.


*OPINION: SPEED OF RACIAL INTEGRATION

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in nine surveys over the Kennedy years. Four surveys with this variable are included in this dataset: USAIPO1962-0664 (October 19, 1962 - October 24, 1962), USAIPO1963-0674 (June 21, 1963 - June 26, 1963), USAIPO1963-0675 (July 18, 1963 - July 23, 1963), and USAIPO1963-0679 (November 8, 1963 - November 13, 1963). Two surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1963-0673 (May 23, 1963 - May 28, 1963) and USAIPO1963-0676 (August 15, 1963 - August 20, 1963). And three surveys containing this variable are in binary files and thus could not be read in: USAIPO1962-0658 (May 3, 1962 - May 8, 1962), USAIPO1963-0677 (September 12, 1963 - September 17, 1963), and USAIPO1963-0678 (October 11, 1963 - October 16, 1963).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab integrationRate_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen integrationRate = integrationRate_orig


*Save the data
saveold FormattedData\1963-0679.dta, replace

clear






*********************************************** 
	******Create Weights for Duplicates
*********************************************** 
clear all
/*Here's the main difficulty with this task: each .dat file has a different number of lines.
Thus, whenI import a file, I might end up with each respondent giving anywhere from 1 to 4 rows.
To get around this, I will use the already exported data to get the correct count and then
reshape the imported data using that.*/


forvalues year=1961/1963 {
	forvalues file=641/679 {
		*Skip this iteration of the loop if files don't exist
		capture import delimited ".\RawData\aipo`year'-0`file'.dat", stringcols(_all) clear
		qui count
		if r(N)==0 {
		continue
		}
		
		*Generate id and get a count
		capture use ".\FormattedData/`year'-0`file'.dta", clear
		capture drop i
		capture drop dup_weight tag_dups
		gen i=_n
		qui count
		local c=r(N)
		qui saveold ".\FormattedData/`year'-0`file'.dta", replace
	
		*Generate dup_weights and tag_dups from Raw Data
		capture import delimited ".\RawData\aipo`year'-0`file'.dat", stringcols(_all) clear
		gen length = length(v1)
		drop if length<2 //At least one file has a single character symbol in the last row
		drop length
		qui count
		local g=r(N)/`c'
		 
		egen i = seq(), f(1) b(`g')
		egen j = seq(), f(1) t(`g')
		qui reshape wide v1, i(i) j(j)
		gen svy = "`year'-0`file'"

		egen dup_groups=group(v*)
		bysort dup_group: egen dup_weight=count(dup_group)
		label var dup_weight "Number of duplicate entries in survey"
		sort i
		egen tag_dups=tag(dup_groups)
		label var tag_dups "Only 1 of the duplicates has tag==1"
		drop dup_groups v*
		tempfile temp`year'`file'
		qui save "`temp`year'`file''"
		
		*Merge
		use ".\FormattedData/`year'-0`file'.dta", clear
		qui merge 1:1 i using `temp`year'`file''
	
		*Test
		egen dup_groups=group(presApprovala_orig-educ_orig), missing
		egen tag_test=tag(dup_groups)
		count if tag_test==1 & tag_dups==0
		
		*Drop and save
		drop _merge tag_test dup_groups i
		qui saveold ".\FormattedData/`year'-0`file'.dta", replace
		clear
	}
}



********APPEND FILES AND FINALIZE DATASET********

use FormattedData\1961-0641.dta
append using FormattedData\1961-0642.dta
append using FormattedData\1961-0644.dta
append using FormattedData\1961-0646.dta
append using FormattedData\1961-0651.dta
append using FormattedData\1962-0654.dta
append using FormattedData\1962-0660.dta
append using FormattedData\1962-0661.dta
append using FormattedData\1962-0662.dta
append using FormattedData\1962-0663.dta
append using FormattedData\1962-0664.dta
append using FormattedData\1962-0665.dta
append using FormattedData\1962-0666.dta
append using FormattedData\1963-0667.dta
append using FormattedData\1963-0668.dta
append using FormattedData\1963-0669.dta
append using FormattedData\1963-0670.dta
append using FormattedData\1963-0671.dta
append using FormattedData\1963-0674.dta
append using FormattedData\1963-0675.dta
append using FormattedData\1963-0679.dta

*Recode those variables requiring adjustments

*Replace observations set to 0 ("NO CODE OR NO DATA") with missing values per relevant harmonization plan(s)
replace raceSex = . if raceSex == 0
replace state = . if state == 0
replace presApprovala = . if presApprovala == 0
replace rockefellerKennedy = . if rockefellerKennedy == 0
replace goldwaterKennedy = . if goldwaterKennedy == 0
replace whoRockefeller = . if whoRockefeller == 0
replace whoGoldwater = . if whoGoldwater == 0
replace whoRomney = . if whoRomney == 0
replace whoScranton = . if whoScranton == 0
replace age = . if age == 0
replace poliPartyID = . if poliPartyID == 0
replace partyState = . if partyState == 0
replace partyCD = . if partyCD == 0
replace partyStateCD = . if partyStateCD == 0
replace fedIncomeTax = . if fedIncomeTax == 0
replace welfSpend = . if welfSpend == 0
replace mostImpProbCivRights = . if mostImpProbCivRights == 0
replace integrationRate = . if integrationRate == 0

*Label variables, define values, and assign values to variables

label variable svy "SURVEY CODE"

label variable svy_yr "SURVEY YEAR"

label variable svy_month "SURVEY MONTH(S)"

label variable binary "INDICATOR FOR BINARY FILE CONVERSION"
label define lb_binary 1 "BINARY FILE CONVERSION" 2 "NOT BINARY FILE CONVERSION"
label values binary lb_binary

label variable raceSex "RACE AND GENDER OF THE RESPONDENT"
label define lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

label variable state "STATE THE RESPONDENT LIVES IN"
label define lb_state 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"
label values state lb_state

label variable presApprovala "APPROVAL OF CURRENT PRESIDENT"
label define lb_presApprovala 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"
label values presApprovala lb_presApprovala

label variable rockefellerKennedy "PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS KENNEDY"
label define lb_rockefellerKennedy 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA"
label values rockefellerKennedy lb_rockefellerKennedy

label variable goldwaterKennedy "PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY"
label define lb_goldwaterKennedy 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA"
label values goldwaterKennedy lb_goldwaterKennedy

label variable whoRockefeller "WHO IS NELSON ROCKEFELLER"
label define lb_whoRockefeller 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA"
label values whoRockefeller lb_whoRockefeller

label variable whoGoldwater "WHO IS BARRY GOLDWATER"
label define lb_whoGoldwater 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA"
label values whoGoldwater lb_whoGoldwater

label variable whoRomney "WHO IS GEORGE ROMNEY"
label define lb_whoRomney 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA"
label values whoRomney lb_whoRomney

label variable whoScranton "WHO IS WILLIAM SCRANTON"
label define lb_whoScranton 1 "CORRECT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA"
label values whoScranton lb_whoScranton

label variable age "AGE OF THE RESPONDENT"

label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

label variable partyState "PREFERRED PARTY FOR CONGRESS IN STATE"
label define lb_partyState 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER"
label values partyState lb_partyState

label variable partyCD "PREFERRED PARTY FOR CONGRESS IN CONGRESSIONAL DISTRICT"
label define lb_partyCD 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER"
label values partyCD lb_partyCD

label variable partyStateCD "PREFERRED PARTY FOR CONGRESS IN EITHER STATE OR CONGRESSIONAL DISTRICT"
label define lb_partyStateCD 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER"
label values partyStateCD lb_partyStateCD

label variable fedIncomeTax "LEVEL OF PERSONAL FEDERAL INCOME TAX"
label define lb_fedIncomeTax 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION"
label values fedIncomeTax lb_fedIncomeTax

label variable welfSpend "GOVERNMENT WELFARE SPENDING"
label define lb_welfSpend 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DON’T KNOW"
label values welfSpend lb_welfSpend

label variable mostImpProbCivRights "RACIAL PROBS, SEGREGATION, INTEGRATION, DISCRIMINATION AS M IMP PROBLEM"
label define lb_mostImpProbCivRights 1 "YES" 2 "NO"
label values mostImpProbCivRights lb_mostImpProbCivRights

label variable integrationRate "OPINION: SPEED OF RACIAL INTEGRATION"
label define lb_integrationRate 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA"
label values integrationRate lb_integrationRate

*Harmonize 1963-0675
replace educ_orig=4 if educ_orig==5 & svy=="1963-0675"
replace educ_orig=5 if educ_orig==6 & svy=="1963-0675"
replace educ_orig=7 if educ_orig==8 & svy=="1963-0675"
replace educ_orig=8 if educ_orig==9 | educ_orig==10 & svy=="1963-0675"

gen educ=educ_orig
replace educ = 1 if (educ_orig == 1 | educ_orig == 2 | educ_orig == 3) //None or Grade 1-8
replace educ = 4 if (educ_orig == 4) //HS Incomplete
replace educ = 5 if (educ_orig == 5) //HS Grad
replace educ = 6 if (educ_orig == 6) //Technical, Trade or Business
replace educ = 7 if (educ_orig == 7) //College, Uni., Incomplete
replace educ = 8 if (educ_orig == 8) //College, Uni., Graduate
label variable educ "EDUCATION OF THE RESPONDENT"
label define lb_edu 1 "NONE, OR GRADES 1-8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE" 0 "NO CODE OR DATA"
label values educ lb_edu

*Check the data

*Count observations in the dataset
count

*Add numeric values to value labels to help check the data
numlabel, add

*Check each variable
bys svy: tab svy_yr
bys svy: tab svy_month
bys svy: tab binary
bys svy: tab wgt_timesAtHome
bys svy: tab wgt_edu
bys svy: tab raceSex
bys svy: tab state
bys svy: tab presApprovala
bys svy: tab rockefellerKennedy
bys svy: tab goldwaterKennedy
bys svy: tab whoRockefeller
bys svy: tab whoGoldwater
bys svy: tab whoRomney
bys svy: tab whoScranton
bys svy: tab age
bys svy: sum age
bys svy: tab poliPartyID
bys svy: tab partyState
bys svy: tab partyCD
bys svy: tab partyStateCD
bys svy: tab fedIncomeTax
bys svy: tab welfSpend
bys svy: tab mostImpProbCivRights
bys svy: tab integrationRate

*Remove the numeric values from value labels
numlabel, remove

*Sort the data
sort svy_yr svy

*Order the variables
order svy svy_yr svy_month state state_orig raceSex raceSex_orig age age_orig poliPartyID poliPartyID_orig partyState partyState_orig partyCD partyCD_orig partyStateCD partyStateCD_orig presApprovala presApprovala_orig rockefellerKennedy rockefellerKennedy_orig goldwaterKennedy goldwaterKennedy_orig whoRockefeller whoRockefeller_orig whoGoldwater whoGoldwater_orig whoRomney whoRomney_orig whoScranton whoScranton_orig fedIncomeTax fedIncomeTax_orig welfSpend welfSpend_orig mostImpProbCivRights mostImpProbCivRights_orig integrationRate integrationRate_orig wgt_timesAtHome wgt_edu binary

*Compress data in memory
compress

*Rename educ so that I can merge it later
rename educ eduHarmonized

*Save the data
saveold PresidentialApprovalQuestionsKennedy6.18.2016.dta, replace

log close

exit, clear
