
*********************************************************************************************************
// Why did the Democrats Lose the South? Bringing New Data to an Old Debate, Kuziemko & Washington (2018)
// This do file imports ASCII-FORMAT Gallup Polls into Stata

/*

It imports Gallup polls (downloaded from the iPoll databank in ascii format) into Stata.
	- For some polls, all variables are read in and labelled;
	- for others, only key variables later used in the analysis are shaped and harmonized;
	- at the end of the do file, all polls are appended, and only key variables are kept
	  (the resulting dataset is called gallup.dta)

"use gallup.dta, clear" // "tab svy" gives the list of the 30 Gallup polls included in
the dataset.

*/

clear all
clear matrix
clear mata
set more off
set matsize 11000

else if "`c(username)'"=="kuziemko"  {

cap cd ~/Dropbox/southern_strategy
global path ~/Dropbox/southern_strategy
global output "$path/Replication/Output"
global input "$path/Replication/Input"
global do "$path/Replication/DoFiles"
global ascii "$path/Replication/Input/ASCII_Gallup"
}


else if "`c(username)'"=="fvivar" { 

cap cd ~/Dropbox/southern_strategy
global path ~/Dropbox/southern_strategy
global output "$path/Replication/Output"
global input "$path/Replication/Input"
global do "$path/Replication/DoFiles"
global ascii "$path/Replication/Input/ASCII_Gallup"
}


/* READING ASCII-FORMAT GALLUP POLLS ONE-BY-ONE */

local svys
clear
infix ///
	q1a		9 ///
	q32		39 ///
	q101	50 ///
	n111	68 ///
	n116	73-74 ///
	using "$ascii/aipo0599.dat"

rename q1a presApprovala
replace presApprovala = . if presApprovala == 0
label values presApprovala lb_presApproval

rename q32 cathPresident
label values cathPresident lb_xxPres
	
rename q101 poliPartyID
replace poliPartyID = . if poliPartyID == 0 	// No code/no data
replace poliPartyID = 5 if poliPartyID == 4		// ind and other switched
replace poliPartyID = 4 if poliPartyID == 3		// other = 4
replace poliPartyID = 3 if poliPartyID == 5		// ind = 3
label values poliPartyID lb_poliPartyID

rename n111 raceSex
label values raceSex lb_raceSexNew

rename n116 state
label define lb_stateOld 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
label values state lb_stateOld
replace state = . if state == 0
replace state = state + 20 if inrange(state,80,89)
replace state = state + 10 if inrange(state,70,79)
replace state = state + 10 if inrange(state,60,69)
replace state = state - 40 if inrange(state,100,109)
label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

gen svy_year = 1958
gen svy_month = "May"
gen svy = "1958-0599"
saveold "$ascii/1958-0599.dta", replace 
local svys `svys' 1958-0599

*Gallup Poll # 1958-0602: Russia/Religion and the Presidency/Presidential Election
*Find weight variable
clear 
infix ///
	card 1 ///
	deck 2-4 ///
	ballot 5-8 ///
	q1a 9 ///
	q2a 10 ///
	q3 11 ///
	q4 12 ///
	q6a 13 ///
	q6b 14 ///
	q7 15 ///
	q8a 16 ///
	q8b 17 ///
	q8c 18 ///
	q8d 19 ///
	q8e 20 ///
	q9 21 ///
	q25 22 ///
	q26a 23 ///
	q26b 24 ///
	q26d 25 ///
	q27 26 ///
	q28 27 ///
	q29 28 ///
	q30a 29 ///
	q50 30 ///
	q51 31 ///
	q52 32 ///
	q101 33 ///
	q102 34 ///
	q103 35-36 ///
	q104 37-38 ///
	q105_1 39 ///
	q105_2 40 ///
	q105_3 41 ///
	q105_4 42 ///
	child1t9 43 ///
	child10t14 44 ///
	child15t20 45 ///
	minorsHH 46-47 ///
	q106 48 ///
	q107 49 ///
	rentOwn 51 ///
	q108b 52-54 ///
	q110a 55 ///
	q110b 56-57 ///
	q110c 58 ///
	religion 59 ///
	age 60-61 ///
	raceSex 62 ///
	n114 63 ///
	n115 64 ///
	citySize 65-66 ///
	state 67-68 ///	
	using "$ascii/aipo0602.dat"

label define  lb_yesNo 0 "No" 1 "Yes"
label define  lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define  lb_yesNoIA 1 "Yes" 2 "No" 9 "INAPPLICABLE"
label define  lb_favOppNoOp 1 "FAVOR" 2 "OPPOSE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_appDisapp 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_agrDisagr 1 "AGREE" 2 "DISAGREE" 3 "NO OPINION"  9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"
label define  lb_shouldNot1 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 0 "NO CODE OR NO DATA" 
label define  lb_shouldNot2 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"  
label define  lb_yesNoRem 1 "Yes" 2 "NO" 3 "Don't Remember" 4 "NO CODE OR NO DATA"
label define  lb_UpDown 1 "GO UP" 2 "GO DOWN" 3 "REMAIN SAME" 4 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_PosImpos 1 "POSSIBLE" 2 "IMPOSSIBLE" 3 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_GoodPoor 1 "GOOD IDEA" 2 "POOR IDEA" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_BetterWorse 1 "BETTER" 2 "WORSE" 3 "ABOUT SAME" 4 "NO OPINION"
label define  lb_MoreLess 1 "MORE" 2 "LESS" 3 "SAME" 4 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_YesNoDontKnow 1 "YES" 2 "NO" 3 "DON'T KNOW" 9 "INAPPLICABLE"
label define  lb_IncreaseDecrease 1 "INCREASED" 2 "DECREASED" 3 "KEPT SAME" 4 "NO OPINION"
label define lb_interest 1 "IS INTERESTED" 2 "IS NOT INTERESTED" 3 "NO OPINION"
label define lb_5scale 1 "5" 2 "4" 3 "3" 4 "2" 5 "1" 6 "-1" 7 "-2" 8 "-3" 9 "-4" 10 "-5" 11 "DON'T KNOW ENOUGH"
label define lb_YesNoDK 1 "YES" 2 "NO" 3 "DON'T KNOW"
label define lb_ExGoodPoor 1 "EXCELLENT" 2 "GOOD" 3 "FAIR" 4 "POOR" 5 "DON'T KNOW"
label define lb_MoreLessAbout 1 "MORE" 2 "LESS" 3 "ABOUT THE SAME (VOLUNTEERED)" 4 "NO OPINION"
label define  lb_favOppDK 1 "FAVOR" 2 "OPPOSE" 3 "DON'T KNOW" 0 "NO CODE OR NO DATA"
label define lb_Wrong 1 "WRONG" 2 "NOT WRONG" 3 "DON'T KNOW"
label define lb_LotSome 1 "LOT" 2 "SOME" 3 "LITTLE" 4 "NONE" 0 "NO CODE OR NO DATA"
label define lb_VeryFairly 1 "VERY" 2 "FAIRLY" 3 "NOT TOO INTERESTED" 4 "DONíT KNOW" 0 "NO CODE OR NO DATA"


local varMissing q1a q2a q3 q4 q6a q7 q8a q8b q8c q8d q8e q9 q25 q26a q26b q26d q27
local varMissing `varMissing' q28 q29 q30a q50 q51 q52 q101 q102 q103 q104 q106 q107
local varMissing `varMissing' rentOwn religion n114 n115
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNo q6a q26a n114
foreach var in `varYesNo' { 
	replace `var'  = 2-`var'
	label values `var' lb_yesNo
}

local varAppDisapp q1a q25 q30a
foreach var in `varAppDisapp' {
	label values `var' lb_appDisapp
}

local varYesNoNoOp q3 q4 q8a q8b q8c q8d q8e q26d
foreach var in `varYesNoNoOp' {
	label values `var' lb_yesNoNoOp
}

rename q1a presApprovala
label variable presApprovala "PRESIDENT JOB APPROVAL"
label define  lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label values presApprovala lb_presApproval

rename q2a subbmitKhrushchev
label variable subbmitKhrushchev "GOOD IDEA TO HAVE A UN SUMMIT BETWEEN THE LEADING WORLD FIGURES, INCL. KHRUSHCHEV OF RUSSIA"
label values subbmitKhrushchev lb_GoodPoor

rename q3 whiteHseKhrushchev
label variable whiteHseKhrushchev "INVITE KHRUSHCHEV TO WHITE HOUSE IF COMES TO UN SUMMIT"

rename q4 moscowEisenhower
label variable moscowEisenhower "IF INVITED, SHOULD EISENHOWER GO TO MOSCOW"

rename q6a heardAdams
label variable heardAdams "HEARD OR READ ABOUT SHERMAN ADAMS IN THE NEWS RECENTLY"

rename q6b resignAdams
label variable resignAdams "SHOULD SHERMAN ADAMS RESIGN?"
label values resignAdams lb_shouldNot2

rename q7 thoughtElection
label variable thoughtElection "HOW MUCH THOUGHT HAVE YOU GIVEN TO THE COMING NOVEMBER ELECTIONS FOR CONGRESS"
label values thoughtElection lb_LotSome

rename q8a cathPresident
rename q8b baptistPresident
rename q8c jewPresident
rename q8d blkPresident
rename q8e atheistPresident

rename q9 partyIDWWIII
label variable  partyIDWWIII "PARTY MORE LIKELY TO KEEP THE UNITED STATES OUT OF WWIII"
label define lb_partyIDWWIII 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "SAME" 4 "NO OPINION" 0 "NO CODE OR NO DATA"
label values partyIDWWIII lb_partyIDWWIII

rename q25 usTroopsLebanon
label variable usTroopsLebanon "APPROVE OF THE UNITED STATES SENDING TROOPS INTO LEBANON"

rename q26a whoNasser
label variable whoNasser "WHO IS NASSER?"

rename q26b usFrdlyNasser
label variable usFrdlyNasser "U.S. GET ON FRIENDLY TERMS WITH NASSER AND THE UNITED ARAB REPUBLIC"
label values usFrdlyNasser lb_shouldNot2

rename q26d usInviteNasser
label variable usInviteNasser "U.S. SHOULD INVITE NASSER TO U.S."

local n = 1
foreach v in Stevenson Kennedy Symington {
	local V = upper("`v'")
	local m = 26 + `n'
	rename q`m' nixon`v'
	label variable nixon`v' "PRESIDENTAL ELECTION: NIXON VS `V'"
	label define lb_nixon`v' 1 "NIXON" 2 "`V'" 3 "OTHER" 4 "UNDECIDED, NO ANSWER TO Q.27B" 5 "UNDECIDED, LEANS MORE TOWARD NIXON, THE REPUBLICAN" 6 "UNDECIDED, LEANS MORE TOWARD `V', THE DEMOCRAT" 7 "UNDECIDED, UNDECIDED" 0 "NO CODE OR NO DATA"
	label values nixon`v' lb_nixon`v'
	local n = `n' + 1
}

rename q30a refugesCommun
label variable refugesCommun "ADMIT 65K COMMUNIST REFUGES"

rename q50 carModels
label variable carModels "INTEREST OF CLOSE FRIENDS IN LOOK OF NEW CAR MODELS"
label values carModels lb_VeryFairly

rename q51 carFriends
label variable carFriends "ROLE OF ATTRACTIVENESS TO FRIENDS IN CAR PURCHASE"
label values carFriends lb_VeryFairly

rename q52 newCarModel
label variable newCarModel "IMPORTANCE OF NEW CAR MODEL FOR FRIENDS"
label values newCarModel lb_VeryFairly

rename q101 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
replace poliPartyID = 5 if poliPartyID == 3
replace poliPartyID = 3 if poliPartyID == 4
replace poliPartyID = 4 if poliPartyID == 5
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

rename q102 partyCD
label variable partyCD "PREFERRED PARTY FOR CONGRESS"
label define lb_partyCD 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, NO ANSWER TO PART B" 5 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 6 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 7 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 8 "UNDECIDED OR REFUSED, UNDECIDED" 9 "UNDECIDED OR REFUSED, REFUSED TO ANSWER"
label values partyCD lb_partyCD

rename q103 occupation
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q104 adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

local n = 1
foreach v in haveChild1t9 haveChild10t14 haveChild15t20 haveMinorHH {
	rename q105_`n' `v'
	replace `v' = 2 - `v'
	label values `v' lb_yesNo
	local n = `n' + 1
}
label variable haveChild1t9 "HAS CHILD AGES 1 TO 9"
label variable haveChild10t14 "HAS CHILD AGES 10 TO 14" 
label variable haveChild15t20 "HAS CHILD AGES 15 TO 20"
label variable haveMinorHH "HAS CHILD AGES 1 TO 20"

label variable child1t9 "NUM CHILD AGES 1 TO 9"
label variable child10t14 "NUM CHILD AGES 10 TO 14" 
label variable child15t20 "NUM CHILD AGES 15 TO 20"

label define lb_child 1 "ONE CHILD" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 9 "INAPPLICABLE"
foreach v in child1t9 child10t14 child15t20 {
	label values `v' lb_child
}
label variable minorsHH "NUMBER OF CHILDREN (MINORS) LIVING IN THIS HOUSEHOLD"
label define lb_minorsHH 1 "ONE CHILD" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE" 11 "NO MINOR CHILDREN"
label values minorsHH lb_minorsHH

rename q106 voteStevensonEisenhower
label define lb_voteStevensonEisenhower 1 "STEVENSON" 2 "EISENHOWER" 3 "OTHER" 4 "VOTED, DONíT REMEMBER WHOM" 5 "NO, DIDNíT VOTE" 6 "DONíT REMEMBER IF VOTED" 0 "NO CODE OR NO DATA"
label values voteStevensonEisenhower lb_voteStevensonEisenhower

rename q107 edu_1958
label define lb_edu_1958 1 "NONE, OR GRADES 1-6" 2 "GRADE 7 OR 8" 3 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 4 "HIGH SCHOOL GRADUATE (GRADE 12)" 5 "TECHNICAL, TRADE OR BUSINESS" 6 "COLLEGE, UNIVERSITY, INCOMPLETE" 7 "COLLEGE, UNIVERSITY, GRADUATE"
label values edu_1958 lb_edu_1958

label variable rentOwn "DO YOU OWN OR RENT YOUR HOME"
label define lb_rentOwn 1 "OWN" 2 "RENT" 3 "OTHER ARRANGEMENT" 0 "NO CODE OR NO DATA" 
label values rentOwn lb_rentOwn

rename q108b monthlyRent 

rename q110a ownFarmWork
label variable ownFarmWork "IF LIVE ON FARM: IS IT BEING WORKED NOW?"
label variable ownFarmWork lb_yesNoIA

rename q110b ownFarmAcres
label variable ownFarmAcres "IF LIVE ON FARM: HOW MANY ACRES"
label define lb_ownFarmAcres 1 "UNDER 3 ACRES" 2 "3 - 9 ACRES" 3 "10 - 19 ACRES" 4 "20 - 29 ACRES" 5 "30 - 49 ACRES" 6 "50 - 99 ACRES" 7 "100 - 179 ACRES" 8 "180 - 259 ACRES" 9 "260 - 499 ACRES" 10 "500 - 999 ACRES" 11 "1000 ACRES AND OVER" 12 "NOT ASCERTAINED, DOES NOT KNOW HOW MANY ACRES" 99 "INAPPLICABLE"
label values ownFarmAcres lb_ownFarmAcres

rename q110c ownFarmReven250
label variable ownFarmReven250 "IF LIVE ON FARM: DOES REVENUE FROM SALES EXCEED $250 A YEAR"
label values ownFarmReven250 lb_yesNoIA

label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

label define  lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "NEGRO MAN" 4 "NEGRO WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

rename n114 liveFarm
label variable liveFarm "LIVES ON FARM PROPERTY"

rename n115 econLvl
label variable econLvl "ECONOMIC LEVEL"
label define lb_econLvl 1 "HIGH" 2 "MEDIUM" 3 "LOW" 0 "NO CODE OR NO DATA" 
label values econLvl lb_econLvl

label define lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB." 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

label define lb_stateOld 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 0 "NO CODE OR NO DATA"
label values state lb_stateOld
replace state = . if state == 0
replace state = state + 20 if (state == 81 | state == 82 | state == 83 | state == 84)
replace state = state + 10 if (state == 71 | state == 72 | state == 73)
replace state = state + 10 if (state == 61 | state == 62 | state == 63 | state == 64 | state == 65 | state == 66 | state == 67 | state == 68)
replace state = state - 40 if (state == 101 | state == 102 | state == 103 | state == 104)
label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

gen svy_year = 1958
gen svy_month = "August"
gen svy = "1958-0602"
save "$ascii/1958-0602.dta", replace 
local svys `svys' 1958-0602


*Gallup Poll # 604 [USAIPO1958-0604] 
clear 
infix ///
	card 1 ///
	deck 2-4 ///
	ballot 5-8 ///
	q1a 9 ///
	q2a 10-11 ///
	q2b 12 ///
	q3 13 ///
	q4a 14 ///
	q4b 15 ///
	q4c 16 ///
	q4d 17 ///
	q5 18 ///
	q6 19 ///
	q27 20 ///
	q28 21 ///
	q29a 22 ///
	q29b 23 ///
	q30a 24 ///
	q30c 25 ///
	q30d 26 ///
	q30e 27 ///
	q31a 28 ///
	q31b 29 ///
	q32a 30 ///
	q50 31 ///
	q51a 32 ///
	q52b 33 ///
	q53 34 ///
	q54a1 35 ///
	q54a2 36 ///
	q54a3 37 ///
	q54a4 38 ///
	q54a5 39 ///
	q54b 40 ///
	q101 41 ///
	q102b 42-43 ///
	q102c 44 ///
	q104 45-46 ///
	q105 47-48 ///
	q106 49 ///
	q107 50 ///
	q108 51 ///
	q109a 52 ///
	q109b 53-54 ///
	q109c 55 ///
	q110 56 ///
	age 57-58 ///
	raceSex 59 ///
	n113 60 ///
	citySize 62-63 ///
	state 64-65 ///
	using "$ascii/604.dat"
	
label define  lb_yesNo 0 "No" 1 "Yes"
label define  lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define  lb_yesNoIA 1 "Yes" 2 "No" 9 "INAPPLICABLE"
label define  lb_favOppNoOp 1 "FAVOR" 2 "OPPOSE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_appDisapp 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_agrDisagr 1 "AGREE" 2 "DISAGREE" 3 "NO OPINION"  9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"
label define  lb_shouldNot1 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 0 "NO CODE OR NO DATA" 
label define  lb_shouldNot2 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"  
label define  lb_yesNoRem 1 "Yes" 2 "NO" 3 "Don't Remember" 4 "NO CODE OR NO DATA"
label define  lb_UpDown 1 "GO UP" 2 "GO DOWN" 3 "REMAIN SAME" 4 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_PosImpos 1 "POSSIBLE" 2 "IMPOSSIBLE" 3 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_GoodPoor 1 "GOOD IDEA" 2 "POOR IDEA" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_BetterWorse 1 "BETTER" 2 "WORSE" 3 "ABOUT SAME" 4 "NO OPINION"
label define  lb_MoreLess 1 "MORE" 2 "LESS" 3 "SAME" 4 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_YesNoDontKnow 1 "YES" 2 "NO" 3 "DON'T KNOW" 9 "INAPPLICABLE"
label define  lb_IncreaseDecrease 1 "INCREASED" 2 "DECREASED" 3 "KEPT SAME" 4 "NO OPINION"
label define lb_interest 1 "IS INTERESTED" 2 "IS NOT INTERESTED" 3 "NO OPINION"
label define lb_5scale 1 "5" 2 "4" 3 "3" 4 "2" 5 "1" 6 "-1" 7 "-2" 8 "-3" 9 "-4" 10 "-5" 11 "DON'T KNOW ENOUGH"
label define lb_YesNoDK 1 "YES" 2 "NO" 3 "DON'T KNOW"
label define lb_ExGoodPoor 1 "EXCELLENT" 2 "GOOD" 3 "FAIR" 4 "POOR" 5 "DON'T KNOW"
label define lb_MoreLessAbout 1 "MORE" 2 "LESS" 3 "ABOUT THE SAME (VOLUNTEERED)" 4 "NO OPINION"
label define  lb_favOppDK 1 "FAVOR" 2 "OPPOSE" 3 "DON'T KNOW" 0 "NO CODE OR NO DATA"
label define lb_Wrong 1 "WRONG" 2 "NOT WRONG" 3 "DON'T KNOW"
label define lb_LotSome 1 "LOT" 2 "SOME" 3 "LITTLE" 4 "NONE" 0 "NO CODE OR NO DATA"
label define lb_VeryFairly 1 "VERY" 2 "FAIRLY" 3 "NOT TOO INTERESTED" 4 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define lb_HelpHurt 1 "HELPED" 2 "HURT" 3 "NO OPINION" 9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"


local varMissing q1a q2b q3 q4a q4b q5 q6 q27 q28 q29b q30c q30d q30e q32a q50 q51a q52 q53
local varMissing `varMissing' q54a1 q54a2 q54a3 q54a4 q54a5 q54b q101 q102b q102c q105 q106
local varMissing `varMissing' q107 q108 q109a q109c q110 age n113 
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNo q51a
foreach var in `varYesNo' { 
	replace `var'  = 2-`var'
	label values `var' lb_yesNo
}

local varAppDisapp q1a  
foreach var in `varAppDisapp' {
	label values `var' lb_appDisapp
}

local varYesNoNoOp q4b q4c q4d q29b q30c q54a1 q54a2 q54a3 q54a4 q54a5 q54b
foreach var in `varYesNoNoOp' {
	label values `var' lb_yesNoNoOp
}

local varYesNoIA q4a
foreach var in `varYesNoIA' {
	label values `var' lb_yesNoIA
}

local varAgrDisagr 
foreach var in `varAgrDisagr' {
	label values `var' lb_agrDisagr
}

local varFavOppNoOp
foreach var in `varFavOppNoOp' {
	label values `var' lb_favOppNoOp
}

foreach var in   {
	label values `var' lb_YesNoDontKnow
}

gen svy_year = 1958
gen svy_month = "September"
gen svy = "1958-0604"

rename q1a presApprovala
label variable presApprovala "PRESIDENT JOB APPROVAL"
label define  lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label values presApprovala lb_presApproval

rename q2a mostImpProblem
label variable mostImpProblem "MOST IMPORTANT PROBLEM FACING THIS COUNTRY TODAY"
label define lb_mostImpProblem 1 "KEEPING THE PEACE, DEALING WITH RUSSIA, KEEPING US OUT OF WAR, FOREIGN POLICY, COMMUNISM" 2 "UNEMPLOYMENT, JOB SITUATION, FINDING PEOPLE WORK" 3 "INTEGRATION, SEGREGATION, RACIAL DISPUTES, CIVIL RIGHTS" 4 "NATIONAL DEFENSE, MILITARY PREPAREDNESS, KEEPING OUR DEFENSES STRONG" 5 "ECONOMIC PROBLEMS, HIGH COST OF LIVING, HIGH TAXES, KEEPING TAXES DOWN" 6 "PROBLEMS OF SPACE, 'SPUTNIK', SHOOTING THE MOON" 7 "EDUCATION, GETTING BETTER SCHOOLS, DOING BETTER JOB OF EDUCATING" 8 "FARM PROBLEMS, HELPING THE FARMER, GETTING FARM PRICES UP" 9 "NUCLEAR TESTS, DANGER FROM ATOMIC EXPLOSIONS" 10 "JUVENILE DELINQUENCY" 11 "FOREIGN AID (ANTI), SENDING TOO MUCH MONEY ABROAD" 12 "LABOR UNION PROBLEMS, UNION CORRUPTION" 13 "COMMUNISM IN THE U.S., INTERNAL SUBVERSION" 14 "IMPORTANT NEWS EVENT (WHEN IT OCCURS, IF WE WANT SPECIAL MEASUREMENT ON IT) MIDDLE EAST, LEBANON, ETC." 15 "IMPORTANT NEWS EVENTS (QUEMOY, FORMOSA, CHINA, COMMUNIST BLOCKADE OF OFFSHORE ISLANDS) CHIANG-KAI-SHEK, ETC." 16 "ALL OTHERS" 17 "NONE, NO ANSWER, DON,T KNOW"
label values mostImpProblem lb_mostImpProblem

rename q2b partyMostImpProblem
label variable partyMostImpProblem "PARTY THAT CAN DO A BETTER JOB WITH THE PROBLEM YOU JUST MENTIONED"
label define lb_partyMostImpProblem 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "NO DIFFERENCE" 4 "NO OPINION" 0 "NO CODE OR NO DATA" 
label values partyMostImpProblem lb_partyMostImpProblem

rename q3 timeToIntegrate
label variable timeToIntegrate "TIME GIVEN TO SCHOOLS TO INTEGRATE"
label define lb_timeToIntegrate 1 "IMMEDIATELY" 2 "FEW YEARS" 3 "41932" 4 "NOT AT ALL" 5 "NO OPINION" 0 "NO CODE OR NO DATA"
label values timeToIntegrate lb_timeToIntegrate

rename q4a childInSchool
rename q4b fewMixedSchool
rename q4c halfMixedSchool
rename q4d halfPlusMixedSchool
label variable childInSchool "ANY CHILD IN GRADE OR HIGH SCHOOL"
label variable fewMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH A FEW BLACK CHILDREN"
label variable halfMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH HALF BLACK CHILDREN"
label variable halfPlusMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH MORE THAN HALF BLACK CHILDREN"

rename q5 relationsIntegrate
label variable relationsIntegrate "IMPACT OF INTEGRATION ON RACE RELATIONS"
label values relationsIntegrate lb_HelpHurt

rename q6 thoughtElection
label variable thoughtElection "THOUGHT GIVEN TO UPCOMING NOVEMBER ELECTIONS"
label values thoughtElection lb_LotSome

rename q27 expWinHouse
label variable expWinHouse "WHICH PARTY WILL WIN CONTROL OF HOUSE"
label define lb_expWinHouse 1 "REPUBLICANS" 2 "DEMOCRATS" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label values expWinHouse lb_expWinHouse

rename q28 partyProsperous
label variable partyProsperous "PARTY BEST AT KEEPING THE COUNTRY PROSPEROUS"
label define lb_partyProsperous 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "SAME" 4 "NO OPINION" 0 "NO CODE OR NO DATA"
label values partyProsperous lb_partyProsperous

rename q29a whoFaubus
label variable whoFaubus "WHO IS ORVAL FAUBU?"
replace whoFaubus = 2 - whoFaubus
label define lb_whoFaubus 1 "CORRECTLY ID" 2 "INCORRECTLY ID"
label values whoFaubus lb_whoFaubus

rename q29b voteFaubus
label variable voteFaubus "WOULD YOU VOTE FOR ORVAL FAUBU?"
label define lb_voteFaubus 1 "YES" 2 "NO" 3 "NO OPINION" 4 "INAPPLICABLE" 5 "NO CODE OR NO DATA"
label values voteFaubus lb_voteFaubus

rename q30a quemoyMatsu
label variable quemoyMatsu "HEARD ABOUT WAR OVER QUEMOY AND MATSU ISLANDS"

rename q30c unQuemoyMatsu
label variable unQuemoyMatsu "U.S. GO TO U.N. BEFORE WAR OVER QUEMOY AND MATSU ISLANDS"

rename q30d nukeQuemoyMatsu
label variable nukeQuemoyMatsu "IF WARRING OVER QUEMOY AND MATSU ISLANDS, USE ATOMIC WEAPONS TO DESTROY CHINESE INSTALLATIONS ON ISLAND"
label define lb_nukeQuemoyMatsu 1 "YES, SHOULD" 2 "NO, SHOULD NOT" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label values nukeQuemoyMatsu lb_nukeQuemoyMatsu

rename q30e formosaNeu
label variable formosaNeu "NEUTRALIZE FORMOSA"
label values formosaNeu lb_GoodPoor

rename q31a popChinaCom
label variable popChinaCom "GUESS COMMUNIST CHINESE POPULATION"
label define lb_chinaComPop 1 "CORRECT (500 MILLION TO 700 MILLION)" 2 "INCORRECT (ALL OTHER ANSWERS)" 3 "NO ANSWER, DON,T KNOW"
label values popChinaCom lb_chinaComPop

rename q31b popFormosa
label variable popFormosa "GUESS POPULATION OF FORMOSA"
label define lb_popFormosa 1 "CORRECT (8 MILLION TO 10 MILLION)" 2 "INCORRECT (ALL OTHER ANSWERS)" 3 "NO ANSWER, DON,T KNOW"
label values popFormosa lb_popFormosa

rename q32a chooseSex
label variable chooseSex "PREFERRED SEX IF BORN AGAIN" 
label define lb_chooseSex 1 "MAN" 2 "WOMAN" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label values chooseSex lb_chooseSex

rename q50 partyRacketUnions
label variable partyRacketUnions "PARTY MORE LIKELY TO CLEAN RACKETEERING IN LABOR UNIONS"
label values partyRacketUnions lb_partyProsperous

rename q51a matthewsCommission
label variable matthewsCommission "HEARD ABOUT REPORT OF THE MATTHEWS COMMISSION"

label define lb_voteRegist 1 "YES, REGISTERED" 2 "DON,T HAVE TO REGISTER" 3 "NO, NO ANSWER TO Q.52B" 4 "DON,T KNOW, NO ANSWER TO Q.52B" 5 "NO OR DON,T KNOW, YES PLAN TO REGISTER" 6 "NO OR DON,T KNOW, DO NOT PLAN TO REGISTER" 7 "NO OR DON,T KNOW, OTHER ANSWERS" 0 "NO CODE OR NO DATA"
rename q52b voteRegist
label variable voteRegist "REGISTERED TO VOTE"
//rename q52b planVoteRegist
//label variable planVoteRegist "PLANNING TO REGISTER TO VOTE"
label values voteRegist lb_voteRegist
//label values planVoteRegist lb_voteRegist

rename q54a1 blkPresident
rename q54a2 baptistPresident
rename q54a3 jewPresident
rename q54a4 cathPresident
rename q54a5 atheistPresident
rename q54b womanPresident

rename q101 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
replace poliPartyID = 5 if poliPartyID == 3
replace poliPartyID = 3 if poliPartyID == 4
replace poliPartyID = 4 if poliPartyID == 5
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

rename q102b partyCD
label variable partyCD "PREFERRED PARTY FOR CONGRESS"
label define lb_partyCD 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, NO ANSWER TO PART B" 5 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 6 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 7 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 8 "UNDECIDED OR REFUSED, UNDECIDED" 9 "UNDECIDED OR REFUSED, REFUSED TO ANSWER"
replace partyCD = 4 if partyCD == 5
replace partyCD = partyCD - 1 if partyCD > 5
label values partyCD lb_partyCD

rename q102c dixiecrats
label variable dixiecrats "WOULD YOU FAVOR A STATES RIGHTS DEM PARTY IF DEM CANDIDATE WAS PRO-INTEGRATION"
lab def lb_dixiecrats 1 "FAVOR" 2 "OPPOSE" 3 "NO OPINION" 9 "INAPPLICABLE"
lab val dixiecrats lb_dixiecrats

rename q104 occupation
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q105 adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

rename q106 voteStevensonEisenhower 
label define lb_voteStevensonEisenhower 1 "STEVENSON" 2 "EISENHOWER" 3 "OTHER" 4 "VOTED, DON,T REMEMBER WHOM" 5 "NO, DIDN,T VOTE" 6 "DON,T REMEMBER IF VOTED" 0 "NO CODE OR NO DATA"
label values voteStevensonEisenhower lb_voteStevensonEisenhower

rename q107 edu_1958
label define lb_edu_1958 1 "NONE, OR GRADES 1-6" 2 "GRADE 7 OR 8" 3 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 4 "HIGH SCHOOL GRADUATE (GRADE 12)" 5 "TECHNICAL, TRADE OR BUSINESS" 6 "COLLEGE, UNIVERSITY, INCOMPLETE" 7 "COLLEGE, UNIVERSITY, GRADUATE"
label values edu_1958 lb_edu_1958

rename q108 union
label define lb_union 1 "YES, RESPONDENT IS" 2 "YES, SPOUSE IS" 3 "YES, BOTH ARE" 4 "NO, NEITHER IS"
label values union lb_union

rename q109a ownFarmWork
label variable ownFarmWork "IF LIVE ON FARM: IS IT BEING WORKED NOW?"
label values ownFarmWork lb_yesNoIA

rename q109b ownFarmAcres
label variable ownFarmAcres "IF LIVE ON FARM: HOW MANY ACRES"
label define lb_ownFarmAcres 1 "UNDER 3 ACRES" 2 "3 - 9 ACRES" 3 "10 - 19 ACRES" 4 "20 - 29 ACRES" 5 "30 - 49 ACRES" 6 "50 - 99 ACRES" 7 "100 - 179 ACRES" 8 "180 - 259 ACRES" 9 "260 - 499 ACRES" 10 "500 - 999 ACRES" 11 "1,000 ACRES AND OVER" 12 "NOT ASCERTAINED, DON,T KNOW HOW MANY ACRES" 99 "PROPERTY NOT A WORKING FARM (RANCH), INAPPLICABLE"
label values ownFarmAcres lb_ownFarmAcres

rename q109c ownFarmReven150
label variable ownFarmReven150 "IF LIVE ON FARM: DOES REVENUE FROM SALES EXCEED $150 A YEAR"
label values ownFarmReven150 lb_yesNoIA

rename q110 religion
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

label define  lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "NEGRO MAN" 4 "NEGRO WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex 

rename n113 farmProperty
label define  lb_farmProperty 1 "CITY, TOWN, OR RURAL NON-FARM PROPERTY" 2 "FARM PROPERTY" 0 "NOT RECORDED"
label values farmProperty lb_farmProperty

label define lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

label define lb_stateOld 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 0 "NO CODE OR NO DATA"
label values state lb_stateOld
replace state = . if state == 0
replace state = state + 20 if (state == 81 | state == 82 | state == 83 | state == 84)
replace state = state + 10 if (state == 71 | state == 72 | state == 73)
replace state = state + 10 if (state == 61 | state == 62 | state == 63 | state == 64 | state == 65 | state == 66 | state == 67 | state == 68)
replace state = state - 40 if (state == 101 | state == 102 | state == 103 | state == 104)
label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/1958-0604.dta", replace 
local svys `svys' 1958-0604


*USAIPO1959-0622
clear 
infix 2 lines 1: ///
	card 1 ///
	deck 2-4 ///
	ballot 5-8 ///
	q1a 9 ///
	q1b 10 ///
	q1c1 11 ///
	q1c2 12 ///
	q1c3 13 ///
	q1c4 14 ///
	q1c5 15 ///
	q1c6 16 ///
	q1c7 17 ///
	q1c8 18 ///
	q1c9 19 ///
	q1c10 20 ///
	q1c11 21 ///
	q1c12 22 ///
	q1c13 23 ///
	q1c14 24 ///
	q1c15 25 ///
	q1c16 26 ///
	q4 27 ///
	q5 28 ///
	q6 29-30 ///
	q7 31 ///
	q8a 32-33 ///
	q8b 34-35 ///
	q8c 36-37 ///
	q8d 38-39 ///
	q9 40 ///
	q20a 41 ///
	q20b 42 ///
	q21a 43 ///
	q21b 44 ///
	q22 45 ///
	q23 46 ///
	q24 47 ///
	q25 48 ///
	q25b 49 ///
	q26 50 ///
	q27 51 ///
	q40a 52 ///
	q41 53 ///
	q43a 54 ///
	q45 55 ///
	q46 56 ///
	q47 57 ///
	q48a 58 ///
	q48b1 59 ///
	q48b2 60 ///
	q48b3 61 ///
	q48b4 62 ///
	q61ab 63 ///
	q62ab 64 ///
	q63ab 65 ///
	q64ab 66 ///
	q65 67 ///
	q66a 68 ///
	q66b 69 ///
	q66c 70 ///
	q66d 71-72 ///
	q80a 73 ///
	q80a1 74 ///
	q80a2 75 ///
	q80a3 76 ///
	q80a4 77 ///
	q80b 78 ///
	q99 79 ///
	q100 80	 ///
	2: ///
	card2 1 ///
	deck2 2-4 ///
	ballot2 5-8 ///
	q101 9 ///
	q102ab 10-11 ///
	religion 12 ///
	q104 13-14 ///
	q105 15 ///
	q106 16 ///
	q107 17 ///
	q108 18 ///
	q109_110 19-21 ///
	q112 22-23 ///
	age 24-25 ///
	q114 26 ///
	racegender 27 ///
	socialstatus 28 ///
	citysize 29-30 ///
	section 31 ///
	state 31-32 ///
	interviewerno 33-34 ///
	using "$ascii/622.dat"
	
gen svy_year = 1959
gen svy_month = "December"
gen svy = "1959-0622"

label define lb_yesNo 0 "No" 1 "Yes"
label define lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define lb_yesNoIA 1 "Yes" 2 "No" 9 "INAPPLICABLE"
label define lb_favOppNoOp 1 "FAVOR" 2 "OPPOSE" 3 "NO OPINION"
label define lb_appDisapp 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define lb_agrDisagr 1 "AGREE" 2 "DISAGREE" 3 "NO OPINION"  9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"
label define lb_shouldNot1 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 0 "NO CODE OR NO DATA" 
label define lb_shouldNot2 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"  
label define lb_yesNoRem 1 "Yes" 2 "NO" 3 "Don't Remember" 4 "NO CODE OR NO DATA"
label define lb_UpDown 1 "GO UP" 2 "GO DOWN" 3 "REMAIN SAME" 4 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define lb_PosImpos 1 "POSSIBLE" 2 "IMPOSSIBLE" 3 "DON'T KNOW"
label define lb_GoodPoor 1 "GOOD IDEA" 2 "POOR IDEA" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define lb_BetterWorse 1 "BETTER" 2 "WORSE" 3 "ABOUT SAME" 4 "NO OPINION"
label define lb_MoreLess 1 "MORE" 2 "LESS" 3 "SAME" 4 "NO OPINION" 0 "NO CODE OR NO DATA"
label define lb_YesNoDontKnow 1 "YES" 2 "NO" 3 "DON'T KNOW" 9 "INAPPLICABLE"
label define lb_IncreaseDecrease 1 "INCREASED" 2 "DECREASED" 3 "KEPT SAME" 4 "NO OPINION"
label define lb_interest 1 "IS INTERESTED" 2 "IS NOT INTERESTED" 3 "NO OPINION"
label define lb_5scale 1 "5" 2 "4" 3 "3" 4 "2" 5 "1" 6 "-1" 7 "-2" 8 "-3" 9 "-4" 10 "-5" 11 "DON'T KNOW ENOUGH"
label define lb_YesNoDK 1 "YES" 2 "NO" 3 "DON'T KNOW"
label define lb_ExGoodPoor 1 "EXCELLENT" 2 "GOOD" 3 "FAIR" 4 "POOR" 5 "DON'T KNOW"
label define lb_MoreLessAbout 1 "MORE" 2 "LESS" 3 "ABOUT THE SAME (VOLUNTEERED)" 4 "NO OPINION"
label define lb_favOppDK 1 "FAVOR" 2 "OPPOSE" 3 "DON'T KNOW" 0 "NO CODE OR NO DATA"
label define lb_Wrong 1 "WRONG" 2 "NOT WRONG" 3 "DON'T KNOW"
label define lb_LotSome 1 "LOT" 2 "SOME" 3 "LITTLE" 4 "NONE" 0 "NO CODE OR NO DATA"
label define lb_VeryFairly 1 "VERY" 2 "FAIRLY" 3 "NOT TOO INTERESTED" 4 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define lb_HelpHurt 1 "HELPED" 2 "HURT" 3 "NO OPINION" 9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"

local varMissing q1a q1b q4 q5 q6 q7 q9 q20a q20b q21a q21b q22 q23 q24 q26 q27 q40a q41
local varMissing `varMissing' q45 q46 q47 q48a q61ab q62ab q63ab q64ab q65 q66a q66b q66c
local varMissing `varMissing' q80a q80a1 q80a2 q80a3 q80a4 q80b q99 q100 q101 q102ab
local varMissing `varMissing' religion q105 q106 q107 q108 q109_110 q112 age q114
local varMissing `varMissing' racegender socialstatus
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNo q1c1 q1c2 q1c3 q1c4 q1c5 q1c6 q1c7 q1c8 q1c9 q1c10 q1c11 q1c12 q1c13 q1c14
local varYesNo `varYesNo' q1c15 q1c16 q48a q48b1 q48b2 q48b3 q48b4 q65 q100 q114
foreach var in `varYesNo' { 
	replace `var'  = 2-`var'
	label values `var' lb_yesNo
}

local varPosImpos q9
foreach var in `varPosImpos' {
	label values `var' lb_PosImpos
}

local varYesNoNoOp q41 q66a q66b q66c q80a q80a1 q80a2 q80a3 q80a4 q80b
foreach var in `varYesNoNoOp' {
	label values `var' lb_yesNoNoOp
}

local varFavOppNoOp q47
foreach var in `varFavOppNoOp' {
	label values `var' lb_favOppNoOp
}

rename q1a firstManInSpace
lab var firstManInSpace "FIRST TO SEND A MAN INTO OUTER SPACE: THE US OR RUSSIA"
lab def lb_USRussia 1 "US" 2 "RUSSIA" 3 "NO OPINION"
lab val firstManInSpace lb_USRussia

rename q1b firstMissilesRocket
lab var firstMissilesRocket "FARTHER AHEAD IN LONG RANGE MISSILES AND ROCKETS: THE US OR RUSSIA"
lab val firstMissilesRocket lb_USRussia

forvalues i = 1/16 {
	rename q1c`i' reason`i'RussiaFirst
  }
lab var reason1RussiaFirst "RUSSIA FARTHER AHEAD BECAUSE MORE WORK / EFFORT / RESOURCES / MONEY"
lab var reason2RussiaFirst "RUSSIA FARTHER AHEAD BECAUSE OF PREVIOUS ACCOMPLISHMENTS (SPUTNIKS, ETC.)"
lab var reason3RussiaFirst "RUSSIA FARTHER AHEAD BECAUSE WORKED LONGER ON IT, MORE EXPERIENCE, ETC."
lab var reason4RussiaFirst "RUSSIA FARTHER AHEAD BECAUSE BETTER EDUCATIONAL SYSTEMS, MORE TRAINING"
lab var reason5RussiaFirst "RUSSIA FARTHER AHEAD BECAUSE STOLE BEST SCIENTISTS FROM OTHER COUNTRIES"
lab var reason6RussiaFirst "RUSSIA FARTHER AHEAD BECAUSE MORE SCIENTISTS, BETTER SCIENTISTS"
lab var reason7RussiaFirst "RUSSIA FARTHER AHEAD BECAUSE BAD ORGANIZATION / RED TAPE IN THE US"
lab var reason8RussiaFirst "RUSSIA FARTHER AHEAD BECAUSE INTER-SERVICE RIVALRY, JEALOUSY, FEUDING, ETC."
lab var reason9RussiaFirst "RUSSIA FARTHER AHEAD BECAUSE US HAS FALLEN BEHIND IN EDUCATION"
lab var reason10RussiaFirst "RUSSIA FARTHER AHEAD BECAUSE OF US EDUCATION IN SCIENCE COURSES, MATH COURSES"
lab var reason11RussiaFirst "RUSSIA FARTHER AHEAD BECAUSE I'VE READ OR HEARD MORE ABOUT IT IN THE MEDIA"
lab var reason12RussiaFirst "RUSSIA FARTHER AHEAD ACCORDING TO RUSSIA'S OWN REPORTS, RUSSIAN PROPAGANDA, ETC."
lab var reason13RussiaFirst "RUSSIA FARTHER AHEAD BECAUSE MORE EMPHASIS AND SUPPORT FOR SCIENCE AND RESEARCH"
lab var reason14RussiaFirst "RUSSIA FARTHER AHEAD BECAUSE: MISCELLANEOUS REASONS"
lab var reason15RussiaFirst "RUSSIA FARTHER AHEAD BECAUSE: DON'T KNOW"
lab var reason16RussiaFirst "RUSSIA FARTHER AHEAD BECAUSE: NOT ASCERTAINED, BLANK"

rename q4 qualityJobUN
lab var qualityJobUN "IS THE UN DOING A GOOD OR A POOR JOB IN SOLVING THE PROBLEMS IT HAS HAD TO FACE"
lab def lb_GoodFairPoor 1 "GOOD" 2 "FAIR" 3 "POOR" 4 "DON'T KNOW"
lab val qualityJobUN lb_GoodFairPoor

rename q5 importanceUNsuccess
lab var importanceUNsuccess "IMPORTANCE OF TRYING TO MAKE THE UN A SUCCESS"
lab def lb_Important 1 "VERY IMPORTANT" 2 "FAIRLY IMPORTANT" 3 "NOT SO IMPORTANT" 4 "DON'T KNOW"
lab val importanceUNsuccess lb_Important

rename q6 CongressWork
lab var CongressWork "WHAT CONGRESS SHOULD DO WHEN IT MEETS AGAIN THIS JANUARY"
lab def lb_CongressWork 11 "Farm legislation: farm situation; prices stabilized; pre-help for farmers" ///
	12 "Labor legislation: law against strikes; better labor laws; clean out crookedness in unions" ///
	13 "Labor-management relations: better labor and management laws" ///
	14 "Budget legislation: cut budget; reduce spending; balance the budget" ///
	15 "Tax legislation: eliminate taxes; cut taxes; cut income tax, remove living tax; remove sales tax" ///
	16 "Cost of living: inflation; cut down on high cost of living; inflationary control" ///
	17 "Social welfare: take care of invalids and old people; pay welfare more money" ///
	18 "Employment legislation: more jobs for people" ///
	19 "Small business legislation: help to small businesses" ///
	21 "Housing legislation: better living facilities; building costs reduced; more money available for loans" ///
	22 "Public highway legislation" ///
	23 "Socialized medicine" ///
 	24 "Drug investigation: probe into the drug graft; reduce the price of medicine" ///
 	25 "High cost of medical care: doctor's, dental fees, etc." ///
 	26 "Space program: unification of outer space program; keep up with rockets and missiles" ///
	27 "Defense: stay prepared" ///
	28 "Peace program: keep U.S. out of war" ///
	29 "Anti-communist legislation" ///
	31 "Foreign aid: cut foreign aid" ///
	32 "Cost of government operation" ///
	33 "Veterans benefits, pensions" ///
	34 "Education: more for education - aid for public schools; increase teachers, salaries; build more schools" ///
	35 "Juvenile delinquency" ///
	36 "Prohibition: get rid of liquor" ///
	37 "Voting requirements: lower voting age" ///
	38 "Civil rights: give everyone equal rights" ///
	39 "Segregation: stop integration in schools" ///
	40 "Miscellaneous" ///
	41 "Don't know" ///
	99 "Nothing to write about"
lab val CongressWork lb_CongressWork

rename q7 presApprovala
label variable presApprovala "APPROVAL OF CURRENT PRESIDENT"
label define lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"
label values presApprovala lb_presApproval

rename q8a highestLivingStandard
rename q8b leaderInScience
rename q8c strongestMilitary
rename q8d happiestPeople
lab var highestLivingStandard "HIGHEST STANDARD OF LIVING IN 10 YEARS"
lab var leaderInScience "LEADING POSITION IN THE FIELD OF SCIENCE IN 10 YEARS"
lab var strongestMilitary "STRONGEST MILITARY FORCES IN 10 YEARS"
lab var happiestPeople "WILL OFFER THE MOST FOR THE HAPPINESS AND CONTENTMENT OF ORDINARY PEOPLE IN 10 YEARS"
lab def lb_Country 01 "UNITED STATES" 02 "RUSSIA" 03 "GREAT BRITAIN" 04 "CHINA" 05 "FRANCE" 06 "INDIA" 07 "ITALY" 08 "GERMANY (WEST GERMANY)" 09 "BOTH THE US AND RUSSIA" 10 "ALL OTHER COUNTRIES" 20 "DON'T KNOW, NOT ASCERTAINED"
lab val highestLivingStandard leaderInScience strongestMilitary happiestPeople lb_Country

rename q9 peaceWithRussia
lab var peaceWithRussia "POSSIBLE OR IMPOSSIBLE TO REACH A PEACEFUL SETTLEMENT OF DIFFERENCES WITH RUSSIA"

rename q20a dangerWar
lab var dangerWar "MUCH DANGER OF WAR, OR NOT MUCH DANGER"
lab def lb_dangerWar 1 "MUCH DANGER" 2 "NOT MUCH DANGER" 3 "DON'T KNOW"
lab val dangerWar lb_dangerWar

rename q20b sourceDangerWar
lab var sourceDangerWar "IF DANGER OF WAR, WILL IT ARISE THROUGH RUSSIA OR AMERICA"
lab def lb_sourceDangerWar 1 "RUSSIA" 2 "AMERICA" 3 "BOTH" 4 "OTHER" 5 "DON'T KNOW"
lab val sourceDangerWar lb_sourceDangerWar

rename q21a democratNom1_1960
lab var democratNom1_1960 "PREFERRED DEMOCRAT CANDIDATE FOR PRESIDENT IN 1960, FIRST CHOICE"
lab def lb_democratNom_1960 1 "EDMUND (PAT) BROWN, GOVERNOR OF CALIFORNIA" 2 "HUBERT HUMPHREY, SENATOR FROM MINNESOTA" 3 "ESTES KEFAUVER, SENATOR FROM TENNESSEE" 4 "LYNDON JOHNSON, SENATOR FROM TEXAS" 5 "JOHN KENNEDY, SENATOR FROM MASSACHUSETTS" 6 "ROBERT MEYNER, GOVERNOR OF NEW JERSEY" 7 "ADLAI STEVENSON, FORMER GOVERNOR OF ILLINOIS" 8 "STUART SYMINGTON, SENATOR FROM MISSOURI" 9 "G. MENNEN WILLIAMS, GOVERNOR OF MICHIGAN"
lab val democratNom1_1960 lb_democratNom_1960

rename q21b democratNom2_1960
lab var democratNom2_1960 "PREFERRED DEMOCRAT CANDIDATE FOR PRESIDENT IN 1960, SECOND CHOICE"
lab val democratNom2_1960 lb_democratNom_1960

rename q22 stevensonKennedy
lab var stevensonKennedy "PREFERRED DEMOCRAT CANDIDATE: STEVENSON VS KENNEDY"
lab def lb_stevensonKennedy 1 "STEVENSON" 2 "KENNEDY" 3 "NO OPINION"
lab val stevensonKennedy lb_stevensonKennedy

rename q23 stevensonSymington
lab var stevensonSymington "PREFERRED DEMOCRAT CANDIDATE: STEVENSON VS SYMINGTON"
lab def lb_stevensonSymington 1 "STEVENSON" 2 "SYMINGTON" 3 "NO OPINION"
lab val stevensonSymington lb_stevensonSymington

rename q24 kennedySymington
lab var kennedySymington "PREFERRED DEMOCRAT CANDIDATE: KENNEDY VS SYMINGTON"
lab def lb_kennedySymington 1 "KENNEDY" 2 "SYMINGTON" 3 "NO OPINION"
lab val kennedySymington lb_kennedySymington

rename q25 republicanNom1_1960
lab var republicanNom1_1960 "PREFERRED REPUBLICAN CANDIDATE FOR PRESIDENT IN 1960, FIRST CHOICE"
replace republicanNom1_1960 = . if republicanNom1_1960 == 8
lab def lb_republicanNom_1960 1 "BARRY GOLDWATER, SENATOR FROM ARIZONA" 2 "CHARLES HALLECK, CONGRESSMAN FROM INDIANA" 3 "CHRISTIAN HERTER, SECRETARY FO STATE" 4 "HENRY CABOT LODGE, JR., UNITED NATIONS DELEGATE" 5 "JAMES MITCHELL, SECRETARY OF LABOR" 6 "RICHARD NIXON, VICE-PRESIDENT" 7 "NELSON ROCKEFELLER, GOVERNOR OF NEW YORK"
lab val republicanNom1_1960 lb_republicanNom_1960

rename q25b republicanNom2_1960
lab var republicanNom2_1960 "PREFERRED REPUBLICAN CANDIDATE FOR PRESIDENT IN 1960, SECOND CHOICE"
replace republicanNom2_1960 = . if republicanNom2_1960 == 8
lab val republicanNom2_1960 lb_republicanNom_1960

rename q26 nixonRockefeller
lab var nixonRockefeller "PREFERRED REPUBLICAN CANDIDATE: NIXON VS ROCKEFELLER"
lab def lb_nixonRockefeller 1 "NIXON" 2 "ROCKEFELLER" 3 "NO OPINION"
lab val nixonRockefeller lb_nixonRockefeller

rename q27 rockefellerHerter
lab var rockefellerHerter "PREFERRED REPUBLICAN CANDIDATE: ROCKEFELLER VS HERTER"
lab def lb_rockefellerHerter 1 "ROCKEFELLER" 2 "HERTER" 3 "NO OPINION"
lab val rockefellerHerter lb_rockefellerHerter

rename q40a sizeFarms
lab var sizeFarms "PREFER LARGER FARMS (LIKE BIG BUSINESS) OR SMALLER FARMS (SMALL-SCALE FARMERS)"
lab def lb_sizeFarms 1 "GET SMALLER" 2 "STAY SMALL" 3 "NO OPINION"
lab val sizeFarms lb_sizeFarms

rename q41 treatmentFarmers
lab var treatmentFarmers "FAIR TREATMENT OF FARMERS OF THIS COUNTRY BY THE EISENHOWER ADMINISTRATION"

rename q43a surplusAgreement
lab var surplusAgreement "IF SURPLUS, PAY NORMAL SURPLUS AMOUNT TO FARMERS FOR THEM TO NOT GROW THIS SURPLUS"
lab def lb_GoodPoorInapp 1 "GOOD IDEA" 2 "POOR IDEA" 3 "NO OPINION" 9 "NO ANSWER, INAPPLICABLE"
lab val surplusAgreement lb_GoodPoorInapp

rename q45 activeParty
lab var activeParty "MOST ACTIVE PARTY IN NEIGHBORHOOD CURRENTLY"
lab def lb_activeParty 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "DON'T KNOW"
lab val activeParty lb_activeParty

rename q46 activePolitically
lab var activePolitically "ACTIVE PART IN POLITICS"
lab def lb_activePolitically 1 "YES, IN DEMOCRATIC PARTY" 2 "YES, IN REPUBLICAN PARTY" 3 "YES, IN OTHER PARTY" 4 "YES, UNDESIGNATED" 5 "NO, DO NOT"
lab val activePolitically lb_activePolitically

rename q47 alcoholBan
lab var alcoholBan "FAVOR OR OPPOSE A LAW FORBIDDING THE SALE OF ALL BEER, WINE, AND LIQUOR IN US"

rename q48a alcoholCons
lab var alcoholCons "EVER USE ALCOHOLIC BEVERAGES SUCH AS LIQUOR, WINE, OR BEER"

rename q48b1 beerCons
lab var beerCons "EVER USE BEER"

rename q48b2 wineCons
lab var wineCons "EVER USE WINE"

rename q48b3 liquorCons
lab var liquorCons "EVER USE LIQUOR"

rename q48b4 otherAlcoholCons
lab var otherAlcoholCons "EVER USE OTHER ALCOHOL"

rename q61ab stevensonRockefeller
lab var stevensonRockefeller "PREFERRED PRESIDENT: ADLAI STEVENSON (DEM) VS NELSON ROCKEFELLER (REP)"
lab def lb_stevensonRockefeller 1 "STEVENSON" 2 "ROCKEFELLER" 3 "OTHER CANDIDATE" 4 "UNDECIDED, NO ANSWER TO PART B" 5 "UNDECIDED, LEANS TOWARD STEVENSON" 6 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 7 "UNDECIDED, UNDECIDED"
lab val stevensonRockefeller lb_stevensonRockefeller

rename q62ab nixonKennedy
lab var nixonKennedy "PREFERRED PRESIDENT: RICHARD NIXON (REP) VS JOHN KENNEDY (DEM)"
lab def lb_nixonKennedy 1 "NIXON" 2 "KENNEDY" 3 "OTHER CANDIDATE" 4 "UNDECIDED, NO ANSWER TO PART B" 5 "UNDECIDED, LEANS TOWARD NIXON" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 7 "UNDECIDED, UNDECIDED"
lab val nixonKennedy lb_nixonKennedy

rename q63ab kennedyRockefeller
lab var kennedyRockefeller "PREFERRED PRESIDENT: JOHN KENNEDY (DEM) VS NELSON ROCKEFELLER (REP)"
lab def lb_kennedyRockefeller 1 "KENNEDY" 2 "ROCKEFELLER" 3 "OTHER CANDIDATE" 4 "UNDECIDED, NO ANSWER TO PART B" 5 "UNDECIDED, LEANS TOWARD KENNEDY" 6 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 7 "UNDECIDED, UNDECIDED"
lab val kennedyRockefeller lb_kennedyRockefeller

rename q64ab stevensonNixon
lab var stevensonNixon "PREFERRED PRESIDENT: ADLAI STEVENSON (DEM) VS RICHARD NIXON (REP)"
lab def lb_stevensonNixon 1 "STEVENSON" 2 "NIXON" 3 "OTHER CANDIDATE" 4 "UNDECIDED, NO ANSWER TO PART B" 5 "UNDECIDED, LEANS TOWARD STEVENSON" 6 "UNDECIDED, LEANS TOWARD NIXON" 7 "UNDECIDED, UNDECIDED"
lab val stevensonNixon lb_stevensonNixon

rename q65 attendChurch
lab var attendChurch "ATTENDED CHURCH OR SYNAGOGUE IN THE LAST 7 DAYS"

rename q66a createLife
lab var createLife "SCIENCE WILL EVER BE ABLE TO CREATE LIFE"

rename q66b earthDestroyed
lab var earthDestroyed "THE EARTH WILL EVER BE COMPLETELY DESTROYED"

rename q66c JesusReturn
lab var JesusReturn "JESUS CHRIST WILL EVER RETURN TO EARTH"

rename q66d JesusReturnDate
lab var JesusReturnDate "WHEN WILL JESUS CHRIST RETURN TO EARTH"
lab def lb_JesusReturnDate 1 "0 TO AND INCLUDING 25 YEARS (INCLUDING RIGHT AWAY)" 2 "26 TO AND INCLUDING 50 YEARS (INCLUDING TURN OF CENTURY)" 3 "51 TO AND INCLUDING 100 YEARS (INCLUDING IN NEXT CENTURY)" 4 "101 YEARS TO AND INCLUDING 500 YEARS" 5 "501 YEARS TO AND INCLUDING 1000 YEARS" 6 "1001 YEARS TO AND INCLUDING 2000 YEARS" 7 "DISTANT FUTURE, MILLIONS OF YEARS, OVER 2000 YEARS" 8 "JUDGEMENT DAY, ARMAGEDDON, END OF WORLD" 9 "SOON, IMMEDIATELY, NOT LONG" 10 "MISCELLANEOUS" 11 "DON'T KNOW, NO ONE KNOWS, UNDETERMINED" 20 "NOT ASCERTAINED, BLANK" 99 "INAPPLICABLE"
lab val JesusReturnDate lb_JesusReturnDate

rename q80a blkPresident
rename q80a1 baptistPresident
rename q80a2 jewPresident
rename q80a3 cathPresident
rename q80a4 atheistPresident
rename q80b womanPresident

rename q99 daysHome
lab var daysHome "NUMBER OF TIMES HOME, OUT OF LAST NIGHT/LAST SAT./LAST SUN."
lab def lb_daysHome 1 "AT HOME ONLY ONCE OF THE THREE DAYS SHOWN" 2 "AT HOME TWO DAYS OF THE THREE SHOWN" 3 "AT HOME ALL THREE DAYS" 4 "NOT AT HOME ANY OF THE THREE DAYS SHOWN"
lab val daysHome lb_daysHome

rename q100 telephone
lab var telephone "TELEPHONE IN HOME LISTED IN OWN NAME OR NAME OF IMMEDIATE FAMILY MEMBER"

rename q101 poliPartyID
lab var poliPartyID "PARTY ID IN POLITICS TODAY"
lab def  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
lab val poliPartyID lb_poliPartyID

rename q102ab partyCD
lab var partyCD "PREFERRED PARTY FOR CONGRESS"
lab def lb_partyCD 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, NO ANSWER TO PART B" 5 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 6 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 7 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 8 "UNDECIDED OR REFUSED, UNDECIDED" 9 "UNDECIDED OR REFUSED, REFUSED TO ANSWER"
replace partyCD = 4 if partyCD == 5
replace partyCD = partyCD - 1 if partyCD > 5
label values partyCD lb_partyCD

lab def lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
lab val religion lb_religion

rename q104 occupation
lab var occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
lab def lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
lab val occupation lb_occupation

rename q105 union
lab def lb_union 1 "YES, RESPONDENT IS" 2 "YES, SPOUSE IS" 3 "YES, BOTH ARE" 4 "NO, NEITHER IS"
lab val union lb_union

rename q106 edu
lab def lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
lab val edu lb_edu

rename q107 voteStevensonEisenhower
lab var voteStevensonEisenhower "ELECTION IN NOVEMBER 1956: VOTED FOR WHOM"
lab def lb_voteStevensonEisenhower 1 "STEVENSON" 2 "EISENHOWER" 3 "OTHER" 4 "VOTED, DON,T REMEMBER WHOM" 5 "NO, DIDN,T VOTE" 6 "DON,T REMEMBER IF VOTED" 0 "NO CODE OR NO DATA"
lab val voteStevensonEisenhower lb_voteStevensonEisenhower

rename q108 ownHome
lab var ownHome "DO YOU OWN OR RENT YOUR HOME"
lab def lb_ownHome 1 "OWN" 2 "RENT" 3 "OTHER ARRANGEMENT"
lab val ownHome lb_ownHome

rename q109_110 rentMonth
lab var rentMonth "RENT PER MONTH (ACTUAL OR PREDICTED IF RENTED HOME)"

rename q112 adultsHH
lab var adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
lab def lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
lab val adultsHH lb_adultsHH

rename q114 television
lab var television "TELEVISION SET AT HOME"

rename racegender raceSex
lab def lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "NEGRO MAN" 4 "NEGRO WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
lab val raceSex lb_raceSex 

rename socialstatus socialClass
lab var socialClass "SOCIAL CLASS THE RESPONDENT BELONGS TO"
lab def lb_socialClass 1 "LOWER" 2 "MIDDLE" 3 "UPPER"
lab val socialClass lb_socialClass

rename citysize citySize
lab def lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
lab val citySize lb_citySize

lab var section "SECTION OF COUNTRY THE RESPONDENT LIVES IN"
lab def lb_section 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTHERN" 6 "ROCKY MOUNTAIN" 7 "PACIFIC"
replace section = 5 if section == 8
lab val section lb_section

lab def lb_stateOld 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"
lab val state lb_stateOld
replace state = . if state == 0
replace state = state + 20 if (state == 81 | state == 82 | state == 83 | state == 84)
replace state = state + 10 if (state == 71 | state == 72 | state == 73 | state == 74 | state == 75)
replace state = state + 10 if (state == 61 | state == 62 | state == 63 | state == 64 | state == 65 | state == 66 | state == 67 | state == 68)
replace state = state - 40 if (state == 101 | state == 102 | state == 103 | state == 104)
lab def lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
lab val state lb_stateNew

rename interviewerno interviewerNo
lab var interviewerNo "INTERVIEWER NUMBER"

save "$ascii/622-1959.dta", replace
local svys `svys' 622-1959


*Gallup Poll # 1961-0649: Presidential Election/Electoral College [USAIPO1961-0649]
clear
infix ///
	card 1 ///
	deck 2-4 ///
	ballot 5-8 ///
	q1 9 ///
	q2a 10 ///
	q2b 11 ///
	q2c 12 ///
	q2d 13 ///
	q3 14 ///
	q4 15 ///
	q5 16 ///
	q6 17 ///
	q25 18 ///
	q26 19 ///
	q27 20 ///
	q28 21 ///
	q29a 22 ///
	q29b 23 ///
	q30 24 ///
	q31a 25 ///
	q31b 26 ///
	q31c 27 ///
	q32 28 ///
	q33 29 ///
	q34 30 ///
	q51 31 ///
	q52 32 ///
	q75 33 ///
	q76 34 ///
	q101 35 ///
	q102 36 ///
	q103 37 ///
	q104 38 ///
	q105 39-40 ///
	q106 41 ///
	q107 42 ///
	q108 43-44 ///
	n108 45 ///
	q110 46-47 ///
	q111 48-49 ///
	n113 50 ///
	raceSex 51 ///
	n115 54-55 ///
	n117 56-57 ///
	n118 58-59 ///
	wgt_timesAtHome 60 ///
	wgt_edu 61 ///
	using "$ascii/aipo0649.dat"
rename n117 state
rename q1 presApprovala
label variable presApprovala "KENNEDY JOB APPROVAL"
label define  lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label values presApprovala lb_presApproval
replace presApprovala = . if presApprovala == 0

label define  lb_yesNo 0 "No" 1 "Yes"
label define  lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define  lb_favOppNoOp 1 "FAVOR" 2 "OPPOSE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
replace q2a = 2-q2a
label values q2a lb_yesNo
rename q2a knowBerlin
label variable knowBerlin "KNOW ABOUT DISPUTE OVER BERLIN"

rename q2b BerlinApproval
label define  lb_BerlinApproval 1 "SATISFIED - HANDLING IT WELL, ETC." 2 "DISSATISFIED - NOT DOING ENOUGH, SHOULD BE TOUGHER" 3 "DISSATISFIED - GOING TOO FAR, WE MIGHT START A WAR" 4 "DISSATISFIED - GENERAL DISAPPROVAL" 5 "MISCELLANEOUS OTHERS" 6 "DONíT KNOW, NO OPINION" 7 "NO ANSWER, BLANK" 9 "INAPPLICABLE"
label values BerlinApproval lb_BerlinApproval
label variable BerlinApproval "FEEL ABOUT U.S. HANDLING OF THE BERLIN SITUATION"


rename q2c fightBerlin
label define  lb_opinion1 1 "YES, WILL" 2 "NO, WILL NOT" 3 "NO OPINION" 9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"
label values fightBerlin lb_opinion1
replace fightBerlin = . if fightBerlin == 0
label variable fightBerlin "HYPO: U.S. AND ALLIES FIGHT INTO BLOCKED BERLIN"

rename q2d warOverBerlin
label values warOverBerlin lb_opinion1

rename q3 nixonKennedy 
label define lb_nixonKennedy 1 "NIXON" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED, LEANS TOWARD NIXON" 5 "UNDECIDED, LEANS TOWARD KENNEDY" 6 "UNDECIDED, UNDECIDED" 0 "NO CODE OR NO DATA"
label values nixonKennedy lb_nixonKennedy
label variable nixonKennedy "NIXON vs KENNEDY (DECIDED)"

rename q4 rockefellerKennedy 
label define  lb_rockefellerKennedy 1 "ROCKEFELLER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 5 "UNDECIDED, LEANS TOWARD KENNEDY" 6 "UNDECIDED, UNDECIDED" 0 "NO CODE OR NO DATA"
label values rockefellerKennedy lb_rockefellerKennedy
label variable rockefellerKennedy "ROCKEFELLER vs KENNEDY (DECIDED)"

local vars nixonKennedy  rockefellerKennedy q5 q6 q25 q26 q27 q28
local vars `vars' q29a q29b q30 q31a q31b q31c q33 q51 q52 q75 q76 q103 q104 q106 q107 q108
local vars `vars' n108 q110 q111 n113 state warOverBerlin
foreach v in `vars' {
	replace `v' = . if `v' == 0
}

rename q5 nuclearAttack 
label variable nuclearAttack "PREPARE HOME FOR NUCLEAR ATTACK"
rename q6 prepNuclearAttack
label variable prepNuclearAttack "FOOD IN CASE OF NUCLEAR ATTACK"

local varYesNo nuclearAttack prepNuclearAttack q28 
foreach var in `varYesNo' {
	replace `var' = 2-`var'
	label values `var' lb_yesNo
}

rename q25 livingNuWar
label define  lb_livingNuWar 1 "VERY GOOD" 2 "POOR" 3 "50-50" 4 "NO OPINION" 0 "NO CODE OR NO DATA"
label values livingNuWar lb_livingNuWar
label variable livingNuWar "CHANCE SURVIVING NUCLEAR WAR"

rename q26 nuclearLocality
label define  lb_nuclearLocality 1 "YES" 2 "NO" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label values nuclearLocality lb_nuclearLocality
label variable nuclearLocality "CHANCE LOCALITY BOMBED"

rename q27 elecCollege 
label define  lb_elecCollege 1 "CORRECT ANSWER 'A BODY OF INDIVIDUALS ELECTED BY THE PEOPLE TO ELECT THE PRESIDENT OF THE U.S.' OR ANY FACSIMILE THEREOF." 2 "INCORRECT ANSWER" 3 "DONíT KNOW" 4 "NO ANSWER, BLANK" 0 "NO CODE OR NO DATA"
label values elecCollege lb_elecCollege
label variable elecCollege "UNDERSTAND ELECTORAL COLLEGE"

rename q28 chgElecCollege
label variable chgElecCollege "CHANGE ELECTORAL COLLEGE"
label define  lb_chgElecCollege 1 "GET ALL ELECTORAL VOTES" 2 "GET PROPORTION OF VOTES" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label values chgElecCollege lb_chgElecCollege

rename q29a undrstdLiberal
label variable undrstdLiberal "KNOW WHAT IS MEANT BY LIBERAL"
rename q29b undrstdConservative
label variable undrstdConservative "KNOW WHAT IS MEANT BY CONSERVATIVE"

rename q30 libConParty
label variable libConParty "CHOICE: LIBERAL OR CONSERVATIVE PARTY"
label define  lb_libConParty 1 "LIBERAL" 2 "CONSERVATIVE" 3 "NO OPINION"

rename q31a blkPresident 
rename q31b jewPresident
rename q31c cathPresident

foreach var in blkPresident jewPresident cathPresident {
	label values `var' lb_yesNoNoOp
}

rename q32 postOfficeDeficit
label variable postOfficeDeficit "POST OFFICE DEFICIT"
label define  lb_postOfficeDeficit 1 "RAISE POSTAGE - GENERAL" 2 "RAISE POSTAGE RATES OF 2ND, 3RD, 4TH, CLASS MAIL, BULK RATES, ADVERTISING, GET RID OF 'JUNK MAIL', GOVERNMENT MAIL SHOULD PAY" 3 "RUN POST OFFICE MORE EFFICIENTLY, STREAMLINE, CUT WASTE, PERSONNEL, ETC." 4 "SUBSIDIZE POST OFFICE, GIVE MORE MONEY, TAXES" 5 "DO SOMETHING, GENERAL, INVESTIGATE, AND STOP IT" 6 "DO NOTHING, LEAVE IT" 7 "TAKE THE POST OFFICE OUT OF POLITICS" 8 "MISCELLANEOUS OTHERS" 9 "DONíT KNOW" 0 "NO ANSWER"
label values postOfficeDeficit lb_postOfficeDeficit

rename q33 rateLocalMail
label variable rateLocalMail "4 CT TO 5 CT INCREASE RATE ON 1ST-CLASS LOCAL MAIL FOR POST OFFICE DEFICIT"
label values rateLocalMail lb_favOppNoOp

rename q34 rateAirLetters
label variable rateAirLetters "7 CT TO 8 CT INCREASE RATE ON AIR-MAIL LETTERS"
label values rateAirLetters lb_favOppNoOp

rename q51 regPartyID
label define lb_regPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "OTHER" 4 "INDEPENDENT" 5 "NOT REGISTERED"
label values regPartyID lb_regPartyID
label variable regPartyID "REGISTERED PARTY ID"

rename q52 curPartyID
label variable curPartyID "CURRENT PREFERED PARTY ID (IF HAD TO REGISTER)"
label define lb_curPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "OTHER PARTY, NO ANSWER TO PART B" 4 "INDEPENDENT, NO ANSWER TO PART B" 5 "OTHER PARTY OR INDEPENDENT, WOULD REGISTER AS REPUBLICAN" 6 "OTHER PARTY OR INDEPENDENT, WOULD REGISTER AS DEMOCRAT" 7 "OTHER PARTY OR INDEPENDENT, CAN'T DECIDE" 8 "OTHER PARTY OR INDEPENDENT, WOULD REFUSE TO REGISTER" 9 "UNDECIDED"
label values curPartyID lb_curPartyID

rename q75 africanU
label variable africanU "US ESTABLISHING A UNIVERSITY IN AFRICA"
label values africanU lb_favOppNoOp

rename q76 SEAsiaU
label variable SEAsiaU "US ESTABLISHING A UNIVERSITY IN SOUTHEAST ASIA"
label values SEAsiaU lb_favOppNoOp

rename q101 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID
replace poliPartyID = . if poliPartyID == 0

label define  lb_atHome 1 "AT HOME ONLY ONCE OF THE THREE DAYS SHOWN" 2 "AT HOME ONLY TWO DAYS OF THE THREE DAYS SHOWN" 3 "AT HOME ALL THREE DAYS" 4 "NOT AT HOME ANY OF THE THREE DAYS SHOWN" 0 "NOT ASCERTAINED, BLANK"
rename q102 atHome
label variable atHome "HOME YESTERDAY AT THIS TIME"
label values atHome lb_atHome

rename q103 religion
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

rename q104 partyCD
label variable partyCD "PREFERRED PARTY FOR CONGRESS"
label define lb_partyCD 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, NO ANSWER TO PART B" 5 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 6 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 7 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 8 "UNDECIDED OR REFUSED, UNDECIDED" 9 "UNDECIDED OR REFUSED, REFUSED TO ANSWER"
label values partyCD lb_partyCD

rename q105 occupation
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q106 edu
label define lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
label values edu lb_edu

rename q107 voteNixonKennedy
label define  lb_voteNixonKennedy 1 "KENNEDY" 2 "NIXON" 3 "OTHER" 4 "VOTED, DONíT REMEMBER WHOM" 5 "NO, DIDNíT VOTE" 6 "DONíT REMEMBER IF VOTED" 7 "REFUSED TO ANSWER" 0 "NO CODE OR NO DATA"
label values voteNixonKennedy lb_voteNixonKennedy

rename q108 incomeHH_1961
label define lb_incomeHH_1961 1 "UNDER $500" 2 "$500 - $999" 3 "$1,000 - $1,499" 4 "$1,500 - $1,999" 5 "$2,000 - $2,499" 6 "$2,500 - $2,999" 7 "$3,000 - $3,999" 8 "$4,000 - $4,999" 9 "$5,000 - $6,999" 10 "$7,000 - $9,999" 11 "$10,000 - $14,999" 12 "$15,000 AND OVER"
label values incomeHH_1961 lb_incomeHH_1961

	gen incomeHHharmonized = .
	replace incomeHHharmonized = 250 if incomeHH_1961 == 1
	replace incomeHHharmonized = 750 if incomeHH_1961 == 2
	replace incomeHHharmonized = 1250 if incomeHH_1961 == 3
	replace incomeHHharmonized = 1750 if incomeHH_1961 == 4
	replace incomeHHharmonized = 2250 if incomeHH_1961 == 5
	replace incomeHHharmonized = 2750 if incomeHH_1961 == 6
	replace incomeHHharmonized = 3500 if incomeHH_1961 == 7
	replace incomeHHharmonized = 4500 if incomeHH_1961 == 8
	replace incomeHHharmonized = 6000 if incomeHH_1961 == 9
	replace incomeHHharmonized = 8500 if incomeHH_1961 == 10
	replace incomeHHharmonized = 12500 if incomeHH_1961 == 11
	replace incomeHHharmonized = 15000 if incomeHH_1961 == 12

rename n108 svyIncomeHH
label define lb_svyIncomeHH 1 "RESPONSE" 2 "ESTIMATE" 0 "NOT RECORDED" 
label values svyIncomeHH lb_svyIncomeHH

rename q110 adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define  lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH
replace adultsHH = . if adultsHH == 0

rename q111 age

rename n113 farmProperty
label define  lb_farmProperty 1 "CITY, TOWN, OR RURAL NON-FARM PROPERTY" 2 "FARM PROPERTY" 0 "NOT RECORDED"
label values farmProperty lb_farmProperty

label define  lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "NEGRO MAN" 4 "NEGRO WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

rename n115 citySize
label define  lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

label define lb_stateOld 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 0 "NO CODE OR NO DATA"
label values state lb_stateOld
replace state = . if state == 0
replace state = state + 20 if (state == 81 | state == 82 | state == 83 | state == 84)
replace state = state + 10 if (state == 71 | state == 72 | state == 73)
replace state = state + 10 if (state == 61 | state == 62 | state == 63 | state == 64 | state == 65 | state == 66 | state == 67 | state == 68)
replace state = state - 40 if (state == 101 | state == 102 | state == 103 | state == 104)
label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

gen svy_year = 1961
gen svy_month = "August"
gen svy = "1961-0649"

save "$ascii/649-1961.dta", replace 
local svys `svys' 649-1961


*Gallup Poll # 1962-0655: Work Week/Politics [USAIPO1962-0655]
clear 
infix 2 lines 1: ///
	card 1 ///
	deck 2-4 ///
	ballot 5-8 ///
	q1 9 ///
	q2a 10 ///
	q2b 11 ///
	q3a 12 ///
	q3b 13 ///
	q3c 14 ///
	q3d 15 ///
	q3e 16 ///
	q3f 17 ///
	q3g 18 ///
	q3h 19 ///
	q3i 20 ///
	q4a 21 ///
	q4b 22 ///
	q6a 23 ///
	q7 24 ///
	q25a 25 ///
	q25b 26 ///
	q25c 27 ///
	q25d 28 ///
	q26a 29-30 ///
	q26b 31-32 ///
	q27 33 ///
	q28 34 ///
	q29 35 ///
	q30a 36 ///
	q50 37-38 ///
	q51 39 ///
	q52 40 ///
	q54a 41 ///
	q101 42 ///
	q102 43 ///
	q103 44 ///
	q104a 45 ///
	q104c 46 ///
	q104d 47-48 ///
	q104e1 49 ///
	q104e2 50 ///
	q104e3 51 ///
	q104e4 52 ///
	q104e5 53 ///
	q104e6 54 ///
	q104f1 55 ///
	q104f2 56 ///
	q104f3 57 ///
	q104f4 58 ///
	q104f5 59 ///
	q104f6 60 ///
	q104f7 61 ///
	q104f8 62 ///
	q104f9 63 ///
	q104f10 64 ///
	q104f11 65 ///
	q104f12 66 ///
	q104f13 67 ///
	q104f14 68 ///
	q104f15 69 ///
	q105 70-71 ///
	q106 72 ///
	q107 73 ///
	q108 74-75 ///
	n108 76 ///
	2: ///
	card2 1 ///
	deck2 2-4 ///
	ballot2 5-8 ///
	q110 9-10 ///
	child 11-12 ///
	numHH 13-14 ///
	age 15-16 ///
	raceSex 18 ///
	n114 19-20 ///
	n115 22-23 ///
	state 24-25 ///
	n118 26-27 ///
	wgt_edu 28 ///
	wgt_timesAtHome 29 ///
	using "$ascii/aipo0655.dat"
gen svy_year = 1962
gen svy_month = "February"
gen svy = "1962-0655"

label define  lb_yesNo 0 "No" 1 "Yes"
label define  lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion"
label define  lb_favOppNoOp 1 "FAVOR" 2 "OPPOSE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_appDisapp 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_shouldNot 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 0 "NO CODE OR NO DATA"  
label define  lb_yesNoRem 1 "Yes" 2 "NO" 3 "Don't Remember" 4 "NO CODE OR NO DATA"

local varMissing q1 q2a q2b q4a q4b q6a q7 q25a q25b q25c q25d q26a q27 q28 q29
local varMissing `varMissing' q30a q51 q52 q54a q101 q103 q104a q104c q104d q106
local varMissing `varMissing' q107 q108 n108 q110 child numHH age state 
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNo q54a 
foreach var in `varYesNo' {
	replace `var' = 2-`var'
	label values `var' lb_yesNo
}

local varAppDisapp q2a q2b q30a
foreach var in `varAppDisapp' {
	label values `var' lb_appDisapp
}

local varShouldNot q4a
foreach var in `varShouldNot' {
	label values `var' lb_shouldNot
}

rename q1 presApprovala
label define  lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label variable presApprovala "KENNEDY JOB APPROVAL"
label values presApprovala lb_presApproval

rename q2a presForeign
label variable presForeign "KENNEDY FOREIGN POLICY JOB APPROVAL"
rename q2b presDomestic 
label variable presDomestic "KENNEDY DOMESTIC POLICY JOB APPROVAL"
label values presForeign lb_presApproval
label values presDomestic lb_presApproval

rename q3a frdlyIndia
label variable frdlyIndia "INDIA, FRIENDLY TO THE UNITED STATES"
rename q3b frdlyIndonesia
label variable frdlyIndonesia "INDONESIA, FRIENDLY TO THE UNITED STATES"
rename q3c frdlyJapan
label variable frdlyJapan "JAPAN, FRIENDLY TO THE UNITED STATES"
rename q3d frdlyPakistan
label variable frdlyPakistan "PAKISTAN, FRIENDLY TO THE UNITED STATES"
rename q3e frdlySKorea
label variable frdlySKorea "SOUTH KOREA, FRIENDLY TO THE UNITED STATES"
rename q3f frdlyThailand
label variable frdlyThailand "THAILAND, FRIENDLY TO THE UNITED STATES"
rename q3g frdlyPhilippines
label variable frdlyPhilippines "PHILIPPINES, FRIENDLY TO THE UNITED STATES"

rename q4a fourtyHrWk
label variable fourtyHrWk "REDUCED WORK WEEK FROM 40 HOURS TO 35 HOURS"

rename q4b pay30HrWk 
label variable pay30HrWk "REDUCED WORK WEEK FROM 40 HOURS TO 35 HOURS"
label define  lb_pay30HrWk 1 "PAID FOR 40 HOURS" 2 "PAID FOR 35 HOURS" 3 "NO OPINION" 9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"
label values pay30HrWk lb_pay30HrWk

rename q6a tvChildren 
label variable tvChildren "INFLUENCE OF T.V. ON YOUR OWN CHILDREN"
label define  lb_tvChildren 1 "MORE GOOD" 2 "MORE POOR" 3 "NO DIFFERENCE" 4 "DONíT HAVE CHILD/CHILDREN" 5 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label values tvChildren lb_tvChildren

rename q7 importRestr
label variable importRestr "RESTRICTIONS ON GOODS IMPORTED"
label define  lb_importRestr 1 "IMPORT MORE" 2 "MORE RESTRICTIONS" 3 "DO ABOUT AS WE ARE NOW" 4 "DEPENDS" 5 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label values importRestr lb_importRestr

rename q25a importTextiles
rename q25b importOil
rename q25c importAutomobiles
rename q25d importSteel
foreach var in Textiles Oil Automobiles Steel {
	label variable import`var' "RESTRICTIONS ON `var' IMPORTED"
	label values import`var' lb_importRestr
}

rename q26a republicanNom1st
label variable republicanNom1st "PREFERRED REPUBLICAN CANDIDATE FOR PRESIDENT, FIRST CHOICE"
label define  lb_republicanNom 1 "ROBERT ANDERSON, FORMER SECRETARY OF THE TREASURY" 2 "EVERETT DIRKSEN, SENATOR FROM ILLINOIS" 3 "MILTON EISENHOWER, PRESIDENT OF JOHNS HOPKINS UNIVERSITY" 4 "BARRY GOLDWATER, SENATOR FROM ARIZONA" 5 "CHARLES HALLECK, CONGRESSMAN FROM INDIANA" 6 "MARK HATFIELD, GOVERNOR OF OREGON" 7 "RICHARD NIXON, FORMER VICE PRESIDENT" 8 "NELSON ROCKEFELLER, GOVERNOR OF NEW YORK" 9 "GEORGE ROMNEY, PRESIDENT OF AMERICAN MOTORS CORP." 10 "FREDERICK SEATON, FORMER SECRETARY OF THE INTERIOR" 11 "DONíT KNOW, NO ANSWER" 0 "NO CODE OR NO DATA"
label values republicanNom1st lb_republicanNom

rename q26b republicanNom2nd
label variable republicanNom2nd "PREFERRED REPUBLICAN CANDIDATE FOR PRESIDENT, SECOND CHOICE"
label values republicanNom2nd lb_republicanNom

rename q27 goldwaterRockefeller
label variable goldwaterRockefeller "PREFERRED REPUBLICAN CANDIDATE: GOLDWATER VS ROCKEFELLER"
label define  lb_goldwaterRockefeller 1 "GOLDWATER" 2 "ROCKEFELLER" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label values goldwaterRockefeller lb_goldwaterRockefeller

rename q28 inflReligion
label variable inflReligion "CHANGING INFLUCENCE OF RELIGION"
label define  lb_inflReligion 1 "INCREASING" 2 "LOSING" 3 "SAME" 4 "NO OPINION" 0 "NO CODE OR NO DATA"
label values inflReligion lb_inflReligion

rename q29 largeCityIssues
label variable largeCityIssues "RESPONSIBILITY FOR PROBLEMS OF LARGE CITIES: FED GOVT OR CITIES"
label define  lb_largeCityIssues 1 "FEDERAL GOVERNMENT" 2 "CITIES" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label values largeCityIssues lb_largeCityIssues

rename q30a approWeaver
label variable approWeaver "KENNEDY'S CHOICE OF WEAVER"

rename q50 idealChildren
label variable idealChildren "IDEAL NUMBER OF CHILDREN"
label define  lb_idealChildren 1 "ONE CHILD" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE" 11 "AS MANY AS YOU CAN HAVE, AS MANY AS YOU CAN AFFORD" 12 "NO OPINION"
label values idealChildren lb_idealChildren

rename q51 militaryForeign
label variable militaryForeign "MILITARY LEADERS, FREE SPEECH, FOREIGN POLICY"
label define  lb_militaryForeign 1 "ONE CHILD" 2 "TWO" 3 "THREE" 4 "FOUR"
label values militaryForeign lb_militaryForeign

rename q52 fedIncomeTax
label variable fedIncomeTax "LEVEL OF PERSONAL FEDERAL INCOME TAX"
label define  lb_fedIncomeTax 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION"
label values fedIncomeTax lb_fedIncomeTax

rename q54a religionExp
label variable religionExp "HAD RELIGIOUS OR MYSTICAL EXPERIENCE"

rename q101 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

label define  lb_atHome 1 "AT HOME ONLY ONCE OF THE THREE DAYS SHOWN" 2 "AT HOME ONLY TWO DAYS OF THE THREE DAYS SHOWN" 3 "AT HOME ALL THREE DAYS" 4 "NOT AT HOME ANY OF THE THREE DAYS SHOWN" 0 "NOT ASCERTAINED, BLANK"
rename q102 atHome
label variable atHome "HOME YESTERDAY AT THIS TIME (`vv')"
label values atHome lb_atHome

rename q103 religion
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

rename q104a partyCD
label variable partyCD "PREFERRED PARTY FOR CONGRESS"
label define lb_partyCD 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, NO ANSWER TO PART B" 5 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 6 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 7 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 8 "UNDECIDED OR REFUSED, UNDECIDED" 9 "UNDECIDED OR REFUSED, REFUSED TO ANSWER"
label values partyCD lb_partyCD

rename q104c voteRepuCongress
label variable voteRepuCongress "EVER VOTED FOR REPUBLICAN CONGRESSIONAL CANDIDATE"
label values voteRepuCongress lb_yesNoRem

rename q104d timeVoteRepuCong
label variable timeVoteRepuCong "LAST TIME VOTED FOR REPUBLICAN CONGRESSIONAL CANDIDATE"

rename q104e1 voteRepuQualified
label variable voteRepuQualified "REASON FOR VOTING REPUBLICAN: QUALIFIED"
rename q104e2 voteRepuRepublican
label variable voteRepuRepublican "REASON FOR VOTING REPUBLICAN: REPUBLICAN"
rename q104e3 voteRepuPlatform
label variable voteRepuPlatform "REASON FOR VOTING REPUBLICAN: PLATFORM"
rename q104e4 voteRepuConservative
label variable voteRepuConservative "REASON FOR VOTING REPUBLICAN: CONSERVATIVE"
rename q104e5 voteRepuMisc
label variable voteRepuMisc "REASON FOR VOTING REPUBLICAN: MISCELLANEOUS"
rename q104e6 voteRepuDontKnow
label variable voteRepuDontKnow "REASON FOR VOTING REPUBLICAN: DONíT KNOW" 

rename q104f1 chgtoRepuSincere
label variable chgtoRepuSincere "WHICH TO REPUBLICAN VOTE: SINCERE MAN"
rename q104f2 chgtoRepuPeace
label variable chgtoRepuPeace "WHICH TO REPUBLICAN VOTE: KEEP OUT OF WAR"
rename q104f3 chgtoRepuLowerTaxes
label variable chgtoRepuLowerTaxes "WHICH TO REPUBLICAN VOTE: LOWER TAXES"
rename q104f4 chgtoRepuFarmers
label variable chgtoRepuFarmers "WHICH TO REPUBLICAN VOTE: HELP THE FARMER"
rename q104f5 chgtoRepuWrkPpl
label variable chgtoRepuWrkPpl "WHICH TO REPUBLICAN VOTE: CREATE MORE JOBS"
rename q104f6 chgtoRepuPlatform
label variable chgtoRepuPlatform "WHICH TO REPUBLICAN VOTE: GOOD PLATFORM"
rename q104f7 chgtoRepuSame
label variable chgtoRepuSame "WHICH TO REPUBLICAN VOTE: KEEP ON"
rename q104f8 chgtoRepuNothing
label variable chgtoRepuNothing "WHICH TO REPUBLICAN VOTE: NOTHING ANYTHING"
rename q104f9 chgtoRepuBttrDem
label variable chgtoRepuBttrDem "WHICH TO REPUBLICAN VOTE: BETTER PLATFORM THAN DEMOCRATS"
rename q104f10 chgtoRepuRepPrinc
label variable chgtoRepuRepPrinc "WHICH TO REPUBLICAN VOTE: STICK TO PRINCIPLES"
rename q104f11 chgtoRepuSegregation
label variable chgtoRepuSegregation "WHICH TO REPUBLICAN VOTE: FIGHT SEGREGATION"
rename q104f12 chgtoRepuMedAged
label variable chgtoRepuMedAged "WHICH TO REPUBLICAN VOTE: MEDICAL CARE FOR AGED"
rename q104f13 chgtoRepuMisc
label variable chgtoRepuMisc "WHICH TO REPUBLICAN VOTE: MISCELLANEOUS"
rename q104f14 chgtoRepuDontKnow
label variable chgtoRepuDontKnow "WHICH TO REPUBLICAN VOTE: DONíT KNOW"

rename q105 occupation
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q106 edu
label define lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
label values edu lb_edu

rename q107 voteNixonKennedy
label define  lb_voteNixonKennedy 1 "KENNEDY" 2 "NIXON" 3 "OTHER" 4 "VOTED, DONíT REMEMBER WHOM" 5 "NO, DIDNíT VOTE" 6 "DONíT REMEMBER IF VOTED" 7 "REFUSED TO ANSWER" 0 "NO CODE OR NO DATA"
label values voteNixonKennedy lb_voteNixonKennedy

rename q108 incomeHH_60s
label define lb_incomeHH_60s 1 "UNDER 1000 DOLLARS A YEAR OR UNDER $20 A WEEK" 2 "1,000 TO 1,499 A YEAR OR $20 TO $28.50 A WEEK" 3 "1,500 TO 1,999 A YEAR OR $29 TO $37.50 A WEEK" 4 "2,000 TO 2,499 A YEAR OR $38 TO $47.50 A WEEK" 5 "2,500 TO 2,999 A YEAR OR $48 TO $57.50 A WEEK" 6 "3,000 TO 3,999 A YEAR OR $58 TO $76.50 A WEEK" 7 "4,000 TO 4,999 A YEAR OR $77 TO $95.50 A WEEK" 8 "5,000 TO 6,999 A YEAR OR $96 TO $134.50 A WEEK" 9 "7,000 TO 9,999 A YEAR OR $135 TO $192.50 A WEEK" 10 "10,000 TO 14,999 A YEAR OR $193 TO $288.50 A WEEK" 11 "15,000 AND OVER A YEAR OR $289 AND MORE A WEEK"
label values incomeHH_60s lb_incomeHH_60s

	gen incomeHHharmonized = .
	replace incomeHHharmonized = 500 if incomeHH_60s == 1
	replace incomeHHharmonized = 1250 if incomeHH_60s == 2
	replace incomeHHharmonized = 1750 if incomeHH_60s == 3
	replace incomeHHharmonized = 2250 if incomeHH_60s == 4
	replace incomeHHharmonized = 2750 if incomeHH_60s == 5
	replace incomeHHharmonized = 3500 if incomeHH_60s == 6
	replace incomeHHharmonized = 4500 if incomeHH_60s == 7
	replace incomeHHharmonized = 6000 if incomeHH_60s == 8
	replace incomeHHharmonized = 8500 if incomeHH_60s == 9
	replace incomeHHharmonized = 12500 if incomeHH_60s == 10
	replace incomeHHharmonized = 15000 if incomeHH_60s == 11

rename n108 svyIncomeHH
label define lb_svyIncomeHH 1 "RESPONSE" 2 "ESTIMATE" 0 "NOT RECORDED" 
label values svyIncomeHH lb_svyIncomeHH

rename q110 adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define  lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

rename child minorsHH
label variable minorsHH "NUMBER OF CHILDREN (MINORS) LIVING IN THIS HOUSEHOLD"
label define lb_minorsHH 1 "ONE CHILD" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE" 11 "NO MINOR CHILDREN"
label values minorsHH lb_minorsHH

label values numHH lb_adultsHH

label define  lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "NEGRO MAN" 4 "NEGRO WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

rename n115 citySize
label define  lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

label define lb_stateOld 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 0 "NO CODE OR NO DATA"
label values state lb_stateOld
replace state = . if state == 0
replace state = state + 20 if (state == 81 | state == 82 | state == 83 | state == 84)
replace state = state + 10 if (state == 71 | state == 72 | state == 73)
replace state = state + 10 if (state == 61 | state == 62 | state == 63 | state == 64 | state == 65 | state == 66 | state == 67 | state == 68)
replace state = state - 40 if (state == 101 | state == 102 | state == 103 | state == 104)
label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/655-1962.dta", replace 
local svys `svys' 655-1962


*Gallup Poll # 1963-0676: Russian Nuclear Weapons Testing/1964 Presidential Election [USAIPO1963-0676]
clear 
infix 2 lines 1: ///
	card 1 ///
	deck 2-4 ///
	ballot 5-8 ///
	q1 9 ///
	q2 10 ///
	q3a 11 ///
	q3b 12 ///
	q3c1 13 ///
	q3c2 14 ///
	q3c3 15 ///
	q3c4 16 ///
	q3c5 17 ///
	q3c6 18 ///
	q3c7 19 ///
	q3c8 20 ///
	q3c9 21 ///
	q3c10 22 ///
	q3c11 23 ///
	q3c12 24 ///
	q3c13 25 ///
	q3c14 26 ///
	q3c15 27 ///
	q3c16 28 ///
	q3c17 29 ///
	q3c18 30 ///
	q3c19 31 ///
	q3c20 32 ///
	q4 33 ///
	q5a 34 ///
	q5b 35 ///
	q6 42-44 ///
	q7 45 ///
	q8 46 ///
	q9 47 ///
	q10 48 ///
	q11a 49 ///
	q11b 50 ///
	q11c 51 ///
	q11d 52 ///
	q11e 53 ///
	q11f 54 ///
	q11g 55 ///
	q11h 56 ///
	q11i 57 ///
	q11j 58 ///
	q11k 59 ///
	q11l 60 ///
	q12a 61 ///
	q12b 62 ///
	q13 63 ///
	q14 64 ///
	q15b 65 ///
	q16b 66 ///
	q17b 67 ///
	q31a 68 ///
	q31b 69 ///
	q31c 70 ///
	q31d 71 ///
	q62 72 ///
	q63a 73 ///
	q63b 74 ///
	q64 75 ///
	q101 76 ///
	q102 77 ///
	q103 78 ///
	q104 79-80 ///
	2: ///
	card2 1 ///
	deck2 2-4 ///
	ballot2 5-8 ///
	q106 9 ///
	q107 10 ///
	q108 11 ///
	q109 12 ///
	q110 13-14 ///
	q112 15-16 ///
	q113 17-18 ///
	num_hh 19-20 ///
	child1 21 ///
	child2 22 ///
	child3 23 ///
	child4 24 ///
	child5 25 ///
	child6 26 ///
	age 27-28 ///
	raceSex 29 ///
	n117 30-31 ///
	state 32-33 ///
	interNum 34-35 ///
	wgt_timesAtHome 36 ///
	wgt_edu 37 ///
	using "$ascii/aipo0676.dat"
gen svy_year = 1963
gen svy_month = "August"
gen svy = "1963-0676"

label define  lb_yesNo 0 "No" 1 "Yes"
label define  lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define  lb_favOppNoOp 1 "FAVOR" 2 "OPPOSE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_appDisapp 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_agrDisagr 1 "AGREE" 2 "DISAGREE" 3 "NO OPINION"  9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"
label define  lb_shouldNot1 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 0 "NO CODE OR NO DATA" 
label define  lb_shouldNot2 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"  
label define  lb_yesNoRem 1 "Yes" 2 "NO" 3 "Don't Remember" 4 "NO CODE OR NO DATA"
label define  lb_UpDown 1 "GO UP" 2 "GO DOWN" 3 "REMAIN SAME" 4 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_PosImpos 1 "POSSIBLE" 2 "IMPOSSIBLE" 3 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_GoodPoor 1 "GOOD IDEA" 2 "POOR IDEA" 3 "NO OPINION" 0 "NO CODE OR NO DATA"

rename num_hh numHH
local varMissing q1 q2 q5a q5b q7 q9 q10 q11k q11l q13 q14 q15 q16 q17 q31b q31c
local varMissing `varMissing' q31d q62 q63a q63b q101 q103 q106 q107 q108 q109 q110
local varMissing `varMissing' q112 q113 numHH age
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNo q3a q5a q107 
foreach var in `varYesNo' {
	replace `var'  = 2-`var'
	label values `var' lb_yesNo
}

local varAppDisapp q1
foreach var in `varAppDisapp' {
	label values `var' lb_appDisapp
}

local varShouldNot1 q4
foreach var in `varShouldNot1' {
	label values `var' lb_shouldNot1
}

local varShouldNot2 q3b
foreach var in `varShouldNot2' {
	label values `var' lb_shouldNot2
}

replace q31a = 3 if q31a == 0
local varYesNoNoOp q31a q31b q31c q31d q63a q64
foreach var in `varYesNoNoOp' {
	label values `var' lb_yesNoNoOp
}

local varAgrDisagr q63b
foreach var in `varAgrDisagr' {
	label values `var' lb_agrDisagr
}

rename q1 presApprovala
label define  lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label variable presApprovala "KENNEDY JOB APPROVAL"
label values presApprovala lb_presApproval 
replace presApprovala = . if presApprovala == 3
replace presApprovala = 3 if presApprovala == 4

rename q2 integrationRate
label variable integrationRate "OPINION: SPEED OF RACIAL INTEGRATION"
label define  lb_integrationRate 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA"
label values integrationRate lb_integrationRate

rename q3a nuclearBan
label variable nuclearBan "KNOW ABOUT U.S. RUSSIAN NUCLEAR WEAPONS PARTIAL BAN"

rename q3b approNuclearBan
label variable approNuclearBan "SENATE APPROVE U.S. RUSSIAN NUCLEAR WEAPONS PARTIAL BAN"

rename q4 USRussiaForces
label variable USRussiaForces "U.S. RUSSIA AGREE TO REDUCE THEIR ARMAMENTS"

rename q5a knRightsRally
label variable knRightsRally "HEARD ABOUT MASS CIVIL RIGHTS RALLY"

rename q5b flRightsRally
label variable flRightsRally "FEELINGS ABOUT MASS CIVIL RIGHTS RALLY"
label define  lb_flRightsRally 1 "FAVORABLE" 2 "UNFAVORABLE - GENERAL" 3 "UNFAVORABLE - PREDICT VIOLENCE" 4 "UNFAVORABLE ñ WONíT ACCOMPLISH ANYTHING" 5 "NO OPINION - UNDECIDED" 9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"
label values flRightsRally lb_flRightsRally

rename q6 basicIncome
label variable basicIncome "MIN. INCOME: TWO-ADULT TWO-CHILD"

rename q7 compBasicIncome 
label variable compBasicIncome "HH INCOME VS 4 PERSON MIN. INCOME"
label define  lb_compBasicIncome 1 "FAVORABLE" 2 "UNFAVORABLE - GENERAL" 3 "UNFAVORABLE - PREDICT VIOLENCE" 4 "UNFAVORABLE ñ WONíT ACCOMPLISH ANYTHING" 5 "NO OPINION - UNDECIDED"
label values compBasicIncome lb_compBasicIncome

rename q8 chgUnempl
label variable chgUnempl "EXPECTED CHANGE IN UNEMPLOYMENT RATE"
label values chgUnempl lb_UpDown

rename q9 chgPrice
label variable chgPrice "EXPECTED CHANGE IN PRICES"
label values chgPrice lb_UpDown

rename q10 peaceRussia
label variable peaceRussia "PEACEFUL SETTLEMENT WITH RUSSIA" 
label values peaceRussia lb_PosImpos 

rename q11a whoNixon
label variable whoNixon "WHO IS NIXON"
label define  lb_whoNixon 1 "CORRECT: LAWYER, FORMER VICE-PRESIDENT, FORMER CANDIDATE FOR PRESIDENT, FORMER CANDIDATE, GOVERNOR OF CALIFORNIA" 2 "PARTLY CORRECT: POLITICIAN, 'KNOW WHO HE IS'" 3 "INCORRECT" 4 "DONíT KNOW"
label values whoNixon lb_whoNixon

rename q11b whoCase
label variable whoCase "WHO IS CLIFFORD CASE"
label define  lb_whoCase 1 "CORRECT: U.S. SENATOR FROM NEW JERSEY" 2 "PARTLY CORRECT: POLITICIAN, 'KNOW WHO HE IS'" 3 "INCORRECT" 4 "DONíT KNOW"
label values whoCase lb_whoCase

rename q11c whoGlenn
label variable whoGlenn "WHO IS JOHN GLENN"
label define  lb_whoGlenn 1 "CORECT: SPACEMAN, ASTRONAUT, BOY SCOUT" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DONíT KNOW"
label values whoGlenn lb_whoGlenn

rename q11d whoRockefeller
label variable whoRockefeller "WHO IS ROCKEFELLER"
label define  lb_whoRockefeller 1 "CORRECT: GOVERNOR OF NEW YORK, CANDIDATE FOR PRESIDENT" 2 "PARTLY CORRECT: POLITICIAN, 'HEARD OF HIM', 'RECENTLY MARRIED'" 3 "INCORRECT" 4 "DONíT KNOW"
label values whoRockefeller lb_whoRockefeller

rename q11e whoMorton
label variable whoMorton "WHO IS THRUSTON MORTON"
label define  lb_whoMorton 1 "CORRECT: U.S. SENATOR FROM KENTUCKY, MENTIONED AS A PRESIDENTIAL CANDIDATE, FORMER CHAIRMAN OF REPUBLICAN NATIONAL COMMITTEE" 2 "PARTLY CORRECT: POLITICIAN, 'HEARD OF HIM'" 3 "INCORRECT" 4 "DONíT KNOW"
label values whoMorton lb_whoMorton

rename q11f whoRomney
label variable whoRomney "WHO IS GEORGE ROMNEY"
label define  lb_whoRomney 1 "CORRECT: GOVERNOR OF MICHIGAN, PRESIDENTIAL CANDIDATE, FORMER HEAD OF AMERICAN MOTORS" 2 "PARTLY CORRECT: POLITICIAN, 'HEARD OF HIM'" 3 "INCORRECT" 4 "DONíT KNOW"
label values whoRomney lb_whoRomney

rename q11g whoTaylor
label variable whoTaylor "WHO IS ELIZABETH TAYLOR"
label define  lb_whoTaylor 1 "CORRECT: ACTRESS IN FILMS, CLEOPATRA" 2 "PARTLY CORRECT" 3 "INCORRECT" 4 "DONíT KNOW"
label values whoTaylor lb_whoTaylor

rename q11h whoStassen
label variable whoStassen "WHO IS HAROLD STASSEN"
label define  lb_Stassen 1 "CORRECT: FORMER GOVERNOR OF MINNESOTA, PRESIDENTIAL CANDIDATE, MEMBER OF EISENHOWER ADMINISTRATION, FOE OF NIXON, CANDIDATE FOR MAYOR OF PHILADELPHIA" 2 "PARTLY CORRECT: POLITICIAN, 'HEARD OF HIM'" 3 "INCORRECT" 4 "DONíT KNOW"
label values whoStassen lb_Stassen

rename q11i whoHatfield
label variable whoHatfield "WHO IS MARK HATFIELD"
label define  lb_whoHatfield 1 "CORRECT: GOVERNOR OF OREGON, WESTERN STATE CANDIDATE FOR PRESIDENT, VICE-PRESIDENT" 2 "PARTLY CORRECT: POLITICIAN, 'HEARD OF HIM'" 3 "INCORRECT" 4 "DONíT KNOW"
label values whoHatfield lb_whoHatfield

rename q11j whoGoldwater
label variable whoGoldwater "WHO IS BARRY GOLDWATER"
label define lb_whoGoldwater 1 "CORRECT: U.S. SENATOR FROM ARIZONA, WESTERN STATE, A CONSERVATIVE SPOKESMAN, A CANDIDATE FOR PRESIDENT" 2 "PARTLY CORRECT: POLITICIAN, 'HEARD OF HIM'" 3 "INCORRECT" 4 "DONíT KNOW"
label values whoGoldwater lb_whoGoldwater

rename q11k whoScranton
label variable whoScranton "WHO IS WILLIAM SCRANTON"
label define  lb_whoScranton 1 "CORRECT: GOVERNOR OF PENNSYLVANIA, CANDIDATE FOR PRESIDENT, FORMER CONGRESSMAN" 2 "PARTLY CORRECT: POLITICIAN, 'HEARD OF HIM'" 3 "INCORRECT" 4 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label values whoScranton lb_whoScranton

rename q11l whoEisenhower
label variable whoEisenhower "WHO IS MILTON EISENHOWER"
label define  lb_whoEisenhower 1 "CORRECT: BROTHER OF PRESIDENT EISENHOWER, CANDIDATE FOR PRESIDENT, VICE-PRESIDENT, COLLEGE PRESIDENT, AUTHOR OF BOOK ON SOUTH AMERICA" 2 "PARTLY CORRECT" 3 "INCORRECT - FORMER PRESIDENT OF U.S." 4 "DONíT KNOW"
label values whoEisenhower lb_whoEisenhower

rename q12a republicanNom1st
label variable republicanNom1st "FIRST CHOICE 1964 REPUBLICAN CANDIDATES"

rename q12b republicanNom2nd
label variable republicanNom2nd "SECOND CHOICE 1964 REPUBLICAN CANDIDATES" 

label define  lb_republicanNom 1 "BARRY GOLDWATER, SENATOR FROM ARIZONA" 2 "NELSON ROCKEFELLER, GOVERNOR OF NEW YORK" 3 "GEORGE ROMNEY, GOVERNOR OF MICHIGAN" 4 "WILLIAM SCRANTON, GOVERNOR OF PENNSYLVANIA" 5 "HAROLD STASSEN, FORMER GOVERNOR OF MINNESOTA" 6 "NONE" 7 "DONíT KNOW, NO ANSWER"
label values republicanNom1st lb_republicanNom
label values republicanNom2nd lb_republicanNom

rename q13 goldwaterRockefeller
label variable goldwaterRockefeller "PREFERRED REPUBLICAN CANDIDATE: GOLDWATER VS ROCKEFELLER"
label define  lb_goldwaterRockefeller 1 "GOLDWATER" 2 "ROCKEFELLER" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label values goldwaterRockefeller lb_goldwaterRockefeller

rename q14 goldwaterEisenhower
label variable goldwaterEisenhower "PREFERRED REPUBLICAN CANDIDATE: GOLDWATER VS EISENHOWER"
label define  lb_goldwaterEisenhower 1 "GOLDWATER" 2 "EISENHOWER" 3 "NO OPINION" 0 "NO CODE OR NO DATA" 
label values goldwaterEisenhower lb_goldwaterEisenhower

rename q15 nixonKennedy
label variable nixonKennedy "PRESIDENTIAL ELECTION CHOICE: NIXON VS KENNEDY"
label define  lb_nixonKennedy 1 "NIXON" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED, NO ANSWER TO Q.15B" 5 "UNDECIDED, LEANS TOWARD NIXON" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 7 "UNDECIDED, UNDECIDED" 0 "NO CODE OR NO DATA"
label values nixonKennedy lb_nixonKennedy

rename q16 eisenhowerKennedy 
label variable eisenhowerKennedy "PRESIDENTIAL ELECTION CHOICE: MILTON VS KENNEDY"
label define  lb_eisenhowerKennedy 1 "KENNEDY" 2 "EISENHOWER" 3 "OTHER" 4 "UNDECIDED, NO ANSWER TO Q.16B" 5 "UNDECIDED, LEANS TOWARD KENNEDY" 6 "UNDECIDED, LEANS TOWARD EISENHOWER" 7 "UNDECIDED, UNDECIDED" 0 "NO CODE OR NO DATA"
label values eisenhowerKennedy lb_eisenhowerKennedy

rename q17 goldwaterKennedy
label variable goldwaterKennedy "PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY"
label define  lb_goldwaterKennedy 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED, NO ANSWER TO Q.16B" 5 "UNDECIDED, LEANS TOWARD KENNEDY" 6 "UNDECIDED, LEANS TOWARD GOLDWATER" 7 "UNDECIDED, UNDECIDED" 0 "NO CODE OR NO DATA"
label values goldwaterKennedy lb_goldwaterKennedy

rename q31a divorcedPresident
rename q31b jewPresident
rename q31c cathPresident
rename q31d blkPresident

rename q62 youthConservation
label variable youthConservation "SUPPORT YOUTH CONSERVATION CORPS"
label values youthConservation lb_GoodPoor

rename q63a equalServices
label variable equalServices "RIGHT TO BE SERVED IN PUBLIC PLACES"
label define  lb_equalServices 1 "YES, LIKE TO SEE PASSED" 2 "NO" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label values equalServices lb_equalServices

rename q63b equalSmallBuz
label variable equalSmallBuz "RIGHT TO BE SERVED IN SMALL BUSINESSES"
label values equalSmallBuz lb_agrDisagr

rename q64 womanPresident

rename q101 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

label define  lb_atHome 1 "AT HOME ONLY ONCE OF THE THREE DAYS SHOWN" 2 "AT HOME ONLY TWO DAYS OF THE THREE DAYS SHOWN" 3 "AT HOME ALL THREE DAYS" 4 "NOT AT HOME ANY OF THE THREE DAYS SHOWN" 0 "NOT ASCERTAINED, BLANK"
rename q102 atHome
label variable atHome "HOME YESTERDAY AT THIS TIME (`vv')"
label values atHome lb_atHome

rename q103 partyCD
label variable partyCD "PREFERRED PARTY FOR CONGRESS"
replace partyCD = 22 if partyCD == 1
replace partyCD = 1 if partyCD == 2
replace partyCD = 2 if partyCD == 22
replace partyCD = 55 if partyCD == 5
replace partyCD = 5 if partyCD == 6
replace partyCD = 6 if partyCD == 55
label define lb_partyCD 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, NO ANSWER TO PART B" 5 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 6 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 7 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 8 "UNDECIDED OR REFUSED, UNDECIDED" 9 "UNDECIDED OR REFUSED, REFUSED TO ANSWER"
label values partyCD lb_partyCD

rename q104 occupation
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q106 religion
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

rename q107 attendChurch
label variable attendChurch "ATTENDED CHURCH OR SYNAGOGUE IN THE LAST 7 DAYS"

rename q108 edu
label define lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
label values edu lb_edu

rename q109 voteNixonKennedy
label define  lb_voteNixonKennedy 1 "KENNEDY" 2 "NIXON" 3 "OTHER" 4 "VOTED, DONíT REMEMBER WHOM" 5 "NO, DIDNíT VOTE" 6 "DONíT REMEMBER IF VOTED" 7 "REFUSED TO ANSWER" 0 "NO CODE OR NO DATA"
label values voteNixonKennedy lb_voteNixonKennedy

rename q110 incomeHH_60s
label define lb_incomeHH_60s 1 "UNDER 1000 DOLLARS A YEAR OR UNDER $20 A WEEK" 2 "1,000 TO 1,499 A YEAR OR $20 TO $28.50 A WEEK" 3 "1,500 TO 1,999 A YEAR OR $29 TO $37.50 A WEEK" 4 "2,000 TO 2,499 A YEAR OR $38 TO $47.50 A WEEK" 5 "2,500 TO 2,999 A YEAR OR $48 TO $57.50 A WEEK" 6 "3,000 TO 3,999 A YEAR OR $58 TO $76.50 A WEEK" 7 "4,000 TO 4,999 A YEAR OR $77 TO $95.50 A WEEK" 8 "5,000 TO 6,999 A YEAR OR $96 TO $134.50 A WEEK" 9 "7,000 TO 9,999 A YEAR OR $135 TO $192.50 A WEEK" 10 "10,000 TO 14,999 A YEAR OR $193 TO $288.50 A WEEK" 11 "15,000 AND OVER A YEAR OR $289 AND MORE A WEEK"
label values incomeHH_60s lb_incomeHH_60s

	gen incomeHHharmonized = .
	replace incomeHHharmonized = 500 if incomeHH_60s == 1
	replace incomeHHharmonized = 1250 if incomeHH_60s == 2
	replace incomeHHharmonized = 1750 if incomeHH_60s == 3
	replace incomeHHharmonized = 2250 if incomeHH_60s == 4
	replace incomeHHharmonized = 2750 if incomeHH_60s == 5
	replace incomeHHharmonized = 3500 if incomeHH_60s == 6
	replace incomeHHharmonized = 4500 if incomeHH_60s == 7
	replace incomeHHharmonized = 6000 if incomeHH_60s == 8
	replace incomeHHharmonized = 8500 if incomeHH_60s == 9
	replace incomeHHharmonized = 12500 if incomeHH_60s == 10
	replace incomeHHharmonized = 15000 if incomeHH_60s == 11

rename q112 adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define  lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

rename q113 minorsHH
label variable minorsHH "NUMBER OF CHILDREN (MINORS) LIVING IN THIS HOUSEHOLD"
label define lb_minorsHH 1 "ONE CHILD" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE" 11 "NO MINOR CHILDREN"
label values minorsHH lb_minorsHH

label values numHH lb_minorsHH

label define  lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "NEGRO MAN" 4 "NEGRO WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

rename n117 citySize
label define  lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

label define lb_stateOld 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
label values state lb_stateOld
replace state = . if state == 0
replace state = state + 20 if (state == 81 | state == 82 | state == 83 | state == 84)
replace state = state + 10 if (state == 71 | state == 72 | state == 73 | state == 74 | state == 75)
replace state = state + 10 if (state == 61 | state == 62 | state == 63 | state == 64 | state == 65 | state == 66 | state == 67 | state == 68)
replace state = state - 40 if (state == 101 | state == 102 | state == 103 | state == 104)
label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/676-1963.dta", replace 
local svys `svys' 676-1963


*Gallup Poll # 714 [USAIPO1965-0714]
clear 
infix 2 lines 1: ///
	card 1 ///
	deck 2-4 ///
	ballot 5-8 ///
	q1 9 ///
	q2a 10 ///
	q2b 11 ///
	q3a1 12 ///
	q3a2 13 ///
	q3a3 14 ///
	q3a4 15 ///
	q3a5 16 ///
	q3a6 17 ///
	q3a7 18 ///
	q3a8 19 ///
	q3a9 20 ///
	q3a10 21 ///
	q3a11 22 ///
	q3a12 23 ///
	q3a13 24 ///
	q3a14 25 ///
	q3a15 26 ///
	q3a16 27 ///
	q3a17 28 ///
	q3a18 29 ///
	q3a19 30 ///
	q3a20 31 ///
	q3a21 32 ///
	q3a22 33 ///
	q3a23 34 ///
	q3a24 35 ///
	q3a25 36 ///
	q3a26 37 ///
	q3a27 38 ///
	q3a28 39 ///
	q3a29 40 ///
	q3a30 41 ///
	q3a31 42 ///
	q3a32 43 ///
	q3b 44 ///
	q4a 45 ///
	q4b1 46 ///
	q4b2 47 ///
	q4b3 48 ///
	q4b4 49 ///
	q4b5 50 ///
	q4b6 51 ///
	q4b7 52 ///
	q4b8 53 ///
	q4b9 54 ///
	q4b10 55 ///
	q4b11 56 ///
	q4b12 57 ///
	q4b13 58 ///
	q4b14 59 ///
	q4b15 60 ///
	q4b16 61 ///
	q4b17 62 ///
	q4b18 63 ///
	q4b19 64 ///
	q5a 65 ///
	q7 66-69 ///
	q8 70 ///
	q10 71 ///
	q11a 72 ///
	q11b 73 ///
	q11c 74 ///
	q11d 75	///
	2: ///
	card2 1 ///
	deck2 2-4 ///
	ballot2 5-8 ///
	q12a 9 ///
	q12c 10 ///
	q12d 11 ///
	q12e 12 ///
	q12f 13 ///
	q12g 14 ///
	q12h 15 ///
	q13a 16-18 ///
	q13b 19-21 ///
	q14a 22 ///
	q14b1 23 ///
	q14b2 24 ///
	q14b3 25 ///
	q14b4 26 ///
	q14b5 27 ///
	q14b6 28 ///
	q14b7 29 ///
	q14b8 30 ///
	q14b9 31 ///
	q14c 32 ///
	q14d1 33 ///
	q14d2 34 ///
	q14d3 35 ///
	q14d4 36 ///
	q14d5 37 ///
	q14d6 38 ///
	q14d7 39 ///
	q14d8 40 ///
	q14d9 41 ///
	q14d10 42 ///
	q14d11 43 ///
	q14d12 44 ///
	q14d13 45 ///
	q14d14 46 ///
	q14d15 47 ///
	q14d16 48 ///
	q14d17 49 ///
	q14d18 50 ///
	q14d19 51 ///
	q14e 52 ///
	q15a 53 ///
	q15b 54 ///
	q15c 55 ///
	q15d 56 ///
	q98 57 ///
	q100 58-59 ///
	q103 60 ///
	q104 61-62 ///
	q107a 63 ///
	q108 64 ///
	q110 65-66 ///
	age 67-68 ///
	n112 69 ///
	n113 70-71 ///
	state 72-73  ///
	wgt_timesAtHome  74 ///
	wgt_edu 75 ///
	using "$ascii/714.dat"
gen svy_year = 1965
gen svy_month = "July"
gen svy = "1965-0714"

rename n112 raceSex
label define  lb_yesNo 0 "No" 1 "Yes"
label define  lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define  lb_favOppNoOp 1 "FAVOR" 2 "OPPOSE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_appDisapp 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_agrDisagr 1 "AGREE" 2 "DISAGREE" 3 "NO OPINION"  9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"
label define  lb_shouldNot1 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 0 "NO CODE OR NO DATA" 
label define  lb_shouldNot2 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"  
label define  lb_yesNoRem 1 "Yes" 2 "NO" 3 "Don't Remember" 4 "NO CODE OR NO DATA"
label define  lb_UpDown 1 "GO UP" 2 "GO DOWN" 3 "REMAIN SAME" 4 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_PosImpos 1 "POSSIBLE" 2 "IMPOSSIBLE" 3 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_GoodPoor 1 "GOOD IDEA" 2 "POOR IDEA" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_BetterWorse 1 "BETTER" 2 "WORSE" 3 "ABOUT SAME" 4 "NO OPINION"
label define  lb_MoreLess 1 "MORE" 2 "LESS" 3 "SAME" 4 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_YesNoDontKnow 1 "YES" 2 "NO" 3 "DON'T KNOW" 9 "INAPPLICABLE"

local varMissing q2a q8 q11d q103 q104 q107a q108 q110
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varAppDisapp q2a q4a
foreach var in `varAppDisapp' {
	label values `var' lb_appDisapp
}

local varFavOppNoOp q11a
foreach var in `varFavOppNoOp' {
	label values `var' lb_favOppNoOp
}

rename q1 mandVote
label variable mandVote "Mandatory Vote"
label define  lb_mandVote 1 "GOOD LAW" 2 "POOR LAW" 3 "NO OPINION"
label values mandVote lb_mandVote

rename q2a presApprovala
label define  lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label variable presApprovala "JOHNSON JOB APPROVAL"
label values presApprovala lb_presApproval

rename q2b presApprovalb
label define  lb_presApprovalb 1 "VERY STRONGLY" 2 "NOT SO" 3 "NO OPINION" 9 "INAPPLICABLE"
label variable presApprovalb lb_presApprovalb

local vars Vietnam CivilRights CivitRightsDemon War ForeignAffairs Communism ForeignAid
local vars `vars' RedChina Russia Cuba NationalDefense DemRepublic Inflation Poverty BigGovt
local vars `vars' SocialSec Unemploy Edu Slums Crime JuvenileDelinq TeenProb Atheism
local vars `vars' InterCommunism InterApathy GoldStd Moral Agric Unions PopSize Misc DontKnow
local n = 1
foreach m in `vars' {
	rename q3a`n' mstImport`m'
	local n = `n' + 1
}

rename q3b partyMstImport
label variable partyMstImport "PARTY TO BEST HANDLE MOST IMPORTANT PROBLEM"
label define  lb_partyMstImport 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "NO DIFFERENCE" 4 "NO OPINION" 9 "INAPPLICABLE" 
label values partyMstImport lb_partyMstImport

rename q4a johnsonVietnam
label variable johnsonVietnam "JOHNSON'S VIETNAM POLICY"

rename q5a progVietnam
label variable progVietnam "SITUATION IN VIETNAM"
label values progVietnam lb_BetterWorse

rename q7 fallenSoldiersNam
label variable fallenSoldiersNam "GUESS AT FALLEN VIETNAM SOLDIERS"

rename q8 integrationRate
label variable integrationRate "OPINION: SPEED OF RACIAL INTEGRATION"
label define  lb_integrationRate 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA"
label values integrationRate lb_integrationRate

rename q10 blkwhtRelations
label variable blkwhtRelations "BLACK AND WHITE RELATIONS"
label values blkwhtRelations lb_BetterWorse

rename q11a catholicContraception
label variable catholicContraception "KNOW CATHOLIC CONTRACEPTION POLICY"
rename q11b chgCatholicContraceptiona
label variable chgCatholicContraceptiona "EXPECT CHANGE IN CATHOLIC CONTRACEPTION POLICY"
label values chgCatholicContraceptiona lb_YesNoDontKnow
rename q11c chgCatholicContraceptionb
label variable chgCatholicContraceptionb "TIMING IN CHANGE IN CATHOLIC CONTRACEPTION POLICY"
label define  lb_chgCatholicContraceptionb 1 "5 YEARS" 2 "10 YEARS" 3 "25 YEARS" 4 "50 YEARS" 5 "MORE THAN 50 YEARS" 6 "DON,T KNOW" 9 "INAPPLICABLE"
label values chgCatholicContraceptionb lb_chgCatholicContraceptionb
rename q11d chgCatholicContraceptionc
label variable chgCatholicContraceptionc "CHANGE CATHOLIC CONTRACEPTION POLICY'S IMPACT ON OPINION"
label values chgCatholicContraceptionc lb_MoreLess

label define lb_vote 1 "YES, SHOULD" 2 "NO, SHOULD NOT" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
rename q12a literacyVote 
label values literacyVote lb_vote
rename q12c communistVote
label values communistVote lb_vote
rename q12d age18t20Vote
label values age18t20Vote lb_vote
rename q12e noHSVote 
label values noHSVote lb_vote
rename q12f kkkVote 
label values kkkVote lb_vote
rename q12g inmatesVote 
label values inmatesVote lb_vote
rename q12h atheistsVote 
label values atheistsVote lb_vote

rename q13a age60plusIncome 
rename q13b age65plusIncome

rename q14a defineFBI
foreach n of num 1/9 {
	rename q14b`n' roleFBI`n' 
}

rename q14c sonFBI
label variable sonFBI "APPROVE OF SON IN FBI"
label define  lb_sonFBI 1 "PLEASED" 2 "DISPLEASED" 0 "DON'T KNOW"
label values sonFBI lb_sonFBI

foreach n of num 1/19 {
	rename q14d`n' whySonFBI`n'
}

label values q15* lb_yesNoNoOp
rename q15a divorcedPresident
rename q15b jewPresident
rename q15c cathPresident
rename q15d blkPresident

rename q98 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID
replace poliPartyID = . if poliPartyID == 0

rename q100 occupation
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q103 edu
label define lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
label values edu lb_edu

rename q104 adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define  lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

rename q107a religion
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

rename q110 incomeHH_60s 
label define lb_incomeHH_60s 1 "UNDER 1000 DOLLARS A YEAR OR UNDER $20 A WEEK" 2 "1,000 TO 1,499 A YEAR OR $20 TO $28.50 A WEEK" 3 "1,500 TO 1,999 A YEAR OR $29 TO $37.50 A WEEK" 4 "2,000 TO 2,499 A YEAR OR $38 TO $47.50 A WEEK" 5 "2,500 TO 2,999 A YEAR OR $48 TO $57.50 A WEEK" 6 "3,000 TO 3,999 A YEAR OR $58 TO $76.50 A WEEK" 7 "4,000 TO 4,999 A YEAR OR $77 TO $95.50 A WEEK" 8 "5,000 TO 6,999 A YEAR OR $96 TO $134.50 A WEEK" 9 "7,000 TO 9,999 A YEAR OR $135 TO $192.50 A WEEK" 10 "10,000 TO 14,999 A YEAR OR $193 TO $288.50 A WEEK" 11 "15,000 AND OVER A YEAR OR $289 AND MORE A WEEK"
label values incomeHH_60s lb_incomeHH_60s

	gen incomeHHharmonized = .
	replace incomeHHharmonized = 500 if incomeHH_60s == 1
	replace incomeHHharmonized = 1250 if incomeHH_60s == 2
	replace incomeHHharmonized = 1750 if incomeHH_60s == 3
	replace incomeHHharmonized = 2250 if incomeHH_60s == 4
	replace incomeHHharmonized = 2750 if incomeHH_60s == 5
	replace incomeHHharmonized = 3500 if incomeHH_60s == 6
	replace incomeHHharmonized = 4500 if incomeHH_60s == 7
	replace incomeHHharmonized = 6000 if incomeHH_60s == 8
	replace incomeHHharmonized = 8500 if incomeHH_60s == 9
	replace incomeHHharmonized = 12500 if incomeHH_60s == 10
	replace incomeHHharmonized = 15000 if incomeHH_60s == 11

label define  lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "NEGRO MAN" 4 "NEGRO WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

rename n113 citySize
label define  lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/714-1965.dta", replace 
local svys `svys' 714-1965	


*Gallup Poll # 1967-0744: Presidential Johnson/1968 Presidential Election/George Wallace [USAIPO1967-0744]
clear 
infix 2 lines 1: ///
	card 1 ///
	deck 2-4 ///
	ballot 5-8 ///
	q1a 9 ///
	q1b 10 ///
	q2a 11 ///
	q2b1 12 ///
	q2b2 13 ///
	q2b3 14 ///
	q2b4 15 ///
	q2b5 16 ///
	q2b6 17 ///
	q2b7 18 ///
	q2b8 19 ///
	q2b9 20 ///
	q2b10 21 ///
	q2b11 22 ///
	q2b12 23 ///
	q2b13 24 ///
	q2b14 25 ///
	q2b15 26 ///
	q2b16 27 ///
	q2b17 28 ///
	q2b18 29 ///
	q2b19 30 ///
	q2b20 31 ///
	q2b21 32 ///
	q2b22 33 ///
	q2b23 34 ///
	q2b24 35 ///
	q2b25 36 ///
	q2b26 37 ///
	q3_1 38 ///
	q3_2 39 ///
	q3_3 40 ///
	q3_4 41 ///
	q3_5 42 ///
	q3_6 43 ///
	q3_7 44 ///
	q3_8 45 ///
	q3_9 46 ///
	q3_10 47 ///
	q3_11 48 ///
	q4 49 ///
	q5 50 ///
	q6 51 ///
	q7a 52 ///
	q7b 53 ///
	q8 54 ///
	q9 55 ///
	q10 56 ///
	q11a 57 ///
	q11b 58 ///
	q12 59 ///
	q13 60 ///
	q14a 61-62 ///
	q14b 63-64 ///
	q14c 65-66 ///
	q14d 67-68 ///
	q14e 69-70 ///
	q14f 71-72 ///
	q14g 73-74 ///
	q14h 75-76 ///
	q14i 77-78 ///
	q14j 79-80 ///
	2: ///
	card2 1 ///
	deck2 2-4 ///
	ballot2 5-8 ///
	q14k 9-10 ///
	q14l 11-12 ///
	q14m 13-14 ///
	q14n 15-16 ///
	q15a 17 ///
	q15b 18 ///
	q15c 19 ///
	q15d 20 ///
	q15e 21 ///
	q15f 22 ///
	q15g 23 ///
	q16a 24 ///
	q16b1 25 ///
	q16b2 26 ///
	q16b3 27 ///
	q16b4 28 ///
	q16b5 29 ///
	q16b6 30 ///
	q16b7 31 ///
	q16b8 32 ///
	q16b9 33 ///
	q16b10 34 ///
	q16b11 35 ///
	q16b12 36 ///
	q16b13 37 ///
	q16b14 38 ///
	q16b15 39 ///
	q16b16 40 ///
	q16b17 41 ///
	q16b18 42 ///
	q16b19 43 ///
	q16b20 44 ///
	q16b21 45 ///
	q16b22 46 ///
	q18 47 ///
	q98 48 ///
	q101 49 ///
	q102 50-51 ///
	q103 52-53 ///
	q104a 54 ///
	q104b 55 ///
	q104c 56 ///
	q105 57 ///
	q106 58-59 ///
	q108 60-61 ///
	age 62-63 ///
	raceSex 64 ///
	n111 65-66 ///
	state 67-68 ///
	interNum 69-70 ///
	wgt_timesAtHome 71 ///
	wgt_edu 72	 ///
	using "$ascii/aipo0744.dat"
gen svy_year = 1967
gen svy_month = "April"
gen svy = "1967-0744"

label define  lb_yesNo 0 "No" 1 "Yes"
label define  lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define  lb_favOppNoOp 1 "FAVOR" 2 "OPPOSE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_appDisapp 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_agrDisagr 1 "AGREE" 2 "DISAGREE" 3 "NO OPINION"  9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"
label define  lb_shouldNot1 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 0 "NO CODE OR NO DATA" 
label define  lb_shouldNot2 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"  
label define  lb_yesNoRem 1 "Yes" 2 "NO" 3 "Don't Remember" 4 "NO CODE OR NO DATA"
label define  lb_UpDown 1 "GO UP" 2 "GO DOWN" 3 "REMAIN SAME" 4 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_PosImpos 1 "POSSIBLE" 2 "IMPOSSIBLE" 3 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_GoodPoor 1 "GOOD IDEA" 2 "POOR IDEA" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_BetterWorse 1 "BETTER" 2 "WORSE" 3 "ABOUT SAME" 4 "NO OPINION"
label define  lb_MoreLess 1 "MORE" 2 "LESS" 3 "SAME" 4 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_YesNoDontKnow 1 "YES" 2 "NO" 3 "DON'T KNOW" 9 "INAPPLICABLE"
label define  lb_IncreaseDecrease 1 "INCREASED" 2 "DECREASED" 3 "KEPT SAME" 4 "NO OPINION"

local varMissing q9 q102 q103 q104a q104b q104c q105 q108 age state
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNo q9 q104a
foreach var in `varYesNo' { 
	replace `var'  = 2-`var'
	label values `var' lb_yesNo
}

local varAppDisapp q1a q2a
foreach var in `varAppDisapp' {
	label values `var' lb_appDisapp
}

local varYesNoNoOp q4 q5 q7a q7b q15* q18
foreach var in `varYesNoNoOp' {
	label values `var' lb_yesNoNoOp
}

local varAgrDisagr q6
foreach var in `varAgrDisagr' {
	label values `var' lb_agrDisagr
}

local varFavOppNoOp q8
foreach var in `varFavOppNoOp' {
	label values `var' lb_favOppNoOp
}

rename q1a presApprovala
label variable presApprovala "JOHNSON JOB APPROVAL"

rename q1b presApprovalb
label variable presApprovalb "JOHNSON JOB APPROVAL - STRENGTH OF OPINION"
label define  lb_presApprovalb 1 "VERY STRONGLY" 2 "NOT SO" 3 "NO OPINION" 9 "INAPPLICABLE"
label variable presApprovalb lb_presApprovalb

rename q2a presVietnam
foreach n of num 1/26 {
	rename q2b`n' whyPresVietnam`n'
}

foreach n of num 1/11 {
	rename q3_`n' nextStepsVietnam`n'
}

rename q4 mistakeVietnam
label variable mistakeVietnam "VIETNAM, REGRET SENDING TROOPS"
rename q5 justVietnam 
label variable justVietnam "VIETNAM MORALLY JUSTIFIED"
rename q6 allOutVietnam
label variable allOutVietnam "GO ALL-OUT TO WIN VIETNAM"
rename q7a rallyVietnam 
label variable rallyVietnam "PEACEFUL RALLY ON VIETNAM"
rename q7b areaRallyVietnam 
label variable areaRallyVietnam "WOULD ATTEND LOCAL PEACEFUL RALLY ON VIETNAM"

rename q8 assetsCongress
label variable assetsCongress "CONGRESS DISCLOSE ASSETS"

rename q9 foreignAid
label variable foreignAid "FOLLOW FOREIGN AID DISCUSSIONS"

rename q10 chgForeignAid
label values chgForeignAid lb_IncreaseDecrease
label variable chgForeignAid "INCREASED OR DECREASED FOREIGN AID"

rename q11a republicanNom1st
label variable republicanNom1st "FIRST CHOICE 1968 REPUBLICAN CANDIDATES"

rename q11b republicanNom2nd
label variable republicanNom2nd "SECOND CHOICE 1968 REPUBLICAN CANDIDATES" 

label define  lb_republicanNom 1 "MARK HATFIELD" 2 "JOHN LINDSAY" 3 "RICHARD NIXON" 4 "CHARLES PERCY" 5 "RONALD REAGAN" 6 "NELSON ROCKEFELLER" 7 "GEORGE ROMNEY" 8 "DON,T KNOW, NO ANSWER"
label values republicanNom1st lb_republicanNom
label values republicanNom2nd lb_republicanNom

rename q12 nixonRomney
label variable nixonRomney "REPUBLICAN CANDIDATE: NIXON VS ROMNEY"
label define lb_nixonRomney 1 "NIXON" 2 "ROMNEY" 3 "NO OPINION"
label values nixonRomney lb_nixonRomney

rename q13 kennedyJohnson
label variable kennedyJohnson "DEMOCRATIC CANDIDATE: KENNEDY VS JOHNSON"
label define lb_kennedyJohnson 1 "KENNEDY" 2 "JOHNSON" 3 "NO OPINION" 

rename q14a rateCastro
rename q14b rateEisenhower
rename q14c rateJohnson
rename q14d rateKennedy
rename q14e rateHumphrey
rename q14f rateGaulle
label variable rateGaulle "CHARLES DE GAULLE RATING"
rename q14g rateNixon
rename q14h ratePowell
label variable ratePowell "ADAM CLAYTON POWELL RATING"
rename q14i rateRomney
rename q14j rateRockefeller
rename q14k rateReagan
rename q14l rateWallace
rename q14m rateRepublican
rename q14n rateDemocratic
label define  lb_rating 1 "5" 2 "4" 3 "3" 4 "2" 5 "1" 6 "-1" 7 "-2" 8 "-3" 9 "-4" 10 "-5" 0 "DON,T KNOW, NO ANSWER"
local vars rateCastro rateEisenhower rateJohnson rateKennedy rateHumphrey rateGaulle rateNixon 
local vars `vars' ratePowell rateRomney rateRockefeller rateReagan rateWallace rateRepublican rateDemocratic
foreach var in `vars' {
	label values `var' lb_rating
}

rename q15a divorcedPresident
rename q15c jewPresident
rename q15b cathPresident
rename q15d blkPresident 
rename q15e baptistPresident
rename q15f quakerPresident
rename q15g mormonPresident

rename q16a whoWallace
label define  lb_whoWallace 1 "YES, RESPONDENT CORRECTLY IDENTIFIED WALLACE" 2 "YES, RESPONDENT INCORRECTLY IDENTIFIED WALLACE" 3 "NO OR NO ANSWER"
label values whoWallace lb_whoWallace

local n = 1
local vars Insincere Conceited Arrogant Stupid Prejudiced Radical Dislike Scoundrel Ambitious ProNegro_bad TooMchStatesRights HideBehindWife
local vars `vars' Sincere Independent Intelligent Good Courageous Strong AntiNegro_good TooLittStatesRights Misc 
foreach v in `vars' {
	rename q16b`n' wallace`v'
	local n = `n' + 1
}

rename q18 womanPresident

rename q98 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID
replace poliPartyID = . if poliPartyID == 0

rename q101 voteGoldwaterJohnson
label define  lb_voteGoldwaterJohnson 1 "JOHNSON" 2 "GOLDWATER" 3 "OTHER" 4 "VOTED, DON,T REMEMBER WHOM" 5 "NO, DIDN,T VOTE" 6 "DON,T REMEMBER" 0 "NO CODE OR NO DATA"

rename q102 adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define  lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

rename q103 minorsHH
label variable minorsHH "NUMBER OF CHILDREN (MINORS) LIVING IN THIS HOUSEHOLD"
label define lb_minorsHH 1 "ONE CHILD" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE" 11 "NO MINOR CHILDREN"
label values minorsHH lb_minorsHH

rename q104a attendChurch
label variable attendChurch "ATTENDED CHURCH OR SYNAGOGUE IN THE LAST 7 DAYS"

rename q104b religionOrtho
label define lb_religionOrtho 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "EASTERN ORTHODOX" 5 "OTHER" 6 "NONE"
label values religion lb_religionOrtho

gen religion = religionOrtho
replace religion = 4 if religionOrtho == 5
replace religion = 5 if religionOrtho == 6
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

rename q104c vProtestant
label variable vProtestant "PROTESTANT DENOMINATION"
label define  lb_vProtestant 1 "BAPTIST" 2 "METHODIST" 3 "PRESBYTERIAN" 4 "LUTHERAN" 5 "EPISCOPAL" 6 "OTHER" 9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"
label values vProtestant lb_vProtestant

rename q105 edu
label define lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
label values edu lb_edu

rename q106 occupation
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q108 incomeHH_60s 
label define lb_incomeHH_60s 1 "UNDER 1000 DOLLARS A YEAR OR UNDER $20 A WEEK" 2 "1,000 TO 1,499 A YEAR OR $20 TO $28.50 A WEEK" 3 "1,500 TO 1,999 A YEAR OR $29 TO $37.50 A WEEK" 4 "2,000 TO 2,499 A YEAR OR $38 TO $47.50 A WEEK" 5 "2,500 TO 2,999 A YEAR OR $48 TO $57.50 A WEEK" 6 "3,000 TO 3,999 A YEAR OR $58 TO $76.50 A WEEK" 7 "4,000 TO 4,999 A YEAR OR $77 TO $95.50 A WEEK" 8 "5,000 TO 6,999 A YEAR OR $96 TO $134.50 A WEEK" 9 "7,000 TO 9,999 A YEAR OR $135 TO $192.50 A WEEK" 10 "10,000 TO 14,999 A YEAR OR $193 TO $288.50 A WEEK" 11 "15,000 AND OVER A YEAR OR $289 AND MORE A WEEK"
label values incomeHH_60s lb_incomeHH_60s

	gen incomeHHharmonized = .
	replace incomeHHharmonized = 500 if incomeHH_60s == 1
	replace incomeHHharmonized = 1250 if incomeHH_60s == 2
	replace incomeHHharmonized = 1750 if incomeHH_60s == 3
	replace incomeHHharmonized = 2250 if incomeHH_60s == 4
	replace incomeHHharmonized = 2750 if incomeHH_60s == 5
	replace incomeHHharmonized = 3500 if incomeHH_60s == 6
	replace incomeHHharmonized = 4500 if incomeHH_60s == 7
	replace incomeHHharmonized = 6000 if incomeHH_60s == 8
	replace incomeHHharmonized = 8500 if incomeHH_60s == 9
	replace incomeHHharmonized = 12500 if incomeHH_60s == 10
	replace incomeHHharmonized = 15000 if incomeHH_60s == 11

label define  lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "NEGRO MAN" 4 "NEGRO WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

rename n111 citySize
label define  lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/744-1967.dta", replace 
local svys `svys' 744-1967


*Gallup Poll # 1968-0761: 1968 Presidential Election/Racial Discrimination/Race Relations [USAIPO1968-0761]
clear 
infix 2 lines 1: ///
	card 1 ///
	deck 2-4 ///
	ballot 5-8 ///
	q1 9 ///
	q2 10 ///
	q3 11 ///
	q4 12 ///
	q5 13 ///
	q6 14 ///
	q7 15 ///
	q8 16 ///
	q9 17 ///
	q10 18 ///
	q11 19 ///
	q13a 20 ///
	q13b 21 ///
	q13c 22 ///
	q14 23 ///
	q15 24 ///
	q17 25 ///
	q19 26 ///
	q20 27 ///
	q21 28 ///
	q22 29 ///
	q23 30 ///
	q24 31 ///
	q25 32 ///
	q26 33 ///
	q27 34 ///
	q28 35 ///
	q29a 36 ///
	q29b 37 ///
	q29c 38 ///
	q30a 39-40 ///
	q30b 41-42 ///
	q30c 43-44 ///
	q30d 45-46 ///
	q30e 47-48 ///
	q30f 49-50 ///
	q30g 51-52 ///
	q30h 53-54 ///
	q30i 55-56 ///
	q30j 57-58 ///
	q30k 59-60 ///
	q30l 61-62 ///
	q30m 63-64 ///
	q98 65 ///
	q101a 66-67 ///
	q101b 68-69 ///
	q102 70 ///
	q103 71-72 ///
	q104 73-74 ///
	age 75-76 ///
	raceSex 77 ///
	religion 78 ///
	union 79 ///
	2: ///
	card2 1 ///
	deck2 2-4 ///
	ballot2 5-8 ///
	citySize 9-10 ///
	state 11-12 ///
	wgt 13 ///
	using "$ascii/aipo0761.dat"
gen svy_year = 1968
gen svy_month = "May"
gen svy = "1968-0761"

label define  lb_yesNo 0 "No" 1 "Yes"
label define  lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define  lb_favOppNoOp 1 "FAVOR" 2 "OPPOSE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_appDisapp 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_agrDisagr 1 "AGREE" 2 "DISAGREE" 3 "NO OPINION"  9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"
label define  lb_shouldNot1 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 0 "NO CODE OR NO DATA" 
label define  lb_shouldNot2 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"  
label define  lb_yesNoRem 1 "Yes" 2 "NO" 3 "Don't Remember" 4 "NO CODE OR NO DATA"
label define  lb_UpDown 1 "GO UP" 2 "GO DOWN" 3 "REMAIN SAME" 4 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_PosImpos 1 "POSSIBLE" 2 "IMPOSSIBLE" 3 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_GoodPoor 1 "GOOD IDEA" 2 "POOR IDEA" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_BetterWorse 1 "BETTER" 2 "WORSE" 3 "ABOUT SAME" 4 "NO OPINION"
label define  lb_MoreLess 1 "MORE" 2 "LESS" 3 "SAME" 4 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_YesNoDontKnow 1 "YES" 2 "NO" 3 "DON'T KNOW" 9 "INAPPLICABLE"
label define  lb_IncreaseDecrease 1 "INCREASED" 2 "DECREASED" 3 "KEPT SAME" 4 "NO OPINION"
label define lb_interest 1 "IS INTERESTED" 2 "IS NOT INTERESTED" 3 "NO OPINION"
label define lb_5scale 1 "5" 2 "4" 3 "3" 4 "2" 5 "1" 6 "-1" 7 "-2" 8 "-3" 9 "-4" 10 "-5" 11 "UNDESIGNATED, NO ANSWER"


local varMissing q1 q11 q17 q98 q101a q101b q102 q104 age religion union
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNo 
foreach var in `varYesNo' { 
	replace `var'  = 2-`var'
	label values `var' lb_yesNo
}

local varAppDisapp q1 q2 q14 q17 q22
foreach var in `varAppDisapp' {
	label values `var' lb_appDisapp
}

local varYesNoNoOp q25 q27 q28
foreach var in `varYesNoNoOp' {
	label values `var' lb_yesNoNoOp
}

local varAgrDisagr 
foreach var in `varAgrDisagr' {
	label values `var' lb_agrDisagr
}

local varFavOppNoOp 
foreach var in `varFavOppNoOp' {
	label values `var' lb_favOppNoOp
}

foreach var in  {
	label values `var' lb_YesNoDontKnow
}

rename q1 presApprovala
label variable presApprovala "JOHNSON JOB APPROVAL"

rename q2 youthConservation
label variable youthConservation "SUPPORT YOUTH CONSERVATION CORPS"
label values youthConservation lb_appDisapp

rename q3 voteRegist
label variable voteRegist "REGISTERED TO VOTE"	
label define lb_voteRegist 1 "YES" 2 "NO" 3 "DONíT HAVE TO REGISTER" 4 "DONíT KNOW"
label values voteRegist lb_voteRegist

local n = 4
foreach v in Humphrey Kennedy McCarthy {
	local V = upper("`v'")
	*q4-6
	rename q`n' nixon`v'Wallace
	label variable nixon`v'Wallace "ELECTION: NIXON VS `V' VS WALLACE"
	label define lb_nixon`v'Wallace 1 "NIXON" 2 "`V'" 3 "WALLACE" 4 "UNDECIDED"
	label values nixon`v'Wallace lb_nixon`v'Wallace
	
	*q7-q9
	local m = (`n' + 3)
	rename q`m' rockefeller`v'Wallace
	label variable rockefeller`v'Wallace "ELECTION: ROCKEFELLER VS `V' VS WALLACE"
	label define lb_rockefeller`v'Wallace 1 "ROCKEFELLER" 2 "`V'" 3 "WALLACE" 4 "UNDECIDED"
	label values rockefeller`v'Wallace lb_rockefeller`v'Wallace
	
	local n = `n' + 1
}

rename q10 kennedyMcCarthyHumphrey
label variable kennedyMcCarthyHumphrey "DEMOCRATIC CANDIDATE: KENNEDY VS MCCARTHY VS HUMPHREY"
label define lb_kennedyMcCarthyHumphrey 1 "KENNEDY" 2 "MCCARTHY" 3 "HUMPHREY" 4 "UNDECIDED" 
label values kennedyMcCarthyHumphrey lb_kennedyMcCarthyHumphrey

rename q11 nixonRockefeller
label variable nixonRockefeller "NIXON VS ROCKEFELLER"
label define lb_nixonRockefeller 1 "NIXON" 2 "ROCKEFELLER" 3 "UNDECIDED" 0 "NO CODE OR NO DATA" 

rename q13a votedPres
label variable votedPres "VOTED PRESIDENTIAL ELECTION"
label define lb_votedPres 1 "YES, VOTED" 2 "THINK SO" 3 "DIDNíT VOTE" 4 "CANíT REMEMBER"
label values votedPres lb_votedPres

rename q13b voteJohnsonGoldwater
label define lb_voteJohnsonGoldwater 1 "JOHNSON" 2 "GOLDWATER" 3 "OTHER" 4 "DONíT REMEMBER" 9 "INAPPLICABLE"
label values voteJohnsonGoldwater lb_voteJohnsonGoldwater

rename q13c voteNixonKennedy
label define lb_voteNixonKennedy 1 "NIXON" 2 "KENNEDY" 3 "DONíT REMEMBER" 4 "DON'T VOTE" 
label values voteNixonKennedy lb_voteNixonKennedy

rename q14 johnsonVietnam
label variable johnsonVietnam "JOHNSON'S VIETNAM APPROACH"

rename q15 integrationRate
label variable integrationRate "OPINION: SPEED OF RACIAL INTEGRATION"
label define  lb_integrationRate 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA"
label values integrationRate lb_integrationRate 

rename q17 planVietnam
label variable planVietnam "OPINION: VIETNAM PLAN SUGGESTION"
label values planVietnam lb_appDisapp

rename q19 endingVietnam 
label variable endingVietnam "EXPECTING ENDING TO VIETNAM"
label define lb_endingVietnam 1 "ALL OUT VICTORY" 2 "COMPROMISE PEACE SETTLEMENT" 3 "DEFEAT" 4 "OTHER" 5 "NO OPINION"
label values endingVietnam lb_endingVietnam

rename q20 peaceNVietnam
label variable peaceNVietnam "N. VIETNAM'S INTEREST IN PEACE"
label values peaceNVietnam lb_interest 

rename q21 peaceUS
label variable peaceUS "U.S.'S INTEREST IN PEACE"
label values peaceUS lb_interest

rename q22 civilDisorders
label variable civilDisorders "AGREEMENT WITH CIVIL DISORDERS REPORT"
label values civilDisorders lb_agrDisagr

rename q23 blkTreatment
label variable blkTreatment "TREATMENT OF BLACKS"
label define lb_blkTreatment 1 "SAME AS WHITES" 2 "NOT VERY WELL" 3 "BADLY" 4 "DONíT KNOW"
label values blkTreatment lb_blkTreatment

rename q24 blameBlkState 
label variable blameBlkState "BLAME FOR BLACK'S CONDITION"
label define lb_blameBlkState 1 "WHITE PEOPLE" 2 "NEGROES" 3 "NO OPINION"
label values blameBlkState lb_blameBlkState

rename q25 racialTrouble
label variable racialTrouble "LIKELINESS OF RACIAL TROUBLE WITHIN SIX MONTHS"
label values racialTrouble lb_yesNoNoOp

rename q26 shootLooting
label variable shootLooting "SUPPORT SHOOTING LOOTERS DURING RACE RIOTS"
label define lb_shootLooting 1 "BEST WAY TO DEAL WITH THIS PROBLEM" 2 "THERE IS A BETTER WAY" 3 "NO OPINION"
label values shootLooting lb_shootLooting

rename q27 blkHiring
label variable blkHiring "THINK MOST BUSINESS IN AREA DISCRIMINATE AGAINST NEGROES"
label values blkHiring lb_yesNoNoOp

rename q28 blkUnions
label variable blkUnions "THINK MOST UNIONS IN AREA DISCRIMINATE AGAINST NEGROES"
label values blkUnions lb_yesNoNoOp

rename q29a factoriesUrate
label variable factoriesUrate "LOWER URATE: GOVT SUBSIDIZED FACTORIES NEAR POVERTY AREAS"
label values factoriesUrate lb_GoodPoor

rename q29b modelCitiesUrate
label variable modelCitiesUrate "MODEL CITIES TO INCLUDE BOTH WHITES AND NEGROES WHERE JOB OPPORTUNITIES EXIST"
label values modelCitiesUrate lb_GoodPoor

rename q29c govtSupportUrate
label variable govtSupportUrate "GOVERNMENT GIVE FINANCIAL HELP UNTIL WORKER IS EMPLOYED"
label values govtSupportUrate lb_GoodPoor

rename q30a rateEisenhower
rename q30b rateWallace
rename q30c rateJohnson
rename q30d rateKennedy
rename q30e rateMcCarthy
rename q30f rateHumphrey
rename q30g rateNixon
rename q30h rateRockefeller
rename q30i rateReagon
rename q30j rateDemocrats
rename q30k rateRepublican
rename q30l rateBlacks
rename q30m rateWhites

local vars Eisenhower Wallace Johnson Kennedy McCarthy Humphrey Nixon Rockefeller 
local vars `vars' Reagon Democrats Republican Blacks Whites
foreach v in `vars' {
	local V = upper("`v'")
	label variable rate`v' "RATE `V'"
	label values rate`v' lb_5scale
}

rename q98 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
replace poliPartyID = . if poliPartyID == 5
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

rename q101a adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

rename q101b minorsHH
label variable minorsHH "NUMBER OF CHILDREN (MINORS) LIVING IN THIS HOUSEHOLD"
label define lb_minorsHH 1 "ONE CHILD" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE" 11 "NO MINOR CHILDREN"
label values minorsHH lb_minorsHH

rename q102 edu 
label define lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
label values edu lb_edu

rename q103 occupation
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q104 incomeHH_60s
label define lb_incomeHH_60s 1 "UNDER 1000 DOLLARS A YEAR OR UNDER $20 A WEEK" 2 "1,000 TO 1,499 A YEAR OR $20 TO $28.50 A WEEK" 3 "1,500 TO 1,999 A YEAR OR $29 TO $37.50 A WEEK" 4 "2,000 TO 2,499 A YEAR OR $38 TO $47.50 A WEEK" 5 "2,500 TO 2,999 A YEAR OR $48 TO $57.50 A WEEK" 6 "3,000 TO 3,999 A YEAR OR $58 TO $76.50 A WEEK" 7 "4,000 TO 4,999 A YEAR OR $77 TO $95.50 A WEEK" 8 "5,000 TO 6,999 A YEAR OR $96 TO $134.50 A WEEK" 9 "7,000 TO 9,999 A YEAR OR $135 TO $192.50 A WEEK" 10 "10,000 TO 14,999 A YEAR OR $193 TO $288.50 A WEEK" 11 "15,000 AND OVER A YEAR OR $289 AND MORE A WEEK"
label values incomeHH_60s lb_incomeHH_60s

	gen incomeHHharmonized = .
	replace incomeHHharmonized = 500 if incomeHH_60s == 1
	replace incomeHHharmonized = 1250 if incomeHH_60s == 2
	replace incomeHHharmonized = 1750 if incomeHH_60s == 3
	replace incomeHHharmonized = 2250 if incomeHH_60s == 4
	replace incomeHHharmonized = 2750 if incomeHH_60s == 5
	replace incomeHHharmonized = 3500 if incomeHH_60s == 6
	replace incomeHHharmonized = 4500 if incomeHH_60s == 7
	replace incomeHHharmonized = 6000 if incomeHH_60s == 8
	replace incomeHHharmonized = 8500 if incomeHH_60s == 9
	replace incomeHHharmonized = 12500 if incomeHH_60s == 10
	replace incomeHHharmonized = 15000 if incomeHH_60s == 11

label define  lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "NEGRO MAN" 4 "NEGRO WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

rename religion religionOrtho
label define lb_religionOrtho 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "EASTERN ORTHODOX" 5 "OTHER" 6 "NONE"
label values religionOrtho lb_religionOrtho

gen religion = religionOrtho
replace religion = 4 if religionOrtho == 5
replace religion = 5 if religionOrtho == 6
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

label define lb_union 1 "YES, RESPONDENT IS" 2 "YES, SPOUSE IS" 3 "YES, BOTH ARE" 4 "NO, NEITHER IS"
label values union lb_union

label define  lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/761-1968.dta", replace 
local svys `svys' 761-1968


*Gallup Poll # 1969-0776: Ratings of Leaders [USAIPO1969-0776]
clear 
infix 2 lines 1: ///
	card 1 ///
	deck 2-4 ///
	ballot 5 ///
	area 6-8 ///
	q1 9 ///
	q2a 10 ///
	q2b1 11 ///
	q2b2 12 ///
	q2b3 13 ///
	q2b4 14 ///
	q2b5 15 ///
	q2b6 16 ///
	q2b7 17 ///
	q2b8 18 ///
	q2b9 19 ///
	q2b10 20 ///
	q2b11 21 ///
	q2b12 22 ///
	q2b13 23 ///
	q2b14 24 ///
	q2b15 25 ///
	q2b16 26 ///
	q2b17 27 ///
	q2b18 28 ///
	q2b19 29 ///
	q2b20 30 ///
	q2b21 31 ///
	q3a 32 ///
	q3b 33 ///
	q3c 34 ///
	q4 35 ///
	q5_1 36 ///
	q5_2 37 ///
	q5_3 38 ///
	q5_4 39 ///
	q5_5 40 ///
	q5_6 41 ///
	q5_7 42 ///
	q5_8 43 ///
	q5_9 44 ///
	q5_10 45 ///
	q6 46 ///
	q7 47 ///
	q8a 48-49 ///
	q8b 50-51 ///
	q8c 52-53 ///
	q8d 54-55 ///
	q8e 56-57 ///
	q8f 58-59 ///
	q8g 60-61 ///
	q8h 62-63 ///
	q8i 64-65 ///
	q8j 66-67 ///
	q8k 68-69 ///
	q8l 70-71 ///
	q9 72 ///
	q10a 73 ///
	q10b 74 ///
	q96 75-76 ///
	q97 77 ///
	q100 78 ///
	q101a 79-80 ///	
	2: ///
	card2 1 ///
	deck2 2-4 ///
	ballot2 5 ///
	q101b 9-10 ///
	q102 11 ///
	q103 12-13 ///
	q104 14 ///
	q107a 15 ///
	q107b 16 ///
	q107c 17 ///
	age 18-19 ///
	union 20 ///
	raceSex 21 ///
	q112 22 ///
	citySize 23-24 ///
	state 25-26 ///
	interNum 27-28 ///
	wgt 29 ///	
	using "$ascii/aipo0776.dat"
gen svy_year = 1969
gen svy_month = "March"
gen svy = "1969-0776"

label define  lb_yesNo 0 "No" 1 "Yes"
label define  lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define  lb_favOppNoOp 1 "FAVOR" 2 "OPPOSE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_appDisapp 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_agrDisagr 1 "AGREE" 2 "DISAGREE" 3 "NO OPINION"  9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"
label define  lb_shouldNot1 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 0 "NO CODE OR NO DATA" 
label define  lb_shouldNot2 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"  
label define  lb_yesNoRem 1 "Yes" 2 "NO" 3 "Don't Remember" 4 "NO CODE OR NO DATA"
label define  lb_UpDown 1 "GO UP" 2 "GO DOWN" 3 "REMAIN SAME" 4 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_PosImpos 1 "POSSIBLE" 2 "IMPOSSIBLE" 3 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_GoodPoor 1 "GOOD IDEA" 2 "POOR IDEA" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_BetterWorse 1 "BETTER" 2 "WORSE" 3 "ABOUT SAME" 4 "NO OPINION"
label define  lb_MoreLess 1 "MORE" 2 "LESS" 3 "SAME" 4 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_YesNoDontKnow 1 "YES" 2 "NO" 3 "DON'T KNOW" 9 "INAPPLICABLE"
label define  lb_IncreaseDecrease 1 "INCREASED" 2 "DECREASED" 3 "KEPT SAME" 4 "NO OPINION"
label define lb_interest 1 "IS INTERESTED" 2 "IS NOT INTERESTED" 3 "NO OPINION"
label define lb_5scale 1 "5" 2 "4" 3 "3" 4 "2" 5 "1" 6 "-1" 7 "-2" 8 "-3" 9 "-4" 10 "-5" 11 "UNDESIGNATED, NO ANSWER"

local varMissing q2a q3a q4 q6 q7 q8a q8b q8c q8d q8e q8f q8g q8h q8i q8j q8k q8l
local varMissing `varMissing' q9 q10a q10b q96 q97 q101a q101b q102 q103 q104 q107a
local varMissing `varMissing' q107b q107c age union q112 state
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNo q107a
foreach var in `varYesNo' { 
	replace `var'  = 2-`var'
	label values `var' lb_yesNo
}

local varAppDisapp q1
foreach var in `varAppDisapp' {
	label values `var' lb_appDisapp
}

local varYesNoNoOp q3a q3b q3c
foreach var in `varYesNoNoOp' {
	label values `var' lb_yesNoNoOp
}

local varAgrDisagr 
foreach var in `varAgrDisagr' {
	label values `var' lb_agrDisagr
}

local varFavOppNoOp 
foreach var in `varFavOppNoOp' {
	label values `var' lb_favOppNoOp
}

foreach var in  {
	label values `var' lb_YesNoDontKnow
}

rename q1 presApprovala
label variable presApprovala "NIXON JOB APPROVAL"

rename q2a nixonProgress
label variable nixonProgress "NIXON'S IMPROVEMENT SINCE ELECTION"
label define lb_BetterWorse2 1 "BETTER" 2 "WORSE" 3 "NO CHANGE" 4 "DON'T KNOW" 0 "NO CODE OR NO DATA"
label values nixonProgress lb_BetterWorse2

local vars PeaceVietnam HelpPoor ForeignRelations Image Promises Dignity Listen
local vars `vars' HandleIssuesWell MoreCautious Honesty Firm Initiative BetterJohnson 
local vars `vars' Favorable MiscFavor MissPromises IgnorePoor DisapproEuroTrip Unfavorable
local vars `vars' MiscUnfavor NoAnswer
local n = 1
foreach v in `vars' {
	rename q2b`n' nixon`v'
	local n = `n' + 1
}

rename q3a jewPresident
rename q3b cathPresident
rename q3c blkPresident
rename q4 womanPresident
foreach var in blkPresident jewPresident cathPresident womanPresident {
	label values `var' lb_yesNoNoOp
}


local vars AntiCommstPeace PeaceTalks KeepFighting MoreMilitary PullOut ExitOrExculate
local vars `vars' EndWar Misc DontKnow 
local n = 1
foreach v in `vars' {
	rename q5_`n' vietnam`v'
	local n = `n' + 1
}

rename q6 lengthVietnam
label variable lengthVietnam "HOW LONG WILL VIETNAM LAST"
label define lb_lengthVietnam 1 "UNDER 2 YEARS" 2 "OVER 2 YEARS" 3 "DONíT KNOW" 0 "NO CODE OR NO DATA" 
label values lengthVietnam lb_lengthVietnam

rename q7 womenPolitics
label variable womenPolitics "WOULD U.S. BE GOVERNED BETTER IF WOMEN HAD MORE SAY"
label define lb_BetterWorse3 1 "BETTER" 2 "WORSE" 3 "SAME" 4 "NO OPINION" 0 "NO CODE OR NO DATA"
label values womenPolitics lb_BetterWorse3 

rename q8a rateCastro
rename q8b rateEisenhower
rename q8c rateMcCarthy
rename q8d rateWallace
rename q8e rateNixon
rename q8f rateHumphrey
rename q8g rateAgnew
rename q8h rateMuskie
rename q8i rateKennedy
rename q8j rateMcGovern
rename q8k rateStokes
rename q8l rateMrsNixon
local var Castro Eisenhower McCarthy Wallace Nixon Humphrey Agnew Muskie Kennedy McGovern Stokes MrsNixon
foreach v in `var' {
	local V = upper("`v'")
	label variable rate`v' "RATE `V'"
}

rename q9 fedIncomeTax
label variable fedIncomeTax "LEVEL OF PERSONAL FEDERAL INCOME TAX"
recode fedIncomeTax (2 = 3) (3 = 2)
label define  lb_fedIncomeTax 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION"
label values fedIncomeTax lb_fedIncomeTax

rename q10a voteRegist
label variable voteRegist "REGISTERED TO VOTE"	
label define lb_voteRegist 1 "YES" 2 "NO" 3 "DONíT HAVE TO REGISTER" 4 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label values voteRegist lb_voteRegist

rename q10b planVoteRegist
label variable planVoteRegist "PLANNING TO REGISTER TO VOTE"
label define lb_planVoteRegist 1 "YES" 2 "NO" 3 "OTHER" 9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"
label values planVoteRegist lb_planVoteRegist

rename q96 incomeHH_60s
label define lb_incomeHH_60s 1 "UNDER 1000 DOLLARS A YEAR OR UNDER $20 A WEEK" 2 "1,000 TO 1,499 A YEAR OR $20 TO $28.50 A WEEK" 3 "1,500 TO 1,999 A YEAR OR $29 TO $37.50 A WEEK" 4 "2,000 TO 2,499 A YEAR OR $38 TO $47.50 A WEEK" 5 "2,500 TO 2,999 A YEAR OR $48 TO $57.50 A WEEK" 6 "3,000 TO 3,999 A YEAR OR $58 TO $76.50 A WEEK" 7 "4,000 TO 4,999 A YEAR OR $77 TO $95.50 A WEEK" 8 "5,000 TO 6,999 A YEAR OR $96 TO $134.50 A WEEK" 9 "7,000 TO 9,999 A YEAR OR $135 TO $192.50 A WEEK" 10 "10,000 TO 14,999 A YEAR OR $193 TO $288.50 A WEEK" 11 "15,000 AND OVER A YEAR OR $289 AND MORE A WEEK"
label values incomeHH_60s lb_incomeHH_60s

	gen incomeHHharmonized = .
	replace incomeHHharmonized = 500 if incomeHH_60s == 1
	replace incomeHHharmonized = 1250 if incomeHH_60s == 2
	replace incomeHHharmonized = 1750 if incomeHH_60s == 3
	replace incomeHHharmonized = 2250 if incomeHH_60s == 4
	replace incomeHHharmonized = 2750 if incomeHH_60s == 5
	replace incomeHHharmonized = 3500 if incomeHH_60s == 6
	replace incomeHHharmonized = 4500 if incomeHH_60s == 7
	replace incomeHHharmonized = 6000 if incomeHH_60s == 8
	replace incomeHHharmonized = 8500 if incomeHH_60s == 9
	replace incomeHHharmonized = 12500 if incomeHH_60s == 10
	replace incomeHHharmonized = 15000 if incomeHH_60s == 11

rename q97 goMovies
label variable goMovies "LAST TIME WENT OUT TO THE MOVIES"
label define lb_goMovies 1 "WITHIN PAST 7 DAYS" 2 "1 WEEK UP TO 1 MONTH" 3 "1 MONTH UP TO 6 MONTHS" 4 "MORE THAN 6 MONTHS" 5 "NEVER ATTEND" 0 "NO CODE OR NO DATA"
label values goMovies lb_goMovies

rename q100 voteNixonHumphreyWallace
label variable voteNixonHumphreyWallace "1968 ELECTION: NIXON VS HUMPHREY VS WALLACE"
label define lb_voteNixonHumphreyWallace 1 "NIXON" 2 "HUMPHREY" 3 "WALLACE" 4 "OTHER" 5 "VOTED, DONíT REMEMBER FOR WHOM" 6 "NO, DIDNíT VOTE" 7 "DONíT REMEMBER"
label values voteNixonHumphreyWallace lb_voteNixonHumphreyWallace

rename q101a adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

rename q101b minorsHH
label variable minorsHH "NUMBER OF CHILDREN (MINORS) LIVING IN THIS HOUSEHOLD"
label define lb_minorsHH 1 "ONE CHILD" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE" 11 "NO MINOR CHILDREN"
label values minorsHH lb_minorsHH

rename q102 edu 
label define lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
label values edu lb_edu

rename q103 occupation
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q104 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

rename q107a attendChurch
label variable attendChurch "ATTENDED CHURCH OR SYNAGOGUE IN THE LAST 7 DAYS"

rename q107b religionOrtho
label define  lb_religionOrtho 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "EASTERN ORTHODOX" 5 "OTHER" 6 "NONE"
label values religionOrtho lb_religionOrtho

gen religion = religionOrtho
replace religion = 4 if religionOrtho == 5
replace religion = 5 if religionOrtho == 6
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

rename q107c vProtestant
label variable vProtestant "PROTESTANT DENOMINATION"
label define  lb_vProtestant 1 "BAPTIST" 2 "METHODIST" 3 "PRESBYTERIAN" 4 "LUTHERAN" 5 "EPISCOPAL" 6 "OTHER" 9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"
label values vProtestant lb_vProtestant

label define lb_union 1 "YES, RESPONDENT IS" 2 "YES, SPOUSE IS" 3 "YES, BOTH ARE" 4 "NO, NEITHER IS"
label values union lb_union

label define  lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "NEGRO MAN" 4 "NEGRO WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

rename q112 rentOwn
label variable rentOwn "DO YOU OWN OR RENT YOUR HOME"
label define lb_rentOwn 1 "OWN" 2 "RENT" 3 "OTHER ARRANGEMENT" 0 "NO CODE OR NO DATA" 
label values rentOwn lb_rentOwn

label define  lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/776-1969.dta", replace 
local svys `svys' 776-1969


*Gallup News Service Poll: Kosovo/Hillary Clinton [USAIPOGNS1999-9902012]
clear 
infix 7 lines 1: ///
	wgt 13-15 ///
	sex 44 ///
	age 45-46 ///
	edu 47 ///
	state 78-79 ///
	5: ///
	advDegree 12 ///
	hispanic 13 ///
	race 14-15 ///
	hispWhtBlk 16-17 ///
	incomeHH 53-54 ///
	phoneLines 55 ///
	partyID 18 ///
	partyIDLean 19 ///
	poliPhilo 25 ///
	voteRegist 60 ///
	articulate 30 ///
	contact 31 ///
	name 32-51 ///
	dow 53 ///
	sexInter 54 ///
	6: ///
	q1 20 ///
	q2a 21 ///
	q2b 22 ///
	q2c 23 ///
	q2d 24 ///
	q2e 25 ///
	q2f 26 ///
	q2g 27 ///
	q2h 28 ///
	q2i 29 ///
	q2j 30 ///
	q2l 31 ///
	q2m 32 ///
	q2n 33 ///
	q2o 34 ///
	q2p 35 ///
	q2q 36 ///
	q2r 37 ///
	q2s 38 ///
	q2t 39 ///
	q2u 40 ///
	q3 41 ///
	q3a 42 ///
	q4 43 ///
	q4a 44 ///
	q5a 45 ///
	q5b 46 ///
	q6 47 ///
	q7 48 ///
	q8 49 ///
	q9a 50 ///
	q9b 51 ///
	q9c 52 ///
	q9d 53 ///
	q10 54 ///
	q11 55 ///
	q12 56 ///
	q13 57 ///
	q14a 58 ///
	q14b 59 ///
	q15 60 ///
	q16 61 ///
	q17 62 ///
	q18 63 ///
	q20 65 ///
	q21 66 ///
	q21a 64 ///
	q22 67 ///
	q23 68 ///
	q24 69 ///
	q25 70 ///
	q26 71 ///
	q27 72 ///
	q28 73 ///
	q29 74 ///
	q30 75 ///
	7: ///
	q31 12 ///
	q32 13 ///
	q33a 14 ///
	q33b 15 ///
	q33c 16 ///
	q34 17 ///
	q35a 18 ///
	q35b 19 ///
	q35c 20 ///
	q35d 21 ///
	q35e 22 ///
	q35f 23 ///
	voteJewish 24 ///
	voteAtheist 25 ///
	voteBlack 26 ///
	voteCatholic 27 ///
	voteLGBT 28 ///
	voteWomen 29 ///
	voteBaptist 30 ///
	voteMormon 31 ///	
	using "$ascii/9902012.dat"
gen svy_year = 1999
gen svy_month = "February"
gen svy = "1999-9902012"

label define  lb_yesNo 0 "No" 1 "Yes"
label define  lb_yesNoNoDK 1 "Yes" 2 "No" 3 "DON'T KNOW/REFUSED"
label define  lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define  lb_favOppNoOp 1 "FAVOR" 2 "OPPOSE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_favOppDK 1 "FAVOR" 2 "OPPOSE" 3 "DON'T KNOW/REFUSED" 
label define  lb_appDisapp 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_appDisappDK 1 "APPROVE" 2 "DISAPPROVE" 3 "DON'T KNOW/REFUSED"
label define  lb_agrDisagr 1 "AGREE" 2 "DISAGREE" 3 "NO OPINION"  9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"
label define  lb_shouldNot1 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 0 "NO CODE OR NO DATA" 
label define  lb_shouldNot2 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"  
label define  lb_yesNoRem 1 "Yes" 2 "NO" 3 "Don't Remember" 4 "NO CODE OR NO DATA"
label define  lb_UpDown 1 "GO UP" 2 "GO DOWN" 3 "REMAIN SAME" 4 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_PosImpos 1 "POSSIBLE" 2 "IMPOSSIBLE" 3 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_GoodPoor 1 "GOOD IDEA" 2 "POOR IDEA" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_BetterWorse 1 "BETTER" 2 "WORSE" 3 "ABOUT SAME" 4 "NO OPINION"
label define  lb_MoreLess 1 "MORE" 2 "LESS" 3 "SAME" 4 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_YesNoDontKnow 1 "YES" 2 "NO" 3 "DON'T KNOW" 9 "INAPPLICABLE"
label define  lb_IncreaseDecrease 1 "INCREASED" 2 "DECREASED" 3 "KEPT SAME" 4 "NO OPINION"
label define lb_interest 1 "IS INTERESTED" 2 "IS NOT INTERESTED" 3 "NO OPINION"
label define lb_5scale 1 "5" 2 "4" 3 "3" 4 "2" 5 "1" 6 "-1" 7 "-2" 8 "-3" 9 "-4" 10 "-5" 11 "UNDESIGNATED, NO ANSWER"

local varMissing age
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNo articulate contact
foreach var in `varYesNo' { 
	replace `var'  = 2-`var'
	label values `var' lb_yesNo
}

local varAppDisappDK q1 q20 q28
foreach var in `varAppDisappDK' {
	label values `var' lb_appDisappDK
}

local varYesNoNoDK q7 q25 q26 advDegree hispanic q9a q9b q9c q9d q22
foreach var in `varYesNoNoDK' {
	label values `var' lb_yesNoNoDK
}

local varAgrDisagr 
foreach var in `varAgrDisagr' {
	label values `var' lb_agrDisagr
}

local varFavOppDK q6 q11 q12 q27 q29 q31 q35a q35b q35c q35d q35e q35f
foreach var in `varFavOppDK' {
	label values `var' lb_favOppDK
}

foreach var in voteJewish-voteMormon {
	label values `var' lb_yesNoNoOp
}

foreach var in  {
	label values `var' lb_YesNoDontKnow
}

rename q1 presApprovala
label variable presApprovala "MR. CLINTON JOB APPROVAL"

label define lb_heardOf 1 "FAVORABLE" 2 "UNFAVORABLE" 3 "HEARD OF, NO OPINION" 4 "NEVER HEARD OF" 5 "REFUSED"
rename q2a opinionMrClinton
rename q2b opinionMrsClinton
rename q2c opinionHastert
rename q2d opinionLott
rename q2e opinionLewinsky
rename q2f opinionTripp
rename q2g opinionStarr
rename q2h opinionHyde
rename q2i opinionKasich
rename q2j opinionQuayle
rename q2l opinionGore
rename q2m opinionBush
rename q2n opinionMcCain
rename q2o opinionForbes
rename q2p opinionSmith
rename q2q opinionBradley
rename q2r opinionJackson
rename q2s opinionDole
rename q2t opinionBauer
rename q2u opinionKerry
local vars MrClinton MrsClinton Hastert Lott Lewinsky Tripp Starr Hyde Kasich Quayle Gore Bush McCain Forbes Smith Bradley Jackson Dole Bauer Kerry
foreach v in `vars' {
	local V = upper("`v'")
	label variable opinion`v' "OPINION OF OR HEARD OF `V'"
	label values opinion`v' lb_heardOf	
}

rename q3 voteGoreBusha
label variable voteGoreBusha "HYPOTH VOTE: GORE VS BUSH (DOESN'T MENTION BUSH SR.)"
label define lb_voteGoreBush 1 "AL GORE, THE DEMOCRAT" 2 "GEORGE W BUSH, THE REPUBLICAN" 3 "NEITHER" 4 "OTHER" 5 "DON'T KNOW" 6 "REFUSED"
label values voteGoreBusha lb_voteGoreBush

rename q3a leanGoreBusha
label variable leanGoreBusha "LEANINGS: GORE VS BUSH"
label values leanGoreBusha lb_voteGoreBush

rename q4 voteGoreBushb
label variable voteGoreBushb "HYPOTH VOTE: GORE VS BUSH (MENTIONs BUSH SR.)"
label values voteGoreBushb lb_voteGoreBush

rename q4a leanGoreBushb
label variable leanGoreBushb "LEANINGS: GORE VS BUSH"
label values leanGoreBushb lb_voteGoreBush

rename q5a opinionRepublicans
label variable opinionRepublicans "OPINION OF REPUBLICAN PARTY" 
label values opinionRepublicans lb_heardOf
rename q5b opinionDemocratics
label variable opinionDemocratics "OPINION OF DEMOCRATIC PARTY"
label values opinionDemocratics lb_heardOf

rename q6 hateCrimeLaws
label variable hateCrimeLaws "SUPPORT HATE CRIME LAWS IN STATE"

rename q7 knowHateCrime
label variable knowHateCrime "KNOW SOMEONE CAPABLE OF HATE CRIME"

rename q8 worryHateCrime
label variable worryHateCrime "WORRY ABOUT BEING HATE CRIME VICTIM"

rename q9a minorityHateCrime
label variable minorityHateCrime "EXPECT MINORITIES COVERED UNDER HATE CRIME"
rename q9b womenHateCrime
label variable womenHateCrime "EXPECT WOMEN COVERED UNDER HATE CRIME"
rename q9c LGBTHateCrime
label variable LGBTHateCrime "EXPECT LGBT COVERED UNDER HATE CRIME"
rename q9d ReliEthnicHateCrime
label variable ReliEthnicHateCrime "EXPECT RELIGIOUS AND ETHNIC MINORITIES COVERED UNDER HATE CRIME"

rename q10 followKosovo
label variable followKosovo "FOLLOW KOSOVO SITUATION"
label define lb_Closeness 1 "VERY CLOSELY" 2 "FAIRLY CLOSELY" 3 "NOT TOO CLOSELY" 4 "NOT AT ALL?" 5 "DON'T KNOW/REFUSED" 
label values followKosovo lb_Closeness

rename q11 natoSerbAttack
label variable natoSerbAttack "FAVOR NATO MISSILE ATTACKS AGAINST SERB MILITARY INSTALLATIONS"

rename q12 usTroopsKosovo 
label variable usTroopsKosovo "FAVOR U.S. PEACEKEEPING TROOPS TO KOSOVO"

rename q13 timeTableKosovo
label variable timeTableKosovo "FAVOR SPECIFIC TIMETABLE FOR KOSOVO WITHDRAWAL"
label define lb_timeTableKosovo 1 "FAVOR SETTING TIMETABLE" 2 "FAVOR TIMETABLE BE ESTABLISHED AS WARRANTED" 3 "DON'T KNOW/REFUSED"
label values timeTableKosovo lb_timeTableKosovo

label define lb_confident 1 "VERY CONFIDENT" 2 "SOMEWHAT CONFIDENT" 3 "NOT TOO CONFIDENT" 4 "NOT AT ALL CONFIDENT" 5 "DON'T KNOW/REFUSED"
rename q14a fewUSDeathKosovo
label variable fewUSDeathKosovo "U.S. HIT GOAL WITH FEW U.S. CASUALTIES"
rename q14b usNatoPeace
label variable usNatoPeace "U.S. & NATO PEACE MISSION IN KOSOVO WILL SECCEED"
label values fewUSDeathKosovo lb_confident
label values usNatoPeace lb_confident

rename q15 usInterestKosovo
label variable usInterestKosovo "SHOULD U.S. BE INVOLVED IN KOSOVO FOR ITS OWN INTEREST"
label define lb_usInterestKosovo 1 "NEEDS TO BE INVOLVED" 2 "DON'T THINK SO" 3 "DON'T KNOW/REFUSED"
label values usInterestKosovo lb_usInterestKosovo

rename q16 moralPeaceKosovo
label variable moralPeaceKosovo "U.S. HAS MORAL OBLIGATION TO KEEP PEACE IN KOSOVO"
label define lb_moralPeaceKosovo 1 "YES, DOES HAVE MORAL OBLIGATION" 2 "NO, DOES NOT" 3 "DON'T KNOW/REFUSED"
label values moralPeaceKosovo lb_moralPeaceKosovo

rename q17 approvalKosovo
label variable approvalKosovo "CLINTON GET APPROVAL FROM CONGRESS BEFORE KOSOVO"
label define lb_approvalKosovo 1 "SHOULD GET APPROVAL" 2 "DON'T THINK SO" 3 "DON'T KNOW/REFUSED"
label values approvalKosovo lb_approvalKosovo

rename q18 descKosovo
label variable descKosovo "WHAT BEST DESCRIBES KOSOVO"
label define lb_descKosovo 1 "IT IS LOCATED IN THE BALKANS REGIONS OF CENTRAL EUROPE, NORTH OF GREECE" 2 "IT IS LOCATED IN CENTRAL ASIA, AND WAS PART OF THE SOVIET UNION BEFORE IT BROKE UP" 3 "IT IS LOCATED IN CENTRAL AFRICA, AND WAS A FORMER COLONIAL POSSESSION"	4 "IT IS LOCATED IN SOUTHEAST ASIA, NEAR BURMA AND CAMBODIA" 5 "DON'T KNOW/REFUSED"
label values descKosovo lb_descKosovo

rename q20 firstLadyApproval
label variable firstLadyApproval "APPROVAL OF MRS. CLINTON'S JOB AS FIRST LADY"

rename q21 impactHClinton
label variable impactHClinton "H. CLINTON'S IMPACT ON ADMINISTRATION"
label define lb_impactHClinton 1 "GENERALLY POSITIVE" 2 "GENERALLY NEGATIVE" 3 "MIXED" 4 "DON'T KNOW/REFUSED"
label values impactHClinton lb_impactHClinton

rename q21a ideaFirstLady
label variable ideaFirstLady "REPRESENTATIVE IDEAL FIRST LADY"
label define lb_ideaFirstLady 1 "ROSLYN CARTER" 2 "NANCY REAGAN" 3 "BARBARA BUSH" 4 "HILLARY CLINTON" 5 "ALL/ANY" 6 "NONE" 7 "DON'T KNOW/REFUSED"
label values ideaFirstLady lb_ideaFirstLady

rename q22 hillaryRunSenate
label variable hillaryRunSenate "SHOULD H. CLINTON FOR SENATOR IN 2000"

rename q23 hillarySenateFLady 
label variable hillarySenateFLady "SHOULD H. CLINTON RUN SENATE CAMPAIGN WHILE FIRST LADY"
label define lb_hillarySenateFLady 1 "YES, APPROPRIATE" 2 "NO, NOT APPROPRIATE" 3 "DON'T KNOW/REFUSED"
label values hillarySenateFLady lb_hillarySenateFLady

rename q24 impactHillaryCampg
label variable impactHillaryCampg "IMPACT OF H. CLINTON SENATE RUN ON ADMINISTRATION"
label define lb_impactHillaryCampg 1 "POSITIVE EFFECT" 2 "NEGATIVE EFFECT" 3 "WON'T MAKE ANY DIFFERENCE" 4 "DON'T KNOW/REFUSED"
label values impactHillaryCampg lb_impactHillaryCampg

rename q25 hillaryQualPres
label variable hillaryQualPres "H. CLINTON EVENTUALLY QUALIFIED TO BE U.S. PRESIDENT"

rename q26 hillaryRunPres
label variable hillaryRunPres "SHOULD H. CLINTON EVENTUALLY RUN FOR PRESIDENT"

rename q27 miscondStarr
label variable miscondStarr "INVESTIGATE POSSIBLE MISCONDUCT BY STARR"

rename q28 clintonIraq
label variable clintonIraq "APPROVE B. CLINTON'S HANDLING OF IRAQ"

rename q29 militaryIraq
label variable militaryIraq "U.S. AND ALLIES ALL-OUT MILITARY ACTION AGAINST IRAQ"

rename q30 resolutionIraq
label variable resolutionIraq "PREFERRED IRAQ RESOLUTION"
label define lb_resolutionIraq 1 "THROUGH DIPLOMATIC PRESSURE AND ECONOMIC SANCTIONS" 2 "THROUGH MILITARY AIR-STRIKES AND MISSILE ATTACKS LAUNCHED BY THE U.S. AND OTHER COUNTRIES"	3 "THROUGH A MILITARY INVASION USING U.S. AND ALLIED COUNTRIES' GROUND FORCE" 4 "NEITHER/OTHER" 5 "DON'T KNOW/REFUSED" 
label values resolutionIraq lb_resolutionIraq

rename q31 forceHussein
label variable forceHussein "USE FORCE TO REMOVE HUSSEIN"

rename q32 usIraqSanctions
label variable usIraqSanctions "FEELINGS ABOUT IRAQ SANCTIONS"
label define lb_usIraqSanctions 1 "THE UNITED NATIONS SHOULD CONTINUE THESE SANCTIONS UNTIL SADDAM HUSSEIN COMPLIES WITH ALL U.N. RESOLUTIONS" 2 "THE UNITED NATIONS SHOULD LIFT ALL SANCTIONS AGAINST IRAQ" 3 "OTHER" 4 "DON'T KNOW/REFUSED"
label values usIraqSanctions lb_usIraqSanctions

rename q33a clintonCongressTax
label variable clintonCongressTax "TRUST WITH TAXES: CLINTON OR CONGRESS"
rename q33b clintonCongressSS
label variable clintonCongressSS "TRUST WITH SOCIAL SECURITY: CLINTON OR CONGRESS"
rename q33c clintonCongressBudget 
label variable clintonCongressBudget "TRUST WITH BUDGET: CLINTON OR CONGRESS"

label define lb_trustIssue 1 "CLINTON" 2 "REPUBLICANS IN CONGRESS" 3 "SAME/BOTH" 4 "NEITHER" 5 "DON'T KNOW/REFUSED"
foreach v in Tax SS Budget {
	label values clintonCongress`v' lb_trustIssue
}

rename q34 useSurplus
label variable useSurplus "USE OF BUDGET SURPLUS"
label define lb_useSurplus 1 "TO FUND NEW RETIREMENT SAVINGS ACOUNTS, AS WELL AS INCREASE SPENDING ON EDUCATION, DEFENSE, MEDICARE, AND OTHER PROGRAMS" 2 "TO PAY FOR A 10 PERCENT CUT IN FEDERAL INCOME TAX RATES" 3 "NEITHER/OTHER" 4 "DON'T KNOW/REFUSED"
label values useSurplus lb_useSurplus

rename q35a propCutTax
label variable propCutTax "SUPPORT CUTTING TAX RATES BY 10%"
rename q35b propMarriagePen
label variable propMarriagePen "SUPPORT REMOVING MARRIAGE PENALTY"
rename q35c propFedPrograms
label variable propFedPrograms "SUPPORT MORE SPENDING ON FEDERAL PROGRAMS"
rename q35d propMedicare
label variable propMedicare "SUPPORT MORE SPENDING ON MEDICARE"
rename q35e propSS
label variable propSS "SUPPORT MORE SPENDING ON SOCIAL SECURITY"
rename q35f propFedRetirement
label variable propFedRetirement "SUPPORT NEW FED RETIREMENT PROGRAM"

rename voteJewish jewPresident
rename voteAtheist atheistPresident
rename voteBlack blkPresident
rename voteCatholic cathPresident
rename voteLGBT LGBTPresident
rename voteWomen womanPresident
rename voteBaptist baptistPresident  
rename voteMormon mormonPresident

rename incomeHH incomeHH_1999

gen raceSex = .
replace raceSex = 1 if (sex == 1 & race == 6)
replace raceSex = 2 if (sex == 2 & race == 6)
replace raceSex = 3 if (sex == 1 & race == 7)
replace raceSex = 4 if (sex == 2 & race == 7)
replace raceSex = 5 if (sex == 1 & (race == 1 | race == 8))
replace raceSex = 6 if (sex == 2 & (race == 1 | race == 8))
label define  lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "NEGRO MAN" 4 "NEGRO WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

label define lb_sex 1 "MALE" 2 "FEMALE"
label values sex lb_sex
replace sex = . if sex == 3

rename race raceDetailed
label define lb_raceDetailed 1 "OTHER" 2 "DON'T KNOW" 3 "REFUSED" 6 "WHITE" 7 "AFRICAN-AMERICAN/BLACK" 8 "HISPANIC"
label values raceDetailed lb_raceDetailed

gen race = .
replace race = 1 if raceDetailed == 6
replace race = 2 if raceDetailed == 7
replace race = 3 if (raceDetailed == 1 | raceDetailed == 8)
label define lb_race 1 "WHITE" 2 "BLACK" 3 "OTHER"
label values race lb_race

replace edu = . if edu == 9
label define lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
label values edu lb_edu

label variable advDegree "ANY POST-GRADUATE EDUCATION BEYOND BA/BS"
label variable hispWhtBlk "White- or Black-Hispanic"
label variable phoneLines "NUMBER OF PHONE NUMBERS IN HOUSEHOLDS"

rename partyID poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID
replace poliPartyID = . if poliPartyID == 5

label variable dow "Day of Week"
label define lb_dow 1 "MON" 2 "TUES" 3 "WED" 4 "THURS" 5 "FRI" 6 "SAT" 7 "SUN"
label values dow lb_dow

label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/9902012-1999.dta", replace 
local svys `svys' 9902012-1999


*Gallup Poll # 838
clear 
infix ///
	card 1 ///
	deck 2-4 ///
	ballot 5 ///
	area 6-8 ///
	q1 9 ///
	q2 10 ///
	q3 11 ///
	q4 12 ///
	q5 13 ///
	q6b 14-15 ///
	q6c 16 ///
	q7a 17 ///
	q7b 18 ///
	q8a 19 ///
	q8b1 20 ///
	q8b2 21 ///
	q8b3 22 ///
	q8b4 23 ///
	q8b5 24 ///
	q8b6 25 ///
	q8b7 26 ///
	q8b8 27 ///
	q8b9 28 ///
	q8b10 29 ///
	q8b11 30 ///
	q8b12 31 ///
	q8b13 32 ///
	q8b14 33 ///
	q8b15 34 ///
	q8b16 35 ///
	q8b17 36 ///
	q8b18 37 ///
	q9a 38 ///
	q9b 39 ///
	q9c 40-41 ///
	q10 42 ///
	q11 43 ///
	q12 44 ///
	q13 45 ///
	q14 46 ///
	q100 47 ///
	q101 48 ///
	q102a 49-50 ///
	q103a 51-52 ///
	q105 53 ///
	q106 54-55 ///
	q107 56-57 ///
	q108 58 ///
	age 59-60 ///
	religion 61 ///
	union 62 ///
	raceSex 63 ///
	citySize 64-65 ///
	state 66-67 ///
	wgt 68 ///
	wgt_trendsFactor 69 ///
	using "$ascii/838.dat"
gen svy_year = 1971
gen svy_month = "October"
gen svy = "1971-0838"

label define  lb_yesNo 0 "No" 1 "Yes"
label define  lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define  lb_favOppNoOp 1 "FAVOR" 2 "OPPOSE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_appDisapp 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_agrDisagr 1 "AGREE" 2 "DISAGREE" 3 "NO OPINION"  9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"
label define  lb_shouldNot1 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 0 "NO CODE OR NO DATA" 
label define  lb_shouldNot2 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"  
label define  lb_yesNoRem 1 "Yes" 2 "NO" 3 "Don't Remember" 4 "NO CODE OR NO DATA"
label define  lb_UpDown 1 "GO UP" 2 "GO DOWN" 3 "REMAIN SAME" 4 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_PosImpos 1 "POSSIBLE" 2 "IMPOSSIBLE" 3 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_GoodPoor 1 "GOOD IDEA" 2 "POOR IDEA" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_BetterWorse 1 "BETTER" 2 "WORSE" 3 "ABOUT SAME" 4 "NO OPINION"
label define  lb_MoreLess 1 "MORE" 2 "LESS" 3 "SAME" 4 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_YesNoDontKnow 1 "YES" 2 "NO" 3 "DON'T KNOW" 9 "INAPPLICABLE"
label define  lb_IncreaseDecrease 1 "INCREASED" 2 "DECREASED" 3 "KEPT SAME" 4 "NO OPINION"
label define lb_interest 1 "IS INTERESTED" 2 "IS NOT INTERESTED" 3 "NO OPINION"
label define lb_5scale 1 "5" 2 "4" 3 "3" 4 "2" 5 "1" 6 "-1" 7 "-2" 8 "-3" 9 "-4" 10 "-5" 11 "UNDESIGNATED, NO ANSWER"

local varMissing q1 q2 q5 q6b q4 q3 q7a q8a q9a q9b q10 q12 q13 q14 q100 q101 q102a
local varMissing `varMissing' q103a q105 q107 q108 age religion union 
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNo q7a 
foreach var in `varYesNo' { 
	replace `var'  = 2-`var'
	label values `var' lb_yesNo
}

local varAppDisapp q2 q12
foreach var in `varAppDisapp' {
	label values `var' lb_appDisapp
}

local varYesNoNoOp q10 q11
foreach var in `varYesNoNoOp' {
	label values `var' lb_yesNoNoOp
}

local varAgrDisagr 
foreach var in `varAgrDisagr' {
	label values `var' lb_agrDisagr
}

local varFavOppNoOp q5 q7b
foreach var in `varFavOppNoOp' {
	label values `var' lb_favOppNoOp
}

foreach var in  {
	label values `var' lb_YesNoDontKnow
}

label define lb_UpDown2 1 "HIGHER" 2 "LOWER" 3 "ABOUT SAME" 4 "NO OPINION" 0 "NO CODE OR NO DATA"
rename q1 chgPrice
label variable chgPrice "EXPECTED CHANGE IN PRICES"
label values chgPrice lb_UpDown2

rename q2 schoolBible
label variable schoolBible "OPINION OF BAN ON MANDATORY PRAYER AND BIBLE VERSES IN P. SCHOOLS"

rename q3 chgUnempl
label variable chgUnempl "EXPECTED CHANGE IN UNEMPLOYMENT RATE"
label values chgUnempl lb_MoreLess

rename q4 underWires
label variable underWires "REQUIRE UNDERGROUND WIRES"
label values underWires lb_GoodPoor

rename q5 gunPermit
label variable gunPermit "REQUIRE POLICE PERMIT BEFORE GUN PERCHASE"

rename q6b leanNixonMuskieWallace
label variable leanNixonMuskieWallace "LEANINGS: NIXON VS MUSKIE VS WALLACE"
label define lb_leanNixonMuskieWallace 1 "BARRY GOLDWATER, SENATOR FROM ARIZONA" 2 "NELSON ROCKEFELLER, GOVERNOR OF NEW YORK" 3 "GEORGE ROMNEY, GOVERNOR OF MICHIGAN" 1 "NIXON" 2 "MUSKIE" 3 "WALLACE" 4 "OTHER, NO ANSWER TO Q.6B" 5 "UNDECIDED, NO ANSWER TO Q.6B" 6 "UNDECIDED OR OTHER, LEANS TOWARD NIXON" 7 "UNDECIDED OR OTHER, LEANS TOWARD MUSKIE" 8 "UNDECIDED OR OTHER, LEANS TOWARD WALLACE" 9 "UNDECIDED OR OTHER, LEANS TOWARD OTHER CANDIDATE" 10 "UNDECIDED OR OTHER, UNDECIDED" 0 "NO CODE OR NO DATA"
label values leanNixonMuskieWallace lb_leanNixonMuskieWallace

rename q6c voteNixonMuskie
label variable voteNixonMuskie "PREFER: NIXON VS MUSKIE"
label define lb_voteNixonMuskie 1 "NIXON" 2 "MUSKIE" 3 "DON'T KNOW, NO ANSWER" 9 "INAPPLICABLE"
label values voteNixonMuskie lb_voteNixonMuskie

rename q7a heardBusIntegration
label variable heardBusIntegration "HEARD OF INTEGRATION VIA BUSSING"
rename q7b favorBusIntegration
label variable favorBusIntegration "FAVOR INTEGRATION VIA BUSSING"

rename q8a wagePriceFreeze
label variable wagePriceFreeze "OPINION OF WAGE-PRICE FREEZE"
label define lb_wagePriceFreeze 1 "KEEP AS ARE NOW" 2 "KEEP, BUT CHANGE" 3 "GIVE UP" 4 "DONíT KNOW, NO ANSWER" 0 "NO CODE OR NO DATA"
label values wagePriceFreeze lb_wagePriceFreeze

foreach n of num 1/18 {
	rename q8b`n' wagePriceFreeze_`n'
}

label define lb_republicanViceNom 1 "SPIRO AGNEW" 2 "JOHN CONNALLY" 3 "PAUL MCCLOSKY, JR." 4 "RONALD REAGAN" 5 "NELSON ROCKEFELLER" 6 "GEORGE ROMNEY" 7 "CHARLES PERCY" 8 "OTHER" 9 "DONíT KNOW, NO ANSWER" 0 "NO CODE OR NO DATA"
rename q9a republicanViceNom1st 
label variable republicanViceNom1st "PREFERRED REPUBLICAN CANDIDATE FOR VICE PRESIDENT, FIRST CHOICE"
rename q9b republicanViceNom2nd 
label variable republicanViceNom2nd "PREFERRED REPUBLICAN CANDIDATE FOR VICE PRESIDENT, SECOND CHOICE"
foreach v in 1st 2nd {
	label values republicanViceNom`v' lb_republicanViceNom
}

rename q9c republicanViceNomAdd
label variable republicanViceNomAdd "ADDITIONAL REPUBLICAN CANDIDATES FOR VICE PRESIDENT"
label define lb_republicanViceNomAdd 1 "HICKEL" 2 "GOLDWATER" 3 "MARK HATFIELD" 4 "JOSEPH RHODES - PAST GOVERNOR OF OHIO" 5 "LT. GOVERNOR MALCOLM WILSON OF NEW YORK" 6 "GERALD FORD" 7 "EDWARD BROOKE" 8 "A DEMOCRAT:  KENNEDY, LINDSAY" 9 "OTHER:  WALLACE, MYSELF" 10 "MISCELLANEOUS:  REPUBLICAN SENATOR FROM WASHINGTON" 11 "NO" 12 "NO ANSWER"
label values republicanViceNomAdd lb_republicanViceNomAdd

rename q10 blkPresident
rename q11 blkVicePresident
rename q12 presApprovala
label variable presApprovala "NIXON JOB APPROVAL"

rename q13 voteRegist
label variable voteRegist "REGISTERED TO VOTE"	
label define lb_voteRegist 1 "YES" 2 "NO" 3 "DONíT HAVE TO REGISTER" 4 "DONíT KNOW" 0 "NO CODE OR NO DATA"

rename q14 curPartyID
label variable curPartyID "CURRENT PREFERED PARTY ID (IF HAD TO REGISTER)"
replace curPartyID = 9 if curPartyID == 3
label define lb_curPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "OTHER PARTY, NO ANSWER TO PART B" 4 "INDEPENDENT, NO ANSWER TO PART B" 5 "OTHER PARTY OR INDEPENDENT, WOULD REGISTER AS REPUBLICAN" 6 "OTHER PARTY OR INDEPENDENT, WOULD REGISTER AS DEMOCRAT" 7 "OTHER PARTY OR INDEPENDENT, CAN'T DECIDE" 8 "OTHER PARTY OR INDEPENDENT, WOULD REFUSE TO REGISTER" 9 "UNDECIDED"
label values curPartyID lb_curPartyID

rename q100 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

rename q101 citizenship
label define lb_citizenship 1 "NATURAL-BORN CITIZEN" 2 "NATURALIZED CITIZEN" 3 "NON-CITIZEN" 0 "NO CODE OR NO DATA"
label values citizenship lb_citizenship

rename q102a adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define  lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

rename q103a minorsHH
label variable minorsHH "NUMBER OF CHILDREN (MINORS) LIVING IN THIS HOUSEHOLD"
label define lb_minorsHH 1 "ONE CHILD" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE" 11 "NO MINOR CHILDREN"
label values minorsHH lb_minorsHH

rename q105 relationship
label variable relationship "RELATIONSHIP STATUS"
label define lb_relationship 1 "MARRIED" 2 "SINGLE" 3 "DIVORCED-WIDOWED"
label values relationship lb_relationship

rename q106 occupation
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q107 incomeHH_70s
label define lb_incomeHH_70s 1 "UNDER $1,000 A YEAR OR UNDER $20 A WEEK" 2 "$1,000 TO $1,999 A YEAR OR $20 TO $37.50 A WEEK" 3 "$2,000 TO $2,999 A YEAR OR $38 TO $57.50 A WEEK" 4 "$3,000 TO $3,999 A YEAR OR $58 TO $76.50 A WEEK" 5 "$4,000 TO $4,999 A YEAR OR $77 TO $95.50 A WEEK" 6 "$5,000 TO $5,999 A YEAR OR $96 TO $114.50 A WEEK" 7 "$6,000 TO $6,999 A YEAR OR $115 TO $134.50 A WEEK" 8 "$7,000 TO $9,999 A YEAR OR $135 TO $192.50 A WEEK" 9 "$10,000 TO $11,999 A YEAR OR $193 TO $229.50 A WEEK" 10 "$12,000 TO $14,999 A YEAR OR $230 TO $288.50 A WEEK" 11 "$15,000 AND MORE A YEAR OR $289 AND MORE A WEEK"
label values incomeHH_70s lb_incomeHH_70s

	gen incomeHHharmonized = .
	replace incomeHHharmonized = 500 if incomeHH_70s == 1
	replace incomeHHharmonized = 1500 if incomeHH_70s == 2
	replace incomeHHharmonized = 2500 if incomeHH_70s == 3
	replace incomeHHharmonized = 3500 if incomeHH_70s == 4
	replace incomeHHharmonized = 4500 if incomeHH_70s == 5
	replace incomeHHharmonized = 5500 if incomeHH_70s == 6
	replace incomeHHharmonized = 6500 if incomeHH_70s == 7
	replace incomeHHharmonized = 8500 if incomeHH_70s == 8
	replace incomeHHharmonized = 11000 if incomeHH_70s == 9
	replace incomeHHharmonized = 13500 if incomeHH_70s == 10
	replace incomeHHharmonized = 15000 if incomeHH_70s == 11

rename q108 edu
label define lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
label values edu lb_edu

rename religion religionOrtho
label define lb_religionOrtho 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "EASTERN ORTHODOX" 5 "OTHER" 6 "NONE"
label values religionOrtho lb_religionOrtho

gen religion = religionOrtho
replace religion = 4 if religionOrtho == 5
replace religion = 5 if religionOrtho == 6
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

label define lb_union 1 "YES, RESPONDENT IS" 2 "YES, SPOUSE IS" 3 "YES, BOTH ARE" 4 "NO, NEITHER IS"
label values union lb_union

label define  lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "NEGRO MAN" 4 "NEGRO WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

label define  lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/838-1971.dta", replace 
local svys `svys' 838-1971


*Gallup Poll # 211G March 11-14, 1983
clear 
infix ///
	wgt 1 ///
	svyNum 2 ///
	q1 6 ///
	q2a 7 ///
	q2b 8 ///
	q3a 9 ///
	q3b 10 ///
	q3c 11 ///
	q3d 12 ///
	q4a1 13 ///
	q4a2 14 ///
	q4a3 15 ///
	q4a4 16 ///
	q4a5 17 ///
	q4a6 18 ///
	q4a7 19 ///
	q4a8 20 ///
	q4a9 21 ///
	q4a10 22 ///
	q4a11 23 ///
	q4a12 24 ///
	q4a13 25 ///
	q4a14 26 ///
	q4a15 27 ///
	q4a16 28 ///
	q4a17 29 ///
	q4b1 30 ///
	q4b2 31 ///
	q4b3 32 ///
	q4b4 33 ///
	q4b5 34 ///
	q4b6 35 ///
	q4b7 36 ///
	q4b8 37 ///
	q4b9 38 ///
	q4b10 39 ///
	q4b11 40 ///
	q4b12 41 ///
	q4b13 42 ///
	q4b14 43 ///
	q4b15 44 ///
	q4b16 45 ///
	q4b17 46 ///
	q4c 47-48 ///
	q4d 49-50 ///
	q4e1 51 ///
	q4e2 52 ///
	q4e3 53 ///
	q4e4 54 ///
	q4e5 55 ///
	q4e6 56 ///
	q4e7 57 ///
	q4e8 58 ///
	q4e9 59 ///
	q4e10 60 ///
	q4e11 61 ///
	q4e12 62 ///
	q4e13 63 ///
	q4e14 64 ///
	q4e15 65 ///
	q4e16 66 ///
	q4e17 67 ///
	q4f1 68 ///
	q4f2 69 ///
	q4f3 70 ///
	q4f4 71 ///
	q4f5 72 ///
	q4f6 73 ///
	q4f7 74 ///
	q4f8 75 ///
	q4f9 76 ///
	q4f10 77 ///
	q4f11 78 ///
	q4f12 79 ///
	q4f13 80 ///
	q4f14 81 ///
	q4f15 82 ///
	q4f16 83 ///
	q4f17 84 ///
	q5a 85 ///
	q5b 86 ///
	q5c 87 ///
	q5d 88 ///
	q6a 89 ///
	q6b 90 ///
	q6c 91 ///
	q6d 92 ///
	q7a 93 ///
	q7b 94 ///
	q7c 95 ///
	q7d 96 ///
	q7e 97 ///
	q8 98 ///
	q9 99 ///
	q10a 100-101 ///
	q10b 102-103 ///
	q901 104 ///
	q901a 105 ///
	q902 106 ///
	q903 107-108 ///
	q904 109-110 ///
	q904a 111 ///
	q904b 112 ///
	q904c 113 ///
	q904d 114 ///
	q905 115 ///
	q906 116 ///
	q907 117-118 ///
	q908 119 ///
	q909 120 ///
	q910a 121-122 ///
	q910b 123-124 ///
	q911 125 ///
	q912 126 ///
	q913 127 ///
	q914 128-129 ///
	q915 130 ///
	raceSex 131 ///
	sex 132 ///
	race 133 ///
	q917 134-135 ///
	q918 136 ///
	q919a 137 ///
	q919b 138-139 ///
	citySize 140-141 ///
	section 142 ///
	state 143-144 ///	
	smsa 145 ///
	repliSample 146 ///
	fringe 147 ///	
	using "$ascii/1211.dat"
gen svy_year = 1983
gen svy_month = "March"
gen svy = "1983-1211"

label define  lb_yesNo 0 "No" 1 "Yes"
label define  lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define  lb_favOppNoOp 1 "FAVOR" 2 "OPPOSE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_appDisapp 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_agrDisagr 1 "AGREE" 2 "DISAGREE" 3 "NO OPINION"  9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"
label define  lb_shouldNot1 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 0 "NO CODE OR NO DATA" 
label define  lb_shouldNot2 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"  
label define  lb_yesNoRem 1 "Yes" 2 "NO" 3 "Don't Remember" 4 "NO CODE OR NO DATA"
label define  lb_UpDown 1 "GO UP" 2 "GO DOWN" 3 "REMAIN SAME" 4 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_PosImpos 1 "POSSIBLE" 2 "IMPOSSIBLE" 3 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_GoodPoor 1 "GOOD IDEA" 2 "POOR IDEA" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_BetterWorse 1 "BETTER" 2 "WORSE" 3 "ABOUT SAME" 4 "NO OPINION"
label define  lb_MoreLess 1 "MORE" 2 "LESS" 3 "SAME" 4 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_YesNoDontKnow 1 "YES" 2 "NO" 3 "DON'T KNOW" 9 "INAPPLICABLE"
label define  lb_IncreaseDecrease 1 "INCREASED" 2 "DECREASED" 3 "KEPT SAME" 4 "NO OPINION"
label define lb_interest 1 "IS INTERESTED" 2 "IS NOT INTERESTED" 3 "NO OPINION"
label define lb_5scale 1 "5" 2 "4" 3 "3" 4 "2" 5 "1" 6 "-1" 7 "-2" 8 "-3" 9 "-4" 10 "-5" 11 "UNDESIGNATED, NO ANSWER"

local varMissing q4c q4d q7b q7c q7a q7e q9 q10a q10b q901 q901a q902 q903 q904
local varMissing `varMissing' q906 q909 q910a q911 q913 q914 q915 q917 q918 q919a q919b
local varMissing `varMissing' q919b 
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNo q901a q908 q9
foreach var in `varYesNo' { 
	replace `var'  = 2-`var'
	label values `var' lb_yesNo
}

local varAppDisapp q1
foreach var in `varAppDisapp' {
	label values `var' lb_appDisapp
}

local varYesNoNoOp q3b q3c q5a
foreach var in `varYesNoNoOp' {
	label values `var' lb_yesNoNoOp
}

local varAgrDisagr 
foreach var in `varAgrDisagr' {
	label values `var' lb_agrDisagr
}

local varFavOppNoOp 
foreach var in `varFavOppNoOp' {
	label values `var' lb_favOppNoOp
}

foreach var in  q7a {
	label values `var' lb_YesNoDontKnow
}

rename q1 presApprovala
label variable presApprovala "REAGAN JOB APPROVAL"

rename q2a situationMEast
label variable situationMEast "HEARD/READ ABOUT SITUATION IN MIDDLE EAST"

rename q2b israelArab
label variable israelArab "SYMPATHIES: ISRAEL OR ARAB NATIONS"
label define lb_israelArab 1 "ISRAEL" 2 "ARAB NATIONS" 3 "NEITHER (VOLUNTEERED)" 4 "DON'T KNOW" 0 "NO ANSWER/NOT APPLICABLE"
label values israelArab lb_israelArab

rename q3a freezeNWeapons
label variable freezeNWeapons "AGREE: U.S. SOVIET UNION NUCLEAR WEAPONS FREEZE"
label define lb_FavOppDK 1 "FAVOR" 2 "OPPOSE" 3 "DON'T KNOW"
label values freezeNWeapons lb_FavOppDK

rename q3b peaceEffUS
label variable peaceEffUS "U.S. DOING BEST TO KEEP GLOBAL PEACE"

rename q3c peaceEffUSSR
label variable peaceEffUSSR "USSR DOING BEST TO KEEP GLOBAL PEACE"

rename q3d leadNuclearWar
label variable leadNuclearWar "WHICH INCREASES CHANCE OF NUCLEAR WAR MORE"
label define lb_leadNuclearWar 1 "ARMS BUILD-UP" 2 "U.S. FALLING BEHIND SOVIETS" 3 "DON'T KNOW"
label values leadNuclearWar lb_leadNuclearWar

rename q4a1 heardAskew
label variable heardAskew "HEARD OF REUBIN ASKEW"
rename q4a2 heardBabbitt 
label variable heardBabbitt "HEARD OF BRUCE BABBITT"
rename q4a3 heardBentsen
label variable heardBentsen "HEARD OF LLOYD BENTSEN"
rename q4a4 heardBradley
label variable heardBradley "HEARD OF BILL BRADLEY"
rename q4a5 heardJerryBrown
label variable heardJerryBrown "HEARD OF JERRY BROWN"
rename q4a6 heardJohnBrown
label variable heardJohnBrown "HEARD OF JOHN BROWN"
rename q4a7 heardBumpers
label variable heardBumpers "HEARD OF DALE BUMPERS"
rename q4a8 heardCranston
label variable heardCranston "HEARD OF ALAN CRANSTON"
rename q4a9 heardGlenn
label variable heardGlenn "HEARD OF JOHN GLENN"
rename q4a10 heardHart
label variable heardHart "HEARD OF GARY HART"
rename q4a11 heardHollings
label variable heardHollings "HEARD OF ERNEST HOLLINGS"
rename q4a12 heardMcGovern
label variable heardMcGovern "HEARD OF GEORGE MCGOVERN"
rename q4a13 heardMondale
label variable heardMondale "HEARD OF WALTER MONDALE"
rename q4a14 heardPatrick
label variable heardPatrick "HEARD OF WALTER MONDALE"
rename q4a15 heardRockefeller
label variable heardRockefeller "HEARD OF JAY ROCKEFELLER"
rename q4a16 heardStrauss
label variable heardStrauss "HEARD OF ROBERT STRAUSS"
rename q4a17 heardNone 
label variable heardNone "HEARD OF NONE"

rename q4b1 knowAskew
label variable knowAskew "KNOW SOMETHING ABOUT REUBIN ASKEW"
rename q4b2 knowBabbitt 
label variable knowBabbitt "KNOW SOMETHING ABOUT BRUCE BABBITT"
rename q4b3 knowBentsen
label variable knowBentsen "KNOW SOMETHING ABOUT LLOYD BENTSEN"
rename q4b4 knowBradley
label variable knowBradley "KNOW SOMETHING ABOUT BILL BRADLEY"
rename q4b5 knowJerryBrown
label variable knowJerryBrown "KNOW SOMETHING ABOUT JERRY BROWN"
rename q4b6 knowJohnBrown
label variable knowJohnBrown "KNOW SOMETHING ABOUT JOHN BROWN"
rename q4b7 knowBumpers
label variable knowBumpers "KNOW SOMETHING ABOUT DALE BUMPERS"
rename q4b8 knowCranston
label variable knowCranston "KNOW SOMETHING ABOUT ALAN CRANSTON"
rename q4b9 knowGlenn
label variable knowGlenn "KNOW SOMETHING ABOUT JOHN GLENN"
rename q4b10 knowHart
label variable knowHart "KNOW SOMETHING ABOUT GARY HART"
rename q4b11 knowHollings
label variable knowHollings "KNOW SOMETHING ABOUT ERNEST HOLLINGS"
rename q4b12 knowMcGovern
label variable knowMcGovern "KNOW SOMETHING ABOUT GEORGE MCGOVERN"
rename q4b13 knowMondale
label variable knowMondale "KNOW SOMETHING ABOUT WALTER MONDALE"
rename q4b14 knowPatrick
label variable knowPatrick "KNOW SOMETHING ABOUT WALTER MONDALE"
rename q4b15 knowRockefeller
label variable knowRockefeller "KNOW SOMETHING ABOUT JAY ROCKEFELLER"
rename q4b16 knowStrauss
label variable knowStrauss "KNOW SOMETHING ABOUT ROBERT STRAUSS"
rename q4b17 knowNone 
label variable knowNone "KNOW SOMETHING ABOUT NONE"

rename q4c democratNom1st 
label variable democratNom1st "1ST CHOICE DEMOCRATIC PARTY CANDIDATE"
rename q4d democratNom2nd
label variable democratNom2nd "2ND CHOICE DEMOCRATIC PARTY CANDIDATE"
label define lb_democratNom 1 "Reubin Askew-Former Governor of Florida" 2 "Bruce Babbitt-Governor of Arizona" 3 "Lloyd Bentsen-Senator from Texas" 4 "Bill Bradley-Senator from New Jersey" 5 "Jerry Brown-Former Governor of California" 6 "John Y. Brown-Governor of Kentucky" 7 "Dale Bumpers-Senator from Arkansas" 8 "Alan Cranston-Senator from California" 9 "John Glenn-Senator from Ohio" 10 "Gary Hart-Senator from Colorado" 11 "Ernest Hollings-Senator from South Carolina" 12 "George McGovern-Former Senator from South Dakota" 13 "Walter Mondale-Former Vice President of the U.S." 14 "Daniel Patrick 'Pat' Moynihan-Senator from New York" 15 "Jay Rockefeller-Governor of West Virginia" 16 "Robert Strauss-Former Chairman of the Democratic National Committee" 17 "None/Don't Know" 0 "No Answer"
label values democratNom1st lb_democratNom
label values democratNom2nd lb_democratNom

local vars Askew Babbitt Bentsen Bradley JerryBrown JohnBrown Bumpers Cranston Glenn
local vars `vars' Hart Hollings McGovern Mondale Patrick Rockefeller Strauss None  
local n = 1
foreach nom in `vars' {
	local NOM = upper("`nom'")
	rename q4e`n' demNom`nom'
	label variable demNom`nom' "`NOM' AS ADDITIONAL DEMOCRATIC CANDIDATE" 
	local n = `n' + 1
}

local n = 1
foreach nom in `vars' {
	local NOM = upper("`nom'")
	rename q4f`n' badDemNom`nom'
	label variable badDemNom`nom' "`NOM', UNACCEPTABLE DEMOCRATIC CANDIDATE" 
	local n = `n' + 1
}

rename q5a blkPresident
rename q5b impactBlkVicePres
label variable impactBlkVicePres "IMPACT OF BLACK RUNNING MATE"
label define lb_impactBlkVicePres 1 "More likely" 2 "Less likely" 3 "Would make no difference-(Volunteered)" 4 "Don't Know"
label values impactBlkVicePres lb_impactBlkVicePres

rename q5c chgFinancesLY
label variable chgFinancesLY "CHANGE IN PERSONAL FINANCES SINCE LAST YEAR"
label define lb_Better3 1 "BETTER" 2 "WORSE" 3 "SAME (VOLUNTEERED)" 4 "DON'T KNOW"
label values chgFinancesLY lb_Better3

rename q5d chgFinancesNY
label variable chgFinancesNY "EXPECTED CHANGE IN PERSONAL FINANCES, NEXT YEAR"
label values chgFinancesNY lb_Better3

rename q6a reaganFinances
label variable reaganFinances "REAGAN'S POLICIES IMPACT ON PERSONAL FINANCES"
label define lb_Better4 1 "Much better" 2 "Somewhat better" 3 "Somewhat worse" 4 "Much worse" 5 "Same (Volunteered)" 6 "Don't Know"
label values reaganFinances lb_Better4

rename q6b reaganGDP
label variable reaganGDP "REAGAN'S POLICIES IMPACT ON GDP"
label values reaganGDP lb_Better4

rename q6c reaganGDPNY
label variable reaganGDPNY "EXPECTATION: REAGAN'S POLICIES IMPACT ON GDP NEXT YEAR"
label values reaganGDPNY lb_Better4

rename q6d reagonGDPLR
label variable reagonGDPLR "EXPECTATION: REAGAN'S POLICIES IMPACT ON GDP IN LONG RUN"
label values reagonGDPLR lb_Better4

rename q7a situationElSalvador
label variable situationElSalvador "HEARD OF SITUATION IN EL SALVADOR"

rename q7b aidElSalvador
label variable aidElSalvador "SUPPORT $60MIL AID TO EL SALVADOR"
label define lb_ShouldDK 1 "SHOULD" 2 "SHOULD NOT" 3 "DON'T KNOW" 0 "NO ANSWER/NOT APPLICABLE"
label values aidElSalvador lb_ShouldDK

rename q7c advisersElSalvador
label variable advisersElSalvador "SUPPORT US ADVISERS IN EL SALVADOR"
label define lb_ApprDisppDK 1 "APPROVE" 2 "DISAPPROVE" 3 "DON'T KNOW" 0 "NO ANSWER/NOT APPLICABLE" 
label values advisersElSalvador lb_ApprDisppDK

rename q7d longWarElSalvador
label variable longWarElSalvador "LIKELIHOOD OF EL SALVADOR BEING A VIETNAM"
label define lb_Likely3 1 "Very likely" 2 "Fairly likely" 3 "Not very likely" 4 "Not at all likely" 5 "Don't Know" 0 "No Answer/Not Applicable"
label values longWarElSalvador lb_Likely3

rename q7e spreadElSalvador
label variable spreadElSalvador "CHANCE OF EL SALVADOR SITUATION SPREADING TO OTHER L.A. COUNTRIES"
label variable spreadElSalvador lb_Likely3

rename q8 moreNuclPower
label variable moreNuclPower "MORE NUCLEAR WEAPONS: U.S. VS SOVIET UNION"
label define lb_moreNuclPower 1 "U.S. STRONGER" 2 "SOVIETS STRONGER" 3 "BOTH ABOUT EQUAL" 4 "DON'T KNOW"

rename q9 drinkAlcohol
label variable drinkAlcohol "HAVE OCCASION TO USE ALCOHOL"

rename q10a oftenDrink
label variable oftenDrink "HOW OFTEN DO YOU DRINK"
label define lb_OftenTime 1 "Every day" 2 "Almost every day" 3 "About 2 or 3 times a week" 4 "About once a week" 5 "About 2 or 3 times a month" 6 "About once a month" 7 "About once every 2 or 3 months" 8 "Every 6 months or so" 9 "Almost never" 10 "Don't Know/Refused" 0 "No Answer/Not Applicable"
label values oftenDrink lb_OftenTime

rename q10b problemDrink
label variable problemDrink "FREQUENCY DRINKING CAUSES PROBLEMS"
label values problemDrink lb_OftenTime

rename q901 relationshipDetailed
label variable relationshipDetailed "RELATIONSHIP STATUS [DETAILED]"
label define lb_relationshipDetailed 1 "Married" 2 "Single" 3 "Divorced" 4 "Separated" 5 "Widowed" 0 "No Answer"
label values relationshipDetailed lb_relationshipDetailed

gen relationship = .
replace relationship = 1 if relationshipDetailed == 1
replace relationship = 2 if relationshipDetailed == 2
replace relationship = 3 if (relationshipDetailed == 3 | relationshipDetailed == 4 | relationshipDetailed == 5)
label variable relationship "RELATIONSHIP STATUS"
label define lb_relationship 1 "MARRIED" 2 "SINGLE" 3 "DIVORCED-WIDOWED"
label values relationship lb_relationship

rename q901a everSeparated
label variable everSeparated "EVER DIVORCED OR SEPARATED"

rename q902 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

rename q903 adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define  lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

rename q904 minorsHH
label variable minorsHH "NUMBER OF CHILDREN (MINORS) LIVING IN THIS HOUSEHOLD"
label define lb_minorsHH 1 "ONE CHILD" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE" 11 "NO MINOR CHILDREN"
label values minorsHH lb_minorsHH

rename q904a minorHH3yrs
label variable minorHH3yrs "MINERS UNDER 3 YEARS OF AGE"
rename q904b minorHH3t5yrs
label variable minorHH3t5yrs "MINERS 3 TO 5 YEARS OF AGE"
rename q904c minorHH6t12yrs 
label variable minorHH6t12yrs "MINERS 6 TO 12 YEARS OF AGE"
rename q904d minorHH13t17yrs
label variable minorHH13t17yrs "MINERS 13 TO 17 YEARS OF AGE"

label define lb_minors 1 "CHOSEN" 2 "NOT CHOSEN" 3 "N.A." 
foreach v in HH3yrs HH3t5yrs HH6t12yrs HH13t17yrs {
	label values minor`v' lb_minors
}

rename q905 atHome
label variable atHome "AT HOME AT THIS TIME YESTERDAY OR LAST SAT OR SUN"
label values atHome lb_AtHome2

rename q906 employment
label define lb_employment 1 "FULL-TIME" 2 "PART-TIME" 3 "NOT EMPLOYED" 4 "NO ANSWER"
label values employment lb_employment

rename q907 occupationDetailed
label define lb_occupationDetailed 1 "Professional worker" 2 "Works at skilled trade or craft" 3 "Semi-skilled worker" 4 "Manager, executive or official" 5 "Runs own business with two or more employees" 6 "Farm owner, farm manager" 7 "Clerical or office worker" 8 "Sales worker" 9 "Manufacturer's representative" 10 "Service worker who performs services" 11 "Laboring work other than farm" 12 "Farm laborer or helper" 13 "Retired" 14 "Full-time student" 15 "Housewife" 16 "Other" 17 "Can't say"
label values occupationDetailed lb_occupationDetailed

gen occupation = .
replace occupation = 1 if occupationDetailed == 6
replace occupation = 2 if occupationDetailed == 4 | occupationDetailed == 5
replace occupation = 3 if occupationDetailed == 7
replace occupation = 4 if occupationDetailed == 8 | occupationDetailed == 9
replace occupation = 5 if occupationDetailed == 2
replace occupation = 6 if occupationDetailed == 3
replace occupation = 7 if occupationDetailed == 10
replace occupation = 8 if occupationDetailed == 12
replace occupation = 9 if occupationDetailed == 11
replace occupation = 10 if occupationDetailed == 1
replace occupation = 11 if occupationDetailed == 13 | occupationDetailed == 14 | occupationDetailed == 15
replace occupation = 12 if occupationDetailed == 16
replace occupation = 13 if occupationDetailed == 17
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q908 chiefWage
label variable chiefWage "CHIEF WAGE EARNER"

rename q909 employment1stWage
label values employment1stWage lb_employment
label variable employment1stWage "EMPLOYMENT STATUS OF CHIEF WAGE EARNER"

rename q910a occupation2ndWage
label values occupation2ndWage lb_occupation

rename q910b occupationSum
label variable occupationSum "SUMMARY OF OCCUPATIONAL CATEGORIES"
label values occupationSum lb_occupation

rename q911 positionHH 
label variable positionHH "POSITION IN HOUSEHOLD"
label define lb_positionHH 1 "Male head of household" 2 "Female head of household/Wife of head of household" 3 "Son of head of household" 4 "Daughter of head of household" 5 "Father of head of household" 6 "Mother of head of household" 7 "Other male" 8 "Other female"
label values positionHH lb_positionHH

rename q912 rentOwn
label variable rentOwn "RENT OR OWN"
label define lb_rentOwn 1 "OWN" 2 "RENT" 3 "OTHER ARRANGEMENT" 0 "NOT CHOSEN"
label values rentOwn lb_rentOwn

rename q913 edu
label define lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
label values edu lb_edu

rename q914 age

rename q915 union
label define lb_union 1 "YES, RESPONDENT IS" 2 "YES, SPOUSE IS" 3 "YES, BOTH ARE" 4 "NO, NEITHER IS"
label values union lb_union

label define  lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "NEGRO MAN" 4 "NEGRO WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

label define lb_sex 1 "MALE" 2 "FEMALE"
label values sex lb_sex

label define lb_race 1 "WHITE" 2 "BLACK" 3 "OTHER"
label values race lb_race

rename q917 incomeHH_80s
label define lb_incomeHH_80s 1 "Under $2,000 a year" 2 "$2,000 to $2,999 a year" 3 "$3,000 to $3,999 a year" 4 "$4,000 to $4,999 a year" 5 "$5,000 to $5,999 a year" 6 "$6,000 to $6,999 a year" 7 "$7,000 to $9,999 a year" 8 "$10,000 to $11,999 a year" 9 "$12,000 to $14,999 a year" 10 "$15,000 to $19,999 a year" 11 "$20,000 and more a year"
label values incomeHH_80s lb_incomeHH_80s

	gen incomeHHharmonized = .
	replace incomeHHharmonized = 1000 if incomeHH_80s == 1
	replace incomeHHharmonized = 2500 if incomeHH_80s == 2
	replace incomeHHharmonized = 3500 if incomeHH_80s == 3
	replace incomeHHharmonized = 4500 if incomeHH_80s == 4
	replace incomeHHharmonized = 5500 if incomeHH_80s == 5
	replace incomeHHharmonized = 6500 if incomeHH_80s == 6
	replace incomeHHharmonized = 8500 if incomeHH_80s == 7
	replace incomeHHharmonized = 11000 if incomeHH_80s == 8
	replace incomeHHharmonized = 13500 if incomeHH_80s == 9
	replace incomeHHharmonized = 17500 if incomeHH_80s == 10
	replace incomeHHharmonized = 20000 if incomeHH_80s == 11

rename q918 incomeHHwealthy
label define lb_incomeHHwealthy 1 "$20,000 to $24,999" 2 "$25,000 to $29,999" 3 "$30,000 to $39,999" 4 "$40,000 to $49,999" 5 "$50,000 to $99,999" 6 "$100,000 or more" 7 "Not stated"
label values incomeHHwealthy lb_incomeHHwealthy

rename q919a religionOrtho
label define lb_religionOrtho 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "EASTERN ORTHODOX" 5 "OTHER" 6 "NONE"
label values religionOrtho lb_religionOrtho

gen religion = religionOrtho
replace religion = 4 if religionOrtho == 5
replace religion = 5 if religionOrtho == 6
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

rename q919b vProtestant
label define lb_vProtestant 12 "Church of Jesus Christ of the Latter-Day Saints" 21 "Southern Baptist Convention" 22 "American Baptist Churches" 23 "The National Baptist Convention of America" 24 "The National Baptist Convention, U.S.A., Inc" 25 "Other Baptist" 26 "Baptist, don't know which denomination" 31 "Episcopalian" 41 "American Lutheran Church" 42 "Lutheran Church in America" 43 "Missouri Synod Lutheran" 44 "Other Lutheran" 45 "Lutheran, don't know which denomination" 51 "United Methodist Church" 52 "A.M.E. Zion Church" 53 "A.M.E. Church" 54 "Other Methodist" 55 "Methodist, don't know which denomination" 61 "Presbyterian Church in the U.S." 62 "United Presbyterian Church in the U.S.A." 63 "Other Presbyterian" 64 "Presbyterian, don't know which denomination" 71 "United Church of Christ (or Congregationalist or Evangelical and Reformed)" 72 "Christian Church (Disciples of Christ)" 73 "Other Protestant (please specify which)" 74 "Protestant unspecified" 81 "Other religion" 0 "No Answer/Not Applicable"
label values vProtestant lb_vProtestant

replace citySize = 0 if citySize == 1
label define lb_citySize 0 "Not Used" 2 "Open Country" 3 "Under 2,500" 4 "2,500 - 4,999" 5 "5,000 - 9,999" 6 "10,000 - 24,999" 7 "25,000 - 49,999" 8 "50,000 - 99,999" 9 "100,000 - 249,999" 10 "250,000 - 499,999" 11 "500,000 - 999,999" 12 "1 million and over"
label values citySize lb_citySize

label define lb_section 1 "New England" 2 "Middle Atlantic" 3 "East Central" 4 "West Central" 5 "Southeast" 6 "Southwest" 7 "Rocky Mountain" 8 "Pacific"
label values section lb_section

label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/1211-1983.dta", replace 
local svys `svys' 1211-1983


*Gallup Poll # 1278G [USAIPO1987-1278G]
clear 
infix ///
	svyNum 1-4 ///
	wgt 5-7 ///
	q1a 8 ///
	q1b 9 ///
	q1c 10 ///
	q1d 11 ///
	q2a 12 ///
	q2b 13 ///
	q2c 14 ///
	q3a 15 ///
	q3b 16 ///
	q3c 17 ///
	q4a 18 ///
	q4b 19 ///
	q4c 20 ///
	q5a1 21 ///
	q5a2 22 ///
	q5a3 23 ///
	q5a4 24 ///
	q5a5 25 ///
	q5a6 26 ///
	q5a7 27 ///
	q5a8 28 ///
	q5a9 29 ///
	q5b1 30 ///
	q5b2 31 ///
	q5b3 32 ///
	q5b4 33 ///
	q5b5 34 ///
	q5b6 35 ///
	q5b7 36 ///
	q5b8 37 ///
	q5b9 38 ///
	q5c 39 ///
	q5d 40 ///
	q5e 41 ///
	q6a 42-43 ///
	q6b 44-45 ///
	q6c 46-47 ///
	q6d 48-49 ///
	q6e 50-51 ///
	q6f 52-53 ///
	q6g 54-55 ///
	q6h 56-57 ///
	q6i 58-59 ///
	q6j 60-61 ///
	q6k 62-63 ///
	q6l 64-65 ///
	q6m 66-67 ///
	q7a1 68 ///
	q7a2 69 ///
	q7a3 70 ///
	q7a4 71 ///
	q7a5 72 ///
	q7a6 73 ///
	q7a7 74 ///
	q7a8 75 ///
	q7b1 76 ///
	q7b2 77 ///
	q7b3 78 ///
	q7b4 79 ///
	q7b5 80 ///
	q7b6 81 ///
	q7b7 82 ///
	q7b8 83 ///
	q7c 84 ///
	q7d 85 ///
	q7e 86 ///
	q8a 86-88 ///
	q8b 89-90 ///
	q8c 91-92 ///
	q8d 93-94 ///
	q8e 95-96 ///
	q8f 97-98 ///
	q8g 99-100 ///
	q8h 101-102 ///
	q9a 103 ///
	q9b 104 ///
	q10a 105 ///
	q10b 106 ///
	q10c 107 ///
	q10d 108 ///
	q11 109 ///
	q12a 110 ///
	q12b1 111 ///
	q12b2 112 ///
	q12b3 113 ///
	q12b4 114 ///
	q12b5 115 ///
	q12b6 116 ///
	q13a 117 ///
	q13b 118 ///
	q13c 119 ///
	q13d 120 ///
	q13e 121 ///
	q13f 122 ///
	q13g 123 ///
	q13h 124 ///
	q14a 125 ///
	q14b 126 ///
	q14c 127 ///
	q14d 128 ///
	q14e 129 ///
	q14f 130 ///
	q15a 131 ///
	q15b 132-133 ///
	q15c1 134 ///
	q15c2 135 ///
	q15c3 136 ///
	q15c4 137 ///
	q15c5 138 ///
	q15c6 139 ///
	q15d 140-141 ///
	q15e 142 ///
	q15f 143 ///
	q15g 144 ///
	q15h1 145 ///
	q15h2 146 ///
	q15h3 147 ///
	q15h4 148 ///
	q15h5 149 ///
	q15h6 150 ///
	q15i 151 ///
	q15j 152 ///
	q16a 153 ///
	q16b 154 ///
	q16c 155 ///
	q16d 156 ///
	q17a 157 ///
	q17b 158 ///
	q17c 159 ///
	q18a 160 ///
	q18b 161 ///
	q18c 162 ///
	q18d 163 ///
	q19 164 ///
	q20a 165-166 ///
	q20b 167-168 ///
	q20c 169-170 ///
	q20d 171-172 ///
	q20e 173-174 ///
	q20f 175-176 ///
	q20g 177-178 ///
	q21 179 ///
	q901 180 ///
	q901a 181 ///
	q902 182 ///
	q902a 183 ///
	q903 184-185 ///
	q904 186-187 ///
	q904a1 188 ///
	q904a2 189 ///
	q904a3 190 ///
	q904a4 191 ///
	q904a5 192 ///
	q905a 193 ///
	q906 194 ///
	q907 195-196 ///
	q908 197 ///
	q909 198 ///
	q910 199-200 ///
	occupation 201-202 ///
	hhPosition 203 ///
	famFinDecisions 204 ///
	rentOwn 205 ///
	edu 206 ///
	age 207-208 ///
	ageSum 209 ///
	union 210 ///
	hispanic 211 ///
	raceSex 212 ///
	sex 213 ///
	race 214 ///
	incomeHHa 215-216 ///
	incomeHHb 217 ///
	incomeHHc 218 ///
	religion 219 ///
	protDenom 220-221 ///
	citySize 222-223 ///
	section 224 ///
	state 225-226 ///
	smsa 227 ///
	fringe 228 ///
	using "$ascii/1278.dat"
gen svy_year = 1987
gen svy_month = "July"
gen svy = "1987-1278"

rename hhPosition positionHH
rename protDenom vProtestant

label define  lb_yesNo 0 "No" 1 "Yes"
label define  lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define  lb_favOppNoOp 1 "FAVOR" 2 "OPPOSE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_appDisapp 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_agrDisagr 1 "AGREE" 2 "DISAGREE" 3 "NO OPINION"  9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"
label define  lb_shouldNot1 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 0 "NO CODE OR NO DATA" 
label define  lb_shouldNot2 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"  
label define  lb_yesNoRem 1 "Yes" 2 "NO" 3 "Don't Remember" 4 "NO CODE OR NO DATA"
label define  lb_UpDown 1 "GO UP" 2 "GO DOWN" 3 "REMAIN SAME" 4 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_PosImpos 1 "POSSIBLE" 2 "IMPOSSIBLE" 3 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_GoodPoor 1 "GOOD IDEA" 2 "POOR IDEA" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_BetterWorse 1 "BETTER" 2 "WORSE" 3 "ABOUT SAME" 4 "NO OPINION"
label define  lb_MoreLess 1 "MORE" 2 "LESS" 3 "SAME" 4 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_YesNoDontKnow 1 "YES" 2 "NO" 3 "DON'T KNOW" 9 "INAPPLICABLE"
label define  lb_IncreaseDecrease 1 "INCREASED" 2 "DECREASED" 3 "KEPT SAME" 4 "NO OPINION"
label define lb_interest 1 "IS INTERESTED" 2 "IS NOT INTERESTED" 3 "NO OPINION"
label define lb_5scale 1 "5" 2 "4" 3 "3" 4 "2" 5 "1" 6 "-1" 7 "-2" 8 "-3" 9 "-4" 10 "-5" 11 "DON'T KNOW ENOUGH"
label define lb_YesNoDK 1 "YES" 2 "NO" 3 "DON'T KNOW"
label define lb_ExGoodPoor 1 "EXCELLENT" 2 "GOOD" 3 "FAIR" 4 "POOR" 5 "DON'T KNOW"
label define lb_MoreLessAbout 1 "MORE" 2 "LESS" 3 "ABOUT THE SAME (VOLUNTEERED)" 4 "NO OPINION"
label define  lb_favOppDK 1 "FAVOR" 2 "OPPOSE" 3 "DON'T KNOW" 0 "NO CODE OR NO DATA"
label define lb_Wrong 1 "WRONG" 2 "NOT WRONG" 3 "DON'T KNOW"

local varMissing q5c q5d q5e q6a q6b q6c q6d q6e q6f q6g q6h q6i q6j q6k q6l q6m
local varMissing `varMissing' q7c q7d q7e q8a q8b q8c q8d q8e q8f q8g q8h q9a q9b
local varMissing `varMissing' q15b q901 q901a q902 q902a q903 q904 q910 positionHH
local varMissing `varMissing' famFinDecisions rentOwn edu union ageSum incomeHHa
local varMissing `varMissing' incomeHHb incomeHHc religion vProtestant
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNo 
foreach var in `varYesNo' { 
	replace `var'  = 2-`var'
	label values `var' lb_yesNo
}

local varAppDisapp q1a q10a q10b q10c q10d 
foreach var in `varAppDisapp' {
	label values `var' lb_appDisapp
}

local varYesNoNoOp q16c q16d
foreach var in `varYesNoNoOp' {
	label values `var' lb_yesNoNoOp
}

local varAgrDisagr 
foreach var in `varAgrDisagr' {
	label values `var' lb_agrDisagr
}

local varFavOppNoOp 
foreach var in `varFavOppNoOp' {
	label values `var' lb_favOppNoOp
}

foreach var in   {
	label values `var' lb_YesNoDontKnow
}

rename q1a presApprovala
label variable presApprovala "REAGAN JOB APPROVAL"

rename q1b presPerson
label variable presPerson "REAGAN AS A PERSON"
label define lb_AppDisappDK 1 "APPROVE" 2 "DISAPPROVE" 3 "DON'T KNOW"
label values presPerson lb_AppDisappDK

rename q1c legacyReagan 
label variable legacyReagan "EXPECTATION: REAGAN'S LEGACY"
label define lb_AverageRate 1 "Outstanding" 2 "Above average" 3 "Average (Volunteered)" 4 "Below average" 5 "Poor" 6 "Don't Know"

rename q1d voteRegist
label variable voteRegist "REGISTERED TO VOTE"	
label define lb_voteRegist 1 "YES" 2 "NO" 3 "DONíT HAVE TO REGISTER" 4 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label values voteRegist lb_voteRegist

rename q2a followIranContra
label variable followIranContra "HOW CLOSELY DO YOU FOLLOW THE ITRAN CONTRA"
label define lb_Closely3 1 "VERY CLOSELY" 2 "FAIRLY CLOSELY" 3 "NOT CLOSELY"
label values followIranContra lb_Closely3

rename q2b reaganInvestIranContra
label variable reaganInvestIranContra "WILL REAGAN TURN OUT TO BE MORE INVOLVED IN THE IRAN-CONTRA AFFAIR"
label define lb_Involved 1 "MORE INVOLVED" 2 "NOT MORE INVOLVED" 3 "DON'T KNOW"
label values reaganInvestIranContra lb_Involved

rename q2c reaganKnewIranContra
label variable reaganKnewIranContra "IF REAGAN KNEW AND APPROVED OF IRAN CONTRA"
label define lb_reaganKnewIranContra 1 "Reagan should admit his mistakes and apologize?" 2 "He should resign?" 3 "Congress should begin impeachment proceedings" 4 "The matter should be dropped" 5 "Don't Know"
label values reaganKnewIranContra lb_reaganKnewIranContra

rename q3a importReligion
label variable importReligion "PERSONAL IMPORTANCE OF RELIGION"
label define lb_Importance 1 "VERY IMPORTANT" 2 "FAIRLY IMPORTANT" 3 "NOT VERY IMPORTANT" 4 "NO OPINION" 
label values importReligion lb_Importance

rename q3b membChurch
label variable membChurch "MEMBER OF CHURCH OR SYNAGOGUE"
label values membChurch lb_YesNoDK

rename q3c attendChurch
label variable attendChurch "ATTENDED CHURCH OR SYNAGOGUE IN THE LAST 7 DAYS"
replace attendChurch = 0 if attendChurch == 2
replace attendChurch = . if attendChurch == 3
label values attendChurch lb_yesNo

rename q4a rateSCourt
label variable rateSCourt "SUPREME COURT RATING"
label values rateSCourt lb_ExGoodPoor

rename q4b impartialSCourt
label variable impartialSCourt "IS THE SUPREME COURT IMPARTIAL"
label define lb_impartial 1 "IMPARTIAL" 2 "FAVORS ONE GROUP" 3 "DON'T KNOW"
label values impartialSCourt lb_impartial

rename q4c poliSCourt
label variable poliSCourt "PREFERRED POLITICAL LEANINGS OF SUPREME COURT"
label define lb_poli 1 "LIBERAL" 2 "CONSERVATIVE" 3 "NEITHER, STAY THE SAME (VOLUNTEERED)" 4 "DON'T KNOW"
label values poliSCourt lb_poli

local vars Babbitt Biden BClinton Dukakis GoreJr Gephardt JJackson Simon None
local n = 1
foreach v in `vars'{
	local V = upper("`v'")
	rename q5a`n' heard`v'
	label variable heard`v' "HEARD OF `V'"
	local n = `n' + 1
}
local n = 1
foreach v in `vars'{
	local V = upper("`v'")
	rename q5b`n' know`v'
	label variable know`v' "KNOW SOMETHING ABOUT `V'"
	local n = `n' + 1
}

label define lb_democratNom 1 "Bruce Babbitt-Former Governor of Arizona" 2 "Joseph Biden-Senator from Delaware" 3 "Bill Clinton-Governor of Arkansas" 4 "Michael Dukakis-Governor of Massachusetts" 5 "Albert Gore, Jr.-Senator from Tennessee" 6 "Richard Gephardt-Representative from Missouri" 7 "Reverend Jesse Jackson-Baptist Minister" 8 "Paul Simon-Senator from Illinois" 9 "None/Don't Know" 0 "No Answer"
rename q5c democratNom1st 
label variable democratNom1st "1ST CHOICE DEMOCRATIC PARTY CANDIDATE"
label values democratNom1st lb_democratNom
rename q5d democratNom2nd 
label variable democratNom2nd "2ND CHOICE DEMOCRATIC PARTY CANDIDATE"
labe values democratNom2nd lb_democratNom
rename q5e addDemocratNom
label variable addDemocratNom "ADDITIONAL DEMOCRATIC NOMINEES"

local vars Babbitt Biden Bradley BClinton Cuomo Dukakis Gephardt Gore Hart JJackson Iacocca Nunn Simon
rename q6a rateBabbitt 
rename q6b rateBiden 
rename q6c rateBradley 
rename q6d rateBClinton 
rename q6e rateCuomo 
rename q6f rateDukakis 
rename q6g rateGephardt 
rename q6h rateGore 
rename q6i rateHart 
rename q6j rateJJackson 
rename q6k rateIacocca 
rename q6l rateNunn 
rename q6m rateSimon
foreach v in `vars' {
	local V = upper("`v'")
	label variable rate`v' "RATING OF `V'"
	label values rate`v' lb_5scale
}

local vars Bush Dole DuPont Haig Kemp Laxalt PRobertson None2
local n = 1
foreach v in `vars'{
	local V = upper("`v'")
	rename q7a`n' heard`v'
	label variable heard`v' "HEARD OF `V'"
	local n = `n' + 1
}
local n = 1
foreach v in `vars'{
	local V = upper("`v'")
	rename q7b`n' know`v'
	label variable know`v' "KNOW ABOUT `V'"
	local n = `n' + 1
}

label define lb_republicanNom 1 "George Bush-Vice President of the U.S." 2 "Bob Dole-Senator from Kansas" 3 "Pierre (Pete) duPont-Former Governor of Delaware" 4 "Alexander Haig-Former Secretary of State" 5 "Jack Kemp-Representative from New York" 6 "Paul Laxalt-Former Senator from Nevada" 7 "Pat Robertson-Evangelist" 8 "None/Don't Know" 0 "No Answer"
rename q7c republicanNom1st 
label variable republicanNom1st "1ST CHOICE REPUBLICAN PARTY CANDIDATE"
rename q7d republicanNom2nd 
label variable republicanNom2nd "2ND CHOICE REPUBLICAN PARTY CANDIDATE"
label values republicanNom1st lb_republicanNom
label values republicanNom2nd lb_republicanNom
rename q7e addRepublicanNom
label variable addRepublicanNom "ADDITIONAL REPUBLICAN NOMINEES"

local vars Bush Baker Dole DuPont Haig Kemp Laxalt Robertson
rename q8a rateBush 
rename q8b rateBaker 
rename q8c rateDole 
rename q8d rateDuPont 
rename q8e rateHaig 
rename q8f rateKemp 
rename q8g rateLaxalt 
rename q8h rateRobertson
foreach v in `vars' {
	local V = upper("`v'")
	label variable rate`v' "RATING OF `V'"
	label values rate`v' lb_5scale
}

rename q9a votePartyID
label variable votePartyID "PARTY OF CHOICE FOR 1988 PRESIDENTIAL ELECTION"
label define lb_votePartyID 1 "Republican" 2 "Democratic" 3 "Other (Volunteered)" 4 "Depends (Volunteered)" 5 "Don't Know"
label values votePartyID lb_votePartyID

rename q9b fiveYrReligious
label variable fiveYrReligious "RELIGIOUSITY COMPARED TO FIVE YEARS AGO"
label values fiveYrReligious lb_MoreLessAbout

rename q10a deficitTaxes
label variable deficitTaxes "REDUCE DEFICIT VIA TAXES"
label values deficitTaxes lb_appDisapp

rename q10b deficitSocialPrograms
label variable deficitSocialPrograms "REDUCE DEFICIT VIA SOCIAL PROGRAMS"
label values deficitSocialPrograms lb_appDisapp

rename q10c deficitDefense
label variable deficitDefense "REDUCE DEFICIT VIA DEFENSE"
label values deficitDefense lb_appDisapp

rename q10d deficitEntitlement
label variable deficitEntitlement "REDUCE DEFICIT VIA ENTITLEMENT"
label values deficitEntitlement lb_appDisapp

rename q11 balancedSpending
label variable balancedSpending "SUPPORT LAW TO COUNTERBALANCE NEW SPENDING" 
label values balancedSpending lb_favOppDK

rename q12a sexMarriage
label variable sexMarriage "OPINION OF SEX BEFORE MARRIAGE"
label values sexMarriage lb_Wrong

rename q12b1 MoralSexMarriage
label variable MoralSexMarriage "MORAL: OPINION OF SEX BEFORE MARRIAGE"

rename q12b2 PregSexMarriage
label variable PregSexMarriage "PREGNANCY: OPINION OF SEX BEFORE MARRIAGE"

rename q12b3 STDSexMarriage
label variable STDSexMarriage "STD: OPINION OF SEX BEFORE MARRIAGE"

rename q12b4 VirginsSexMarriage
label variable VirginsSexMarriage "FEMALE VIRGINITY: OPINION OF SEX BEFORE MARRIAGE"

rename q12b5 OtherSexMarriage
label variable OtherSexMarriage "OTHER: OPINION OF SEX BEFORE MARRIAGE"

rename q12b6 DontKnowSexMarriage
label variable DontKnowSexMarriage "DON'T KNOW: OPINION OF SEX BEFORE MARRIAGE"

rename q16c blkPresident

label define  lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

label define lb_sex 1 "MALE" 2 "FEMALE"
label values sex lb_sex

label define lb_race 1 "WHITE" 2 "BLACK" 3 "OTHER"
label values race lb_race

rename q902 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

rename q903 adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define  lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

rename q904 minorsHH
label variable minorsHH "NUMBER OF CHILDREN (MINORS) LIVING IN THIS HOUSEHOLD"
label define lb_minorsHH 1 "ONE CHILD" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE" 11 "NO MINOR CHILDREN"
label values minorsHH lb_minorsHH

replace citySize = 0 if citySize == 1
label define lb_citySize 0 "Not Used" 2 "Open Country" 3 "Under 2,500" 4 "2,500 - 4,999" 5 "5,000 - 9,999" 6 "10,000 - 24,999" 7 "25,000 - 49,999" 8 "50,000 - 99,999" 9 "100,000 - 249,999" 10 "250,000 - 499,999" 11 "500,000 - 999,999" 12 "1 million and over"
label values citySize lb_citySize

rename q16d womanPresident

label define lb_union 1 "YES, RESPONDENT IS" 2 "YES, SPOUSE IS" 3 "YES, BOTH ARE" 4 "NO, NEITHER IS"
label values union lb_union

rename q901 relationshipDetailed
label variable relationshipDetailed "RELATIONSHIP STATUS [DETAILED]"
label define lb_relationshipDetailed 1 "Married" 2 "Single" 3 "Divorced" 4 "Separated" 5 "Widowed"
label values relationshipDetailed lb_relationshipDetailed

gen relationship = .
replace relationship = 1 if relationshipDetailed == 1
replace relationship = 2 if relationshipDetailed == 2
replace relationship = 3 if (relationshipDetailed == 3 | relationshipDetailed == 4 | relationshipDetailed == 5)
label variable relationship "RELATIONSHIP STATUS"
label define lb_relationship 1 "MARRIED" 2 "SINGLE" 3 "DIVORCED-WIDOWED"
label values relationship lb_relationship

label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

label define lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
label values edu lb_edu

label variable positionHH "POSITION IN HOUSEHOLD"
label define lb_positionHH 1 "Male head of household" 2 "Female head of household/Wife of head of household" 3 "Son of head of household" 4 "Daughter of head of household" 5 "Father of head of household" 6 "Mother of head of household" 7 "Other male" 8 "Other female"
label values positionHH lb_positionHH

rename incomeHHa incomeHH_80s
label define lb_incomeHH_80s 1 "Under $2,000 a year" 2 "$2,000 to $2,999 a year" 3 "$3,000 to $3,999 a year" 4 "$4,000 to $4,999 a year" 5 "$5,000 to $5,999 a year" 6 "$6,000 to $6,999 a year" 7 "$7,000 to $9,999 a year" 8 "$10,000 to $11,999 a year" 9 "$12,000 to $14,999 a year" 10 "$15,000 to $19,999 a year" 11 "$20,000 and more a year"
label values incomeHH_80s lb_incomeHH_80s
replace incomeHH_80s = . if incomeHH_80s == 12

	gen incomeHHharmonized = .
	replace incomeHHharmonized = 1000 if incomeHH_80s == 1
	replace incomeHHharmonized = 2500 if incomeHH_80s == 2
	replace incomeHHharmonized = 3500 if incomeHH_80s == 3
	replace incomeHHharmonized = 4500 if incomeHH_80s == 4
	replace incomeHHharmonized = 5500 if incomeHH_80s == 5
	replace incomeHHharmonized = 6500 if incomeHH_80s == 6
	replace incomeHHharmonized = 8500 if incomeHH_80s == 7
	replace incomeHHharmonized = 11000 if incomeHH_80s == 8
	replace incomeHHharmonized = 13500 if incomeHH_80s == 9
	replace incomeHHharmonized = 17500 if incomeHH_80s == 10
	replace incomeHHharmonized = 20000 if incomeHH_80s == 11

rename incomeHHb incomeHHwealthy
rename incomeHHc incomeHHveryWealthy

rename q907 occupationDetailed
label define lb_occupationDetailed 1 "Professional worker" 2 "Works at skilled trade or craft" 3 "Semi-skilled worker" 4 "Manager, executive or official" 5 "Runs own business with two or more employees" 6 "Farm owner, farm manager" 7 "Clerical or office worker" 8 "Sales worker" 9 "Manufacturer's representative" 10 "Service worker who performs services" 11 "Laboring work other than farm" 12 "Farm laborer or helper" 13 "Retired" 14 "Full-time student" 15 "Housewife" 16 "Other" 17 "Can't say"
label values occupationDetailed lb_occupationDetailed

rename occupation occupationMainEarner
gen occupation = .
replace occupation = 1 if occupationDetailed == 6
replace occupation = 2 if occupationDetailed == 4 | occupationDetailed == 5
replace occupation = 3 if occupationDetailed == 7
replace occupation = 4 if occupationDetailed == 8 | occupationDetailed == 9
replace occupation = 5 if occupationDetailed == 2
replace occupation = 6 if occupationDetailed == 3
replace occupation = 7 if occupationDetailed == 10
replace occupation = 8 if occupationDetailed == 12
replace occupation = 9 if occupationDetailed == 11
replace occupation = 10 if occupationDetailed == 1
replace occupation = 11 if occupationDetailed == 13 | occupationDetailed == 14 | occupationDetailed == 15
replace occupation = 12 if occupationDetailed == 16
replace occupation = 13 if occupationDetailed == 17
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename religion religionOrthoMorm
label define lb_religionOrthoMorm 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "EASTERN ORTHODOX" 5 "OTHER" 6 "MORMON" 7 "NONE"
label values religionOrthoMorm lb_religionOrthoMorm

gen religion = religionOrthoMorm
replace religion = 4 if (religionOrthoMorm == 5 | religionOrthoMorm == 6)
replace religion = 5 if religionOrtho == 7
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

save "$ascii/1278-1987.dta", replace 
local svys `svys' 1278-1987


*Gallup Poll # 1107G [USAIPO1978-1107G]
clear 
infix ///
	wgt 1 ///
	svy_name 2-4 ///
	q1a 5 ///
	q1b 6 ///
	q2a 7 ///
	q2b 8 ///
	q3a 9 ///
	q3b 10 ///
	q3c 11 ///
	q3d 12 ///
	q3e 13 ///
	q3f 14 ///
	q3g 15 ///
	q4_1 16 ///
	q4_2 17 ///
	q4_3 18 ///
	q4_4 19 ///
	q4_5 20 ///
	q4_6 21 ///
	q4_7 22 ///
	q4_8 23 ///
	q4_9 24 ///
	q4_10 25 ///
	q4_11 26 ///
	q4_12 27 ///
	q4_13 28 ///
	q4_14 29 ///
	q4_15 30 ///
	q4_16 31 ///
	q4_17 32 ///
	q5a 33 ///
	q5b 34 ///
	q5c 35 ///
	q6 36 ///
	q7 37 ///
	q8a 38 ///
	q8b 39 ///
	q8c 40 ///
	q8d 41 ///
	q8e 42 ///
	q8f 43 ///
	q8g 44 ///
	q9a 45 ///
	q9b 46 ///
	q10 47 ///
	q11a 48 ///
	q11b 49 ///
	var48 50 ///
	q124 51 ///
	q128a 52-53 ///
	q133 54 ///
	age 55-56 ///
	ageSum 57 ///
	raceSex 58 ///
	race 59 ///
	sex 60 ///
	incomeHH_80s 61-62 ///
	religionOrtho 63 ///
	citySize 64-65 ///
	section 66 ///
	state 67-68 ///	
	using "$ascii/A1107g.dat"

gen svy_year = 1978
gen svy_month = "July"
gen svy = "1978-1107"

label define  lb_yesNo 0 "No" 1 "Yes"
label define  lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define  lb_yesNoIA 1 "Yes" 2 "No" 9 "INAPPLICABLE"
label define  lb_favOppNoOp 1 "FAVOR" 2 "OPPOSE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_appDisapp 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_agrDisagr 1 "AGREE" 2 "DISAGREE" 3 "NO OPINION"  9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"
label define  lb_shouldNot1 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 0 "NO CODE OR NO DATA" 
label define  lb_shouldNot2 1 "SHOULD" 2 "SHOULD NOT" 3 "NO OPINION" 9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"  
label define  lb_yesNoRem 1 "Yes" 2 "NO" 3 "Don't Remember" 4 "NO CODE OR NO DATA"
label define  lb_UpDown 1 "GO UP" 2 "GO DOWN" 3 "REMAIN SAME" 4 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_PosImpos 1 "POSSIBLE" 2 "IMPOSSIBLE" 3 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define  lb_GoodPoor 1 "GOOD IDEA" 2 "POOR IDEA" 3 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_BetterWorse 1 "BETTER" 2 "WORSE" 3 "ABOUT SAME" 4 "NO OPINION"
label define  lb_MoreLess 1 "MORE" 2 "LESS" 3 "SAME" 4 "NO OPINION" 0 "NO CODE OR NO DATA"
label define  lb_YesNoDontKnow 1 "YES" 2 "NO" 3 "DON'T KNOW" 9 "INAPPLICABLE"
label define  lb_IncreaseDecrease 1 "INCREASED" 2 "DECREASED" 3 "KEPT SAME" 4 "NO OPINION"
label define lb_interest 1 "IS INTERESTED" 2 "IS NOT INTERESTED" 3 "NO OPINION"
label define lb_5scale 1 "5" 2 "4" 3 "3" 4 "2" 5 "1" 6 "-1" 7 "-2" 8 "-3" 9 "-4" 10 "-5" 11 "DON'T KNOW ENOUGH"
label define lb_YesNoDK 1 "YES" 2 "NO" 3 "DON'T KNOW"
label define lb_ExGoodPoor 1 "EXCELLENT" 2 "GOOD" 3 "FAIR" 4 "POOR" 5 "DON'T KNOW"
label define lb_MoreLessAbout 1 "MORE" 2 "LESS" 3 "ABOUT THE SAME (VOLUNTEERED)" 4 "NO OPINION"
label define  lb_favOppDK 1 "FAVOR" 2 "OPPOSE" 3 "DON'T KNOW" 0 "NO CODE OR NO DATA"
label define lb_Wrong 1 "WRONG" 2 "NOT WRONG" 3 "DON'T KNOW"
label define lb_LotSome 1 "LOT" 2 "SOME" 3 "LITTLE" 4 "NONE" 0 "NO CODE OR NO DATA"
label define lb_VeryFairly 1 "VERY" 2 "FAIRLY" 3 "NOT TOO INTERESTED" 4 "DONíT KNOW" 0 "NO CODE OR NO DATA"
label define lb_HelpHurt 1 "HELPED" 2 "HURT" 3 "NO OPINION" 9 "INAPPLICABLE" 0 "NO CODE OR NO DATA"

local varMissing q1b q9a q9b q10 q11b q124 q133 age religionOrtho
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNo 
foreach var in `varYesNo' { 
	replace `var'  = 2-`var'
	label values `var' lb_yesNo
}

local varAppDisapp q1a q2a q2b q3a q3b q3c q3d q3e q3f q3g q5a q5b q5c 
foreach var in `varAppDisapp' {
	label values `var' lb_appDisapp
}

local varYesNoNoOp q8a q8b q8c q8d q8e q8f q8g 
foreach var in `varYesNoNoOp' {
	label values `var' lb_yesNoNoOp
}

local varAgrDisagr 
foreach var in `varAgrDisagr' {
	label values `var' lb_agrDisagr
}

local varFavOppNoOp 
foreach var in `varFavOppNoOp' {
	label values `var' lb_favOppNoOp
}

foreach var in   {
	label values `var' lb_YesNoDontKnow
}

rename q1a presApprovala
label variable presApprovala "PRESIDENT JOB APPROVAL"
label define  lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 0 "NO CODE OR NO DATA" 
label values presApprovala lb_presApproval

rename q1b presApprovalb 
label variable presApprovalb "DEGREE OF PRESIDENT JOB (DIS)APPROVAL"
label define lb_presApprovalb 1 "Very" 2 "Not so" 3 "No Opinion" 0 "No Answer/Not Applicable"
label values presApprovalb lb_presApprovalb

rename q2a presForeign
label variable presForeign "PRESIDENT FOREIGN POLICY JOB APPROVAL"

rename q8a blkPresident

rename q124 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

rename q133 edu
lab def lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
lab val edu lb_edu

label define lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "NEGRO MAN" 4 "NEGRO WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

label define lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

label define lb_race 1 "WHITE" 2 "BLACK" 3 "OTHER"
label values race lb_race

label define lb_sex 1 "MALE" 2 "FEMALE"
label values sex lb_sex

label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

//[...]

save "$ascii/1978-1107.dta", replace 
local svys `svys' 1978-1107


*Gallup Poll # 1239G [USAIPO1984-1239G]
clear 
infix ///
	wgt 1-3 ///
	svyNum 4-7 ///
	q1 8 ///
	q2 9 ///
	q3 10 ///
	q4 11 ///
	q5 12 ///
	q6 13 ///
	q7 14 ///
	q10 15 ///
	q11 16 ///
	q12 17 ///
	q13 18 ///
	q14a 19 ///
	q14b 20 ///
	q15 21 ///
	q16 22 ///
	q17 23 ///
	q18 24 ///
	q19 25-26 ///
	q20 27 ///
	q21 28 ///
	q22a 29 ///
	q22b 30 ///
	q22c 31 ///
	q22d 32 ///
	q22e 33 ///
	q22f 34 ///
	q22g 35 ///
	q22h 36 ///
	q23 37 ///
	q24 38 ///
	q25 39 ///
	q26 40 ///
	q27 41 ///
	q28 42 ///
	q29 43-44 ///
	q30 45 ///
	q31 46 ///
	q49a 47-48 ///
	q49b 49-50 ///
	q49c 51-52 ///
	q50a 53-54 ///
	q50b 55-56 ///
	q50c 57-58 ///
	q50d 59-60 ///
	q50e 61-62 ///
	q50f 63-64 ///
	q50g 65-66 ///
	q50h 67-68 ///
	q50i 69-70 ///
	q51a 71 ///
	q51b 72 ///
	q51c 73 ///
	q51d 74 ///
	q51e 75 ///
	q51f 76 ///
	q52 77 ///
	q53 78 ///
	q54 79 ///
	q55 80 ///
	q56 81 ///
	q57 82 ///
	q57a 83 ///
	q57b 84 ///
	q57c 85 ///
	q57d 86 ///
	q58a 87 ///
	q58b 88 ///
	q58c 89 ///
	q58d 90 ///
	q58e 91 ///
	q58f 92 ///
	q58g 93 ///
	q58h 94 ///
	q58i 95 ///
	q58j 96 ///
	q58k 97 ///
	q58l 98 ///
	q58m 99 ///
	q59a 100 ///
	q59b 101 ///
	q59c 102 ///
	q59d 103 ///
	q59e 104 ///
	q59f 105 ///
	q59g 106 ///
	q59h 107 ///
	q59i 108 ///
	q59j 109 ///
	q59k 110 ///
	q59l 111 ///
	q59m 112 ///
	q60a 113 ///
	q60b 114 ///
	q60c 115 ///
	q60d 116 ///
	q60e 117 ///
	q60f 118 ///
	q60g 119 ///
	q60h 120 ///
	q60i 121 ///
	q60j 122 ///
	q60k 123 ///
	q60l 124 ///
	q60m 125 ///
	q61_1 126 ///
	q61_2 127 ///
	q61_3 128 ///
	q61_4 129 ///
	q61_5 130 ///
	q61_6 131 ///
	q61_7 132 ///
	q61_8 133 ///
	q61_9 134 ///
	q61_10 135 ///
	q61_11 136 ///
	q61_12 137 ///
	q62_1 138 ///
	q62_2 139 ///
	q62_3 140 ///
	q62_4 141 ///
	q62_5 142 ///
	q62_6 143 ///
	q62_7 144 ///
	q62_8 145 ///
	q62_9 146 ///
	q62_10 147 ///
	q62_11 148 ///
	q62_12 149 ///
	q63_1 150 ///
	q63_2 151 ///
	q63_3 152 ///
	q63_4 153 ///
	q63_5 154 ///
	q63_6 155 ///
	q63_7 156 ///
	q63_8 157 ///
	q63_9 158 ///
	q63_10 159 ///
	q63_11 160 ///
	q63_12 161 ///
	q64 162 ///
	q69 163 ///
	q70 164 ///
	q71 165 ///
	q72 166 ///
	q73 167 ///
	q74 168 ///
	q75 169 ///
	q76 170 ///
	q77 171 ///
	q79 172 ///
	q80_1 173 ///
	q80_2 174 ///
	q80_3 175 ///
	q80_4 176 ///
	q80_5 177 ///
	q81 178 ///
	q82 179 ///
	q901 180 ///
	q902 181 ///
	q903 182 ///
	q904 184-185 ///
	q904a1 186 ///
	q904a2 187 ///
	q904a3 188 ///
	q904a4 189 ///
	q904a5 190 ///
	q905a 191 ///
	q906 192 ///
	q907 193-194 ///
	q907a 195 ///
	q907b 196 ///
	q908 197 ///
	q909 198 ///
	q910 199-200 ///
	occupMainEarner 201-202 ///
	positionHH 203 ///
	rentOwn 204 ///
	edu 205 ///
	age 206-207 ///
	ageDecile 208 ///
	ageGroup 209 ///
	union 210 ///
	hispanic 211 ///
	raceSex 212 ///
	sex 213 ///
	race 214 ///
	incomeHHa 215 ///
	incomeHHb 217 ///
	religiona 218 ///
	religionb 219 ///
	telephone 221 ///
	q920 222 ///
	citySize 223-224 ///
	section 225 ///
	state 226-227 ///
	smsa 228 ///
	repliSample 229 ///
	fringe 230 ///	
	using "$ascii/1239.dat"
	
gen svy_year = 1984
gen svy_month = "July"
gen svy = "1984-1239"

label define  lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"

local varMissing q23 edu age
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNoNoOp q56
foreach var in `varYesNoNoOp' {
	label values `var' lb_yesNoNoOp
}

rename q23 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

rename q56 blkPresident

lab def lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
lab val edu lb_edu

label define lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "NEGRO MAN" 4 "NEGRO WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

label define lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

label define lb_race 1 "WHITE" 2 "BLACK" 3 "OTHER"
label values race lb_race

label define lb_sex 1 "MALE" 2 "FEMALE"
label values sex lb_sex

label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

//[...]

save "$ascii/1239-1984.dta", replace 
local svys `svys' 1239-1984


*Gallup Poll # 1959-0610: Politics/Religion [USAIPO1959-0610]
clear
infix ///
	card 1 ///
	deck 2-4 ///
	ballot 5-8 ///
	q1a 9 ///
	q2a 10-11 ///
	q2b 12 ///
	q3 13 ///
	q4 14 ///
	q5 15 ///
	q6a 16 ///
	q6b 17 ///
	q7 18 ///
	q8 19 ///
	q10 20 ///
	q28 21 ///
	q29a 22 ///
	q29b1 23 ///
	q29b2 24 ///
	q29b3 25 ///
	q30 26 ///
	q31ab 27 ///
	q50 28 ///
	q51 29 ///
	q52a 30 ///
	q53 31 ///
	q54 32 ///
	q55 33 ///
	q56 34 ///
	q101a 35-36 ///
	q101b 37-38 ///
	q102ab 39 ///
	q102c 40 ///
	q103a 41 ///
	q103b 42 ///
	q104 43-44 ///
	q105 45 ///
	q106 46 ///
	q107 47-48 ///
	q108 49 ///
	q109 50 ///
	n110 51 ///
	n111 52 ///
	n112 53-54 ///
	n113 55 ///
	n114 55-56 ///
	n115 57-58 ///
	using "$ascii/aipo0610.dat"

gen svy_year = 1959
gen svy_month = "February"
gen svy = "1959-0610"

label define lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define lb_yesNoIA 1 "Yes" 2 "No" 9 "INAPPLICABLE"

local varMissing q1a q29a q50 q101b q102ab q102c q106 q107
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNoNoOp q29b1 q29b2 q29b3
foreach var in `varYesNoNoOp' {
	label values `var' lb_yesNoNoOp
}

local varYesNoIA q29a
foreach var in `varYesNoIA' {
	label values `var' lb_yesNoIA
}

rename q1a presApprovala
label variable presApprovala "APPROVAL OF CURRENT PRESIDENT"
label define lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"
label values presApprovala lb_presApproval

rename q29a childInSchool
rename q29b1 fewMixedSchool
rename q29b2 halfMixedSchool
rename q29b3 halfPlusMixedSchool
label variable childInSchool "ANY CHILD IN GRADE OR HIGH SCHOOL"
label variable fewMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH A FEW BLACK CHILDREN"
label variable halfMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH HALF BLACK CHILDREN"
label variable halfPlusMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH MORE THAN HALF BLACK CHILDREN"

rename q50 religion
label variable religion "RELIGIOUS PREFERENCE"
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

rename q101b adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

gen poliPartyID = .
replace poliPartyID = 1 if q102ab == 1
replace poliPartyID = 2 if q102ab == 2
replace poliPartyID = 3 if (q102ab == 4 | q102ab == 5 | q102ab == 6 | q102ab == 7 | q102ab == 8)
replace poliPartyID = 4 if q102ab == 3
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

rename q102c dixiecrats
label variable dixiecrats "WOULD YOU FAVOR A STATES RIGHTS DEM PARTY IF DEM CANDIDATE WAS PRO-INTEGRATION"
lab def lb_dixiecrats 1 "FAVOR" 2 "OPPOSE" 3 "NO OPINION" 9 "INAPPLICABLE"
lab val dixiecrats lb_dixiecrats

gen partyCD = .
replace partyCD = 1 if q103a == 1
replace partyCD = 2 if q103a == 2
replace partyCD = 3 if q103a == 3
replace partyCD = 4 if (q103a == 4 | q103a == 5) & (q103b == 0 | q103b == 9)
replace partyCD = 5 if (q103a == 4 | q103a == 5) & (q103b == 1)
replace partyCD = 6 if (q103a == 4 | q103a == 5) & (q103b == 2)
replace partyCD = 7 if (q103a == 4 | q103a == 5) & (q103b == 3)
replace partyCD = 8 if (q103a == 4 | q103a == 5) & (q103b == 4)
replace partyCD = 9 if (q103a == 4 | q103a == 5) & (q103b == 5)
label variable partyCD "PREFERRED PARTY FOR CONGRESS"
label define lb_partyCD 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, NO ANSWER TO PART B" 5 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 6 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 7 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 8 "UNDECIDED OR REFUSED, UNDECIDED" 9 "UNDECIDED OR REFUSED, REFUSED TO ANSWER"
label values partyCD lb_partyCD

rename q104 occupation
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q106 edu
lab def lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
lab val edu lb_edu

rename q107 age
label variable age "AGE OF THE RESPONDENT"

rename n110 raceSex
label variable raceSex "RACE AND GENDER OF THE RESPONDENT"
label define lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

rename n112 citySize
label variable citySize "CITY SIZE, WHERE RESPONDENT LIVES"
label define lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

rename n114 state
label variable state "STATE THE RESPONDENT LIVES IN"
label define lb_stateOld 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 0 "NO CODE OR NO DATA"
label values state lb_stateOld
replace state = . if state == 0
replace state = state + 20 if (state == 81 | state == 82 | state == 83 | state == 84)
replace state = state + 10 if (state == 71 | state == 72 | state == 73)
replace state = state + 10 if (state == 61 | state == 62 | state == 63 | state == 64 | state == 65 | state == 66 | state == 67 | state == 68)
replace state = state - 40 if (state == 101 | state == 102 | state == 103 | state == 104)
label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/1959-0610.dta", replace 
local svys `svys' 1959-0610


*Gallup Poll # 1963-0673: Kennedy/Cuba/Race Relations/Presidential Election [USAIPO1963-0673]
clear
infix 2 lines 1: ///
	card 1 ///
	deck 2-4 ///
	ballot 5-8 ///
	q1 9 ///
	q2 10-11 ///
	q3 12 ///
	q4 13 ///
	q5 14 ///
	q6 15 ///
	q7a 16 ///
	q7b 17 ///
	q7c 18 ///
	q7d 19 ///
	q8 20 ///
	q9 21 ///
	q10a 22 ///
	q10b 23 ///
	q20 24 ///
	q21a 25 ///
	q21b 26 ///
	q22ab 27 ///
	q23ab 28 ///
	q24 29 ///
	q25 30 ///
	q26 31 ///
	q27 32 ///
	q28 33 ///
	q30a 34-35 ///
	q30b 36-37 ///
	q30c 38-39 ///
	q30d 40-41 ///
	q30e 42-43 ///
	q30f 44-45 ///
	q30g 46-47 ///
	q30h 48-49 ///
	q30i 50-51 ///
	q30j 52-53 ///
	q30k 54-55 ///
	q31 56 ///
	q101 57 ///
	q102abc 58 ///
	q103ab 59 ///
	q104 60-61 ///
	q105 62 ///
	q106 63 ///
	q107 64 ///
	q108 65 ///
	q109 66 ///
	q110 67-68 ///
	q112a 69 ///
	q112b 70 ///
	q113 71-72 ///
	q114 73-74 ///
	q115 75-76 ///
	n116 77 ///
	n117 78-79 ///
	2: ///
	card2 1 ///
	deck2 2-4 ///
	ballot2 5-8 ///
	n118 9 ///
	n119 9-10 ///
	wgt_timesAtHome 11 ///
	wgt_edu 12 ///
	using "$ascii/aipo0673.dat"

gen svy_year = 1963
gen svy_month = "May"
gen svy = "1963-0673"

label define  lb_yesNo 0 "No" 1 "Yes"
label define lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define lb_yesNoIA 1 "Yes" 2 "No" 9 "INAPPLICABLE"

local varMissing q1 q7a q7b q7c q7d q8 q9 q101 q103ab q106 q108 q107 q110 q113 q114 q115 n119
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNoNoOp q7b q7c q7d
foreach var in `varYesNoNoOp' {
	label values `var' lb_yesNoNoOp
}

local varYesNoIA q7a
foreach var in `varYesNoIA' {
	label values `var' lb_yesNoIA
}

local varYesNo q107
foreach var in `varYesNo' { 
	replace `var'  = 2-`var'
	label values `var' lb_yesNo
}

rename q1 presApprovala
label variable presApprovala "APPROVAL OF CURRENT PRESIDENT"
label define lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"
label values presApprovala lb_presApproval

rename q7a childInSchool
rename q7b fewMixedSchool
rename q7c halfMixedSchool
rename q7d halfPlusMixedSchool
label variable childInSchool "ANY CHILD IN GRADE OR HIGH SCHOOL"
label variable fewMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH A FEW BLACK CHILDREN"
label variable halfMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH HALF BLACK CHILDREN"
label variable halfPlusMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH MORE THAN HALF BLACK CHILDREN"

rename q8 blkNeighbor
replace blkNeighbor = . if blkNeighbor == 9
label variable blkNeighbor "WOULD MOVE IF COLORED NEIGHBOR"
label define lb_blkNeighbor 1 "Yes, definitely" 2 "Might do" 3 "No" 4 "Don't know"
label values blkNeighbor lb_blkNeighbor

rename q9 blkNeighborhood
replace blkNeighborhood = . if blkNeighborhood == 9
label variable blkNeighborhood "WOULD MOVE IF MANY COLORED PEOPLE IN NEIGHBORHOOD"
label values blkNeighborhood lb_blkNeighbor

rename q101 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

rename q103ab partyCD
label variable partyCD "PREFERRED PARTY FOR CONGRESS"
replace partyCD = 22 if partyCD == 1
replace partyCD = 1 if partyCD == 2
replace partyCD = 2 if partyCD == 22
replace partyCD = 55 if partyCD == 5
replace partyCD = 5 if partyCD == 6
replace partyCD = 6 if partyCD == 55
label define lb_partyCD 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, NO ANSWER TO PART B" 5 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 6 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 7 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 8 "UNDECIDED OR REFUSED, UNDECIDED" 9 "UNDECIDED OR REFUSED, REFUSED TO ANSWER"
label values partyCD lb_partyCD

rename q104 occupation
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q106 religion
label variable religion "RELIGIOUS PREFERENCE"
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

rename q107 attendChurch
label variable attendChurch "ATTENDED CHURCH OR SYNAGOGUE IN THE LAST 7 DAYS"

rename q108 edu
lab def lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
lab val edu lb_edu

rename q110 incomeHH_60s
label define lb_incomeHH_60s 1 "UNDER 1000 DOLLARS A YEAR OR UNDER $20 A WEEK" 2 "1,000 TO 1,499 A YEAR OR $20 TO $28.50 A WEEK" 3 "1,500 TO 1,999 A YEAR OR $29 TO $37.50 A WEEK" 4 "2,000 TO 2,499 A YEAR OR $38 TO $47.50 A WEEK" 5 "2,500 TO 2,999 A YEAR OR $48 TO $57.50 A WEEK" 6 "3,000 TO 3,999 A YEAR OR $58 TO $76.50 A WEEK" 7 "4,000 TO 4,999 A YEAR OR $77 TO $95.50 A WEEK" 8 "5,000 TO 6,999 A YEAR OR $96 TO $134.50 A WEEK" 9 "7,000 TO 9,999 A YEAR OR $135 TO $192.50 A WEEK" 10 "10,000 TO 14,999 A YEAR OR $193 TO $288.50 A WEEK" 11 "15,000 AND OVER A YEAR OR $289 AND MORE A WEEK"
label values incomeHH_60s lb_incomeHH_60s

	gen incomeHHharmonized = .
	replace incomeHHharmonized = 500 if incomeHH_60s == 1
	replace incomeHHharmonized = 1250 if incomeHH_60s == 2
	replace incomeHHharmonized = 1750 if incomeHH_60s == 3
	replace incomeHHharmonized = 2250 if incomeHH_60s == 4
	replace incomeHHharmonized = 2750 if incomeHH_60s == 5
	replace incomeHHharmonized = 3500 if incomeHH_60s == 6
	replace incomeHHharmonized = 4500 if incomeHH_60s == 7
	replace incomeHHharmonized = 6000 if incomeHH_60s == 8
	replace incomeHHharmonized = 8500 if incomeHH_60s == 9
	replace incomeHHharmonized = 12500 if incomeHH_60s == 10
	replace incomeHHharmonized = 15000 if incomeHH_60s == 11

rename q113 adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

rename q114 minorsHH
label variable minorsHH "NUMBER OF CHILDREN (MINORS) LIVING IN THIS HOUSEHOLD"
label define lb_minorsHH 1 "ONE CHILD" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE" 11 "NO MINOR CHILDREN"
label values minorsHH lb_minorsHH

rename q115 age
label variable age "AGE OF THE RESPONDENT"

rename n116 raceSex
label variable raceSex "RACE AND GENDER OF THE RESPONDENT"
label define lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

rename n117 citySize
label variable citySize "CITY SIZE, WHERE RESPONDENT LIVES"
label define lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

rename n119 state
label variable state "STATE THE RESPONDENT LIVES IN"
label define lb_stateOld 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA" 0 "NO CODE OR NO DATA"
label values state lb_stateOld
replace state = . if state == 0
replace state = state + 20 if (state == 81 | state == 82 | state == 83 | state == 84)
replace state = state + 10 if (state == 71 | state == 72 | state == 73 | state == 74 | state == 75)
replace state = state + 10 if (state == 61 | state == 62 | state == 63 | state == 64 | state == 65 | state == 66 | state == 67 | state == 68)
replace state = state - 40 if (state == 101 | state == 102 | state == 103 | state == 104)
label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/1963-0673.dta", replace 
local svys `svys' 1963-0673


*Gallup Poll # 710 [USAIPO1965-0710]
clear
infix 2 lines 1: ///
	card 1 ///
	deck 2-4 ///
	ballot 5-8 ///
	q1 9 ///
	q2 10 ///
	q3a 11 ///
	q3b 12 ///
	q3c 13 ///
	q3d 14 ///
	q3e 15 ///
	q3f 16 ///
	q3g 17 ///
	q3h 18 ///
	q3i 19 ///
	q3j 20 ///
	q4 21 ///
	q5 22 ///
	q6a 23 ///
	q6b 24 ///
	q6c 25 ///
	q6d 26 ///
	q6e 27 ///
	q6f 28 ///
	q6g 29-31 ///
	q6h 32-34 ///
	q7a 35 ///
	q7b 36 ///
	q8a 37 ///
	q8b 38 ///
	q9a 39-40 ///
	q9b 41-42 ///
	q9c 43-44 ///
	q10 45 ///
	q11a 46 ///
	q11b 47 ///
	q11c 48 ///
	q11d 49 ///
	q11e 50 ///
	q11f 51 ///
	q12a 52 ///
	q12b 53 ///
	q13a 54 ///
	q13b 55 ///
	q13c 56 ///
	q13d 57 ///
	q14 58 ///
	q15 59 ///
	q16 60 ///
	q17a 61 ///
	q17b 62 ///
	q17c 63 ///
	q17d 64 ///
	q17e 65 ///
	q17f 66 ///
	q17g 67 ///
	q17h 68 ///
	q17i 69 ///
	q17j 70 ///
	q17k 71 ///
	q17l 72 ///
	q17m 73 ///
	q17n 74 ///
	q17o 75 ///
	q17p 76 ///
	q17q 77 ///
	q17r 78 ///
	q17s 79 ///
	2: ///
	card2 1 ///
	deck2 2-4 ///
	ballot2 5-8 ///
	q98 9 ///
	q100a 10-11 ///
	q101 12 ///
	q102ab 13 ///
	q103a 14 ///
	q103b 15 ///
	q105 16-17 ///
	q106a 18-19 ///
	q107a 20 ///
	q107b 21 ///
	q107c 22 ///
	q109 23-24 ///
	q110 25-26 ///
	n111 27 ///
	n112 28-29 ///
	n113 30 ///
	n114 30-31 ///
	wgt_timesAtHome 32 ///
	wgt_edu 33 ///
	using "$ascii/710.dat"

gen svy_year = 1965
gen svy_month = "April"
gen svy = "1965-0710"

label define  lb_yesNo 0 "No" 1 "Yes"
label define lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define lb_yesNoIA 1 "Yes" 2 "No" 9 "INAPPLICABLE"

local varMissing q1 q13a q14 q15 q98 q102ab q103b q105 q106a q107a q107c q109 n114
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNoNoOp q13b q13c q13d
foreach var in `varYesNoNoOp' {
	label values `var' lb_yesNoNoOp
}

local varYesNoIA q13a
foreach var in `varYesNoIA' {
	label values `var' lb_yesNoIA
}

local varYesNo q107c
foreach var in `varYesNo' { 
	replace `var'  = 2-`var'
	label values `var' lb_yesNo
}

rename q1 presApprovala
label variable presApprovala "APPROVAL OF CURRENT PRESIDENT"
label define lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"
label values presApprovala lb_presApproval

rename q13a childInSchool
rename q13b fewMixedSchool
rename q13c halfMixedSchool
rename q13d halfPlusMixedSchool
label variable childInSchool "ANY CHILD IN GRADE OR HIGH SCHOOL"
label variable fewMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH A FEW BLACK CHILDREN"
label variable halfMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH HALF BLACK CHILDREN"
label variable halfPlusMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH MORE THAN HALF BLACK CHILDREN"

rename q14 blkNeighbor
replace blkNeighbor = . if blkNeighbor == 9
label variable blkNeighbor "WOULD MOVE IF COLORED NEIGHBOR"
label define lb_blkNeighbor 1 "Yes, definitely" 2 "Might do" 3 "No" 4 "Don't know"
label values blkNeighbor lb_blkNeighbor

rename q15 blkNeighborhood
replace blkNeighborhood = . if blkNeighborhood == 9
label variable blkNeighborhood "WOULD MOVE IF MANY COLORED PEOPLE IN NEIGHBORHOOD"
label values blkNeighborhood lb_blkNeighbor

rename q98 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

rename q100a occupation
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q102ab partyCD
label variable partyCD "PREFERRED PARTY FOR CONGRESS"
replace partyCD = 22 if partyCD == 1
replace partyCD = 1 if partyCD == 2
replace partyCD = 2 if partyCD == 22
replace partyCD = 55 if partyCD == 5
replace partyCD = 5 if partyCD == 6
replace partyCD = 6 if partyCD == 55
label define lb_partyCD 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, NO ANSWER TO PART B" 5 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 6 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 7 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 8 "UNDECIDED OR REFUSED, UNDECIDED" 9 "UNDECIDED OR REFUSED, REFUSED TO ANSWER"
label values partyCD lb_partyCD

rename q103b edu
lab def lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
lab val edu lb_edu

rename q105 adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

rename q106a minorsHH
label variable minorsHH "NUMBER OF CHILDREN (MINORS) LIVING IN THIS HOUSEHOLD"
label define lb_minorsHH 1 "ONE CHILD" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE" 11 "NO MINOR CHILDREN"
label values minorsHH lb_minorsHH

rename q107a religion
label variable religion "RELIGIOUS PREFERENCE"
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

rename q107c attendChurch
label variable attendChurch "ATTENDED CHURCH OR SYNAGOGUE IN THE LAST 7 DAYS"

rename q109 incomeHH_60s
label define lb_incomeHH_60s 1 "UNDER 1000 DOLLARS A YEAR OR UNDER $20 A WEEK" 2 "1,000 TO 1,499 A YEAR OR $20 TO $28.50 A WEEK" 3 "1,500 TO 1,999 A YEAR OR $29 TO $37.50 A WEEK" 4 "2,000 TO 2,499 A YEAR OR $38 TO $47.50 A WEEK" 5 "2,500 TO 2,999 A YEAR OR $48 TO $57.50 A WEEK" 6 "3,000 TO 3,999 A YEAR OR $58 TO $76.50 A WEEK" 7 "4,000 TO 4,999 A YEAR OR $77 TO $95.50 A WEEK" 8 "5,000 TO 6,999 A YEAR OR $96 TO $134.50 A WEEK" 9 "7,000 TO 9,999 A YEAR OR $135 TO $192.50 A WEEK" 10 "10,000 TO 14,999 A YEAR OR $193 TO $288.50 A WEEK" 11 "15,000 AND OVER A YEAR OR $289 AND MORE A WEEK"
label values incomeHH_60s lb_incomeHH_60s

	gen incomeHHharmonized = .
	replace incomeHHharmonized = 500 if incomeHH_60s == 1
	replace incomeHHharmonized = 1250 if incomeHH_60s == 2
	replace incomeHHharmonized = 1750 if incomeHH_60s == 3
	replace incomeHHharmonized = 2250 if incomeHH_60s == 4
	replace incomeHHharmonized = 2750 if incomeHH_60s == 5
	replace incomeHHharmonized = 3500 if incomeHH_60s == 6
	replace incomeHHharmonized = 4500 if incomeHH_60s == 7
	replace incomeHHharmonized = 6000 if incomeHH_60s == 8
	replace incomeHHharmonized = 8500 if incomeHH_60s == 9
	replace incomeHHharmonized = 12500 if incomeHH_60s == 10
	replace incomeHHharmonized = 15000 if incomeHH_60s == 11

rename q110 age
label variable age "AGE OF THE RESPONDENT"

rename n111 raceSex
label variable raceSex "RACE AND GENDER OF THE RESPONDENT"
label define lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

rename n112 citySize
label variable citySize "CITY SIZE, WHERE RESPONDENT LIVES"
label define lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

rename n114 state
label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/1965-0710.dta", replace 
local svys `svys' 1965-0710


*Gallup Poll # 712 [USAIPO1965-0712]
clear
infix 3 lines 1: ///
	card 1 ///
	deck 2-4 ///
	ballot 5-8 ///
	q1 9 ///
	q2 10 ///
	q3a 11 ///
	q3b 12 ///
	q4a 13 ///
	q4b 14 ///
	q4c 15 ///
	q4d 16 ///
	q4e 17 ///
	q4f 18 ///
	q4g 19 ///
	q4h 20 ///
	q4i 21 ///
	q4j 22 ///
	q4k 23 ///
	q5a 24 ///
	q5b1 25 ///
	q5b2 26 ///
	q5b3 27 ///
	q5b4 28 ///
	q5b5 29 ///
	q5b6 30 ///
	q5b7 31 ///
	q5b8 32 ///
	q5b9 33 ///
	q5b10 34 ///
	q5b11 35 ///
	q6 36-37 ///
	q7 38 ///
	q8a1 39 ///
	q8a2 40 ///
	q8a3 41 ///
	q8a4 42 ///
	q8a5 43 ///
	q8a6 44 ///
	q8a7 45 ///
	q8a8 46 ///
	q8a9 47 ///
	q8a10 48 ///
	q8a11 49 ///
	q8a12 50 ///
	q8a13 51 ///
	q8a14 52 ///
	q8a15 53 ///
	q8a16 54 ///
	q8a17 55 ///
	q8b1 56 ///
	q8b2 57 ///
	q8b3 58 ///
	q8b4 59 ///
	q8b5 60 ///
	q8b6 61 ///
	q8b7 62 ///
	q8b8 63 ///
	q8b9 64 ///
	q8b10 65 ///
	q8b11 66 ///
	q8b12 67 ///
	q9a 68-69 ///
	q9b 70-71 ///
	q9c 72-73 ///
	q10 74 ///
	2: ///
	card2 1 ///
	deck2 2-4 ///
	ballot2 5-8 ///
	q11a 9 ///
	q11b 10 ///
	q11c 11 ///
	q11d 12 ///
	q11e 13 ///
	q11f 14 ///
	q11g 15 ///
	q11h 16 ///
	q11i 17 ///
	q11j 18 ///
	q11k 19 ///
	q11l 20 ///
	q11m 21 ///
	q11n 22 ///
	q11o 23 ///
	q11p 24 ///
	q11q 25 ///
	q11r 26 ///
	q11s 27 ///
	q11t 28 ///
	q11u 29 ///
	q11v 30 ///
	q11w 31 ///
	q11x 32 ///
	q21 33 ///
	q22 34 ///
	q23a 35 ///
	q23b 36 ///
	q23c 37 ///
	q23d 38 ///
	q23e 39 ///
	q23f 40 ///
	q23g 41 ///
	q23h 42 ///
	q23i 43 ///
	q23j 44 ///
	q23k 45 ///
	q23l 46 ///
	q24a 47 ///
	q24b 48 ///
	q24c 49 ///
	q24d 50 ///
	q24e 51 ///
	q24f 52 ///
	q24g 53 ///
	q24h 54 ///
	q24i 55 ///
	q24j 56 ///
	q24k 57 ///
	q24l 58 ///
	q25a 59 ///
	q25b 60 ///
	q25c 61 ///
	q25d 62 ///
	q26a 63 ///
	q26b 64 ///
	q27a 65 ///
	q27b 66 ///
	q27c1 67 ///
	q27c2 68 ///
	q27c3 69 ///
	q27c4 70 ///
	q27c5 71 ///
	q27c6 72 ///
	q27c7 73 ///
	q27c8 74 ///
	q27c9 75 ///
	q27c10 76 ///
	q27c11 77 ///
	3: ///
	card3 1 ///
	deck3 2-4 ///
	ballot3 5-8 ///
	q28a 9 ///
	q28b 10 ///
	q28c 11 ///
	q28d 12 ///
	q28e 13 ///
	q28f 14 ///
	q28g 15 ///
	q28h 16 ///
	q28i 17 ///
	q28j 18 ///
	q28k 19 ///
	q28l 20 ///
	q29 21 ///
	q30 22 ///
	q98 23 ///
	q100 24-25 ///
	q101 26 ///
	q102ab 27 ///
	q103 28 ///
	q104 29-30 ///
	q107a 31 ///
	q109 32-33 ///
	q110 34-35 ///
	n111 36 ///
	n112 37-38 ///
	n113 39 ///
	n114 39-40 ///
	wgt_timesAtHome 41 ///
	wgt_edu 42 ///
	using "$ascii/712.dat"

gen svy_year = 1965
gen svy_month = "June"
gen svy = "1965-0712"

label define lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define lb_yesNoIA 1 "Yes" 2 "No" 9 "INAPPLICABLE"

local varMissing q2 q25a q98 q102ab q103 q104 q107a q109 q110 n114
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNoNoOp q25b q25c q25d
foreach var in `varYesNoNoOp' {
	label values `var' lb_yesNoNoOp
}

local varYesNoIA q25a
foreach var in `varYesNoIA' {
	label values `var' lb_yesNoIA
}

rename q2 presApprovala
label variable presApprovala "APPROVAL OF CURRENT PRESIDENT"
label define lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"
label values presApprovala lb_presApproval

rename q25a childInSchool
rename q25b fewMixedSchool
rename q25c halfMixedSchool
rename q25d halfPlusMixedSchool
label variable childInSchool "ANY CHILD IN GRADE OR HIGH SCHOOL"
label variable fewMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH A FEW BLACK CHILDREN"
label variable halfMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH HALF BLACK CHILDREN"
label variable halfPlusMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH MORE THAN HALF BLACK CHILDREN"

rename q98 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

rename q100 occupation
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q102ab partyCD
label variable partyCD "PREFERRED PARTY FOR CONGRESS"
replace partyCD = 22 if partyCD == 1
replace partyCD = 1 if partyCD == 2
replace partyCD = 2 if partyCD == 22
replace partyCD = 55 if partyCD == 5
replace partyCD = 5 if partyCD == 6
replace partyCD = 6 if partyCD == 55
label define lb_partyCD 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, NO ANSWER TO PART B" 5 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 6 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 7 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 8 "UNDECIDED OR REFUSED, UNDECIDED" 9 "UNDECIDED OR REFUSED, REFUSED TO ANSWER"
label values partyCD lb_partyCD

rename q103 edu
lab def lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
lab val edu lb_edu

rename q104 adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

rename q107a religion
label variable religion "RELIGIOUS PREFERENCE"
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

rename q109 incomeHH_60s
label define lb_incomeHH_60s 1 "UNDER 1000 DOLLARS A YEAR OR UNDER $20 A WEEK" 2 "1,000 TO 1,499 A YEAR OR $20 TO $28.50 A WEEK" 3 "1,500 TO 1,999 A YEAR OR $29 TO $37.50 A WEEK" 4 "2,000 TO 2,499 A YEAR OR $38 TO $47.50 A WEEK" 5 "2,500 TO 2,999 A YEAR OR $48 TO $57.50 A WEEK" 6 "3,000 TO 3,999 A YEAR OR $58 TO $76.50 A WEEK" 7 "4,000 TO 4,999 A YEAR OR $77 TO $95.50 A WEEK" 8 "5,000 TO 6,999 A YEAR OR $96 TO $134.50 A WEEK" 9 "7,000 TO 9,999 A YEAR OR $135 TO $192.50 A WEEK" 10 "10,000 TO 14,999 A YEAR OR $193 TO $288.50 A WEEK" 11 "15,000 AND OVER A YEAR OR $289 AND MORE A WEEK"
label values incomeHH_60s lb_incomeHH_60s

	gen incomeHHharmonized = .
	replace incomeHHharmonized = 500 if incomeHH_60s == 1
	replace incomeHHharmonized = 1250 if incomeHH_60s == 2
	replace incomeHHharmonized = 1750 if incomeHH_60s == 3
	replace incomeHHharmonized = 2250 if incomeHH_60s == 4
	replace incomeHHharmonized = 2750 if incomeHH_60s == 5
	replace incomeHHharmonized = 3500 if incomeHH_60s == 6
	replace incomeHHharmonized = 4500 if incomeHH_60s == 7
	replace incomeHHharmonized = 6000 if incomeHH_60s == 8
	replace incomeHHharmonized = 8500 if incomeHH_60s == 9
	replace incomeHHharmonized = 12500 if incomeHH_60s == 10
	replace incomeHHharmonized = 15000 if incomeHH_60s == 11

rename q110 age
label variable age "AGE OF THE RESPONDENT"

rename n111 raceSex
label variable raceSex "RACE AND GENDER OF THE RESPONDENT"
label define lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

rename n112 citySize
label variable citySize "CITY SIZE, WHERE RESPONDENT LIVES"
label define lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

rename n114 state
label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/1965-0712.dta", replace 
local svys `svys' 1965-0712


*Gallup Poll # 1966-0728: Politics/Vietnam/Political Parties/Recreation [USAIPO1966-0728]
clear
infix 2 lines 1: ///
	card 1 ///
	deck 2-4 ///
	ballot 5-8 ///
	q1a 9 ///
	q1b 10 ///
	q1c 11 ///
	q1d 12 ///
	q1e 13 ///
	q1f 14 ///
	q1g 15 ///
	q1h 16 ///
	q1i 17 ///
	q1j 18 ///
	q1k 19 ///
	q1l 20 ///
	q1m 21 ///
	q1n 22 ///
	q1o 23 ///
	q1p 24 ///
	q1q 25 ///
	q1r 26 ///
	q1s 27 ///
	q1t 28 ///
	q1u 29 ///
	q1v 30 ///
	q1w 31 ///
	q1x 32 ///
	q2ab 33 ///
	q3ab 34 ///
	q4 35 ///
	q5a1 36 ///
	q5a2 37 ///
	q5a3 38 ///
	q5a4 39 ///
	q5a5 40 ///
	q5a6 41 ///
	q5a7 42 ///
	q5a8 43 ///
	q5a9 44 ///
	q5a10 45 ///
	q5a11 46 ///
	q5a12 47 ///
	q5a13 48 ///
	q5a14 49 ///
	q5a15 50 ///
	q5a16 51 ///
	q5a17 52 ///
	q5a18 53 ///
	q5a19 54 ///
	q5a20 55 ///
	q5a21 56 ///
	q5a22 57 ///
	q5a23 58 ///
	q5a24 59 ///
	q5a25 60 ///
	q5a26 61 ///
	q5a27 62 ///
	q5a28 63 ///
	q5a29 64 ///
	q5a30 65 ///
	q5a31 66 ///
	q5a32 67 ///
	q5a33 68 ///
	q5a34 69 ///
	q5a35 70 ///
	q5a36 71 ///
	q5b 72 ///
	q6a 73 ///
	q7 74 ///
	q8 75-76 ///
	q9 77 ///
	q10a 78 ///
	q10b 79 ///
	q10c 80 ///
	2: ///
	card2 1 ///
	deck2 2-4 ///
	ballot2 5-8 ///
	q11 9 ///
	q11a 10 ///
	q11b 11 ///
	q11c 12 ///
	q11d 13 ///
	q11e 14 ///
	q12 15 ///
	q13 16 ///
	q14 17 ///
	q15 18 ///
	q16a 19 ///
	q16b 20 ///
	q16c 21 ///
	q16d 22 ///
	q17a 23 ///
	q17b1 24 ///
	q17b2 25 ///
	q17b3 26 ///
	q17b4 27 ///
	q17b5 28 ///
	q17b6 29 ///
	q17b7 30 ///
	q17b8 31 ///
	q17b9 32 ///
	q17b10 33 ///
	q17b11 34 ///
	q17b12 35 ///
	q17c 36 ///
	q18a 37 ///
	q18b1 38 ///
	q18b2 39 ///
	q18b3 40 ///
	q18b4 41 ///
	q18b5 42 ///
	q18b6 43 ///
	q18b7 44 ///
	q18b8 45 ///
	q18b9 46 ///
	q18b10 47 ///
	q18b11 48 ///
	q18b12 49 ///
	q18b13 50 ///
	q18b14 51 ///
	q19 52 ///
	q20 53 ///
	q21 54 ///
	q22a 55 ///
	q22b 56 ///
	q98 57 ///
	q100ab 58 ///
	q102a 59-60 ///
	q103a 61-62 ///
	q104 63 ///
	q105 64 ///
	q106 65 ///
	q107 66-67 ///
	q109 68-69 ///
	q110 70-71 ///
	n111 72 ///
	n112 73-74 ///
	n113 75 ///
	n114 75-76 ///
	wgt_timesAtHome 77 ///
	wgt_edu 78 ///
	using "$ascii/aipo0728.dat"

gen svy_year = 1966
gen svy_month = "May"
gen svy = "1966-0728"

label define lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define lb_yesNoIA 1 "Yes" 2 "No" 9 "INAPPLICABLE"

local varMissing q4 q16a q98 q100ab q102a q103a q105 q106 q109 q110 n114
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNoNoOp q16b q16c q16d
foreach var in `varYesNoNoOp' {
	label values `var' lb_yesNoNoOp
}

local varYesNoIA q16a
foreach var in `varYesNoIA' {
	label values `var' lb_yesNoIA
}

rename q4 presApprovala
label variable presApprovala "APPROVAL OF CURRENT PRESIDENT"
label define lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"
label values presApprovala lb_presApproval

rename q16a childInSchool
rename q16b fewMixedSchool
rename q16c halfMixedSchool
rename q16d halfPlusMixedSchool
label variable childInSchool "ANY CHILD IN GRADE OR HIGH SCHOOL"
label variable fewMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH A FEW BLACK CHILDREN"
label variable halfMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH HALF BLACK CHILDREN"
label variable halfPlusMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH MORE THAN HALF BLACK CHILDREN"

rename q98 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

rename q100ab partyCD
label variable partyCD "PREFERRED PARTY FOR CONGRESS"
replace partyCD = 22 if partyCD == 1
replace partyCD = 1 if partyCD == 2
replace partyCD = 2 if partyCD == 22
replace partyCD = 55 if partyCD == 5
replace partyCD = 5 if partyCD == 6
replace partyCD = 6 if partyCD == 55
label define lb_partyCD 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, NO ANSWER TO PART B" 5 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 6 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 7 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 8 "UNDECIDED OR REFUSED, UNDECIDED" 9 "UNDECIDED OR REFUSED, REFUSED TO ANSWER"
label values partyCD lb_partyCD

rename q102a adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

rename q103a minorsHH
label variable minorsHH "NUMBER OF CHILDREN (MINORS) LIVING IN THIS HOUSEHOLD"
label define lb_minorsHH 1 "ONE CHILD" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE" 11 "NO MINOR CHILDREN"
label values minorsHH lb_minorsHH

rename q105 religionOrtho
label define lb_religionOrtho 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "EASTERN ORTHODOX" 5 "OTHER" 6 "NONE"
label values religion lb_religionOrtho

gen religion = religionOrtho
replace religion = 4 if religionOrtho == 5
replace religion = 5 if religionOrtho == 6
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

rename q106 edu
lab def lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
lab val edu lb_edu

rename q107 occupation
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q109 incomeHH_60s
label define lb_incomeHH_60s 1 "UNDER 1000 DOLLARS A YEAR OR UNDER $20 A WEEK" 2 "1,000 TO 1,499 A YEAR OR $20 TO $28.50 A WEEK" 3 "1,500 TO 1,999 A YEAR OR $29 TO $37.50 A WEEK" 4 "2,000 TO 2,499 A YEAR OR $38 TO $47.50 A WEEK" 5 "2,500 TO 2,999 A YEAR OR $48 TO $57.50 A WEEK" 6 "3,000 TO 3,999 A YEAR OR $58 TO $76.50 A WEEK" 7 "4,000 TO 4,999 A YEAR OR $77 TO $95.50 A WEEK" 8 "5,000 TO 6,999 A YEAR OR $96 TO $134.50 A WEEK" 9 "7,000 TO 9,999 A YEAR OR $135 TO $192.50 A WEEK" 10 "10,000 TO 14,999 A YEAR OR $193 TO $288.50 A WEEK" 11 "15,000 AND OVER A YEAR OR $289 AND MORE A WEEK"
label values incomeHH_60s lb_incomeHH_60s

	gen incomeHHharmonized = .
	replace incomeHHharmonized = 500 if incomeHH_60s == 1
	replace incomeHHharmonized = 1250 if incomeHH_60s == 2
	replace incomeHHharmonized = 1750 if incomeHH_60s == 3
	replace incomeHHharmonized = 2250 if incomeHH_60s == 4
	replace incomeHHharmonized = 2750 if incomeHH_60s == 5
	replace incomeHHharmonized = 3500 if incomeHH_60s == 6
	replace incomeHHharmonized = 4500 if incomeHH_60s == 7
	replace incomeHHharmonized = 6000 if incomeHH_60s == 8
	replace incomeHHharmonized = 8500 if incomeHH_60s == 9
	replace incomeHHharmonized = 12500 if incomeHH_60s == 10
	replace incomeHHharmonized = 15000 if incomeHH_60s == 11

rename q110 age
label variable age "AGE OF THE RESPONDENT"

rename n111 raceSex
label variable raceSex "RACE AND GENDER OF THE RESPONDENT"
label define lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

rename n112 citySize
label variable citySize "CITY SIZE, WHERE RESPONDENT LIVES"
label define lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

rename n114 state
label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/1966-0728.dta", replace 
local svys `svys' 1966-0728


*Gallup Poll # 1969-0784: Vietnam/Views of Large Cities/ABM Program/Racial Integration [USAIPO1969-0784]
clear
infix ///
	card 1 ///
	deck 2-4 ///
	ballot 5 ///
	area 6-8 ///
	q1 9 ///
	q2 10 ///
	q3a 11 ///
	q3b1 12 ///
	q3b2 13 ///
	q3b3 14 ///
	q3b4 15 ///
	q3b5 16 ///
	q3b6 17 ///
	q3b7 18 ///
	q3b8 19 ///
	q3b9 20 ///
	q3b10 21 ///
	q3b11 22 ///
	q3b12 23 ///
	q4 24 ///
	q5a 25-26 ///
	q5b 27-28 ///
	q5c 29-30 ///
	q5d 31-32 ///
	q5e 33-34 ///
	q5f 35-36 ///
	q6 37-38 ///
	q7a 39 ///
	q7b 40 ///
	q7c 41 ///
	q8a 42 ///
	q8b 43 ///
	q8c 44 ///
	q8d 45 ///
	q10 46 ///
	q11 47-48 ///
	q12 49 ///
	q13 50 ///
	q100 51 ///
	q101a 52-53 ///
	q101b 54-55 ///
	q102 56 ///
	q103 57-58 ///
	q104 59 ///
	q106 60-61 ///
	q107a 62 ///
	q107b 63 ///
	q107c 64 ///
	q108 65-66 ///
	q109 67 ///
	q110 68 ///
	n111 69 ///
	n112 70-71 ///
	n113 72 ///
	n114 72-73 ///
	n115 74-75 ///
	wgt 76 ///
	using "$ascii/aipo0784.dat"

gen svy_year = 1969
gen svy_month = "July"
gen svy = "1969-0784"

label define  lb_yesNo 0 "No" 1 "Yes"
label define lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define lb_yesNoIA 1 "Yes" 2 "No" 9 "INAPPLICABLE"

local varMissing q8a q101a q101b q102 q104 q106 q107a q107b q108 q109 n114
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNoNoOp q8b q8c q8d
foreach var in `varYesNoNoOp' {
	label values `var' lb_yesNoNoOp
}

local varYesNoIA q8a
foreach var in `varYesNoIA' {
	label values `var' lb_yesNoIA
}

local varYesNo q107a
foreach var in `varYesNo' { 
	replace `var'  = 2-`var'
	label values `var' lb_yesNo
}

rename q1 presApprovala
label variable presApprovala "APPROVAL OF CURRENT PRESIDENT"
label define lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"
label values presApprovala lb_presApproval

rename q8a childInSchool
rename q8b fewMixedSchool
rename q8c halfMixedSchool
rename q8d halfPlusMixedSchool
label variable childInSchool "ANY CHILD IN GRADE OR HIGH SCHOOL"
label variable fewMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH A FEW BLACK CHILDREN"
label variable halfMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH HALF BLACK CHILDREN"
label variable halfPlusMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH MORE THAN HALF BLACK CHILDREN"

rename q101a adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

rename q101b minorsHH
label variable minorsHH "NUMBER OF CHILDREN (MINORS) LIVING IN THIS HOUSEHOLD"
label define lb_minorsHH 1 "ONE CHILD" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE" 11 "NO MINOR CHILDREN"
label values minorsHH lb_minorsHH

rename q102 edu
lab def lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
lab val edu lb_edu

rename q103 occupation
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q104 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

rename q106 incomeHH_60s
label define lb_incomeHH_60s 1 "UNDER 1000 DOLLARS A YEAR OR UNDER $20 A WEEK" 2 "1,000 TO 1,499 A YEAR OR $20 TO $28.50 A WEEK" 3 "1,500 TO 1,999 A YEAR OR $29 TO $37.50 A WEEK" 4 "2,000 TO 2,499 A YEAR OR $38 TO $47.50 A WEEK" 5 "2,500 TO 2,999 A YEAR OR $48 TO $57.50 A WEEK" 6 "3,000 TO 3,999 A YEAR OR $58 TO $76.50 A WEEK" 7 "4,000 TO 4,999 A YEAR OR $77 TO $95.50 A WEEK" 8 "5,000 TO 6,999 A YEAR OR $96 TO $134.50 A WEEK" 9 "7,000 TO 9,999 A YEAR OR $135 TO $192.50 A WEEK" 10 "10,000 TO 14,999 A YEAR OR $193 TO $288.50 A WEEK" 11 "15,000 AND OVER A YEAR OR $289 AND MORE A WEEK"
label values incomeHH_60s lb_incomeHH_60s

	gen incomeHHharmonized = .
	replace incomeHHharmonized = 500 if incomeHH_60s == 1
	replace incomeHHharmonized = 1250 if incomeHH_60s == 2
	replace incomeHHharmonized = 1750 if incomeHH_60s == 3
	replace incomeHHharmonized = 2250 if incomeHH_60s == 4
	replace incomeHHharmonized = 2750 if incomeHH_60s == 5
	replace incomeHHharmonized = 3500 if incomeHH_60s == 6
	replace incomeHHharmonized = 4500 if incomeHH_60s == 7
	replace incomeHHharmonized = 6000 if incomeHH_60s == 8
	replace incomeHHharmonized = 8500 if incomeHH_60s == 9
	replace incomeHHharmonized = 12500 if incomeHH_60s == 10
	replace incomeHHharmonized = 15000 if incomeHH_60s == 11

rename q107a attendChurch
label variable attendChurch "ATTENDED CHURCH OR SYNAGOGUE IN THE LAST 7 DAYS"

rename q107b religionOrtho
label define lb_religionOrtho 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "EASTERN ORTHODOX" 5 "OTHER" 6 "NONE"
label values religion lb_religionOrtho

gen religion = religionOrtho
replace religion = 4 if religionOrtho == 5
replace religion = 5 if religionOrtho == 6
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

rename q108 age
label variable age "AGE OF THE RESPONDENT"

rename q109 union
label define lb_union 1 "YES, RESPONDENT IS" 2 "YES, SPOUSE IS" 3 "YES, BOTH ARE" 4 "NO, NEITHER IS"
label values union lb_union

rename n111 raceSex
label variable raceSex "RACE AND GENDER OF THE RESPONDENT"
label define lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

rename n112 citySize
label variable citySize "CITY SIZE, WHERE RESPONDENT LIVES"
label define lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

rename n114 state
label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/1969-0784.dta", replace 
local svys `svys' 1969-0784


*Gallup Poll # 801 [USAIPO1970-0801]
clear
infix 2 lines 1: ///
	card 1 ///
	deck 2-4 ///
	ballot 5 ///
	area 6-8 ///
	q1 9 ///
	q2 10 ///
	q3a 11 ///
	q3b 12 ///
	q3c 13 ///
	q3d 14 ///
	q4 15 ///
	q5 16 ///
	q6a 17 ///
	q6b 18 ///
	q6c 19 ///
	q6d 20 ///
	q6e 21 ///
	q6f 22 ///
	q6g 23 ///
	q6h 24 ///
	q6i 25 ///
	q6j 26 ///
	q6k 27 ///
	q6l 28 ///
	q6m 29 ///
	q6n 30 ///
	q7a 31 ///
	q7b 32 ///
	q7c 33 ///
	q7d 34 ///
	q7e 35 ///
	q7f 36 ///
	q7g 37 ///
	q7h 38 ///
	q7i 39 ///
	q7j 40 ///
	q8 41 ///
	q9 42 ///
	q10a 43 ///
	q10b 44 ///
	q10c1 45 ///
	q10c2 46 ///
	q10c3 47 ///
	q10c4 48 ///
	q10c5 49 ///
	q10c6 50 ///
	q10c7 51 ///
	q10c8 52 ///
	q10c9 53 ///
	q10c10 54 ///
	q10c11 55 ///
	q10c12 56 ///
	q10c13 57 ///
	q10c14 58 ///
	q10c15 59 ///
	q10c16 60 ///
	q10c17 61 ///
	q10c18 62 ///
	q10c19 63 ///
	q10c20 64 ///
	q10c21 65 ///
	q10c22 66 ///
	q10c23 67 ///
	q100a 68 ///
	q101 69-70 ///
	q102 71-72 ///
	q104 73 ///
	q105a 74-75 ///
	q106 76-77 ///
	q107a 78 ///
	q107b 79 ///
	q107c 80 ///
	2: ///
	card2 1 ///
	deck2 2-4 ///
	ballot2 5 ///
	area2 6-8 ///
	q108 9 ///
	q109 10-11 ///
	q110 12 ///
	n111 13 ///
	n112 14-15 ///
	n113 16 ///
	n114 16-17 ///
	n115 18-19 ///
	wgt 20 ///
	using "$ascii/801.dat"

gen svy_year = 1970
gen svy_month = "March"
gen svy = "1970-0801"

label define  lb_yesNo 0 "No" 1 "Yes"
label define lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define lb_yesNoIA 1 "Yes" 2 "No" 9 "INAPPLICABLE"

local varMissing q3a q101 q102 q104 q106 q107a q107b q108 q109 n114
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNoNoOp q3b q3c q3d
foreach var in `varYesNoNoOp' {
	label values `var' lb_yesNoNoOp
}

local varYesNoIA q3a
foreach var in `varYesNoIA' {
	label values `var' lb_yesNoIA
}

local varYesNo q107a
foreach var in `varYesNo' { 
	replace `var'  = 2-`var'
	label values `var' lb_yesNo
}

rename q1 presApprovala
label variable presApprovala "APPROVAL OF CURRENT PRESIDENT"
label define lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"
label values presApprovala lb_presApproval

rename q3a childInSchool
rename q3b fewMixedSchool
rename q3c halfMixedSchool
rename q3d halfPlusMixedSchool
label variable childInSchool "ANY CHILD IN GRADE OR HIGH SCHOOL"
label variable fewMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH A FEW BLACK CHILDREN"
label variable halfMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH HALF BLACK CHILDREN"
label variable halfPlusMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH MORE THAN HALF BLACK CHILDREN"

rename q101 adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

rename q102 minorsHH
label variable minorsHH "NUMBER OF CHILDREN (MINORS) LIVING IN THIS HOUSEHOLD"
label define lb_minorsHH 1 "ONE CHILD" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE" 11 "NO MINOR CHILDREN"
label values minorsHH lb_minorsHH

rename q104 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

rename q105a occupation
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q106 incomeHH_70s
label define lb_incomeHH_70s 1 "UNDER $1,000 A YEAR OR UNDER $20 A WEEK" 2 "$1,000 TO $1,999 A YEAR OR $20 TO $37.50 A WEEK" 3 "$2,000 TO $2,999 A YEAR OR $38 TO $57.50 A WEEK" 4 "$3,000 TO $3,999 A YEAR OR $58 TO $76.50 A WEEK" 5 "$4,000 TO $4,999 A YEAR OR $77 TO $95.50 A WEEK" 6 "$5,000 TO $5,999 A YEAR OR $96 TO $114.50 A WEEK" 7 "$6,000 TO $6,999 A YEAR OR $115 TO $134.50 A WEEK" 8 "$7,000 TO $9,999 A YEAR OR $135 TO $192.50 A WEEK" 9 "$10,000 TO $11,999 A YEAR OR $193 TO $229.50 A WEEK" 10 "$12,000 TO $14,999 A YEAR OR $230 TO $288.50 A WEEK" 11 "$15,000 AND MORE A YEAR OR $289 AND MORE A WEEK"
label values incomeHH_70s lb_incomeHH_70s

	gen incomeHHharmonized = .
	replace incomeHHharmonized = 500 if incomeHH_70s == 1
	replace incomeHHharmonized = 1500 if incomeHH_70s == 2
	replace incomeHHharmonized = 2500 if incomeHH_70s == 3
	replace incomeHHharmonized = 3500 if incomeHH_70s == 4
	replace incomeHHharmonized = 4500 if incomeHH_70s == 5
	replace incomeHHharmonized = 5500 if incomeHH_70s == 6
	replace incomeHHharmonized = 6500 if incomeHH_70s == 7
	replace incomeHHharmonized = 8500 if incomeHH_70s == 8
	replace incomeHHharmonized = 11000 if incomeHH_70s == 9
	replace incomeHHharmonized = 13500 if incomeHH_70s == 10
	replace incomeHHharmonized = 15000 if incomeHH_70s == 11

rename q107a attendChurch
label variable attendChurch "ATTENDED CHURCH OR SYNAGOGUE IN THE LAST 7 DAYS"

rename q107b religionOrtho
label define lb_religionOrtho 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "EASTERN ORTHODOX" 5 "OTHER" 6 "NONE"
label values religion lb_religionOrtho

gen religion = religionOrtho
replace religion = 4 if religionOrtho == 5
replace religion = 5 if religionOrtho == 6
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

rename q108 edu
lab def lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
lab val edu lb_edu

rename q109 age
label variable age "AGE OF THE RESPONDENT"

rename n111 raceSex
label variable raceSex "RACE AND GENDER OF THE RESPONDENT"
label define lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

rename n112 citySize
label variable citySize "CITY SIZE, WHERE RESPONDENT LIVES"
label define lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

rename n114 state
label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/1970-0801.dta", replace 
local svys `svys' 1970-0801


*Gallup Poll # 804 [USAIPO1970-0804]
clear
infix ///
	card 1 ///
	deck 2-4 ///
	ballot 5 ///
	area 6-8 ///
	q1 9 ///
	q2 10 ///
	q3 11 ///
	q4a 12 ///
	q4b 13 ///
	q4c 14 ///
	q4d 15 ///
	q5 16 ///
	q6ab 17 ///
	q101 18-19 ///
	q102 20-21 ///
	q103 22 ///
	q104 23 ///
	q105a 24-25 ///
	q106 26-27 ///
	n106 28 ///
	q107 29 ///
	q108 30 ///
	q109 31-32 ///
	n114 33 ///
	n115 34-35 ///
	n116 36 ///
	n117 36-37 ///
	wgt 38 ///
	using "$ascii/804.dat"

gen svy_year = 1970
gen svy_month = "April"
gen svy = "1970-0804"

label define lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define lb_yesNoIA 1 "Yes" 2 "No" 9 "INAPPLICABLE"

local varMissing q4a q6ab q101 q102 q104 q106 q107 q108 q109 n117
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNoNoOp q4b q4c q4d
foreach var in `varYesNoNoOp' {
	label values `var' lb_yesNoNoOp
}

local varYesNoIA q4a
foreach var in `varYesNoIA' {
	label values `var' lb_yesNoIA
}

rename q1 presApprovala
label variable presApprovala "APPROVAL OF CURRENT PRESIDENT"
label define lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"
label values presApprovala lb_presApproval

rename q4a childInSchool
rename q4b fewMixedSchool
rename q4c halfMixedSchool
rename q4d halfPlusMixedSchool
label variable childInSchool "ANY CHILD IN GRADE OR HIGH SCHOOL"
label variable fewMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH A FEW BLACK CHILDREN"
label variable halfMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH HALF BLACK CHILDREN"
label variable halfPlusMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH MORE THAN HALF BLACK CHILDREN"

rename q6ab partyCD
label variable partyCD "PREFERRED PARTY FOR CONGRESS"
replace partyCD = 22 if partyCD == 1
replace partyCD = 1 if partyCD == 2
replace partyCD = 2 if partyCD == 22
label define lb_partyCD 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, NO ANSWER TO PART B" 5 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 6 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 7 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 8 "UNDECIDED OR REFUSED, UNDECIDED" 9 "UNDECIDED OR REFUSED, REFUSED TO ANSWER"
label values partyCD lb_partyCD

rename q101 adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

rename q102 minorsHH
label variable minorsHH "NUMBER OF CHILDREN (MINORS) LIVING IN THIS HOUSEHOLD"
label define lb_minorsHH 1 "ONE CHILD" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE" 11 "NO MINOR CHILDREN"
label values minorsHH lb_minorsHH

rename q104 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

rename q105a occupation
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q106 incomeHH_70s
label define lb_incomeHH_70s 1 "UNDER $1,000 A YEAR OR UNDER $20 A WEEK" 2 "$1,000 TO $1,999 A YEAR OR $20 TO $37.50 A WEEK" 3 "$2,000 TO $2,999 A YEAR OR $38 TO $57.50 A WEEK" 4 "$3,000 TO $3,999 A YEAR OR $58 TO $76.50 A WEEK" 5 "$4,000 TO $4,999 A YEAR OR $77 TO $95.50 A WEEK" 6 "$5,000 TO $5,999 A YEAR OR $96 TO $114.50 A WEEK" 7 "$6,000 TO $6,999 A YEAR OR $115 TO $134.50 A WEEK" 8 "$7,000 TO $9,999 A YEAR OR $135 TO $192.50 A WEEK" 9 "$10,000 TO $11,999 A YEAR OR $193 TO $229.50 A WEEK" 10 "$12,000 TO $14,999 A YEAR OR $230 TO $288.50 A WEEK" 11 "$15,000 AND MORE A YEAR OR $289 AND MORE A WEEK"
label values incomeHH_70s lb_incomeHH_70s

	gen incomeHHharmonized = .
	replace incomeHHharmonized = 500 if incomeHH_70s == 1
	replace incomeHHharmonized = 1500 if incomeHH_70s == 2
	replace incomeHHharmonized = 2500 if incomeHH_70s == 3
	replace incomeHHharmonized = 3500 if incomeHH_70s == 4
	replace incomeHHharmonized = 4500 if incomeHH_70s == 5
	replace incomeHHharmonized = 5500 if incomeHH_70s == 6
	replace incomeHHharmonized = 6500 if incomeHH_70s == 7
	replace incomeHHharmonized = 8500 if incomeHH_70s == 8
	replace incomeHHharmonized = 11000 if incomeHH_70s == 9
	replace incomeHHharmonized = 13500 if incomeHH_70s == 10
	replace incomeHHharmonized = 15000 if incomeHH_70s == 11

rename q107 religionOrtho
label define lb_religionOrtho 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "EASTERN ORTHODOX" 5 "OTHER" 6 "NONE"
label values religion lb_religionOrtho

gen religion = religionOrtho
replace religion = 4 if religionOrtho == 5
replace religion = 5 if religionOrtho == 6
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

rename q108 edu
lab def lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
lab val edu lb_edu

rename q109 age
label variable age "AGE OF THE RESPONDENT"

rename n114 raceSex
label variable raceSex "RACE AND GENDER OF THE RESPONDENT"
label define lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

rename n115 citySize
label variable citySize "CITY SIZE, WHERE RESPONDENT LIVES"
label define lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

rename n117 state
label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/1970-0804.dta", replace 
local svys `svys' 1970-0804


*Gallup Poll # 1958-0605: Elections/Communism/Political Parties/Race Relations
clear
infix ///
	card 1 ///
	deck 2-4 ///
	ballot 5-8 ///
	q1 9 ///
	q2 10 ///
	q3 11 ///
	q4 12 ///
	q5a 13 ///
	q5b 14 ///
	q6 15 ///
	q7type 16 ///
	q7ab 17-18 ///
	q7 19 ///
	q8 20 ///
	q9a 21 ///
	q9b 22 ///
	q26a 23 ///
	q27a 24-25 ///
	q27b 26 ///
	q28a 27 ///
	q28b 28 ///
	q29a 29 ///
	q29b 30 ///
	q29c 31 ///
	q30 32 ///
	q31 33 ///
	q32 34 ///
	q33 35 ///
	q50 36 ///
	q51ab 37 ///
	q52ab 38 ///
	q53ab 39 ///
	q54 40 ///
	q55 41 ///
	q56a 42 ///
	q56b 43 ///
	q56c 44 ///
	q103ab 45 ///
	q103c 46 ///
	q104 47-48 ///
	q105 49-50 ///
	q106 51 ///
	q107 52 ///
	q108 53 ///
	q109a 54 ///
	q109b 55-56 ///
	q109c 57 ///
	q110 58 ///
	q111 59-60 ///
	n112 61 ///
	n113 62 ///
	n114 63-64 ///
	n115 65 ///
	n116 65-66 ///
	n117 67-68 ///
	using "$ascii/aipo0605.dat"

gen svy_year = 1958
gen svy_month = "September"
gen svy = "1958-0605"

local varMissing q7ab q26a q56b q56c q103ab q103c q105 q107 q108 q110 q111 n116
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

rename q7ab partyCD
replace partyCD = 1 if partyCD == 99 & q7 == 1
replace partyCD = 2 if partyCD == 99 & q7 == 2
replace partyCD = 4 if (partyCD == 4 | partyCD == 5) | (partyCD == 99 & q7 == 3)
replace partyCD = partyCD - 1 if partyCD > 5
label variable partyCD "PREFERRED PARTY FOR CONGRESS"
label define lb_partyCD 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, NO ANSWER TO PART B" 5 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 6 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 7 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 8 "UNDECIDED OR REFUSED, UNDECIDED" 9 "UNDECIDED OR REFUSED, REFUSED TO ANSWER"
label values partyCD lb_partyCD

rename q26a presApprovala
label variable presApprovala "APPROVAL OF CURRENT PRESIDENT"
label define lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"
label values presApprovala lb_presApproval

rename q56b blkNeighbor
replace blkNeighbor = . if blkNeighbor == 9
label variable blkNeighbor "WOULD MOVE IF COLORED NEIGHBOR"
label define lb_blkNeighbor 1 "Yes, definitely" 2 "Might do" 3 "No" 4 "Don't know"
label values blkNeighbor lb_blkNeighbor

rename q56c blkNeighborhood
replace blkNeighborhood = . if blkNeighborhood == 9
label variable blkNeighborhood "WOULD MOVE IF MANY COLORED PEOPLE IN NEIGHBORHOOD"
label values blkNeighborhood lb_blkNeighbor

gen poliPartyID = .
replace poliPartyID = 1 if q103ab == 1
replace poliPartyID = 2 if q103ab == 2
replace poliPartyID = 3 if (q103ab == 4 | q103ab == 5 | q103ab == 6 | q103ab == 7 | q103ab == 8)
replace poliPartyID = 4 if q103ab == 3
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

rename q103c dixiecrats
label variable dixiecrats "WOULD YOU FAVOR A STATES RIGHTS DEM PARTY IF DEM CANDIDATE WAS PRO-INTEGRATION"
lab def lb_dixiecrats 1 "FAVOR" 2 "OPPOSE" 3 "NO OPINION" 9 "INAPPLICABLE"
lab val dixiecrats lb_dixiecrats

rename q104 occupation
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q105 adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

rename q107 edu_1958
label define lb_edu_1958 1 "NONE, OR GRADES 1-6" 2 "GRADE 7 OR 8" 3 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 4 "HIGH SCHOOL GRADUATE (GRADE 12)" 5 "TECHNICAL, TRADE OR BUSINESS" 6 "COLLEGE, UNIVERSITY, INCOMPLETE" 7 "COLLEGE, UNIVERSITY, GRADUATE"
label values edu_1958 lb_edu_1958

rename q108 union
replace union = 11 if union == 1
replace union = 22 if union == 2
replace union = 1 if (union == 11 & (n112 == 1 | n112 == 3 | n112 == 5)) ///
	| (union == 22 & (n112 == 2 | n112 == 4 | n112 == 6))
replace union = 2 if (union == 22 & (n112 == 1 | n112 == 3 | n112 == 5)) ///
	| (union == 11 & (n112 == 2 | n112 == 4 | n112 == 6))
label define lb_union 1 "YES, RESPONDENT IS" 2 "YES, SPOUSE IS" 3 "YES, BOTH ARE" 4 "NO, NEITHER IS"
label values union lb_union

rename q110 religion
label variable religion "RELIGIOUS PREFERENCE"
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

rename q111 age
label variable age "AGE OF THE RESPONDENT"

rename n112 raceSex
label variable raceSex "RACE AND GENDER OF THE RESPONDENT"
label define lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

rename n114 citySize
label variable citySize "CITY SIZE, WHERE RESPONDENT LIVES"
label define lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

rename n116 state
label variable state "STATE THE RESPONDENT LIVES IN"
label define lb_stateOld 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 0 "NO CODE OR NO DATA"
label values state lb_stateOld
replace state = . if state == 0
replace state = state + 20 if (state == 81 | state == 82 | state == 83 | state == 84)
replace state = state + 10 if (state == 71 | state == 72 | state == 73)
replace state = state + 10 if (state == 61 | state == 62 | state == 63 | state == 64 | state == 65 | state == 66 | state == 67 | state == 68)
replace state = state - 40 if (state == 101 | state == 102 | state == 103 | state == 104)
label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/1958-0605.dta", replace 
local svys `svys' 1958-0605


*Gallup Poll # 1966-0729: Vietnam/1968 Presidential
clear
infix 2 lines 1: ///
	card 1 ///
	deck 2-4 ///
	ballot 5-8 ///
	q1 9 ///
	q2a 10 ///
	q2b1 11 ///
	q2b2 12 ///
	q2b3 13 ///
	q2b4 14 ///
	q2b5 15 ///
	q2b6 16 ///
	q2b7 17 ///
	q2b8 18 ///
	q2b9 19 ///
	q2b10 20 ///
	q2b11 21 ///
	q2b12 22 ///
	q2b13 23 ///
	q2b14 24 ///
	q2b15 25 ///
	q2b16 26 ///
	q2b17 27 ///
	q2b18 28 ///
	q2b19 29 ///
	q2b20 30 ///
	q2b21 31 ///
	q2b22 32 ///
	q2b23 33 ///
	q2b24 34 ///
	q2b25 35 ///
	q2b26 36 ///
	q3 37 ///
	q4 38 ///
	q5a 39 ///
	q5b1 40 ///
	q5b2 41 ///
	q5b3 42 ///
	q5b4 43 ///
	q5b5 44 ///
	q5b6 45 ///
	q5b7 46 ///
	q5b8 47 ///
	q5b9 48 ///
	q5b10 49 ///
	q5b11 50 ///
	q5b12 51 ///
	q5b13 52 ///
	q5b14 53 ///
	q5b15 54 ///
	q5b16 55 ///
	q5b17 56 ///
	q6a 57-58 ///
	q6b 59-60 ///
	q6c 61-62 ///
	q7 63 ///
	q8a 64 ///
	q8b 65 ///
	q9a 66 ///
	q9b1 67 ///
	q9b2 68 ///
	q9b3 69 ///
	q9b4 70 ///
	q9b5 71 ///
	q9b6 72 ///
	q9b7 73 ///
	q9b8 74 ///
	2: ///
	card2 1 ///
	deck2 2-4 ///
	ballot2 5-8 ///
	q9b9 9 ///
	q9b10 10 ///
	q9b11 11 ///
	q9b12 12 ///
	q9b13 13 ///
	q9b14 14 ///
	q9b15 15 ///
	q9b16 16 ///
	q9b17 17 ///
	q9b18 18 ///
	q9b19 19 ///
	q9b20 20 ///
	q98 21 ///
	q100ab 22 ///
	q101 23 ///
	q102 24-25 ///
	q103 26-27 ///
	q104 28 ///
	q105a 29 ///
	q105b 30 ///
	q105c 31 ///
	q106 32 ///
	q107 33 ///
	q108 34-35 ///
	q110 36-37 ///
	q111 38-39 ///
	n112 40 ///
	n113 41-42 ///
	n114 43 ///
	n115 43-44 ///
	wgt_timesAtHome 45 ///
	wgt_edu 46 ///
	using "$ascii/aipo0729.dat"

gen svy_year = 1966
gen svy_month = "May"
gen svy = "1966-0729"

label define  lb_yesNo 0 "No" 1 "Yes"

local varMissing q1 q8a q8b q98 q100ab q102 q103 q105a q105b q106 q110 q111 n115
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNo q105a
foreach var in `varYesNo' { 
	replace `var'  = 2-`var'
	label values `var' lb_yesNo
}

rename q1 presApprovala
label variable presApprovala "APPROVAL OF CURRENT PRESIDENT"
label define lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"
label values presApprovala lb_presApproval

rename q8a blkNeighbor
replace blkNeighbor = . if blkNeighbor == 9
label variable blkNeighbor "WOULD MOVE IF COLORED NEIGHBOR"
label define lb_blkNeighbor 1 "Yes, definitely" 2 "Might do" 3 "No" 4 "Don't know"
label values blkNeighbor lb_blkNeighbor

rename q8b blkNeighborhood
replace blkNeighborhood = . if blkNeighborhood == 9
label variable blkNeighborhood "WOULD MOVE IF MANY COLORED PEOPLE IN NEIGHBORHOOD"
label values blkNeighborhood lb_blkNeighbor

rename q98 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

rename q100ab partyCD
label variable partyCD "PREFERRED PARTY FOR CONGRESS"
replace partyCD = 22 if partyCD == 1
replace partyCD = 1 if partyCD == 2
replace partyCD = 2 if partyCD == 22
replace partyCD = 55 if partyCD == 5
replace partyCD = 5 if partyCD == 6
replace partyCD = 6 if partyCD == 55
label define lb_partyCD 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, NO ANSWER TO PART B" 5 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 6 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 7 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 8 "UNDECIDED OR REFUSED, UNDECIDED" 9 "UNDECIDED OR REFUSED, REFUSED TO ANSWER"
label values partyCD lb_partyCD

rename q102 adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

rename q103 minorsHH
label variable minorsHH "NUMBER OF CHILDREN (MINORS) LIVING IN THIS HOUSEHOLD"
label define lb_minorsHH 1 "ONE CHILD" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE" 11 "NO MINOR CHILDREN"
label values minorsHH lb_minorsHH

rename q105a attendChurch
label variable attendChurch "ATTENDED CHURCH OR SYNAGOGUE IN THE LAST 7 DAYS"

rename q105b religionOrtho
label define lb_religionOrtho 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "EASTERN ORTHODOX" 5 "OTHER" 6 "NONE"
label values religion lb_religionOrtho

gen religion = religionOrtho
replace religion = 4 if religionOrtho == 5
replace religion = 5 if religionOrtho == 6
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

rename q106 edu
lab def lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
lab val edu lb_edu

rename q108 occupation
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q110 incomeHH_60s
label define lb_incomeHH_60s 1 "UNDER 1000 DOLLARS A YEAR OR UNDER $20 A WEEK" 2 "1,000 TO 1,499 A YEAR OR $20 TO $28.50 A WEEK" 3 "1,500 TO 1,999 A YEAR OR $29 TO $37.50 A WEEK" 4 "2,000 TO 2,499 A YEAR OR $38 TO $47.50 A WEEK" 5 "2,500 TO 2,999 A YEAR OR $48 TO $57.50 A WEEK" 6 "3,000 TO 3,999 A YEAR OR $58 TO $76.50 A WEEK" 7 "4,000 TO 4,999 A YEAR OR $77 TO $95.50 A WEEK" 8 "5,000 TO 6,999 A YEAR OR $96 TO $134.50 A WEEK" 9 "7,000 TO 9,999 A YEAR OR $135 TO $192.50 A WEEK" 10 "10,000 TO 14,999 A YEAR OR $193 TO $288.50 A WEEK" 11 "15,000 AND OVER A YEAR OR $289 AND MORE A WEEK"
label values incomeHH_60s lb_incomeHH_60s

	gen incomeHHharmonized = .
	replace incomeHHharmonized = 500 if incomeHH_60s == 1
	replace incomeHHharmonized = 1250 if incomeHH_60s == 2
	replace incomeHHharmonized = 1750 if incomeHH_60s == 3
	replace incomeHHharmonized = 2250 if incomeHH_60s == 4
	replace incomeHHharmonized = 2750 if incomeHH_60s == 5
	replace incomeHHharmonized = 3500 if incomeHH_60s == 6
	replace incomeHHharmonized = 4500 if incomeHH_60s == 7
	replace incomeHHharmonized = 6000 if incomeHH_60s == 8
	replace incomeHHharmonized = 8500 if incomeHH_60s == 9
	replace incomeHHharmonized = 12500 if incomeHH_60s == 10
	replace incomeHHharmonized = 15000 if incomeHH_60s == 11

rename q111 age
label variable age "AGE OF THE RESPONDENT"

rename n112 raceSex
label variable raceSex "RACE AND GENDER OF THE RESPONDENT"
label define lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

rename n113 citySize
label variable citySize "CITY SIZE, WHERE RESPONDENT LIVES"
label define lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

rename n115 state
label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/1966-0729.dta", replace 
local svys `svys' 1966-0729


*Gallup Poll # 1966-0730: Johnson/1968 Presidential Election/Vietnam/Race Relations/Political Parties
clear
infix 3 lines 1: ///
	card 1 ///
	deck 2-4 ///
	ballot 5-8 ///
	q1a 9 ///
	q1b1 10 ///
	q1b2 11 ///
	q1b3 12 ///
	q1b4 13 ///
	q1b5 14 ///
	q1b6 15 ///
	q1b7 16 ///
	q1b8 17 ///
	q1b9 18 ///
	q1b10 19 ///
	q1b11 20 ///
	q1b12 21 ///
	q1b13 22 ///
	q1b14 23 ///
	q1b15 24 ///
	q1b16 25 ///
	q1b17 26 ///
	q1b18 27 ///
	q1b19 28 ///
	q1b20 29 ///
	q1b21 30 ///
	q1b22 31 ///
	q1b23 32 ///
	q1b24 33 ///
	q1b25 34 ///
	q1b26 35 ///
	q1b27 36 ///
	q1b28 37 ///
	q1b29 38 ///
	q1b30 39 ///
	q1b31 40 ///
	q1b32 41 ///
	q1b33 42 ///
	q1b34 43 ///
	q1b35 44 ///
	q1b36 45 ///
	q1b37 46 ///
	q1b38 47 ///
	q1b39 48 ///
	q1b40 49 ///
	q1b41 50 ///
	q1b42 51 ///
	q1b43 52 ///
	q1b44 53 ///
	q2a 54 ///
	q2b1 55 ///
	q2b2 56 ///
	q2b3 57 ///
	q2b4 58 ///
	q2b5 59 ///
	q2b6 60 ///
	q2b7 61 ///
	q2b8 62 ///
	q2b9 63 ///
	q2b10 64 ///
	q2b11 65 ///
	q2b12 66 ///
	q2b13 67 ///
	q2b14 68 ///
	q2b15 69 ///
	q2b16 70 ///
	q2b17 71 ///
	q2b18 72 ///
	q2b19 73 ///
	q2b20 74 ///
	q2b21 75 ///
	q2b22 76 ///
	q2b23 77 ///
	q2b24 78 ///
	q2b25 79 ///
	q2b26 80 ///
	2: ///
	card2 1 ///
	deck2 2-4 ///
	ballot2 5-8 ///
	q3 9 ///
	q4a 10 ///
	q4b1 11 ///
	q4b2 12 ///
	q4b3 13 ///
	q4b4 14 ///
	q4b5 15 ///
	q4b6 16 ///
	q4b7 17 ///
	q4b8 18 ///
	q4b9 19 ///
	q4b10 20 ///
	q4b11 21 ///
	q4b12 22 ///
	q4b13 23 ///
	q4b14 24 ///
	q4b15 25 ///
	q4b16 26 ///
	q4b17 27 ///
	q5a 28-29 ///
	q5b 30-31 ///
	q6 32 ///
	q7 33 ///
	q8a 34 ///
	q9a 35 ///
	q9b 36 ///
	q10a 37 ///
	q10b1 38 ///
	q10b2 39 ///
	q10b3 40 ///
	q10b4 41 ///
	q10b5 42 ///
	q10b6 43 ///
	q10b7 44 ///
	q10b8 45 ///
	q10b9 46 ///
	q10b10 47 ///
	q10b11 48 ///
	q10b12 49 ///
	q10b13 50 ///
	q10b14 51 ///
	q10b15 52 ///
	q10b16 53 ///
	q10b17 54 ///
	q11a 55 ///
	q11b 56 ///
	q12ab 57 ///
	q13ab 58 ///
	q14a 59 ///
	q14b 60 ///
	q14c 61 ///
	q15 62 ///
	q16 63 ///
	q17 64 ///
	q98 65 ///
	q100ab 66 ///
	q101 67 ///
	q102 68-69 ///
	q103 70-71 ///
	q105a 72 ///
	q105b 73 ///
	q105c 74 ///
	q106 75 ///
	q107 76-77 ///
	q108 78-79 ///
	3: ///
	card3 1 ///
	deck3 2-4 ///
	ballot3 5-8 ///
	q110 9-10 ///
	q111 11-12 ///
	n112 13 ///
	n113 14-15 ///
	n114 16 ///
	n115 16-17 ///
	wgt_timesAtHome 18 ///
	wgt_edu 19 ///
	using "$ascii/aipo0730.dat"

gen svy_year = 1966
gen svy_month = "June"
gen svy = "1966-0730"

label define  lb_yesNo 0 "No" 1 "Yes"

local varMissing q1a q9a q9b q98 q100ab q102 q103 q105a q105b q106 q110 q111 n115
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNo q105a
foreach var in `varYesNo' { 
	replace `var'  = 2-`var'
	label values `var' lb_yesNo
}

rename q1a presApprovala
label variable presApprovala "APPROVAL OF CURRENT PRESIDENT"
label define lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"
label values presApprovala lb_presApproval

rename q9a blkNeighbor
replace blkNeighbor = . if blkNeighbor == 9
label variable blkNeighbor "WOULD MOVE IF COLORED NEIGHBOR"
label define lb_blkNeighbor 1 "Yes, definitely" 2 "Might do" 3 "No" 4 "Don't know"
label values blkNeighbor lb_blkNeighbor

rename q9b blkNeighborhood
replace blkNeighborhood = . if blkNeighborhood == 9
label variable blkNeighborhood "WOULD MOVE IF MANY COLORED PEOPLE IN NEIGHBORHOOD"
label values blkNeighborhood lb_blkNeighbor

rename q98 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

rename q100ab partyCD
label variable partyCD "PREFERRED PARTY FOR CONGRESS"
replace partyCD = 22 if partyCD == 1
replace partyCD = 1 if partyCD == 2
replace partyCD = 2 if partyCD == 22
replace partyCD = 55 if partyCD == 5
replace partyCD = 5 if partyCD == 6
replace partyCD = 6 if partyCD == 55
label define lb_partyCD 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, NO ANSWER TO PART B" 5 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 6 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 7 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 8 "UNDECIDED OR REFUSED, UNDECIDED" 9 "UNDECIDED OR REFUSED, REFUSED TO ANSWER"
label values partyCD lb_partyCD

rename q102 adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

rename q103 minorsHH
label variable minorsHH "NUMBER OF CHILDREN (MINORS) LIVING IN THIS HOUSEHOLD"
label define lb_minorsHH 1 "ONE CHILD" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE" 11 "NO MINOR CHILDREN"
label values minorsHH lb_minorsHH

rename q105a attendChurch
label variable attendChurch "ATTENDED CHURCH OR SYNAGOGUE IN THE LAST 7 DAYS"

rename q105b religionOrtho
label define lb_religionOrtho 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "EASTERN ORTHODOX" 5 "OTHER" 6 "NONE"
label values religion lb_religionOrtho

gen religion = religionOrtho
replace religion = 4 if religionOrtho == 5
replace religion = 5 if religionOrtho == 6
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

rename q106 edu
lab def lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
lab val edu lb_edu

rename q107 occupation
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q110 incomeHH_60s
label define lb_incomeHH_60s 1 "UNDER 1000 DOLLARS A YEAR OR UNDER $20 A WEEK" 2 "1,000 TO 1,499 A YEAR OR $20 TO $28.50 A WEEK" 3 "1,500 TO 1,999 A YEAR OR $29 TO $37.50 A WEEK" 4 "2,000 TO 2,499 A YEAR OR $38 TO $47.50 A WEEK" 5 "2,500 TO 2,999 A YEAR OR $48 TO $57.50 A WEEK" 6 "3,000 TO 3,999 A YEAR OR $58 TO $76.50 A WEEK" 7 "4,000 TO 4,999 A YEAR OR $77 TO $95.50 A WEEK" 8 "5,000 TO 6,999 A YEAR OR $96 TO $134.50 A WEEK" 9 "7,000 TO 9,999 A YEAR OR $135 TO $192.50 A WEEK" 10 "10,000 TO 14,999 A YEAR OR $193 TO $288.50 A WEEK" 11 "15,000 AND OVER A YEAR OR $289 AND MORE A WEEK"
label values incomeHH_60s lb_incomeHH_60s

	gen incomeHHharmonized = .
	replace incomeHHharmonized = 500 if incomeHH_60s == 1
	replace incomeHHharmonized = 1250 if incomeHH_60s == 2
	replace incomeHHharmonized = 1750 if incomeHH_60s == 3
	replace incomeHHharmonized = 2250 if incomeHH_60s == 4
	replace incomeHHharmonized = 2750 if incomeHH_60s == 5
	replace incomeHHharmonized = 3500 if incomeHH_60s == 6
	replace incomeHHharmonized = 4500 if incomeHH_60s == 7
	replace incomeHHharmonized = 6000 if incomeHH_60s == 8
	replace incomeHHharmonized = 8500 if incomeHH_60s == 9
	replace incomeHHharmonized = 12500 if incomeHH_60s == 10
	replace incomeHHharmonized = 15000 if incomeHH_60s == 11

rename q111 age
label variable age "AGE OF THE RESPONDENT"

rename n112 raceSex
label variable raceSex "RACE AND GENDER OF THE RESPONDENT"
label define lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

rename n113 citySize
label variable citySize "CITY SIZE, WHERE RESPONDENT LIVES"
label define lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

rename n115 state
label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/1966-0730.dta", replace 
local svys `svys' 1966-0730


*Gallup Poll # 1967-0749: Race Relations
clear
infix 2 lines 1: ///
	card 1 ///
	deck 2-4 ///
	ballot 5-8 ///
	q1 9 ///
	q2a1 10 ///
	q2a2 11 ///
	q2a3 12 ///
	q2a4 13 ///
	q2a5 14 ///
	q2a6 15 ///
	q2a7 16 ///
	q2a8 17 ///
	q2a9 18 ///
	q2a10 19 ///
	q2a11 20 ///
	q2a12 21 ///
	q2a13 22 ///
	q2a14 23 ///
	q2a15 24 ///
	q2a16 25 ///
	q2a17 26 ///
	q2a18 27 ///
	q2a19 28 ///
	q2a20 29 ///
	q2a21 30 ///
	q2a22 31 ///
	q2a23 32 ///
	q2a24 33 ///
	q2a25 34 ///
	q2a26 35 ///
	q2a27 36 ///
	q2a28 37 ///
	q2a29 38 ///
	q2a30 39 ///
	q2a31 40 ///
	q2a32 41 ///
	q2a33 42 ///
	q2a34 43 ///
	q2a35 44 ///
	q2b 45 ///
	q3 46 ///
	q4 47 ///
	q5 48 ///
	q6 49 ///
	q7a 50 ///
	q7b 51 ///
	q7c 52 ///
	q8 53 ///
	q9ab 54 ///
	q10ab 55 ///
	q11a 56 ///
	q11b1 57 ///
	q11b2 58 ///
	q11b3 59 ///
	q12a 60 ///
	q12b 61 ///
	q12c 62 ///
	q12d 63 ///
	q12e 64 ///
	q12f 65 ///
	q12g 66 ///
	q12h 67 ///
	q12i 68 ///
	q12j 69 ///
	q12k 70 ///
	q12l 71 ///
	q12m 72 ///
	q12n 73 ///
	q12o 74 ///
	q12p 75 ///
	q13a 76 ///
	q13b 77 ///
	q14a 78 ///
	q14b 79 ///
	q15 80 ///
	2: ///
	card2 1 ///
	deck2 2-4 ///
	ballot2 5-8 ///
	q16 9 ///
	q98 10 ///
	q100 11 ///
	q101a 12-13 ///
	q101b 14-15 ///
	q102 16 ///
	q103a 17 ///
	q103b 18 ///
	q104 19 ///
	q105 20-21 ///
	q107 22-23 ///
	q108 24-25 ///
	n109 26 ///
	n110 27 ///
	n111 28-29 ///
	n112 30 ///
	n113 30-31 ///
	n114 32-33 ///
	wgt 34 ///
	using "$ascii/aipo0749.dat"

gen svy_year = 1967
gen svy_month = "August"
gen svy = "1967-0749"

label define  lb_yesNo 0 "No" 1 "Yes"

local varMissing q1 q14a q14b q98 q101a q101b q102 q103a q104 q107 q108 n110 n113
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNo q102
foreach var in `varYesNo' { 
	replace `var'  = 2-`var'
	label values `var' lb_yesNo
}

rename q1 presApprovala
label variable presApprovala "APPROVAL OF CURRENT PRESIDENT"
label define lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"
label values presApprovala lb_presApproval

rename q14a blkNeighbor
replace blkNeighbor = . if blkNeighbor == 9
label variable blkNeighbor "WOULD MOVE IF COLORED NEIGHBOR"
label define lb_blkNeighbor 1 "Yes, definitely" 2 "Might do" 3 "No" 4 "Don't know"
label values blkNeighbor lb_blkNeighbor

rename q14b blkNeighborhood
replace blkNeighborhood = . if blkNeighborhood == 9
label variable blkNeighborhood "WOULD MOVE IF MANY COLORED PEOPLE IN NEIGHBORHOOD"
label values blkNeighborhood lb_blkNeighbor

rename q98 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

rename q101a adultsHH
label variable adultsHH "NUMBER OF ADULTS LIVING IN THIS HOUSEHOLD"
label define lb_adultsHH 1 "ONE PERSON" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE"
label values adultsHH lb_adultsHH

rename q101b minorsHH
label variable minorsHH "NUMBER OF CHILDREN (MINORS) LIVING IN THIS HOUSEHOLD"
label define lb_minorsHH 1 "ONE CHILD" 2 "TWO" 3 "THREE" 4 "FOUR" 5 "FIVE" 6 "SIX" 7 "SEVEN" 8 "EIGHT" 9 "NINE" 10 "TEN OR MORE" 11 "NO MINOR CHILDREN"
label values minorsHH lb_minorsHH

rename q102 attendChurch
label variable attendChurch "ATTENDED CHURCH OR SYNAGOGUE IN THE LAST 7 DAYS"

rename q103a religionOrtho
label define lb_religionOrtho 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "EASTERN ORTHODOX" 5 "OTHER" 6 "NONE"
label values religion lb_religionOrtho

gen religion = religionOrtho
replace religion = 4 if religionOrtho == 5
replace religion = 5 if religionOrtho == 6
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

rename q104 edu
lab def lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
lab val edu lb_edu

rename q105 occupation
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q107 incomeHH_60s
label define lb_incomeHH_60s 1 "UNDER 1000 DOLLARS A YEAR OR UNDER $20 A WEEK" 2 "1,000 TO 1,499 A YEAR OR $20 TO $28.50 A WEEK" 3 "1,500 TO 1,999 A YEAR OR $29 TO $37.50 A WEEK" 4 "2,000 TO 2,499 A YEAR OR $38 TO $47.50 A WEEK" 5 "2,500 TO 2,999 A YEAR OR $48 TO $57.50 A WEEK" 6 "3,000 TO 3,999 A YEAR OR $58 TO $76.50 A WEEK" 7 "4,000 TO 4,999 A YEAR OR $77 TO $95.50 A WEEK" 8 "5,000 TO 6,999 A YEAR OR $96 TO $134.50 A WEEK" 9 "7,000 TO 9,999 A YEAR OR $135 TO $192.50 A WEEK" 10 "10,000 TO 14,999 A YEAR OR $193 TO $288.50 A WEEK" 11 "15,000 AND OVER A YEAR OR $289 AND MORE A WEEK"
label values incomeHH_60s lb_incomeHH_60s

	gen incomeHHharmonized = .
	replace incomeHHharmonized = 500 if incomeHH_60s == 1
	replace incomeHHharmonized = 1250 if incomeHH_60s == 2
	replace incomeHHharmonized = 1750 if incomeHH_60s == 3
	replace incomeHHharmonized = 2250 if incomeHH_60s == 4
	replace incomeHHharmonized = 2750 if incomeHH_60s == 5
	replace incomeHHharmonized = 3500 if incomeHH_60s == 6
	replace incomeHHharmonized = 4500 if incomeHH_60s == 7
	replace incomeHHharmonized = 6000 if incomeHH_60s == 8
	replace incomeHHharmonized = 8500 if incomeHH_60s == 9
	replace incomeHHharmonized = 12500 if incomeHH_60s == 10
	replace incomeHHharmonized = 15000 if incomeHH_60s == 11

rename q108 age
label variable age "AGE OF THE RESPONDENT"

rename n110 raceSex
label variable raceSex "RACE AND GENDER OF THE RESPONDENT"
label define lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

rename n111 citySize
label variable citySize "CITY SIZE, WHERE RESPONDENT LIVES"
label define lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

rename n113 state
label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/1967-0749.dta", replace 
local svys `svys' 1967-0749


*Gallup Poll # 1978-1106G
clear
infix ///
	wgt 1 ///
	v2 2-4 ///
	q1a 5 ///
	q1b1 6 ///
	q1b2 7 ///
	q1b3 8 ///
	q1b4 9 ///
	q1b5 10 ///
	q1b6 11 ///
	q1b7 12 ///
	q1b8 13 ///
	q1b9 14 ///
	q1b10 15 ///
	q1b11 16 ///
	q1b12 17 ///
	q1b13 18 ///
	q1b14 19 ///
	q1b15 20 ///
	q1b16 21 ///
	q1b17 22 ///
	q1b18 23 ///
	q1b19 24 ///
	q1b20 25 ///
	q1b21 26 ///
	q1b22 27 ///
	q1b23 28 ///
	q1b24 29 ///
	q1b25 30 ///
	q1b26 31 ///
	q1b27 32 ///
	q1b28 33 ///
	q1b29 34 ///
	q1b30 35 ///
	q1b31 36 ///
	q1b32 37 ///
	q1b33 38 ///
	q1b34 39 ///
	q1b35 40 ///
	q1b36 41 ///
	q1b37 42 ///
	q1b38 43 ///
	q1b39 44 ///
	q1b40 45 ///
	q1b41 46 ///
	q1b42 47 ///
	q1b43 48 ///
	q1b44 49 ///
	q1b45 50 ///
	q1b46 51 ///
	q1b47 52 ///
	q1c 53 ///
	q2a 54 ///
	q2b 55 ///
	q2c 56 ///
	q2d 57 ///
	q2e 58 ///
	q2f 59 ///
	q2g 60 ///
	q2h 61 ///
	q2i 62 ///
	q2j 63 ///
	q2k 64 ///
	q2l 65 ///
	q3a 66 ///
	q3b 67 ///
	q4a 68 ///
	q4b 69 ///
	q4c 70 ///
	q4d 71 ///
	q4e 72 ///
	q4f 73 ///
	q5a 74 ///
	q5b1 75 ///
	q5b2 76 ///
	q5b3 77 ///
	q5b4 78 ///
	q5b5 79 ///
	q5b6 80 ///
	q5b7 81 ///
	q5b8 82 ///
	q5C 83 ///
	q6a 84 ///
	q6b 85 ///
	v84 86 ///
	q6c 87 ///
	q6d 88 ///
	v87 89 ///
	q7a 90 ///
	q7b 91 ///
	v90 92 ///
	q7c 93 ///
	q7d 94 ///
	v93 95 ///
	q8a 96 ///
	q8b 97 ///
	q9a 98 ///
	q9b 99 ///
	q9c 100 ///
	v99 101 ///
	q10 102 ///
	q124 103 ///
	q128a 104-105 ///
	q133 106 ///
	q135 107-108 ///
	v105 109 ///
	q137 110 ///
	v107 111 ///
	v108 112 ///
	q138 113-114 ///
	q143a 115 ///
	v111 116-117 ///
	v112 118 ///
	v113 119-120 ///
	using "$ascii/1106.dat"

gen svy_year = 1978
gen svy_month = "July"
gen svy = "1978-1106"

label define lb_yesNo 0 "No" 1 "Yes"
label define lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label define lb_yesNoIA 1 "Yes" 2 "No" 9 "INAPPLICABLE"

local varMissing q4e q4f q8a q9b q9c q124 q133 q135 q143a
foreach v in `varMissing' {
	replace `v' = . if `v' == 0
}

local varYesNo q8a
foreach var in `varYesNo' { 
	replace `var'  = 2-`var'
	label values `var' lb_yesNo
}

local varYesNoNoOp q4b q4c q4d
foreach var in `varYesNoNoOp' {
	label values `var' lb_yesNoNoOp
}

local varYesNoIA q4a
foreach var in `varYesNoIA' {
	label values `var' lb_yesNoIA
}

rename q1a presApprovala
label variable presApprovala "APPROVAL OF CURRENT PRESIDENT"
label define lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"
label values presApprovala lb_presApproval

foreach var in q4a q4b q4c q4d {
	replace `var' = 9 if `var' == 0
}
rename q4a childInSchool
rename q4b fewMixedSchool
rename q4c halfMixedSchool
rename q4d halfPlusMixedSchool
label variable childInSchool "ANY CHILD IN GRADE OR HIGH SCHOOL"
label variable fewMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH A FEW BLACK CHILDREN"
label variable halfMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH HALF BLACK CHILDREN"
label variable halfPlusMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH MORE THAN HALF BLACK CHILDREN"

rename q4e blkNeighbor
label variable blkNeighbor "WOULD MOVE IF COLORED NEIGHBOR"
label define lb_blkNeighbor 1 "Yes, definitely" 2 "Might do" 3 "No" 4 "Don't know"
label values blkNeighbor lb_blkNeighbor

rename q4f blkNeighborhood
label variable blkNeighborhood "WOULD MOVE IF MANY COLORED PEOPLE IN NEIGHBORHOOD"
label values blkNeighborhood lb_blkNeighbor

rename q8a attendChurch
label variable attendChurch "ATTENDED CHURCH OR SYNAGOGUE IN THE LAST 7 DAYS"

gen partyCD = .
label variable partyCD "PREFERRED PARTY FOR CONGRESS"
replace partyCD = 1 if q9b == 2
replace partyCD = 2 if q9b == 1
replace partyCD = 3 if q9b == 3
replace partyCD = 4 if q9b == 4 & q9c == .
replace partyCD = 5 if q9b == 4 & q9c == 2
replace partyCD = 6 if q9b == 4 & q9c == 1
replace partyCD = 7 if q9b == 4 & q9c == 3
replace partyCD = 8 if q9b == 4 & q9c == 4
replace partyCD = 9 if q9b == 4 & q9c == 5
label define lb_partyCD 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, NO ANSWER TO PART B" 5 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 6 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 7 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 8 "UNDECIDED OR REFUSED, UNDECIDED" 9 "UNDECIDED OR REFUSED, REFUSED TO ANSWER"
label values partyCD lb_partyCD

rename q124 poliPartyID
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

gen occupation = .
label variable occupation "BUSINESS OR INDUSTRY THE CHIEF WAGE EARNER WORKS IN"
replace occupation = 1 if q128a == 6
replace occupation = 2 if q128a == 4 | q128a == 5
replace occupation = 3 if q128a == 7
replace occupation = 4 if q128a == 8 | q128a == 9
replace occupation = 5 if q128a == 2
replace occupation = 6 if q128a == 3
replace occupation = 7 if q128a == 10
replace occupation = 8 if q128a == 12
replace occupation = 9 if q128a == 11
replace occupation = 10 if q128a == 1
replace occupation = 11 if q128a == 13 | q128a == 14 | q128a == 15
replace occupation = 13 if q128a == 0
label define lb_occupation 1 "FARMERS" 2 "BUSINESS, EXECUTIVES" 3 "CLERICAL" 4 "SALES WORKERS" 5 "SKILLED WORKERS" 6 "UNSKILLED WORKERS, OPERATIVES" 7 "SERVICE WORKERS" 8 "FARM LABORERS" 9 "LABORERS, EXCEPT FARM AND MINE" 10 "PROFESSIONAL" 11 "NOT IN LABOR FORCE" 12 "UNDESIGNATED" 13 "CAN'T SAY"
label values occupation lb_occupation

rename q133 edu
lab def lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
lab val edu lb_edu

rename q135 age
label variable age "AGE OF THE RESPONDENT"

rename q137 raceSex
label variable raceSex "RACE AND GENDER OF THE RESPONDENT"
label define lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

rename q138 incomeHH_80s
replace incomeHH_80s = . if incomeHH_80s == 12
label define lb_incomeHH_80s 1 "Under $2,000 a year" 2 "$2,000 to $2,999 a year" 3 "$3,000 to $3,999 a year" 4 "$4,000 to $4,999 a year" 5 "$5,000 to $5,999 a year" 6 "$6,000 to $6,999 a year" 7 "$7,000 to $9,999 a year" 8 "$10,000 to $11,999 a year" 9 "$12,000 to $14,999 a year" 10 "$15,000 to $19,999 a year" 11 "$20,000 and more a year"
label values incomeHH_80s lb_incomeHH_80s

	gen incomeHHharmonized = .
	replace incomeHHharmonized = 1000 if incomeHH_80s == 1
	replace incomeHHharmonized = 2500 if incomeHH_80s == 2
	replace incomeHHharmonized = 3500 if incomeHH_80s == 3
	replace incomeHHharmonized = 4500 if incomeHH_80s == 4
	replace incomeHHharmonized = 5500 if incomeHH_80s == 5
	replace incomeHHharmonized = 6500 if incomeHH_80s == 6
	replace incomeHHharmonized = 8500 if incomeHH_80s == 7
	replace incomeHHharmonized = 11000 if incomeHH_80s == 8
	replace incomeHHharmonized = 13500 if incomeHH_80s == 9
	replace incomeHHharmonized = 17500 if incomeHH_80s == 10
	replace incomeHHharmonized = 20000 if incomeHH_80s == 11

rename q143a religionOrtho
label define lb_religionOrtho 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "EASTERN ORTHODOX" 5 "OTHER" 6 "NONE"
label values religion lb_religionOrtho

gen religion = religionOrtho
replace religion = 4 if religionOrtho == 5
replace religion = 5 if religionOrtho == 6
label define lb_religion 1 "PROTESTANT" 2 "ROMAN CATHOLIC" 3 "JEWISH" 4 "OTHER" 5 "NONE"
label values religion lb_religion

rename v111 citySize
label variable citySize "CITY SIZE, WHERE RESPONDENT LIVES"
label define lb_citySize 1 "FARM RESIDENT" 2 "OPEN COUNTRY, NON-FARM" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

rename v113 statefdta
label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew

save "$ascii/1978-1106.dta", replace 
local svys `svys' 1978-1106


*Gallup/Newsweek Poll: Race Relations - 69-1988
use "$ascii/g88069.dta", clear
capture noisily rename Q01 edu
capture noisily rename Q02 age
capture noisily rename qa race
capture noisily gen svy_year = 1988
capture noisily gen svy_month = "February"
capture noisily gen svy = "1988-88069"
save "$ascii/g88069.dta", replace
local svys `svys' g88069


*Gallup/CNN/USA Today Poll # 2003-32: Hillary Clinton/Iraq/Homosexuality in the Church
use "$ascii/2003_05_30x.dta", clear
label define lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"

rename wtfctr wgt

rename Q6A jewPresident
rename Q6B blkPresident
rename Q6C cathPresident
rename Q6D womanPresident
foreach v in jew blk cath woman {
	label values `v'President lb_yesNoNoOp
	replace `v'President = . if `v'President == 4
}

replace race = . if race == 4
label define lb_race 1 "WHITE" 2 "BLACK" 3 "OTHER"
label values race lb_race

rename S3 sex
label define lb_sex 1 "MALE" 2 "FEMALE"
label values sex lb_sex

rename D2 age
label variable age "AGE OF THE RESPONDENT"

rename D3 edu
replace edu = . if edu == 9
lab def lb_edu 1 "NONE, OR GRADES 1-4" 2 "GRADES 5,6,7" 3 "GRADE 8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
lab val edu lb_edu

gen poliPartyID = .
replace poliPartyID = 1 if D7 == 1
replace poliPartyID = 2 if D7 == 2
replace poliPartyID = 3 if D7 == 3
replace poliPartyID = 4 if D7 == 4
lab var poliPartyID "PARTY ID IN POLITICS TODAY"
lab def  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
lab val poliPartyID lb_poliPartyID

label define lb_stateNew 11 "Maine" 12 "New Hampshire" 13 "Vermont" 14 "Massachusetts" 15 "Rhode Island" 16 "Connecticut" 21 "New York" 22 "New Jersey" 23 "Pennsylvania" 24 "Maryland" 25 "Delaware" 26 "West Virginia" 27 "District of Columbia" 31 "Ohio" 32 "Michigan" 33 "Indiana" 34 "Illinois" 41 "Wisconsin" 42 "Minnesota" 43 "Iowa" 44 "Missouri" 45 "North Dakota" 46 "South Dakota" 47 "Nebraska" 48 "Kansas" 51 "Virginia" 52 "North Carolina" 53 "South Carolina" 54 "Georgia" 55 "Florida" 56 "Kentucky" 57 "Tennessee" 58 "Alabama" 59 "Mississippi" 61 "Arkansas" 62 "Louisiana" 63 "Oklahoma" 64 "Texas" 71 "Montana" 72 "Arizona" 73 "Colorado" 74 "Idaho" 75 "Wyoming" 76 "Utah" 77 "Nevada" 78 "New Mexico" 81 "California" 82 "Oregon" 83 "Washington" 84 "Hawaii" 85 "Alaska"
label values state lb_stateNew
rename region region_2003

rename adults adultsHH
gen svy_year = 2003
gen svy_month = "May-June"
gen svy = "2003-32"
save "$ascii/2003_05_30.dta", replace
local svys `svys' 2003_05_30


/* APPENDING ALL SURVEYS */

clear
foreach d in `svys' {
	append using "$ascii/`d'"
}
lab var svy "SURVEY CODE"
lab var svy_year "SURVEY YEAR"
lab var svy_month "SURVEY MONTH(S)"

*President approval
label variable presApprovala "APPROVAL OF CURRENT PRESIDENT"
capture label drop lb_presApproval
label define lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"
label values presApprovala lb_presApproval

*Current name & party of the President
gen nameCurPresident = ""
lab var nameCurPresident "NAME OF THE CURRENT US PRESIDENT"
replace nameCurPresident = "Eisenhower" if svy_year == 1958 | svy_year == 1959 | svy_year == 1960
replace nameCurPresident = "Kennedy" if svy_year == 1961 | svy_year == 1962 | svy_year == 1963
replace nameCurPresident = "Johnson" if svy_year > 1963 & svy_year < 1969
replace nameCurPresident = "Nixon" if svy_year > 1968 & svy_year < 1974
replace nameCurPresident = "Carter" if svy_year > 1976 & svy_year < 1981
replace nameCurPresident = "Reagan" if svy_year > 1980 & svy_year < 1989
replace nameCurPresident = "Bush_H" if svy_year > 1988 & svy_year < 1993
replace nameCurPresident = "Clinton" if svy_year > 1992 & svy_year < 2001
replace nameCurPresident = "Bush" if svy_year > 2000 & svy_year < 2009

gen partyCurPresident = .
lab var partyCurPresident "POLITICAL PARTY OF THE CURRENT US PRESIDENT"
lab def lb_partyCurPresident 1 "REPUBLICAN" 2 "DEMOCRAT"
lab val partyCurPresident lb_partyCurPresident
local namelist Eisenhower Nixon Reagan Bush_H Bush
foreach name in `namelist' {
	replace partyCurPresident =  1 if nameCurPresident == "`name'"
}
local namelist Kennedy Johnson Carter Clinton
foreach name in `namelist' {
	replace partyCurPresident =  2 if nameCurPresident == "`name'"
}

*President race/gender
label variable cathPresident "IF YOUR PARTY NOMINATED A QUALIFIED CATHOLIC FOR PRESIDENT, WOULD YOU VOTE FOR HIM"
label variable baptistPresident "IF YOUR PARTY NOMINATED A QUALIFIED BAPTIST FOR PRESIDENT, WOULD YOU VOTE FOR HIM"
label variable jewPresident "IF YOUR PARTY NOMINATED A QUALIFIED JEW FOR PRESIDENT, WOULD YOU VOTE FOR HIM"
label variable blkPresident "IF YOUR PARTY NOMINATED A QUALIFIED BLACK FOR PRESIDENT, WOULD YOU VOTE FOR HIM"
label variable atheistPresident "IF YOUR PARTY NOMINATED A QUALIFIED ATHEIST FOR PRESIDENT, WOULD YOU VOTE FOR HIM"
label variable womanPresident "IF YOUR PARTY NOMINATED A QUALIFIED WOMAN FOR PRESIDENT, WOULD YOU VOTE FOR HER"

*Religion
label variable religion "RELIGIOUS PREFERENCE"

*Age
label variable age "AGE OF THE RESPONDENT"
replace age = . if age == 0

*Race/Sex
label variable raceSex "RACE AND GENDER OF THE RESPONDENT"
label drop lb_raceSex
label define lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

*City size
label drop lb_citySize
label define lb_citySize 0 "NOT USED (polls post-1983)" 1 "FARM RESIDENT (polls pre-1983)" 2 "OPEN COUNTRY (NON-FARM for polls pre-1983)" 3 "PLACES UNDER 2,500" 4 "2,500 TO 4,999" 5 "5,000 TO 9,999" 6 "10,000 TO 24,999" 7 "25,000 TO 49,999" 8 "50,000 TO 99,999 AND SUB." 9 "100,000 TO 249,999 AND SUB." 10 "250,000 TO 499,999 AND SUB." 11 "500,000 TO 999,999 AND SUB" 12 "1,000,000 AND OVER AND SUB."
label values citySize lb_citySize

*Race
label variable race "RACE OF THE RESPONDENT"
replace race = 1 if race == . & (raceSex == 1 | raceSex == 2)
replace race = 2 if race == . & (raceSex == 3 | raceSex == 4)
replace race = 3 if race == . & (raceSex == 5 | raceSex == 6)

*Sex
label variable sex "GENDER OF THE RESPONDENT"
replace sex  = 1 if sex == . & (raceSex == 1 | raceSex == 3 | raceSex == 5)
replace sex  = 2 if sex == . & (raceSex == 2 | raceSex == 4 | raceSex == 6)

*Education
gen eduHarmonized = .
replace eduHarmonized = 1 if (edu_1958 == 1 | edu_1958 == 2 | edu == 1 | edu == 2 | edu == 3)
replace eduHarmonized = 4 if (edu_1958 == 3 | edu == 4)
replace eduHarmonized = 5 if (edu_1958 == 4 | edu == 5)
replace eduHarmonized = 6 if (edu_1958 == 5 | edu == 6)
replace eduHarmonized = 7 if (edu_1958 == 6 | edu == 7)
replace eduHarmonized = 8 if (edu_1958 == 7 | edu == 8)
label variable eduHarmonized "LAST GRADE OR CLASS COMPLETED IN SCHOOL [HARMONIZED LABELS ACROSS SURVEYS]"
label define lb_eduHarmonized 1 "NONE, OR GRADES 1-8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
label values eduHarmonized lb_eduHarmonized

*Labor union
label variable union "ARE YOU OR YOUR SPOUSE A MEMBER OF A LABOR UNION"

*Income
label variable incomeHHharmonized "TOTAL ANNUAL HH INCOME PRE-TAXES IN 2013 DOLLARS [USING BRACKET MIDPOINTS]"
merge m:1 svy_year using "$input/cpi_1913-2014.dta", keepusing(cpi_annual)
gen temp = cpi_annual if svy_year == 2013 //2013 = reference year
egen cpi_2013 = max(temp)
label variable cpi_2013 "2013 US Consumer Price Index (all items, all urban consumers, 1982-84 = 100)"
drop if _merge == 2
drop _merge temp
replace incomeHHharmonized = incomeHHharmonized*cpi_2013/cpi_annual if incomeHHharmonized != .

*City size
label variable citySize "CITY SIZE, WHERE RESPONDENT LIVES"

*State
label variable state "STATE THE RESPONDENT LIVES IN"

*Region variables
gen region = 0 if !missing(state)
lab var region "REGION THE RESPONDENT LIVES IN"
lab def lb_region 1 "Northeast" 2 "Midwest" 3 "South" 4 "West"
lab val region lb_region
foreach v in 11 12 13 14 15 16 21 22 23 {
	replace region = 1 if state == `v'
}
foreach v in 31 32 33 34 41 42 43 44 45 46 47 48 {
	replace region = 2 if state == `v'
}
foreach v in 24 25 26 27 51 52 53 54 55 56 57 58 59 61 62 63 64 {
	replace region = 3 if state == `v'
}
foreach v in 71 72 73 74 75 76 77 78 81 82 83 84 85 {
	replace region = 4 if state == `v'
}

** HARMONIZE partyCD AND goldwaterKennedy WITH MEREDITH'S CODING (BY TIM TOH) **

recode goldwaterKennedy	(7=4) (5=6) (6=5)
label variable goldwaterKennedy "PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS KENNEDY"
label define lb_goldwaterKennedy 1 "GOLDWATER" 2 "KENNEDY" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD KENNEDY" 0 "NO CODE OR NO DATA", replace
label values goldwaterKennedy lb_goldwaterKennedy

recode partyCD (5=4) (6=5) (7=6) (4=7) (8=7) (9=7)
label variable partyCD "PREFERRED PARTY FOR CONGRESS"
label define lb_partyCD 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER", replace
label values partyCD lb_partyCD

* Order and Drop Variables
order svy svy_year svy_month wgt* card deck ballot age raceSex race sex citySize state region edu_1958 edu eduHarmonized ///
	occupation positionHH relationship adultsHH minorsHH religion attendChurch ///
	incomeHH_1961 incomeHH_60s incomeHH_70s incomeHH_80s incomeHHharmonized cpi_annual ///
	cpi_2013 union poliPartyID partyCD dixiecrats nameCurPresident partyCurPresident presApprovala ///
	cathPresident baptistPresident jewPresident blkPresident atheistPresident womanPresident ///
	regPartyID curPartyID childInSchool fewMixedSchool halfMixedSchool halfPlusMixedSchool ///
	blkNeighbor blkNeighborhood goldwaterKennedy whoRockefeller whoGoldwater whoRomney whoScranton rockefellerKennedy fedIncomeTax

keep svy-fedIncomeTax
drop if svy_year == 1988 //survey not used

saveold "$input/gallup_2.dta", replace
